/*** This is gfx-2.12. ***/
#ifdef GFX_X11
#undef GFX_X11
#define GFX_X11 1
#endif
#ifdef GFX_FB
#undef GFX_FB
#define GFX_FB 1
#endif
#ifdef GFX_ANDROID
#undef GFX_ANDROID
#define GFX_ANDROID 1
#endif

#if (GFX_X11 + GFX_FB + GFX_ANDROID != 1)
#error "exactly one of GFX_X11, GFX_FB or GFX_ANDROID must be defined"
#endif
#ifdef GFX_X11
#include <stdarg.h>
#include <stdint.h>
#include <alloca.h>
#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <ctype.h>
#include <unistd.h>
#include <errno.h>
#include <signal.h>
#include <sys/types.h>
#include <sys/socket.h>
#include <sys/ipc.h>
#include <sys/shm.h>
#include <sys/stat.h>
#include <dirent.h>
#include <X11/Xlib.h>
#include <X11/Xutil.h>
#include <X11/extensions/XShm.h>
#include <X11/Xatom.h>
#include <X11/Xlocale.h>
#include <X11/Xos.h>
#include <X11/Xproto.h>
#define XK_MISCELLANY
#include <X11/keysymdef.h>

#endif
#ifdef GFX_FB
#include <stdarg.h>
#include <stdint.h>
#include <alloca.h>
#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <ctype.h>
#include <termios.h>
#include <unistd.h>
#include <errno.h>
#include <signal.h>
#include <sys/types.h>
#include <sys/socket.h>
#include <dirent.h>
#include <linux/input.h>
#include <linux/fb.h>
#include <sys/mman.h>
#include <sys/stat.h>
#include <fcntl.h>

#endif
#ifdef GFX_ANDROID
#include <jni.h>
#include <stdlib.h>
#include <alloca.h>
#include <stdio.h>
#include <math.h>
#include <stdint.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <dirent.h>
#include <errno.h>
#include <string.h>
#include <unistd.h>
#include <sys/resource.h>
#include <poll.h>
#include <pthread.h>
#include <sched.h>
#include <android/configuration.h>
#include <android/looper.h>
#include <android/native_activity.h>
#include <android/log.h>

#define quad_t int64_t
#define u_quad_t uint64_t

#endif
/** INCLUDE DIRECTIVE BEGIN **/
typedef struct
      {
  int   type;
  int   x, y;
  int   modifiers;
  int   button;
  int   key;
  char *string;
  void *usr;
  int wide;
  double flo0, flo1;
  unsigned long time;
      }
    gfx_event_t;

enum
{
  GFXEV_BUTTON_PRESS=1, GFXEV_BUTTON_RELEASE, GFXEV_DOUBLE_CLICK,
  GFXEV_KEY_PRESS,      GFXEV_KEY_RELEASE,
  GFXEV_POINTER_MOVE,   
  GFXEV_READY_READ, GFXEV_READY_WRITE, GFXEV_READY_EXCEPT,
  GFXEV_QUIT, GFXEV_SAVE_STATE, GFXEV_JAVARESULT, GFXEV_TIMEOUT,
  GFXEV_FOCUS,
  GFXEV_LAST,
};

#define GFXEV(X,Y) (((X)<<8)|(GFXEV_##Y)|(1<<31))

#define GFXRESERVED 24

/* The event routine returns an event from the queue. It waits a maximum
   of 'msecs' milliseconds for the event. If msecs is zero, it waits
   until an event is received.

   The return value is one if an event is returned. It's zero if the
   return was due to timeout.

   In case of an event, *msecs is updated to reflect the remaining
   wait time.  */

int gfx_event(unsigned int *msecs,gfx_event_t *Revent);

enum
{ 
   GFX_K_PRT=1, 
   GFX_K_BACKSPACE,     GFX_K_TAB,      GFX_K_RETURN, GFX_K_ESCAPE,
   GFX_K_INSERT,        GFX_K_DELETE,   GFX_K_HOME,   GFX_K_END,
   GFX_K_PAGEUP,        GFX_K_PAGEDOWN,
   GFX_K_LEFT,          GFX_K_RIGHT,    GFX_K_DOWN,   GFX_K_UP,
   GFX_K_CONTROL=0x100, GFX_K_SHIFT= 0x200 , GFX_K_ALT= 0x400,
};

#define GFX_VK_NOP -1

typedef struct { char *str[3]; int span; int func; }       gfx_vkeydef_t;
typedef struct { gfx_vkeydef_t keys[15][50]; }             gfx_vkbdef_t;

int gfx_init(char *name, int width, int height, char *title);
void gfx_close();


void gfx_geometry(unsigned int *W, unsigned int *H);
void gfx_set_sysbar_height(int hh);
int gfx_get_dpi();
void gfx_pause() ;
void gfx_resume() ;
void gfx_monitor_file(int fd, int ident, int R,int W,int X);
void gfx_stop_monitor_file(int fd,int ident);
void gfx_leave_screen();
void gfx_set_state(int wno, int state);
int  gfx_get_state(int wno);
int  gfx_get_selected(int wno);
void gfx_set_selected(int wno,int sel);
void gfx_set_text(int wno,char *str);
void gfx_set_fgbg(int wno, int fg, int bg);
void gfx_insert(int wno,int pos, char *text,void *user,unsigned int* icon);
void gfx_remove(int wno, int pos, void **Ruser);
char* gfx_get_text(int wno);
void gfx_clear(int wno);
void gfx_focus(int wno);
void gfx_text_data(int font, const char *str, 
                   int *Rw, int *Rh,int *Ra,unsigned char **Rd);
void gfx_scrollbar_set(int wno, double start, double end, double step);
void gfx_pixgrid_attribs(int pg, int *Rshown, unsigned int *Rw, unsigned int *Rh);
int gfx_pixgrid_buffer
  (int pg, int *Rbpl, int *Rbpp, int *Rorder, unsigned char **Rbuffer);
void gfx_pixgrid_update(int pg, int x,int y,int w, int h);
void gfx_pixgrid_put(int pg, int x,int y,
                     unsigned int *img, unsigned int iW,unsigned int iH,
                     int src_x, int src_y, 
                     int copy_w, int copy_h);
void gfx_pixgrid_putsimple(int pg, unsigned int *img);
 
int gfx_ask(char *title, char *butstr, char *fmt, ...);
char* gfx_select_file(int mode,char *init,char **types);
void gfx_canvas_setsize(int wno, int new_w, int new_h);
void gfx_canvas_draw_rectangle(int wno,int color, int x,int y,int w,int h);
void gfx_canvas_fill_rectangle(int wno,int color, int x,int y,int w,int h);
void gfx_canvas_recsel_begin(int wno, gfx_event_t *ev);
void gfx_canvas_recsel_end(int wno,int *Rx1, int *Ry1, int *Rx2, int *Ry2);
void gfx_canvas_print(int wno, int font, int color, int x, int y, char *str);
void gfx_canvas_put_graymap
       (int wno, unsigned int color, int dx,int dy, int w, int h,
        unsigned char *source, int sw, int sh, int sx, int sy);
void gfx_canvas_put
       (int wno, int dx,int dy, int w, int h,
        unsigned int *source, int sw, int sh, int sx, int sy);
int gfx_canvas_get_buffer
   (int wno, unsigned int *W, unsigned int *H, unsigned int **B);
void gfx_canvas_update(int wno, int x, int y, int w, int h);
void gfx_canvas_begin_report_mouse_position(int wno);
void gfx_canvas_end_report_mouse_position(int wno);
void gfx_canvas_set_zoom_params
  (int wno, int zf, int grid, unsigned int gridcolor,int w,int h);
void gfx_canvas_zoom(int wno,int x,int y);
void gfx_canvas_hide_zoom(int wno);
int gfx_sprite_new(int wno,int func, int w,int h, uint32_t *data);
void gfx_sprite_move(int wno,int sp, int x,int y);
void gfx_sprite_show(int wno,int sp,int sho);
void gfx_sprite_remove(int wno, int sp);
void gfx_spinner_set_imin(int wno, int min);
void gfx_spinner_set_imax(int wno, int max);
void gfx_spinner_set_iquant(int wno, int qua);
void gfx_spinner_set_fmin(int wno, double min);
void gfx_spinner_set_fmax(int wno, double max);
void gfx_spinner_set_fquant(int wno, double qua);
void gfx_spinner_set_fvalue(int wno, double value);
void gfx_spinner_set_ivalue(int wno, int value);
int gfx_spinner_get_ivalue(int wno);
double gfx_spinner_get_fvalue(int wno);
void gfx_logview_printf(int wno, const char *fmt, ...);
void gfx_logview_write(int wno, const char *txt, size_t len);
void gfx_logview_clear(int wno);
void gfx_set_log(int wno);
void loprintv(const char *fmt, va_list ap);
void loprintf(const char *fmt, ...);
void gfx_slider_set(int wno, double pos);
double gfx_slider_get(int wno);
void gfx_progressbar_total(int wno, int total);
void gfx_progressbar_set(int wno, int value);
void gfx_iconlist_insert
   (int wno, int pos,
    char *text, 
    unsigned int w, unsigned int h, unsigned int *data,
    int ival, void *pval);
void gfx_iconlist_updates(int wno, int upd);
void gfx_iconlist_area(int wno, int *Rw, int *Rh);
void gfx_iconlist_select(int wno, int item, int sel);
void gfx_iconlist_permute(int wno, int N, int *P);
void gfx_iconlist_clear_selection(int wno);
void gfx_iconlist_get_selection(int wno,int *Rn, int **Rs);
void gfx_filelist_set_directory(int wno,char *dir);
void gfx_filelist_set_types(int wno, char **types);
char** gfx_filelist_get_files(int wno);
char *gfx_filelist_get_directory(int wno);
void gfx_filelist_refresh(int wno);
void gfx_timer_start(int ident, int ms);
void gfx_timer_stop(int ident);
void gfx_virtual_keyboard(int num, gfx_vkbdef_t *D);
void gfx_edit_field(int widget, int kbnum);
void gfx_hide_virtual_keyboard();

#ifdef GFX_ANDROID
#ifdef JNI_H_
JavaVM *gfx_get_javavm();
#endif
#ifdef ANDROID_NATIVE_ACTIVITY_H
ANativeActivity* gfx_get_activity();
#endif
void gfx_save_state(uint32_t len, uint8_t *data);
extern void (*gfx_app_stop)();
#endif

#ifdef GFX_ANDROID
void gfx_soft_keyboard(int show);
#endif
enum { _XX_WIDGETS_START=GFXEV_LAST+GFXRESERVED,
  /* WIDGET NAMES BELOW */
  WresLIST,
  WresDELETE,
  WresCLOSE,
  WresNAME,
  WresADD,
  WresLAB0,
  WresUSE,
  WresTITLE,
  WresMESSAGE,
  WvarLIST,
  WvarUPDATE,
  WvarTYPE,
  WvarVALUE,
  WvarNAME,
  WvarDEL,
  WvarADD,
  WvarLAB2,
  WvarLAB1,
  WvarLAB0,
  WvarCLOSE,
  WvarTITLE,
  WsetCANCEL,
  WsetOK,
  WsetHDRbut,
  WsetSRCbut,
  WsetHEIGHT,
  WsetWIDTH,
  WsetHDR,
  WsetSRC,
  WsetLABEL3,
  WsetLABEL2,
  WsetLABEL1,
  WsetLABEL0,
  WsetTITLE,
  WsselCANCEL,
  WsselUSE,
  WsselNEW,
  WsselDEL,
  WsselLIST,
  WsselTITLE,
  WevOK,
  WevLIST,
  WevTITLE,
  WwselCANCEL,
  WwselTOGGLE,
  WwselTEXTENTRY,
  WwselSCROLLBAR,
  WwselRADIO,
  WwselPIXGRID,
  WwselPANEL,
  WwselLIST,
  WwselLABEL,
  WwselDROPDOWN,
  WwselCHECKBOX,
  WwselCANVAS,
  WwselBUTTON,
  WwselTITLE,
  WwselSPINNER,
  WwselLOGVIEW,
  WwselSLIDER,
  WwselFILELIST,
  WwselPROGRESS,
  WwselICONLIST,
  WwpeMESSAGE,
  WwpeCANCEL,
  WwpeOK,
  WwpeWIDTHvb,
  WwpeRIGHTvb,
  WwpeLEFTvb,
  WwpeHEIGHTvb,
  WwpeBOTTOMvb,
  WwpeTOPvb,
  WwpeWIDTH,
  WwpeRIGHT,
  WwpeLEFT,
  WwpeHEIGHT,
  WwpeBOTTOM,
  WwpeTOP,
  WwpeIDENT,
  WwpeTITLE,
  WwpeLAB6,
  WwpeLAB5,
  WwpeLAB4,
  WwpeLAB3,
  WwpeLAB2,
  WwpeLAB1,
  WwpeLAB0,
  WfilSET,
  Wcan,
  Wsta,
  Wres,
  WlayVAR,
  WlayAPP,
  WlayEVA,
  Wlab3,
  WwidPOS,
  WwidEDI,
  WwidDEL,
  WwidNEW,
  Wlab2,
  WfilGEN,
  WfilLOD,
  WfilSAV,
  Wlab1,
  WscrEDI,
  WscrLIS,
  Wlab0,
  WlayALGN,
  Wopbtn,
  Wcut,
  Wpaste,
  Wfont,
  WconOK,
  WconCANCEL,
  EWlabTITLE,
  EWlabLAB0,
  EWlabLAB1,
  EWlabLAB2,
  EWlabLAB3,
  EWlabLAB4,
  EWlabOK,
  EWlabCANCEL,
  EWlabTEXT,
  EWlabFG,
  EWlabBG,
  EWlabFONT,
  EWlabJUST,
  EWpanTITLE,
  EWpanLIST,
  EWpanNEW,
  EWpanDEL,
  EWpanOK,
  EWbuttonTITLE,
  EWbuttonLAB0,
  EWbuttonTEXT,
  EWbuttonLAB1,
  EWbuttonICONPOS,
  EWbuttonLAB2,
  EWbuttonICONCHOOSE,
  EWbuttonOK,
  EWbuttonCANCEL,
  EWbuttonICON,
  EWsimpleTITLE,
  EWsimpleLAB0,
  EWsimpleTEXT,
  EWsimpleOK,
  EWsimpleCANCEL,
  EWscbTITLE,
  EWscbOK,
  EWscbCANCEL,
  EWscbLAB0,
  EWscbVERTICAL,
  EWradioTITLE,
  EWradioLAB0,
  EWradioLAB1,
  EWradioTEXT,
  EWradioGROUP,
  EWradioOK,
  EWradioCANCEL,
  WalnTITLE,
  WalnLAB0,
  WalnLAB1,
  WalnLAB2,
  WalnOK,
  WalnCANCEL,
  WalnAleft,
  WalnAright,
  WalnAtop,
  WalnAbottom,
  WalnAnone,
  WalnStop,
  WalnSbottom,
  WalnSnone,
  WalnSleft,
  WalnSright,
  WalnLAB3,
  WalnPAD,
  WalnEwidth,
  WalnEheight,
  EWsliderTITLE,
  EWsliderOK,
  EWsliderCANCEL,
  EWsliderLAB0,
  EWsliderORIENT,
  EWcanHORSCROLL,
  EWcanVERSCROLL,
  EWcanOK,
  EWcanCANCEL,
  EWcanTITLE,
  EWprogTITLE,
  EWprogLAB0,
  EWprogLAB1,
  EWprogLAB2,
  EWprogLAB3,
  EWprogFONT,
  EWprogFG,
  EWprogBG,
  EWprogFILL,
  EWprogOK,
  EWprogCANCEL,
  EWiconlistTITLE,
  WewICONLISTlab0,
  WewICONLISTlab1,
  WewICONLISTlab2,
  WewICONLISTlab3,
  WewICONLISTlab4,
  WewICONLISTfg,
  WewICONLISTbg,
  WewICONLISThpad,
  WewICONLISTvpad,
  WewICONLISTmaxtextw,
  WewICONLISTok,
  WewICONLISTcancel,
  WewICONLISTlab5,
  WewICONLISTmulti,
  WfntLAB0,
  WfntDEFFONT,
  WfntCUSTOMFONT,
  WfntLAB1,
  WfntFILES,
  WfntFILEadd,
  WfntFILEremove,
  WfntLAB5,
  WfntFONTS,
  WfntLAB6,
  WfntSIZE,
  WfntLAB7,
  WfntFILEID,
  WfntLAB8,
  WfntFONTNUM,
  WfntFONTADD,
  WfntFONTmodify,
  WfntFONTremove,
  WfntSAVE,
  WfntCANCEL,

 _XX_WIDGETS_END };
void gfx_SCRres();
void gfx_SCRvar();
void gfx_SCRset();
void gfx_SCRselscr();
void gfx_SCReval();
void gfx_SCRwidsel();
void gfx_SCRwidpos();
void gfx_SCREEN_0();
void gfx_SCRewLABEL();
void gfx_SCRewPANEL();
void gfx_SCRewBUTTON();
void gfx_SCRewSIMPLE();
void gfx_SCRewSCROLL();
void gfx_SCRewRADIO();
void gfx_SCRalign();
void gfx_SCRewSLIDER();
void gfx_SCRewCANVAS();
void gfx_SCRewPROGRESS();
void gfx_SCRewICONLIST();
void gfx_SCRfonts();
#define _MPRINTF_PROTO static
#ifndef _mprintf_h_included
#define _mprintf_h_included

#ifndef _MPRINTF_PROTO 
#define _MPRINTF_PROTO 
#endif

_MPRINTF_PROTO size_t
vgprintf    (void (*func)(void *,const char *, size_t), void *arg,
             char const *fmt, va_list ap);

_MPRINTF_PROTO size_t fdprintf(int fd, const char *fmt, ...);

_MPRINTF_PROTO char* mprintf(const char *fmt, ...);
_MPRINTF_PROTO char *vmprintf(const char *fmt, va_list ap);

#endif
/*-
 * Copyright (c) 1986, 1988, 1991, 1993
 *	The Regents of the University of California.  All rights reserved.
 * (c) UNIX System Laboratories, Inc.
 * All or some portions of this file are derived from material licensed
 * to the University of California by American Telephone and Telegraph
 * Co. or Unix System Laboratories, Inc. and are reproduced herein with
 * the permission of UNIX System Laboratories, Inc.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)subr_prf.c	8.3 (Berkeley) 1/21/94
 */
#define __USE_BSD 1
#include <sys/types.h>
#include <stddef.h>
#include <stdlib.h>
#include <string.h>
#include <stdint.h>
#include <stdarg.h>
#include <ctype.h>
#include <errno.h>
#include <unistd.h>

#define NBBY    8               /* number of bits in a byte */
static char const hex2ascii_data[] = "0123456789abcdefghijklmnopqrstuvwxyz";
#define hex2ascii(hex)  (hex2ascii_data[hex])

/* Max number conversion buffer length: a u_quad_t in base 2, plus NUL byte. */
#define MAXNBUF	(sizeof(intmax_t) * NBBY + 1)

/*
 * Put a NUL-terminated ASCII number (base <= 36) in a buffer in reverse
 * order; return an optional length and a pointer to the last character
 * written in the buffer (i.e., the first character of the string).
 * The buffer pointed to by `nbuf' must have length >= MAXNBUF.
 */
static char *
ksprintn(char *nbuf, uintmax_t num, int base, int *lenp, int upper)
{
	char *p, c;

	p = nbuf;
	*p = '\0';
	do {
		c = hex2ascii(num % base);
		*++p = upper ? toupper(c) : c;
	} while (num /= base);
	if (lenp)
		*lenp = p - nbuf;
	return (p);
}

/*
 * Scaled down version of printf(3).
 *
 * Two additional formats:
 *
 * The format %b is supported to decode error registers.
 * Its usage is:
 *
 *	printf("reg=%b\n", regval, "*");
 *
 * where  is the output base expressed as a control character, e.g.
 * \10 gives octal; \20 gives hex.  Each arg is a sequence of characters,
 * the first of which gives the bit number to be inspected (origin 1), and
 * the next characters (up to a control character, i.e. a character <= 32),
 * give the name of the register.  Thus:
 *
 *	kvprintf("reg=%b\n", 3, "\10\2BITTWO\1BITONE\n");
 *
 * would produce output:
 *
 *	reg=3
 *
 * XXX:  %D  -- Hexdump, takes pointer and separator string:
 *		("%6D", ptr, ":")   -> XX:XX:XX:XX:XX:XX
 *		("%*D", len, ptr, " " -> XX XX XX XX ...
 */
_MPRINTF_PROTO size_t
vgprintf(void (*func)(void *,const char *, size_t), void *arg,
         char const *fmt, va_list ap)
{
#define PCHAR(c) do {char cc=(c); (*func)(arg,&cc,1); retval++;} while(0)
	char nbuf[MAXNBUF];
	const char *p, *percent, *q;
	u_char *up;
	int ch, n;
	uintmax_t num;
	int base, lflag, qflag, tmp, width, ladjust, sharpflag, neg, sign, dot;
	int cflag, hflag, jflag, tflag, zflag;
	int dwidth, upper;
	char padc;
	int stop = 0, retval = 0;
        int radix= 10;

	num = 0;

	if (fmt == NULL)
		fmt = "(fmt null)\n";

	if (radix < 2 || radix > 36)
		radix = 10;

	for (;;) {
		padc = ' ';
		width = 0;
		while ((ch = (u_char)*fmt++) != '%' || stop) {
			if (ch == '\0')
				return (retval);
			PCHAR(ch);
		}
		percent = fmt - 1;
		qflag = 0; lflag = 0; ladjust = 0; sharpflag = 0; neg = 0;
		sign = 0; dot = 0; dwidth = 0; upper = 0;
		cflag = 0; hflag = 0; jflag = 0; tflag = 0; zflag = 0;
reswitch:	switch (ch = (u_char)*fmt++) {
		case '.':
			dot = 1;
			goto reswitch;
		case '#':
			sharpflag = 1;
			goto reswitch;
		case '+':
			sign = 1;
			goto reswitch;
		case '-':
			ladjust = 1;
			goto reswitch;
		case '%':
			PCHAR(ch);
			break;
		case '*':
			if (!dot) {
				width = va_arg(ap, int);
				if (width < 0) {
					ladjust = !ladjust;
					width = -width;
				}
			} else {
				dwidth = va_arg(ap, int);
			}
			goto reswitch;
		case '0':
			if (!dot) {
				padc = '0';
				goto reswitch;
			}
		case '1': case '2': case '3': case '4':
		case '5': case '6': case '7': case '8': case '9':
				for (n = 0;; ++fmt) {
					n = n * 10 + ch - '0';
					ch = *fmt;
					if (ch < '0' || ch > '9')
						break;
				}
			if (dot)
				dwidth = n;
			else
				width = n;
			goto reswitch;
		case 'b':
			num = (u_int)va_arg(ap, int);
			p = va_arg(ap, char *);
			for (q = ksprintn(nbuf, num, *p++, NULL, 0); *q;)
				PCHAR(*q--);

			if (num == 0)
				break;

			for (tmp = 0; *p;) {
				n = *p++;
				if (num & (1 << (n - 1))) {
					PCHAR(tmp ? ',' : '<');
					for (; (n = *p) > ' '; ++p)
						PCHAR(n);
					tmp = 1;
				} else
					for (; *p > ' '; ++p)
						continue;
			}
			if (tmp)
				PCHAR('>');
			break;
		case 'c':
			PCHAR(va_arg(ap, int));
			break;
		case 'D':
			up = va_arg(ap, u_char *);
			p = va_arg(ap, char *);
			if (!width)
				width = 16;
			while(width--) {
				PCHAR(hex2ascii(*up >> 4));
				PCHAR(hex2ascii(*up & 0x0f));
				up++;
				if (width)
					for (q=p;*q;q++)
						PCHAR(*q);
			}
			break;
		case 'd':
		case 'i':
			base = 10;
			sign = 1;
			goto handle_sign;
		case 'h':
			if (hflag) {
				hflag = 0;
				cflag = 1;
			} else
				hflag = 1;
			goto reswitch;
		case 'j':
			jflag = 1;
			goto reswitch;
		case 'l':
			if (lflag) {
				lflag = 0;
				qflag = 1;
			} else
				lflag = 1;
			goto reswitch;
		case 'n':
			if (jflag)
				*(va_arg(ap, intmax_t *)) = retval;
			else if (qflag)
				*(va_arg(ap, quad_t *)) = retval;
			else if (lflag)
				*(va_arg(ap, long *)) = retval;
			else if (zflag)
				*(va_arg(ap, size_t *)) = retval;
			else if (hflag)
				*(va_arg(ap, short *)) = retval;
			else if (cflag)
				*(va_arg(ap, char *)) = retval;
			else
				*(va_arg(ap, int *)) = retval;
			break;
		case 'o':
			base = 8;
			goto handle_nosign;
		case 'p':
			base = 16;
			sharpflag = (width == 0);
			sign = 0;
			num = (uintptr_t)va_arg(ap, void *);
			goto number;
		case 'q':
			qflag = 1;
			goto reswitch;
		case 'r':
			base = radix;
			if (sign)
				goto handle_sign;
			goto handle_nosign;
		case 's':
			p = va_arg(ap, char *);
			if (p == NULL)
				p = "(null)";
			if (!dot)
				n = strlen (p);
			else
				for (n = 0; n < dwidth && p[n]; n++)
					continue;

			width -= n;

			if (!ladjust && width > 0)
				while (width--)
					PCHAR(padc);
			while (n--)
				PCHAR(*p++);
			if (ladjust && width > 0)
				while (width--)
					PCHAR(padc);
			break;
		case 't':
			tflag = 1;
			goto reswitch;
		case 'u':
			base = 10;
			goto handle_nosign;
		case 'X':
			upper = 1;
		case 'x':
			base = 16;
			goto handle_nosign;
		case 'y':
			base = 16;
			sign = 1;
			goto handle_sign;
		case 'z':
			zflag = 1;
			goto reswitch;
handle_nosign:
			sign = 0;
			if (jflag)
				num = va_arg(ap, uintmax_t);
			else if (qflag)
				num = va_arg(ap, u_quad_t);
			else if (tflag)
				num = va_arg(ap, ptrdiff_t);
			else if (lflag)
				num = va_arg(ap, u_long);
			else if (zflag)
				num = va_arg(ap, size_t);
			else if (hflag)
				num = (u_short)va_arg(ap, int);
			else if (cflag)
				num = (u_char)va_arg(ap, int);
			else
				num = va_arg(ap, u_int);
			goto number;
handle_sign:
			if (jflag)
				num = va_arg(ap, intmax_t);
			else if (qflag)
				num = va_arg(ap, quad_t);
			else if (tflag)
				num = va_arg(ap, ptrdiff_t);
			else if (lflag)
				num = va_arg(ap, long);
			else if (zflag)
				num = va_arg(ap, ssize_t);
			else if (hflag)
				num = (short)va_arg(ap, int);
			else if (cflag)
				num = (char)va_arg(ap, int);
			else
				num = va_arg(ap, int);
number:
			if (sign && (intmax_t)num < 0) {
				neg = 1;
				num = -(intmax_t)num;
			}
			p = ksprintn(nbuf, num, base, &tmp, upper);
			if (sharpflag && num != 0) {
				if (base == 8)
					tmp++;
				else if (base == 16)
					tmp += 2;
			}
			if (neg)
				tmp++;

			if (!ladjust && padc != '0' && width
			    && (width -= tmp) > 0)
				while (width--)
					PCHAR(padc);
			if (neg)
				PCHAR('-');
			if (sharpflag && num != 0) {
				if (base == 8) {
					PCHAR('0');
				} else if (base == 16) {
					PCHAR('0');
					PCHAR('x');
				}
			}
			if (!ladjust && width && (width -= tmp) > 0)
				while (width--)
					PCHAR(padc);

			while (*p)
				PCHAR(*p--);

			if (ladjust && width && (width -= tmp) > 0)
				while (width--)
					PCHAR(padc);

			break;
		default:
			while (percent < fmt)
				PCHAR(*percent++);
			/*
			 * Since we ignore an formatting argument it is no
			 * longer safe to obey the remaining formatting
			 * arguments as the arguments will no longer match
			 * the format specs.
			 */
			stop = 1;
			break;
		}
	}
#undef PCHAR
}

static void write_buf
     (char **x,const char *b,size_t len)
{
    memcpy(*x,b,len);
    *x += len;
}

static void ignore
     (void *arg, const char *b, size_t len)
{
}

_MPRINTF_PROTO char *vmprintf(const char *fmt, va_list ap)
{
    va_list ap2;
    size_t size;
    char *ret,*x;
    int eno;

    eno= errno;

    va_copy(ap2,ap);
    size= vgprintf((void*) ignore, NULL, fmt, ap2);
    va_end(ap2);

    x= ret= malloc(size+1);
    if (ret)
    {
        errno= eno;
        vgprintf((void*) write_buf, (void*) &x,fmt, ap);
    }
    ret[size]= 0;
    return ret;
}

_MPRINTF_PROTO char *mprintf(const char *fmt, ...)
{
    va_list ap;
    char *ret;
    va_start(ap,fmt);
    ret= vmprintf(fmt, ap);
    va_end(ap);
    return ret;
}

static void write_fd(void *arg, const char *buf, size_t len)
{
  write(*(int*)arg, buf,len);
}

_MPRINTF_PROTO size_t fdprintf
      (int fd, const char *fmt, ...)
{
    va_list ap;
    size_t ret;
    va_start(ap,fmt);
    ret= vgprintf(write_fd, &fd, fmt, ap);
    va_end(ap);
    return ret;
}

#ifdef GFX_ANDROID

#define LOGI(...) \
  ((void)__android_log_print(ANDROID_LOG_INFO, "threaded_app", __VA_ARGS__))
#define LOGE(...) \
  ((void)__android_log_print(ANDROID_LOG_ERROR, "threaded_app", __VA_ARGS__))

#ifndef NDEBUG
#  define LOGV(...) \
  ((void)__android_log_print(ANDROID_LOG_VERBOSE, "threaded_app", __VA_ARGS__))
#else
#  define LOGV(...)  ((void)0)
#endif


#define  PIPE_CMD    1
#define  PIPE_EVENT  2
#define  PIPE_SENSOR 3

  
enum
{
  CMD_APP_START,
  CMD_APP_STOP,
  CMD_APP_RESUME,
  CMD_APP_PAUSE,
  CMD_WINDOW_DESTROYED,
  CMD_WINDOW_CREATED,
  CMD_WINDOW_RESIZED,
  CMD_WINDOW_REDRAW,
  CMD_WINDOW_CONTENTRECT,
  CMD_SAVE_STATE,
  CMD_FOCUS_CHANGE,
  CMD_LOW_MEMORY,
  CMD_CONFIG_CHANGE,
  CMD_INPUTQ_DESTROYED,
  CMD_INPUTQ_CREATED,
  CMD_JAVARESULT,
  CMD_QUIT
};


#define x_red_mask    0x0000ff
#define x_green_mask  0x00ff00
#define x_blue_mask   0xff0000
#define x_red_shift   0
#define x_green_shift 8
#define x_blue_shift  16

#endif

#define GFX_UPDATE (1<<0)
#define GFX_ALPHA  (1<<1)
#define GFX_ORDER  (1<<0)    // order returned coordinates
#define GFX_BACKGND (1<<2)   // use background color instead of pixel buffer
#define GFX_FOCUS (1<<6)
#define GFX_HORIZONTAL (1<<7)
#define GFX_VERTICAL   (1<<8)
#define GFX_NOICON     (1<<9)
#define GFX_MULTISELECT (1<<3)

#define RES_COLOR(x,y,z) static uint32_t x= y
#define RES_INT RES_COLOR
#define RES_GRAYIMG(x,y) static const unsigned char x[]= {
#define RES_END };
#define RES_COLORIMG(x,y) unsigned int x[]= {
#define RES_STRING(x,y,z) static const char *x= y

/***********************************************************************
 *                                                                     *
 *                                TYPES                                *
 *                                                                     *
 ***********************************************************************/
#ifdef GFX_X11
/***********************************************************************
  Images can be shared on non-shared. They are represented by the
  following struct.
 ***********************************************************************/
typedef struct 
{
  uint32_t *data;
  unsigned int width,height, bpl;
  int shared;
  XShmSegmentInfo shminfo;
  XImage *x11image;
} ximage_t;


typedef struct xkeyb
{
  int method;
  Window window;
  XIC ic;
  char *buf;
  size_t sbuf;
  uint32_t *wbuf;
  size_t swbuf;
} x_keyboard_t;


#endif
#ifdef GFX_FB

typedef struct {
  int type;     // one of 'M'odifier 'C'ontrol 'P'rintable. 0 if unknown
  char *lo,*hi; // with and without shift
  int value;    // modifier value or control key value
  char ss[4];
} kbmap_t;

#endif
#ifdef GFX_ANDROID
typedef struct req request_t;
typedef struct app app_t;

/***********************************************************************
 *##B                                                                  *
 *                         Application Object                          *
 *                                                                     *
 ***********************************************************************
  The application object is called an 'instance' in the android documents.
  It contains the necessary data to properly handle and serialize events.
  Window handle etc. are also contained in this object.
 ***********************************************************************/

struct app {
      // command pipe. This is used for reporting system events such
      // as Pause, Resume, etc.
  int cmdpipe_r, cmdpipe_w;

      // The worker thread is actually the 'main' thread for our
      // application. It initializes the input system and then calls
      // android_main. When that function is done, it rips up the
      // input/output objects and quits.
  pthread_t worker_thread;

      // These two are used for signalling various conditions. 
  pthread_mutex_t mutex;
  pthread_cond_t cond;

      // This is one of the conditions. When this is set to 1, 
      // the thread which fired off the worker thread can continue
      // in its Java world.
  int running;

  void *init_state; size_t init_state_size;

  ANativeActivity *activity;
  ALooper *looper;
  AConfiguration *config;
  AInputQueue *inputq;
  ANativeWindow *window;

  request_t *quit_request;
  request_t *save_request;
  request_t *stop_request;
  int last_pointer_id;
};


struct req {
  int type;
  int complete;
  union {
    ANativeWindow *window;
    AInputQueue   *inputq;
    struct {
       void* ptr;
       size_t size;
    }             buffer; 
    int           intv;
  } d;
};

#endif

typedef struct { int w,h,stride; uint8_t *data; } graypix_t;
typedef struct { int w,h,stride; uint32_t *data; } colorpix_t;

#define PIX(A,x,y)  (A).data[ (x) + (y)*(A).stride]


typedef struct { int left,right,top,bottom; } rect_t;


typedef struct
{
  int w, h;
  int x,y; // these are relative to the canvas buffer origin
  int func; 
  int shown;
#define SPRITE_FUNC_SET  0
#define SPRITE_FUNC_XOR  1
#define SPRITE_FUNC_AND  2
#define SPRITE_FUNC_NEG  3
  uint32_t *data;
} sprite_t;


typedef struct
{
  int ident;
  unsigned int value;
  int (*func)(void *,gfx_event_t *);
  void *arg;
} gui_timer_t;


typedef struct
{
  int fd;
  int ident;
  int events; // 1=read 2=write 4=except
} file_monitor_t;


#define __PATH_PROTO static

typedef struct { int x,y,w,h; } rrect_t;

#define WOMAP_PROTO static

typedef struct { void *root; } womap_t;


typedef struct
{
  union { struct { void* child[2];           } inte;  
          struct { void *data; uint32_t key; } leaf; } d;
  unsigned internal:1, bit:5;
} womap_node_t;

 // careful, qumap also uses the same things
#ifndef Q_KEY
#define Q_KEY(X)    ((X)->d.leaf.key)
#define Q_DATA(X)   ((X)->d.leaf.data)
#define Q_CHLD(X,Y) ((X)->d.inte.child[Y])
#endif



typedef int (*event_function_t)(void *,gfx_event_t*);

typedef struct widget
{
  int x,y,w,h;
  int klass;
  int number;   // this is for accessing the array from the pointer

  char can_focus, has_focus;
  void (*focus)(void *,int);
  int  (*handle_key)(void *,gfx_event_t *);

  int shown;
  void (*show)(struct widget *);
  void (*hide)(struct widget *);
  void (*position)(struct widget *,int ,int ,int ,int ); // x y w h
  void (*destroy)(struct widget *);
} widget_t;

typedef struct
{
  int ident;
  int n_widgets,s_widgets;
  widget_t **widgets;
} radio_group_t;


enum {
  GFXCLASS_BUTTON,
  GFXCLASS_TOGGLE,

 GFXCLASS_LABEL,

  GFXCLASS_RADIO,
  GFXCLASS_CHECKBOX,

  GFXCLASS_SCROLLBAR,

 GFXCLASS_PANEL,

  GFXCLASS_DROPDOWN,

 GFXCLASS_LIST,

  GFXCLASS_TEXTENTRY,

  GFXCLASS_PIXGRID,

  GFXCLASS_CANVAS,

GFXCLASS_SPINNER,

  GFXCLASS_LOGVIEW,

  GFXCLASS_SLIDER,

 GFXCLASS_PROGRESSBAR,

  GFXCLASS_ICONLIST,

GFXCLASS_FILELIST,

};


typedef struct
{
  int  x,y,w,h;
  int  (*func)(void *,gfx_event_t*);
  void *arg;
  int  *enabled;
  int button;
} click_handler_t;

typedef struct screen
{
  int n_widgets;
  int *widgets;

  int n_click_handlers, s_click_handlers;
  click_handler_t *click_handlers;
  click_handler_t release_handler;
  click_handler_t motion_handler;
  click_handler_t grabber;

  widget_t *focus_widget;
  widget_t *focus_clicked;

  struct screen *up, *down;
  uint32_t *backstore;
  uint32_t back_w, back_h;

  int x,y,w,h; 

  int n_rgroups, s_rgroups;
  radio_group_t *rgroups;

  int n_timers,s_timers;
  gui_timer_t *timers;

  int visible_parts_time;
  int n_visible_parts;
  rect_t *visible_parts;
} screen_t;


typedef struct
{
  int head, tail,size;
  rect_t *data;
} rectque_t;

static rectque_t *rectque_new()
{
  rectque_t *Q;
  Q= malloc(sizeof(*Q));
  Q->size= 20;
  Q->data= malloc(Q->size*sizeof(Q->data[0]));
  Q->head= Q->tail= 0;
  return Q;
}

static void* rectque_free(rectque_t *Q)
{
  free(Q->data);
  free(Q);
  return NULL;
}

static int rectque_len(rectque_t *Q)
{
  if (Q->head==Q->tail) return 0;
  if (Q->tail>Q->head) return Q->tail-Q->head;
  return Q->size-Q->head + Q->tail;
}

static void rectque_get(rectque_t *Q, rect_t *A)
{
  *A= Q->data[Q->head];
  Q->head= (Q->head+1)%Q->size;
}

static void rectque_put(rectque_t *Q, rect_t *A)
{
  if (rectque_len(Q)==Q->size-1)
  {
    rect_t *nd;
    int ns,i;
    ns= (Q->size+Q->size/2);
    nd= malloc(sizeof(nd[0])*ns);
    for(i=0;Q->head!=Q->tail;i++) rectque_get(Q, nd+i);
    nd[i++]= *A;
    Q->head= 0; Q->tail= i;
    free(Q->data);
    Q->data= nd;
    Q->size= ns;
  }
  else
  {
    Q->data[Q->tail]= *A;
    Q->tail= (Q->tail+1)%Q->size;
  }
}

static void rectque_putn(rectque_t *Q, rect_t *A, int N)
{
  int i;
  // I'm too lazy to do properly right now
  for(i=0;i<N;i++) rectque_put(Q,A+i);
}

static void rectque_get_data(rectque_t *Q, rect_t **D, int *N)
{
  rect_t *K;
  int i,j;
  if (Q->head==Q->tail) { *D= NULL; *N= 0; return  ; }
  K= malloc(sizeof(K[0])*rectque_len(Q));
  for(i=0,j=Q->head;j!=Q->tail;i=i+1,j=(j+1)%Q->size)
     K[i]= Q->data[j];
  *D= K;
  *N= i;
}


typedef struct
{
  widget_t widget;
  char *text;
  uint32_t *icon;
  int iconpos; // 'T' 'B' 'L' 'R'
  int state;  //0 = normal, 1= depressed 
  int enabled; 
  int click_handler;

  int (*click_func)(void *,gfx_event_t *);
  int (*release_func)(void *,gfx_event_t *);
  void *click_arg;
} gui_button_t;

typedef struct 
{
  widget_t widget;
  int font, fg, bg;
  int just;
  char *text;
} gui_label_t;


typedef struct radio
{
  widget_t widget;
  int state; 
  int enabled;
  int click;
  int change;  
  int group;
  char *text;
} radio_t;


typedef struct checkbox
{
  widget_t widget;
  int state; 
  int enabled;
  int click;
  char *text;
  void *evarg; 
  event_function_t clickf;
} checkbox_t;


typedef struct
{
  widget_t widget;
  double start, end;          // start/end points for the sliding button
  double step;                // step amount for up/down left/right buttons
  int tro_c0, tro_c1, tro_dc; // start/end points for trough. can be X or 
                              // Y coordinates dc is the difference between
                              // them, but normalized to prevent divide by zero
  int but_c0, but_c1;         // start/end points for button

  int tro_x, tro_y, tro_w, tro_h; // used for updates
  int last_seen_c;

  int enabled;                // for enabling/disabling clicks

  int orient;

  int action;                 // action is used for reporting changes to user.
  void *reportarg;            // the following two are used for reporting
                              // to other widgets.
  void (*reportfunc)(void *, double, double);
  
  // stepper button position
  int SX[2], SY[2];
  // stepper button images, 0 = Up-normal 1= Up-pressed 2-Down-normal ..
  uint32_t *SD[4], SW[4], SH[4];

    // click handler entries
    // 0= up button 
    // 1= down button
    // 2= trough
  int ch0, ch1, ch2;
} scrollbar_t;


typedef struct
{
  int n_widgets;
  int *widgets;
} subscreen_t;

typedef struct
{
  widget_t widget;
  int enabled;
  int active;
  int n_subs;
  subscreen_t *subs;
} panel_t;


typedef struct { void* ptr; char *str; } TUPsp_t;

typedef struct
{
  widget_t widget;
  int shown;
  int n_items, s_items;
  TUPsp_t *items;
  int selected;

  int click_handler;
  int click_enabled;

  int list_active;

  // list stuff
  int list_x,list_y,list_w,list_h;
  int list_px, list_py, list_pw, list_ph; // port coords
  unsigned int *list_backup;
  int fh;
  scrollbar_t *scroll;
  int posy;
  int list_cont_h;  // content height

  int but1clicked;
  int selitem;

  void *evarg; event_function_t clickf;
} dropdown_t;


typedef struct
{
  char *str;
  const unsigned int *icon_data;
  unsigned int icon_width, icon_height;
  int selected;
  void *user;

  int y;
  int w,h;
  int icon_y,icon_x,text_y,text_x;
  int text_w, text_h;
} list_item_t;


typedef struct
{
  widget_t widget;
  int n_items, s_items;
  list_item_t *items;

  int posx, posy; // scrolled position

  int has_scrollv, has_scrollh;
  scrollbar_t *scrollv, *scrollh;

  int content_w, content_h;
  int port_w, port_h;
  int port_x, port_y;

  int max_icon_width;
  int uses_icons;
  int multiselect;

  int enabled;
  int ch0;    // ID of the click handler, we use this
              // to modify the click area when the
              // scrollbars appear/disappear
  int ch1,ch2; // mouse buttons 4 and 5

    // for double click
  unsigned long click_time;
  int click_index;
 
  int x,y,w,h;

  void *evarg;
  event_function_t clickf,dlickf;
} gui_list_t;


typedef struct { uint32_t chr; uint8_t  *d; uint32_t w; int x; } glyph_t;

typedef struct 
 { widget_t widget;
   int x,y,w,h; glyph_t *glyphs; int size, len;
   int fonth;
   uint32_t left; int cursor; 
   int (*key_filter)(void *,void *,gfx_event_t *);
   void *key_arg;
   } text_entry_t;


typedef struct
{
  widget_t widget;
  int enabled; 
  int click_handler;
} gui_pixgrid_t;


#define _BUFFER_PROTO static

typedef struct buffer buffer_t;
#ifndef _BUFFER_PROTO
#define _BUFFER_PROTO 
#endif


struct buffer_node { 
  struct buffer_node *next;
  size_t len,size,start;
  unsigned char data[1];
};

struct buffer {
  struct buffer_node *first, *last;
  size_t blksize;
};




typedef struct
{
  char *label;
  char *dir;
  int width;
} fsent_t;

typedef struct
{
  int n_dirs;
  fsent_t *dirs;
  int dir_start, dir_end;

  int nfiles, shown;
  char **files;

  char **types;
  char **ext;

  char *dir;
  int x,y,w,h;
  int button_h;
  int dirst_y;
} filesel_t;



typedef struct
{
  widget_t widget;
  int buffer_w, buffer_h;
  uint32_t *buffer;
  int enabled;

  int pos_x, pos_y,port_w,port_h;
  int have_scrollh, have_scrollv;
  int can_scrollh, can_scrollv;
  scrollbar_t *scrollh, *scrollv;
  int too_small; // the display is too small for the
                 // scrollbars to fit.

  int click1, click3;

  int recsel;
  int rs_x0, rs_y0, rs_x1, rs_y1;

  int have_zoom, z_factor;
     // zoom window coordinates
  int z_wx, z_wy, z_ww, z_wh;
  unsigned int *z_buffer;
  int z_grid, z_gridcolor; 
     // the point to be zoomed around
  int z_cx, z_cy;

  int nsprites, ssprites;
  sprite_t **sprites;
} gui_canvas_t;


#define GFXceil(X,Y)  (((X)+((Y)-1))/(Y))


typedef struct
{
  widget_t widget;
  int type; // 'F' = float 'I'= integer
  int frac; // fractional digits

  int intv, intq, intmin, intmax;
  double flov, floq, flomin, flomax;
  int limflags;

  int enabled;
  int timer, count;

  gui_button_t less,more;
  widget_t *label;
} gui_spinner_t;


#define SPINNER_MIN 1
#define SPINNER_MAX 2


typedef struct
{
  widget_t widget;
  int nlines,slines;
  char **lines;
  int last_line_incomplete;

  int fh;
  int cx, cy;
  int px, py, pw, ph;

  screen_t *screen;
} gui_logview_t;


typedef struct
{
  widget_t widget;
  int orient;
  double pos;
  int click_handler;
  int pressed;

  int button_x,button_y,button_w,button_h;
  int tx1, tx2, ty1, ty2;

} gui_slider_t;

typedef struct 
{
  widget_t widget;
  int total, current;
  int font;
  int fg, bg, fill;
} gui_progressbar_t;


typedef struct
{
  colorpix_t pix;
  int x,y;
  int iv; void *pv;
  int sel;
} gui_icoent_t;

typedef struct
{
  widget_t widget;
  int multi;
  
  int fg, bg; int hpad, vpad;
  int max_text_width;
  int disp_w, total_h;

  int sel;

  int pos_y;
  scrollbar_t *vscroll;
  int has_scroll;
  int click_handler;
  int click_handler4;
  int click_handler5;

  gui_icoent_t *ent; int sent,nent;
  int layout_ok;
} gui_iconlist_t;


typedef struct
{
  widget_t widget;

  char *dir;
  int nfiles;
  char **files;

  char **extensions;

  gui_list_t *w_list;
  dropdown_t *w_type;
  gui_label_t *w_typelab;
  checkbox_t *w_hidden;

  int show_hidden;

  void *evarg;
  event_function_t clickf,dlickf;
} gui_filelist_t;


typedef struct { int enabled, ident, left; } usr_timer_t;

  // three strings. 0-normal 1-shift 2-symbol
typedef struct { int x,y,w,h; int func; char *str[3]; } vkey_t;

#define OBJ_VKB   1

typedef struct
{
  int nkeys, nrows;
  vkey_t *keys;
  int state;
  int x,y,w,h;
  uint32_t *backstore;
  int pressed;
  int vs; // vertical spacing
} vkb_t;


// Reserved widget numbers
enum { 
     // confirmation dialog buttons
  GUIRaskB1=GFXEV_LAST, GUIRaskB2, GUIRaskB3, GUIRaskB4, GUIRaskB5,
  GUIRaskB6, GUIRaskB7, GUIRaskB8,
     // file selector widgets
  GUIRfilD1, GUIRfilD2, GUIRfilD3, GUIRfilD4, GUIRfilD5, GUIRfilD6,
  GUIRfilD7, GUIRfilD8, GUIRfilD9, GUIRfilD10, 
  GUIRfilHOME, GUIRfilREFRESH, GUIRfilOK, GUIRfilCANCEL, GUIRfilLIST,
  GUIRfilNAME,
     };



/***********************************************************************
 *                                                                     *
 *                             PROTOTYPES                              *
 *                                                                     *
 ***********************************************************************/
#ifdef GFX_X11

 
static uint32_t trailing_zero_bits(uint32_t Y);
static int get_x_visual();
static Window create_window(char *title,int width, int height);
static void get_root_attribs();
int gfx_init(char *name, int width, int height, char *title);
 
static ximage_t *create_image(uint32_t width, uint32_t height);
static ximage_t *ximage_create_simple(uint32_t width,uint32_t height);
static void destroy_image(ximage_t *image);
 
static void put_image(Drawable draw, int dest_x, int dest_y,
               ximage_t *image, int src_x, int src_y,
               int width, int height);
 
static int can_use_shared_images();
static void gfx_update(int x,int y,int width,int height);
void gfx_close();
static void checker_pattern(ximage_t *img,int N);
static int getdpi();
static x_keyboard_t *x_keyboard_init(Window window);
static void x_keyboard_free(x_keyboard_t *xk);
static void get_xim();
static int x_keyboard_event
             (x_keyboard_t *xk, XEvent *ev, gfx_event_t *Revent);
static uint32_t keysym2ucs(KeySym keysym);
 
static int lookup_key(KeySym sym, unsigned int modifiers);
static void tv2msecs(struct timeval *tv, unsigned int* msecs);
static int event_noprocess(unsigned int *msecs,gfx_event_t *Revent);
#endif
#ifdef GFX_ANDROID

void ANativeActivity_onCreate
      (ANativeActivity* activity, void* state, size_t state_size);
   static void* worker_entry(void* arg);
static void make_request(app_t *A, request_t *R);
static int get_request(app_t *A,request_t **R);
static void complete_request(app_t *A, request_t *R);
static void simple_command(ANativeActivity *ac, int cmd);
static void onStart(ANativeActivity* activity);
static void onResume(ANativeActivity* activity);
static void onPause(ANativeActivity* activity);
static void onStop(ANativeActivity* activity);
static void onNativeWindowCreated
   (ANativeActivity* activity, ANativeWindow* window);
static void onNativeWindowDestroyed
   (ANativeActivity* activity, ANativeWindow* window);
static void onNativeWindowRedrawNeeded
              (ANativeActivity* activity, ANativeWindow* window);
static void onInputQueueCreated
   (ANativeActivity* activity, AInputQueue* queue);
static void onInputQueueDestroyed
   (ANativeActivity* activity, AInputQueue* queue);
static void* onSaveInstanceState
   (ANativeActivity* activity, size_t* outLen);
static void onWindowFocusChanged
   (ANativeActivity* activity, int focused);
static void onLowMemory(ANativeActivity* activity);
static void onConfigurationChanged(ANativeActivity* activity);
static int handle_command(app_t *A,int *Rvalue);
static int execute_commands(app_t *app);
static void onDestroy(ANativeActivity* activity);
static void graphics_window_destroyed(app_t *A, ANativeWindow *window);
static void graphics_window_created(app_t *A, ANativeWindow *window);
static void gfx_update(int x,int y,int w,int h);
static int getdpi();
static int millitime();
static int handle_input(app_t *A, gfx_event_t *ev);
static int get_event(unsigned int *msecs, gfx_event_t *E);
int gfx_event (unsigned int *msecs, gfx_event_t *E);
static int event_noprocess(unsigned int *msecs,gfx_event_t *E);
JavaVM *gfx_get_javavm();
ANativeActivity* gfx_get_activity();
void gfx_save_state(uint32_t len, uint8_t *data);
static void have_java_result(JNIEnv* env, jobject thiz, jint rcode);
jint JNI_OnLoad(JavaVM *vm, void *reserved);
static jclass Jcls(JNIEnv *env, const char *name);
static jclass JclsO(JNIEnv *env, jobject obj);
static jobject JstaticfieldO
    (JNIEnv *env, jclass cls, const char *name,const char *type);
   static jobject JmethodO_o
  (JNIEnv *env, jobject obj, 
   const char *name, const char *proto,
   jobject arg1);
   static jobject JmethodO
  (JNIEnv *env, jobject obj, const char *name, const char *proto);
   static jboolean JmethodB_oi
  (JNIEnv *env, jobject obj, 
   const char *name, const char *proto,
   jobject arg1, int arg2);
static jint JmethodI
  (JNIEnv *env, jobject obj, const char *name) ;
 
void gfx_soft_keyboard(int show);
 
#endif
#ifdef GFX_FB

static uint32_t all_ones(uint32_t S,uint32_t L);
int gfx_init(char *DUMMYname, int DUMMYwidth, int DUMMYheight, char *DUMMYtitle);
static void destroy_image();
static void gfx_update(int x,int y,int width,int height);
void gfx_close();
static void checker_pattern(int N);
static void draw_cursor(int ux,int uy,int uw,int uh);
static void move_cursor(int cx,int cy);
static void prt_key(int key,char *lo,char *hi);
static void prt_keys(int SK,int EK, char *lo,char *hi);
static void prt_keys_upper(int SK,int EK,char *inp);
static void ctl_key(int raw,int gf);
static void mod_key(int raw,int gf);
static char *getenvd(char *name,char *def);
static void read_environ_vars();
static void rawinput_init();
static int event_noprocess(unsigned int *msecs, gfx_event_t *Revent);
#endif

 
static graypix_t graypix_sub(graypix_t src, int ofx, int ofy);
static colorpix_t pix_sub(colorpix_t src, int ofx, int ofy);
static void gfx_update_all();
static uint32_t *get_server_pix(int src_x,int src_y,int w,int h);
static void put_server_pix(uint32_t *D,int dst_x,int dst_y,int w, int h);
static void extract_resource_image_mask(uint32_t *D, uint8_t **Rmask);
static void put_server_pix_alphamask
   (uint32_t *D,uint8_t *mask,int dst_x,int dst_y,int w, int h);
static void populate_select_set
  (int *Rmaxfd, fd_set *rfd, fd_set *wfd, fd_set *xfd);
static int get_file_monitor_event
  (fd_set *rfd, fd_set *wfd, fd_set *xfd, gfx_event_t *Revent);
static char *nstrdup(const char *k);
static int flag2(int a,int b);
static int range_test(int v, int s, int w) ;
static int imin2(int a,int b) ;
static int imax2(int a,int b) ;
static double dmin2(double a,double b) ;
static double dmax2(double a,double b) ;
static int utf8_encode_string
    (const uint32_t* wstr,size_t wlen, uint8_t *dst, size_t *dlen);
 
static int utf8_decode_string
  (const uint8_t *input, size_t ilen, uint32_t *output, size_t *olen);
static uint32_t utf8_decode_single_char(char *src);
static void utf8_encode_single_char(uint32_t wide, char *dst);
static void utf8_decode_alloc(char *str, uint32_t **Rwstr, uint32_t *Rwlen);
static int clip_for_rect(int *start, int *amount, int max);
static void freeNnull(void *A);
static void *array_make1space
      (int pos,void **Rarray,int n, int *Rs, int eltsize);
static int clip_rrect(rrect_t *D, rrect_t *S);
static void strmove(char *dst,char *src);
static int remove_mid(char *path, char *pattern, int keep);
static int remove_prefix(char *path, char *pattern, int keep);
static char *has_suffix(char *path, char *sfx);
static int remove_suffix(char *path,char *sfx,int keep);
__PATH_PROTO char *path_file(char *path);
static int dotdotlast(char *path);
static int dotdot(char *path);
__PATH_PROTO char *path_dir(char *path);
__PATH_PROTO char *path_wd();
static char *pacom_fk(char *a,char* b);
__PATH_PROTO char* path_absolute(char *path);
__PATH_PROTO char *path_relative(char *path, char *pivot);
__PATH_PROTO char *path_child(char *path,char *child);
WOMAP_PROTO void* womap_find(womap_t *map,uint32_t key);
WOMAP_PROTO void* womap_insert(womap_t* map, uint32_t key, void *data);
WOMAP_PROTO void *womap_remove(womap_t* map, uint32_t key);
WOMAP_PROTO void *womap_destroy(womap_t *map);
WOMAP_PROTO womap_t  *womap_new();
static inline int womap_dir(uint32_t key,womap_node_t *node);
static inline womap_node_t* womap_leaf_node(uint32_t key, void *data);
static inline womap_node_t* womap_internal_node(uint32_t bit);
static uint8_t womap_crit_bit(uint32_t X, uint32_t Y);
static void screen_store_contents();
static void screen_restore_contents(screen_t *S);
static void enter_screen
   (int n_widgets, int *widgets,int *co);
static int install_click_handler
        (int x,int y,int w,int h,int *enabled,
         void *arg, int (*func)(void*,gfx_event_t*),int button);
static void install_release_handler
        (void *arg, int (*func)(void*,gfx_event_t*));
static void install_motion_handler(void *arg,int (*func)(void *,gfx_event_t*));
static void uninstall_motion_handler();
 
static int handle_grabbed_event(gfx_event_t *event);
static void grab_mouse(int (*func)(void*,gfx_event_t*), void *arg);
static void ungrab_mouse();
static int handle_click_event(gfx_event_t *event);
static void remove_click_handler(int H);
static int handle_release_event(gfx_event_t *event);
static int handle_motion_event(gfx_event_t *event);
static void widget_destroy(widget_t* W);
static void widget_move(widget_t *W,int x,int y,int w,int h);
static void widget_show(widget_t *W, int show);
static void widget_set_text(widget_t *W, char *str);
static char* widget_get_text(widget_t *W);
static widget_t *get_widget(int wno);
static void *get_widgetk(int wno,int klass);
static void widget_set_state(widget_t *W, int state);
static int widget_get_state(widget_t *W);
static int widget_get_selected(widget_t *W);
static void widget_set_selected(widget_t *W,int sel);
static void widget_set_fgbg(widget_t *W,int fg,int bg);
static void widget_insert
  (widget_t *W,int pos, char *text, void *user, uint32_t *icon);
static void widget_remove(widget_t *W,int pos, void **Ruser);
static void widget_clear(widget_t *W);
static void set_focus(widget_t *N);
static void remove_focus();
  static int make_focus_event(gfx_event_t *E);
static int tabs_before(widget_t *A,widget_t *B);
static int focusable_event(gfx_event_t *event);
static void focus_lost();
static void set_click_handler(int click,int x,int y,int w,int h);
static int install_or_modify_click
  (int ch, int *enabled, int (*func)(void*,gfx_event_t*), void* arg,
   int x,int y,int w,int h,int button);
static void widgetpos(widget_t *W,int x,int y,int w,int h);
static void get_screen_rect(screen_t *S, rect_t *A);
static void screen_compute_visible_parts(screen_t *S);
static colorpix_t get_screen_pix(screen_t *S);
static void screen_update_display(screen_t *S, int x,int y,int w, int h);
static int rectangle_intersect(rect_t *A, rect_t *B, rect_t *K);
static void update_screen_pixels(screen_t *S, int x,int y, int w, int h);
static void generic_dummy_hide(widget_t *W) ;
static uint32_t blend_usr_usr(uint32_t alpha, uint32_t fg, uint32_t bg);
static uint32_t blend_usr_usr_usr(uint32_t alpha, uint32_t fg, uint32_t bg);
static uint32_t blend_usr_svr(uint32_t alpha, uint32_t fg, uint32_t bg);
static void blend_graypix_bg
   (int fg, int bg, graypix_t src, 
    colorpix_t dst, int posx, int posy);
static void blend_graypix
   (int fg, graypix_t src, 
    colorpix_t dst, int posx, int posy);
static void colorpix_fill_rect
       (colorpix_t dst, int x,int y, int w, int h, int color);
static void blend_graymap(int flags, int fg, int bg,
                          const unsigned char *src, int src_w, int src_h,
                          int src_x, int src_y,
                          int dst_x, int dst_y, int width, int height);
static uint32_t color_s(uint32_t uR, uint32_t uG, uint32_t uB);
static uint32_t u_red(uint32_t C) ;
static uint32_t u_green(uint32_t C) ;
static uint32_t u_blue(uint32_t C) ;
static uint32_t color_u_to_s(uint32_t U);
static unsigned int blend_chan(unsigned int F, double A, unsigned int B);
static unsigned int blend(uint32_t F, double A, uint32_t B);
static void grad_fill(int x,int y, int w, int h, uint32_t start, uint32_t end);
static void hline(int x1,int x2, int y,uint32_t color);
static void vline(int x,int y1, int y2,uint32_t color);
static void gfx_fill_rect(int flags, int dst_x,int dst_y,
                   int w,int h, unsigned int color);
void gfx_draw_rect(int flags, int dst_x,int dst_y,
                   int w,int h, unsigned int color);
static void blend_graymap_buffer
        (unsigned int fg, const unsigned char *src, int src_w, int src_h,
                          int src_x, int src_y,
                          unsigned int *dst, int dst_w, int dst_h,
                          int dst_x, int dst_y, int width, int height);
static void gfx_put(int flags,
             const unsigned int *buffer, int src_w, int src_h,
             int src_x, int src_y,
             int dst_x, int dst_y,
             int width, int height);
static unsigned int* convert_graymap_to_color
        (unsigned int fg, unsigned int bg, const unsigned char *src);
static void gfx_draw_3dbox(int x,int y,int w,int h, 
                        int light, int dark, int border,
                        int start, int end);
static void convert_images_to_server(uint32_t **images);
static void convert_image_to_server(uint32_t *IMG);
static void draw_icon_and_text
                 (int x,int y,int w,int h,
                  int iconpos, uint32_t *icon,
                  int space,
                  uint32_t text_fg, char *text);
static void draw_icon_centered(int x,int y,int w,int h, uint32_t *icon);
static void put_pix_in_area
    (colorpix_t pix, int x, int y, int Ax, int Ay, int Aw, int Ah);
static void gfx_draw_rect_in
   (unsigned int color, int x,int y, int w,int h,
     int Ax, int Ay, int Aw, int Ah);
static void colorpix_hline(colorpix_t *P,int x1,int x2, int y,uint32_t color);
static void colorpix_vline(colorpix_t *P,int x,int y1, int y2,uint32_t color);
static unsigned int s_red(unsigned int V)
   ;
static unsigned int s_green(unsigned int V)
   ;
static unsigned int s_blue(unsigned int V)
   ;
static unsigned int blend_s(uint32_t F, double A, uint32_t B);
static void colorpix_gradfill
   (colorpix_t *P,int x0,int y0, int w, int h, uint32_t start, uint32_t end);
static void colorpix_3dbox
      (colorpix_t *P, int light, int dark, int border, int start, int end);
static void colorpix_put_graypix_centered
   (colorpix_t *P, graypix_t *G, int fg);
static void get_text_data(int font, const char *str, 
                          int *Rw, int *Rh,int *Ra,unsigned char **Rd);
static void text_to_graypix(int font, const char *str, graypix_t *gp, int *Ra);
static void gfx_text_size(int font, char *str, int *W, int *H);
void txt_print(int flags, int font, int fg, int bg, int x, int y, 
               char *str,int *Rw, int *Rh);
static int max_text_width(int font, ...);
static void txt_print_fit(const char *horz,const char *vert,
                   int x,int y, int w, int h,
                   int font, int alpha, int fg, int bg,
                   const char *str);
static void gui_button_set_text(gui_button_t *B, char *text);
static void button_render(gui_button_t *B);
static gui_button_t *gui_button_new
  (const char *txt, int iconpos, uint32_t* icon, int klass);
static widget_t* gfx_button
     (const char *txt,int iconpos, uint32_t *icon,int klass);
static void button_set_state(gui_button_t *B, int state);
static int gui_button_click(void *arg, gfx_event_t *event);
static int gui_button_release(void *arg, gfx_event_t *event);
static void gui_button_destroy(widget_t *W);
static void button_set_position( gui_button_t *B, int x,int y,int w,int h);
static void gui_button_activate(widget_t *W, int x,int y,int w,int h);
static void gui_button_show(gui_button_t *B,int show);
static void gui_button_init
  (gui_button_t *B,const char *txt, int iconpos, uint32_t* icon, 
   int (*click_func)(void *,gfx_event_t*), 
   int (*release_func)(void *,gfx_event_t*), void *click_arg);
static void label_render(gui_label_t *G);
static widget_t* gfx_label(int font, int fg, int bg, int just, char *str);
static void gui_label_show(widget_t *W);
static void gui_label_set_position(gui_label_t *L,int x,int y,int w,int h);
static void gui_label_destroy(widget_t *W);
static void gui_label_set_text(gui_label_t *G,const char *str);
static void label_set_fgbg(gui_label_t *G, int fg,int bg);
static void init_radio_images();
static void radio_draw_button(radio_t *R,int state,int bg, int upd);
static void radio_show(radio_t *R, int show);
static void radio_set(radio_t *R);
static int radio_click(void *arg, gfx_event_t *event);
static int radio_release(void *arg, gfx_event_t *event);
static widget_t* radio_new(const char *text, int group);
static void radio_draw_text(radio_t *R);
static void radio_draw(radio_t *R);
static radio_group_t *get_rgroup(int ident);
static void rgroup_clear_except(int ident,widget_t *R);
static void register_radio_in_group(int ident, widget_t *W);
static void free_rgroups(screen_t *S);
static int radio_group_get_selected(int ident);
static void init_checkbox_images();
static void checkbox_draw_button(checkbox_t *R,int state,int bg, int upd);
static void checkbox_show(checkbox_t *R, int show);
static void checkbox_set(checkbox_t *R,int value);
static int checkbox_click(void *arg, gfx_event_t *event);
static int checkbox_release(void *arg, gfx_event_t *event);
static widget_t* gui_checkbox_new(const char *text,
    void *evarg, event_function_t clickf);
static void gui_checkbox_destroy(widget_t *W);
static void checkbox_draw_text(checkbox_t *R);
static void checkbox_draw(checkbox_t *R);
static void scrollbar_compute_trough(scrollbar_t *SB);
static void scrollbar_compute_button(scrollbar_t *SB);
static void fill_with_horizontal_gradient
             (int x0,int y0, int y1, unsigned int *gra);
static void three_part_assembly_vertical
    (int x0,int y0, int y1, 
     uint32_t *top, uint32_t *mid, uint32_t *bot);
static void fill_with_vertical_gradient
             (int x0, int x1, int y0, unsigned int *gra);
static void three_part_assembly_horizontal
    (int x0, int x1, int y0, 
     uint32_t *lef, uint32_t *mid, uint32_t *rig);
static void scrollbar_draw_trough(scrollbar_t *SB);
static void scrollbar_draw_stepper(scrollbar_t *SB, int sno, int state);
static void scrollbar_draw_all(scrollbar_t *SB);
static void scrollbar_init_buttons
   (scrollbar_t *SB);
static void scrollbar_position_buttons(scrollbar_t *SB,int x,int y,int w,int h);
static widget_t* scrollbar_new
    (int orient, double start, double end, double step,
     int action, void *reportarg, void *reportfunc);
static void scrollbar_position(scrollbar_t *SB,int x,int y,int w,int h);
static int scrollbar_click_up(void *A, gfx_event_t *E);
static int scrollbar_release_up(void *A, gfx_event_t *event);
static void scrollbar_update(scrollbar_t *SB);
static int scrollbar_set
    (scrollbar_t *SB,double S, double E, int report, gfx_event_t* event);
static int scrollbar_click_down(void *A, gfx_event_t *E);
static int scrollbar_release_down(void *A, gfx_event_t *event);
static int scrollbar_click_tro(void *A,gfx_event_t *event);
static int scrollbar_release_dummy(void *A, gfx_event_t *E);
static int scrollbar_move_pointer(void *A, gfx_event_t *event);
static int scrollbar_release_tro(void *A, gfx_event_t *E);
static void scrollbar_set_all
  (scrollbar_t *SB, double start, double end, double step);
static void scrollbar_relayout
   (scrollbar_t *SB, int nx, int ny, int nw,int nh,
    double start, double end, double step);
static void scrollbar_destroy(scrollbar_t *SB);
static void scrollbar_show(scrollbar_t *SB,int show);
static panel_t *panel_new(int nsubs);
static void panel_show(panel_t *P,int show);
static void panel_show_widgets(panel_t *P,int sub, int show);
static void panel_activate(panel_t *P,int sel);
static void panel_position(panel_t *P,int nx,int ny,int nw,int nh);
static widget_t *dropdown_new(void *evarg, event_function_t clickf);
static void dropdown_show(dropdown_t *DD,int show);
static void dropdown_render_button(dropdown_t *DD, int p);
static int dropdown_click(void *arg, gfx_event_t* event);
static int dropdown_release(void *arg, gfx_event_t *event);
static void dropdown_show_list(dropdown_t *DD);
static void dropdown_draw_listbg(dropdown_t *DD);
static void dropdown_get_list_backup(dropdown_t *DD);
static void dropdown_put_list_backup(dropdown_t *DD);
static void dropdown_draw_contents(dropdown_t *DD);
static int dropdown_draw_item(dropdown_t *DD,int idx);
static void print_clipped(int Cx,int Cy,int Cw,int Ch,
                          int x, int y, int font, const char* str);
static int dropdown_item_pos(dropdown_t *DD,int item);
static void dropdown_draw_listframe(dropdown_t *DD,int which);
static void dropdown_scroll(dropdown_t *DD,double S,double E);
static int dropdown_mouse(dropdown_t *DD, gfx_event_t *event);
static int in_rect(int rx,int ry,int rw,int rh, int x,int y);
static void dropdown_hide_list(dropdown_t *DD);
static void dropdown_scroll_to(dropdown_t *DD,int pos,int report);
static int dropdown_item_at(dropdown_t *DD,int y);
static void dropdown_hilight_item(dropdown_t *DD, int item);
static void fill_clipped_rect
               (int Cx,int Cy,int Cw, int Ch, 
                int dx,int dy,int ow, int oh, unsigned int color);
static void dropdown_insert(dropdown_t *DD,
                            int pos, const char *str, void *usr);
static void dropdown_remove(dropdown_t *DD,int pos, void **Rusr);
static void gui_dropdown_clear(dropdown_t *DD);
static void gfx_dropdown_select(dropdown_t *DD, int pos);
static void gui_dropdown_destroy(widget_t *W);
static void dropdown_position(dropdown_t *DD,int x,int y,int w,int h);
static widget_t* gui_list_new
   (int noicon, int multisel, void *arg, 
       event_function_t clickf,
       event_function_t dlickf);
static void gui_list_set_position(gui_list_t* LL,int x,int y,int w,int h);
static void gfx_list_show(gui_list_t *L, int show);
static void list_install_click_handlers(gui_list_t *LL);
static void compute_list_items
    (gui_list_t* LL, int start, int end);
static void compute_list_content_size(gui_list_t *LL,int *Rw, int *Rh);
static int list_max_icon_width(gui_list_t *LL);
static void compute_list_port
  (gui_list_t* LL, int *Rportw, int *Rporth, int *Rhs, int *Rvs);
static int list_render_item(gui_list_t *LL,int ino,int bg);
static void gui_list_scrollbar_click_horz(void *a, double S, double E);
static void gui_list_scrollbar_click_vert(void *a, double S, double E);
static void list_layout_items(gui_list_t *LL,int start);
static void list_draw_borders(gui_list_t *LL,int which);
static void list_draw_contents(gui_list_t *L);
static void list_compute_scroll
    (int pos,int win,int con, double *Rstart, double *Rend, double *Rstep);
static void list_arrange_scrollbars
   (gui_list_t *LL, int have_horz, int have_vert);
static int gui_list_click(void *a, gfx_event_t *ev);
  static int gui_list_click4(void *a, gfx_event_t *ev);
  static int gui_list_click5(void *a, gfx_event_t *ev);
static void list_relayout(int flags, gui_list_t *L);
static void gfx_list_insert(gui_list_t* L, int pos, char *str, void *usr
                          ,const unsigned int*icon) ;
static void gfx_list_delete(gui_list_t *L, int pos, void **Ruser);
static int gfx_list_selected(gui_list_t *L);
static void gfx_list_select(gui_list_t* L,int pos);
static void gfx_list_clear(gui_list_t *L);
static widget_t *text_entry_new(char *initstr);
static void textentry_position(text_entry_t *te,int x,int y,int w,int h);
static void make_cursor_visible(text_entry_t *te);
static void mk_glyph(glyph_t *G, uint32_t chr);
static int draw_glyph(text_entry_t  *te, int gn, int expose);
static void textentry_focus(void *va, int focus);
static int textentry_key(void* va, gfx_event_t *event) ;
static void text_entry_move_cursor(text_entry_t *te, int newcurs);
static void insert_char(text_entry_t *te, uint32_t chr);
static void delete_cursor_char(text_entry_t *te);
static char *textentry_get_text(text_entry_t *te);
static void textentry_free(text_entry_t *te);
static void text_entry_set(text_entry_t *te, char *str);
static void gui_textentry_show(widget_t *arg);
static void gui_textentry_hide(widget_t *arg);
static widget_t* gfx_pixgrid();
static int gui_pixgrid_click(void *arg,gfx_event_t *event);
static int gui_pixgrid_release(void *arg,gfx_event_t *event);
static void gfxask_make_buttons
  (char *butstr,int *coor,int *Rnbut, int *Rbut_h,int *Rbut_total_w);
static void gfxask_show_buttons
    (int *coor_widgets, int nbuttons,int X,int Y);
static void gfxask_draw_border(int X,int Y,int W,int H);
static void split_string_bychar_d(char *str, int chr, char ***Ra,int *Rn);
static void format_multi_line_str(char *fmt, va_list ap, char ***Rl, int *Rn);
static void multi_line_str_dim
  (int font,char **lines, int nlines,int *Rw,int *Rh);
static char **parse_ext_list(char *inp);
static char **make_file_extension_list(char **inp);
static int file_matches_ext_set(char *fn,char **ext);
static char **list_files(char *dn);
static void file_types(char *dn, char **files);
_BUFFER_PROTO buffer_t *buffer_new(size_t blksize);
_BUFFER_PROTO void buffer_free(buffer_t *B, void **Rd, size_t *Rl);
_BUFFER_PROTO void buffer_collect(buffer_t *B, void **Rd, size_t *Rl);
_BUFFER_PROTO void buffer_write(buffer_t *B, void *d, size_t l);
_BUFFER_PROTO void buffer_append(buffer_t *dst, buffer_t *src_f);
_BUFFER_PROTO size_t buffer_read(buffer_t *B, void *d, size_t l);
static int filter_files_byext(int nfiles,char **files, char **suffixes);
static int filter_files_byhid(int nfiles,char **files,int showhid);
static int comparstr(const void *a,const void* b);
static void sort_files(int nfiles, char **files);
static char *sau_getcwd();
static char *sau_gethome();
static char* combine_path(char *dir,char *fn);
static void split_initial_fn(char *init, char **Rdir, char **Rfil);
static void filesel_make_screen(int *RX,int *RY,int *RW,int *RH,int title_w);
static void file_select_dialog
  (filesel_t *fs,int mode,char *ifil);
static void file_list_icons(const unsigned int **icons);
static void populate_file_list
        (filesel_t *fs);
static int filesel_tab_complete(void *arg,void *te,gfx_event_t *event);
static char **sepdir(char *name);
static void filesel_hide_buttons();
static void filesel_show_buttons(filesel_t *fs);
static void filesel_render_dirstack(filesel_t *fs);
static char* remove_trailing_slash(char *dn);
static void filesel_create_buttons(filesel_t *fs);
static void filesel_free_buttons(filesel_t *fs);
static void filesel_activate_button(filesel_t *fs,int idx);
static void filesel_render_buttons(filesel_t *fs);
static char *com3(char *x,char *y,char *z);
static char *com2(char *x,char *y);
static char *fs_combine(char *x,char *y);
static void filesel_activate_dir(filesel_t *fs, int idx);
static void filesel_setdir(filesel_t *fs,char *dir);
static widget_t *gui_canvas_new(int shor, int sver);
static void gui_canvas_update_click_handlers(gui_canvas_t *CC);
static void gui_canvas_position(gui_canvas_t *CC,int x,int y,int w,int h);
static int gui_canvas_setbuffer(gui_canvas_t *CC,int new_w,int new_h);
static void gui_canvas_arrange_scrollbars
   (gui_canvas_t *CC);
static void gui_canvas_paint_scrollbars(gui_canvas_t *CC);
static void gui_canvas_paint_buffer(gui_canvas_t *CC);
static void gui_canvas_draw_all(gui_canvas_t *CC);
static int subtract_rectangle(rect_t *A,rect_t *B,rect_t *R);
static void gui_canvas_update(gui_canvas_t *CC,int x,int y,int w,int h);
static void gui_canvas_clipped_hline
   (gui_canvas_t *CC,int color,int x1,int x2,int y);
static void gui_canvas_clipped_vline
   (gui_canvas_t *CC,int color,int x,int y1,int y2);
static gui_canvas_t *gui_canvas_get(int wno);
static void gui_canvas_scrollv(gui_canvas_t *CC,double start,double end);
static void gui_canvas_scrollh(gui_canvas_t *CC,double start,double end);
static int gui_canvas_click(void *arg,gfx_event_t *ev);
static int gui_canvas_release(void *arg,gfx_event_t *ev);
static int gui_canvas_motion(void *arg, gfx_event_t *ev);
static void gui_canvas_draw_recsel(gui_canvas_t *CC);
static void gui_canvas_invert_hline(gui_canvas_t *CC, int x1, int x2, int y);
static void gui_canvas_invert_vline(gui_canvas_t *CC,int x,int y1, int y2);
static int gui_canvas_report_motion(void *arg, gfx_event_t *ev);
static void gui_canvas_zupdate
   (gui_canvas_t *CC,int ux0,int uy0,int uw,int uh);
static int rect_intersect
   (int *Rx, int *Ry, int *Rw, int *Rh,
      int tx, int ty, int tw, int th);
static void gui_canvas_paint_sprite
   (gui_canvas_t *C,sprite_t *S,int ux,int uy,int uw,int uh);
static void gui_sprite_free(sprite_t *S);
static int gui_timer_schedule
  (unsigned int msecs, int (*f)(void*,gfx_event_t*), void *a);
      static int gui_timer_get(unsigned int *Rmsecs);
static int gui_timer_elapsed(unsigned int elap,gfx_event_t *event);
static void gui_timer_cancel(int ident);
static widget_t* gui_spinner(int type, int frac);
static void gui_spinner_destroy(gui_spinner_t *SS);
static void gui_spinner_set_position
   (gui_spinner_t* LL,int x,int y,int w,int h);
static void gui_spinner_show(gui_spinner_t *S, int show);
static void gui_spinner_render(gui_spinner_t *S);
static int gui_spinner_delta(gui_spinner_t *S, gfx_event_t *event, int dir);
static void spinner_apply_limits(gui_spinner_t* S);
static gui_spinner_t *get_spinner_widget(int wno);
static void gui_spinner_remove_timer
  (gui_spinner_t *SS);
static void gui_spinner_init_timer
  (gui_spinner_t *SS,int (*F)(void*,gfx_event_t*));
static void gui_spinner_reset_timer
  (gui_spinner_t *SS,int (*F)(void*,gfx_event_t*));
static int gui_spinner_less_release(void *arg,gfx_event_t *event);
static int gui_spinner_less_click(void *arg,gfx_event_t *event);
static int gui_spinner_less_timeout(void *arg,gfx_event_t *event);
static int gui_spinner_more_release(void *arg,gfx_event_t *event);
static int gui_spinner_more_click(void *arg,gfx_event_t *event);
static int gui_spinner_more_timeout(void *arg,gfx_event_t *event);
static widget_t *gui_logview();
static void gui_logview_destroy(widget_t *W);
static void logview_scroll_up(gui_logview_t *L, int yof);
static void logview_print_line
   (gui_logview_t *L,char *line, 
    int nonl,int *Ruys,int *Ruye);
static void logview_render(gui_logview_t *L);
static void gui_logview_show(widget_t *W);
static void gui_logview_hide(widget_t *W) ;
static void gui_logview_position(widget_t *W, int x,int y,int w,int h);
static void logview_write(gui_logview_t *L, const char *txt, size_t len);
static void logview_put_line
   (gui_logview_t *L, const char *txt, size_t len, int nonl);
static void slider_layout_vertical(gui_slider_t *B);
static void slider_layout_horizontal(gui_slider_t *B);
static void slider_layout(gui_slider_t *B);
static void slider_render_horizontal(gui_slider_t *B);
static void slider_render_vertical(gui_slider_t *B);
static void slider_render(gui_slider_t *B);
static widget_t *gui_slider_new(int orient);
static void slider_move_button(gui_slider_t *B, gfx_event_t *event);
static int gui_slider_click(void *arg, gfx_event_t *event);
static int gui_slider_motion(void *arg, gfx_event_t *event);
static int gui_slider_release(void *arg, gfx_event_t *event);
static void gui_slider_destroy(widget_t *B);
static void gui_slider_position(widget_t *W, int x,int y,int w,int h);
static void gui_slider_show(widget_t *B);
static void progressbar_render(gui_progressbar_t *G);
static widget_t* gui_progressbar_new(int font, int fg, int bg, int fill);
static void gui_progressbar_show(widget_t *W);
static void gui_progressbar_position
   (widget_t *W,int x,int y,int w,int h);
static widget_t* gui_iconlist_new
  (int fg, int bg,int vpad, int hpad,int max_text_width,int multisel);
static void render_icoent
   (gui_iconlist_t *IC, gui_icoent_t *EE,
    char *str, int iw, int ih, unsigned int *id);
static void gui_iconlist_render(gui_iconlist_t *IC);
static int gui_icoent_paint(gui_iconlist_t *IC, gui_icoent_t *EE);
static void gui_iconlist_layout(gui_iconlist_t *IC);
static void gui_iconlist_arrange_click_handler
   (gui_iconlist_t *IC, int need_scroll);
static void gui_iconlist_set_scrollbar(gui_iconlist_t *IC);
static void gui_iconlist_make_scrollbar(gui_iconlist_t *IC);
static void gui_iconlist_destroy(widget_t *W);
static void gui_iconlist_position(widget_t *W, int x,int y,int w,int h);
static void gui_iconlist_show(widget_t *W);
static int gui_iconlist_click(void *_arg, gfx_event_t *ev);
static int gui_iconlist_click4(void *_arg, gfx_event_t *ev);
static int gui_iconlist_click5(void *_arg, gfx_event_t *ev);
static void gui_iconsel_draw_selrect
  (gui_iconlist_t *IC,int item, int color,int upd);
static void gui_iconlist_select_item(gui_iconlist_t *IC, int sel);
static void  gui_iconlist_scrollbar_click(void *_arg,double start,double end);
static void gui_iconlist_clear(gui_iconlist_t *IC);
static void gui_iconlist_remove(gui_iconlist_t *IC,int pos, void **Ruser);
static void permute(int N, int *pP, void *aA, size_t size);
static widget_t *gui_filelist_new
  (int s_ext, int s_hidbox,
        void *evarg,event_function_t clickf, event_function_t dlickf);
static int filter_files_byspecial(int nfiles,char **files);
static void gui_filelist_set_directory(gui_filelist_t *FL,char *dir);
static void gui_filelist_show_all(gui_filelist_t *FL,int show);
static void gui_filelist_show(widget_t *W);
static void gui_filelist_hide(widget_t *W);
static void gui_filelist_destroy(widget_t *W);
static void gui_filelist_position(widget_t *W, int x,int y,int w,int h);
static int gui_filelist_ipret_click(gui_filelist_t *FL, gfx_event_t *event);
static int gui_filelist_listclick(void *arg, gfx_event_t *event);
 
static int gui_filesel_listdlick(void *arg, gfx_event_t *event);
 
static int gui_filelist_typeselect(void *arg, gfx_event_t *event);
 
static int gui_filelist_hiddenselect(void *arg, gfx_event_t *event);
 
static void free_extension_list(char **E);
static void gui_filelist_set_types(gui_filelist_t *FL, char **types);
static int have_user_timer(int *Rms);
static int elapsed_user_timer(int ms,int retev, gfx_event_t *event);
static void vkey_render(vkb_t *V, int kn, int state,int upd);
static uint32_t objid(int type, int id);
static void* obj_get(int type, int id);
static void* obj_put(int type, int id, void *data);
static void* obj_remove(int type, int id);
static void vk_textdim(char* str, int *Rw, int *Rh);
static void vkey_getdesc(vkb_t *V, gfx_vkbdef_t *D);
static void vkey_layout(vkb_t *V);
static void vkey_hide(vkb_t *V);
static void vkey_show(vkb_t *V);
static void vkey_ypos(vkb_t *V, int yp);
static int vkey_event(gfx_event_t *ev);
static int vkey_find_button(vkb_t *V, int x, int y);
/***********************************************************************
 *                                                                     *
 *                              VARIABLES                              *
 *                                                                     *
 ***********************************************************************/
#ifdef GFX_X11

static Display *x_display;
static Window   x_root_window;
static int      x_screen_number;
static uint32_t x_root_width, x_root_height;
static int      x_depth;
static Visual  *x_visual;
static int      x_window;
static Pixmap   x_pixmap;
static  Atom    wm_protocols, wm_delete_window;
static ximage_t *x_image;

static XIM xim;
static int xim_tried;
static XIMStyle xim_style;

/*
 * http://www.unicode.org/mail-arch/unicode-ml/Archives-Old/UML015/0422.html
 *
 * This module converts X Window System keysym values into the
 * corresponding ISO 10646-1 (UCS, Unicode) values.
 *
 * The array keysymtab[] contains pairs of X11 keysym values for graphical
 * characters and the corresponding Unicode value. The function
 * keysym2ucs() maps a keysym onto a Unicode value using a binary search,
 * therefore keysymtab[] must remain SORTED by keysym value.
 *
 * The keysym -> UTF-8 conversion will hopefully one day be provided
 * by Xlib via XmbLookupString() and should ideally not have to be
 * done in X applications. But we are not there yet.
 *
 * NOTE: The comments in the table below contain the actual character
 * encoded in UTF-8, so for viewing and editing best use an editor in
 * UTF-8 mode.
 *
 * Author: Markus G. Kuhn <mkuhn@acm.org>, University of Cambridge, June 1999
 *
 * Special thanks to Richard Verhoeven <river@win.tue.nl> for preparing
 * an initial draft of the mapping table. Suggestions for improvement welcome!
 *
 * This software is in the public domain. Share and enjoy!
 */
/** BEGIN KEYSYMTAB **/

static const struct codepair {
  unsigned short keysym;
  unsigned short ucs;
} keysymtab[] = {
  { 0x01a1, 0x0104 }, /* Aogonek Ą LATIN CAPITAL LETTER A WITH OGONEK */
  { 0x01a2, 0x02d8 }, /* breve ˘ BREVE */
  { 0x01a3, 0x0141 }, /* Lstroke Ł LATIN CAPITAL LETTER L WITH STROKE */
  { 0x01a5, 0x013d }, /* Lcaron Ľ LATIN CAPITAL LETTER L WITH CARON */
  { 0x01a6, 0x015a }, /* Sacute Ś LATIN CAPITAL LETTER S WITH ACUTE */
  { 0x01a9, 0x0160 }, /* Scaron Š LATIN CAPITAL LETTER S WITH CARON */
  { 0x01aa, 0x015e }, /* Scedilla Ş LATIN CAPITAL LETTER S WITH CEDILLA */
  { 0x01ab, 0x0164 }, /* Tcaron Ť LATIN CAPITAL LETTER T WITH CARON */
  { 0x01ac, 0x0179 }, /* Zacute Ź LATIN CAPITAL LETTER Z WITH ACUTE */
  { 0x01ae, 0x017d }, /* Zcaron Ž LATIN CAPITAL LETTER Z WITH CARON */
  { 0x01af, 0x017b }, /* Zabovedot Ż LATIN CAPITAL LETTER Z WITH DOT ABOVE */
  { 0x01b1, 0x0105 }, /* aogonek ą LATIN SMALL LETTER A WITH OGONEK */
  { 0x01b2, 0x02db }, /* ogonek ˛ OGONEK */
  { 0x01b3, 0x0142 }, /* lstroke ł LATIN SMALL LETTER L WITH STROKE */
  { 0x01b5, 0x013e }, /* lcaron ľ LATIN SMALL LETTER L WITH CARON */
  { 0x01b6, 0x015b }, /* sacute ś LATIN SMALL LETTER S WITH ACUTE */
  { 0x01b7, 0x02c7 }, /* caron ˇ CARON */
  { 0x01b9, 0x0161 }, /* scaron š LATIN SMALL LETTER S WITH CARON */
  { 0x01ba, 0x015f }, /* scedilla ş LATIN SMALL LETTER S WITH CEDILLA */
  { 0x01bb, 0x0165 }, /* tcaron ť LATIN SMALL LETTER T WITH CARON */
  { 0x01bc, 0x017a }, /* zacute ź LATIN SMALL LETTER Z WITH ACUTE */
  { 0x01bd, 0x02dd }, /* doubleacute ˝ DOUBLE ACUTE ACCENT */
  { 0x01be, 0x017e }, /* zcaron ž LATIN SMALL LETTER Z WITH CARON */
  { 0x01bf, 0x017c }, /* zabovedot ż LATIN SMALL LETTER Z WITH DOT ABOVE */
  { 0x01c0, 0x0154 }, /* Racute Ŕ LATIN CAPITAL LETTER R WITH ACUTE */
  { 0x01c3, 0x0102 }, /* Abreve Ă LATIN CAPITAL LETTER A WITH BREVE */
  { 0x01c5, 0x0139 }, /* Lacute Ĺ LATIN CAPITAL LETTER L WITH ACUTE */
  { 0x01c6, 0x0106 }, /* Cacute Ć LATIN CAPITAL LETTER C WITH ACUTE */
  { 0x01c8, 0x010c }, /* Ccaron Č LATIN CAPITAL LETTER C WITH CARON */
  { 0x01ca, 0x0118 }, /* Eogonek Ę LATIN CAPITAL LETTER E WITH OGONEK */
  { 0x01cc, 0x011a }, /* Ecaron Ě LATIN CAPITAL LETTER E WITH CARON */
  { 0x01cf, 0x010e }, /* Dcaron Ď LATIN CAPITAL LETTER D WITH CARON */
  { 0x01d0, 0x0110 }, /* Dstroke Đ LATIN CAPITAL LETTER D WITH STROKE */
  { 0x01d1, 0x0143 }, /* Nacute Ń LATIN CAPITAL LETTER N WITH ACUTE */
  { 0x01d2, 0x0147 }, /* Ncaron Ň LATIN CAPITAL LETTER N WITH CARON */
  { 0x01d5, 0x0150 }, /* Odoubleacute Ő LATIN CAPITAL LETTER O WITH DOUBLE ACUTE */
  { 0x01d8, 0x0158 }, /* Rcaron Ř LATIN CAPITAL LETTER R WITH CARON */
  { 0x01d9, 0x016e }, /* Uring Ů LATIN CAPITAL LETTER U WITH RING ABOVE */
  { 0x01db, 0x0170 }, /* Udoubleacute Ű LATIN CAPITAL LETTER U WITH DOUBLE ACUTE */
  { 0x01de, 0x0162 }, /* Tcedilla Ţ LATIN CAPITAL LETTER T WITH CEDILLA */
  { 0x01e0, 0x0155 }, /* racute ŕ LATIN SMALL LETTER R WITH ACUTE */
  { 0x01e3, 0x0103 }, /* abreve ă LATIN SMALL LETTER A WITH BREVE */
  { 0x01e5, 0x013a }, /* lacute ĺ LATIN SMALL LETTER L WITH ACUTE */
  { 0x01e6, 0x0107 }, /* cacute ć LATIN SMALL LETTER C WITH ACUTE */
  { 0x01e8, 0x010d }, /* ccaron č LATIN SMALL LETTER C WITH CARON */
  { 0x01ea, 0x0119 }, /* eogonek ę LATIN SMALL LETTER E WITH OGONEK */
  { 0x01ec, 0x011b }, /* ecaron ě LATIN SMALL LETTER E WITH CARON */
  { 0x01ef, 0x010f }, /* dcaron ď LATIN SMALL LETTER D WITH CARON */
  { 0x01f0, 0x0111 }, /* dstroke đ LATIN SMALL LETTER D WITH STROKE */
  { 0x01f1, 0x0144 }, /* nacute ń LATIN SMALL LETTER N WITH ACUTE */
  { 0x01f2, 0x0148 }, /* ncaron ň LATIN SMALL LETTER N WITH CARON */
  { 0x01f5, 0x0151 }, /* odoubleacute ő LATIN SMALL LETTER O WITH DOUBLE ACUTE */
  { 0x01f8, 0x0159 }, /* rcaron ř LATIN SMALL LETTER R WITH CARON */
  { 0x01f9, 0x016f }, /* uring ů LATIN SMALL LETTER U WITH RING ABOVE */
  { 0x01fb, 0x0171 }, /* udoubleacute ű LATIN SMALL LETTER U WITH DOUBLE ACUTE */
  { 0x01fe, 0x0163 }, /* tcedilla ţ LATIN SMALL LETTER T WITH CEDILLA */
  { 0x01ff, 0x02d9 }, /* abovedot ˙ DOT ABOVE */
  { 0x02a1, 0x0126 }, /* Hstroke Ħ LATIN CAPITAL LETTER H WITH STROKE */
  { 0x02a6, 0x0124 }, /* Hcircumflex Ĥ LATIN CAPITAL LETTER H WITH CIRCUMFLEX */
  { 0x02a9, 0x0130 }, /* Iabovedot İ LATIN CAPITAL LETTER I WITH DOT ABOVE */
  { 0x02ab, 0x011e }, /* Gbreve Ğ LATIN CAPITAL LETTER G WITH BREVE */
  { 0x02ac, 0x0134 }, /* Jcircumflex Ĵ LATIN CAPITAL LETTER J WITH CIRCUMFLEX */
  { 0x02b1, 0x0127 }, /* hstroke ħ LATIN SMALL LETTER H WITH STROKE */
  { 0x02b6, 0x0125 }, /* hcircumflex ĥ LATIN SMALL LETTER H WITH CIRCUMFLEX */
  { 0x02b9, 0x0131 }, /* idotless ı LATIN SMALL LETTER DOTLESS I */
  { 0x02bb, 0x011f }, /* gbreve ğ LATIN SMALL LETTER G WITH BREVE */
  { 0x02bc, 0x0135 }, /* jcircumflex ĵ LATIN SMALL LETTER J WITH CIRCUMFLEX */
  { 0x02c5, 0x010a }, /* Cabovedot Ċ LATIN CAPITAL LETTER C WITH DOT ABOVE */
  { 0x02c6, 0x0108 }, /* Ccircumflex Ĉ LATIN CAPITAL LETTER C WITH CIRCUMFLEX */
  { 0x02d5, 0x0120 }, /* Gabovedot Ġ LATIN CAPITAL LETTER G WITH DOT ABOVE */
  { 0x02d8, 0x011c }, /* Gcircumflex Ĝ LATIN CAPITAL LETTER G WITH CIRCUMFLEX */
  { 0x02dd, 0x016c }, /* Ubreve Ŭ LATIN CAPITAL LETTER U WITH BREVE */
  { 0x02de, 0x015c }, /* Scircumflex Ŝ LATIN CAPITAL LETTER S WITH CIRCUMFLEX */
  { 0x02e5, 0x010b }, /* cabovedot ċ LATIN SMALL LETTER C WITH DOT ABOVE */
  { 0x02e6, 0x0109 }, /* ccircumflex ĉ LATIN SMALL LETTER C WITH CIRCUMFLEX */
  { 0x02f5, 0x0121 }, /* gabovedot ġ LATIN SMALL LETTER G WITH DOT ABOVE */
  { 0x02f8, 0x011d }, /* gcircumflex ĝ LATIN SMALL LETTER G WITH CIRCUMFLEX */
  { 0x02fd, 0x016d }, /* ubreve ŭ LATIN SMALL LETTER U WITH BREVE */
  { 0x02fe, 0x015d }, /* scircumflex ŝ LATIN SMALL LETTER S WITH CIRCUMFLEX */
  { 0x03a2, 0x0138 }, /* kra ĸ LATIN SMALL LETTER KRA */
  { 0x03a3, 0x0156 }, /* Rcedilla Ŗ LATIN CAPITAL LETTER R WITH CEDILLA */
  { 0x03a5, 0x0128 }, /* Itilde Ĩ LATIN CAPITAL LETTER I WITH TILDE */
  { 0x03a6, 0x013b }, /* Lcedilla Ļ LATIN CAPITAL LETTER L WITH CEDILLA */
  { 0x03aa, 0x0112 }, /* Emacron Ē LATIN CAPITAL LETTER E WITH MACRON */
  { 0x03ab, 0x0122 }, /* Gcedilla Ģ LATIN CAPITAL LETTER G WITH CEDILLA */
  { 0x03ac, 0x0166 }, /* Tslash Ŧ LATIN CAPITAL LETTER T WITH STROKE */
  { 0x03b3, 0x0157 }, /* rcedilla ŗ LATIN SMALL LETTER R WITH CEDILLA */
  { 0x03b5, 0x0129 }, /* itilde ĩ LATIN SMALL LETTER I WITH TILDE */
  { 0x03b6, 0x013c }, /* lcedilla ļ LATIN SMALL LETTER L WITH CEDILLA */
  { 0x03ba, 0x0113 }, /* emacron ē LATIN SMALL LETTER E WITH MACRON */
  { 0x03bb, 0x0123 }, /* gcedilla ģ LATIN SMALL LETTER G WITH CEDILLA */
  { 0x03bc, 0x0167 }, /* tslash ŧ LATIN SMALL LETTER T WITH STROKE */
  { 0x03bd, 0x014a }, /* ENG Ŋ LATIN CAPITAL LETTER ENG */
  { 0x03bf, 0x014b }, /* eng ŋ LATIN SMALL LETTER ENG */
  { 0x03c0, 0x0100 }, /* Amacron Ā LATIN CAPITAL LETTER A WITH MACRON */
  { 0x03c7, 0x012e }, /* Iogonek Į LATIN CAPITAL LETTER I WITH OGONEK */
  { 0x03cc, 0x0116 }, /* Eabovedot Ė LATIN CAPITAL LETTER E WITH DOT ABOVE */
  { 0x03cf, 0x012a }, /* Imacron Ī LATIN CAPITAL LETTER I WITH MACRON */
  { 0x03d1, 0x0145 }, /* Ncedilla Ņ LATIN CAPITAL LETTER N WITH CEDILLA */
  { 0x03d2, 0x014c }, /* Omacron Ō LATIN CAPITAL LETTER O WITH MACRON */
  { 0x03d3, 0x0136 }, /* Kcedilla Ķ LATIN CAPITAL LETTER K WITH CEDILLA */
  { 0x03d9, 0x0172 }, /* Uogonek Ų LATIN CAPITAL LETTER U WITH OGONEK */
  { 0x03dd, 0x0168 }, /* Utilde Ũ LATIN CAPITAL LETTER U WITH TILDE */
  { 0x03de, 0x016a }, /* Umacron Ū LATIN CAPITAL LETTER U WITH MACRON */
  { 0x03e0, 0x0101 }, /* amacron ā LATIN SMALL LETTER A WITH MACRON */
  { 0x03e7, 0x012f }, /* iogonek į LATIN SMALL LETTER I WITH OGONEK */
  { 0x03ec, 0x0117 }, /* eabovedot ė LATIN SMALL LETTER E WITH DOT ABOVE */
  { 0x03ef, 0x012b }, /* imacron ī LATIN SMALL LETTER I WITH MACRON */
  { 0x03f1, 0x0146 }, /* ncedilla ņ LATIN SMALL LETTER N WITH CEDILLA */
  { 0x03f2, 0x014d }, /* omacron ō LATIN SMALL LETTER O WITH MACRON */
  { 0x03f3, 0x0137 }, /* kcedilla ķ LATIN SMALL LETTER K WITH CEDILLA */
  { 0x03f9, 0x0173 }, /* uogonek ų LATIN SMALL LETTER U WITH OGONEK */
  { 0x03fd, 0x0169 }, /* utilde ũ LATIN SMALL LETTER U WITH TILDE */
  { 0x03fe, 0x016b }, /* umacron ū LATIN SMALL LETTER U WITH MACRON */
  { 0x047e, 0x203e }, /* overline ‾ OVERLINE */
  { 0x04a1, 0x3002 }, /* kana_fullstop 。 IDEOGRAPHIC FULL STOP */
  { 0x04a2, 0x300c }, /* kana_openingbracket 「 LEFT CORNER BRACKET */
  { 0x04a3, 0x300d }, /* kana_closingbracket 」 RIGHT CORNER BRACKET */
  { 0x04a4, 0x3001 }, /* kana_comma 、 IDEOGRAPHIC COMMA */
  { 0x04a5, 0x30fb }, /* kana_conjunctive ・ KATAKANA MIDDLE DOT */
  { 0x04a6, 0x30f2 }, /* kana_WO ヲ KATAKANA LETTER WO */
  { 0x04a7, 0x30a1 }, /* kana_a ァ KATAKANA LETTER SMALL A */
  { 0x04a8, 0x30a3 }, /* kana_i ィ KATAKANA LETTER SMALL I */
  { 0x04a9, 0x30a5 }, /* kana_u ゥ KATAKANA LETTER SMALL U */
  { 0x04aa, 0x30a7 }, /* kana_e ェ KATAKANA LETTER SMALL E */
  { 0x04ab, 0x30a9 }, /* kana_o ォ KATAKANA LETTER SMALL O */
  { 0x04ac, 0x30e3 }, /* kana_ya ャ KATAKANA LETTER SMALL YA */
  { 0x04ad, 0x30e5 }, /* kana_yu ュ KATAKANA LETTER SMALL YU */
  { 0x04ae, 0x30e7 }, /* kana_yo ョ KATAKANA LETTER SMALL YO */
  { 0x04af, 0x30c3 }, /* kana_tsu ッ KATAKANA LETTER SMALL TU */
  { 0x04b0, 0x30fc }, /* prolongedsound ー KATAKANA-HIRAGANA PROLONGED SOUND MARK */
  { 0x04b1, 0x30a2 }, /* kana_A ア KATAKANA LETTER A */
  { 0x04b2, 0x30a4 }, /* kana_I イ KATAKANA LETTER I */
  { 0x04b3, 0x30a6 }, /* kana_U ウ KATAKANA LETTER U */
  { 0x04b4, 0x30a8 }, /* kana_E エ KATAKANA LETTER E */
  { 0x04b5, 0x30aa }, /* kana_O オ KATAKANA LETTER O */
  { 0x04b6, 0x30ab }, /* kana_KA カ KATAKANA LETTER KA */
  { 0x04b7, 0x30ad }, /* kana_KI キ KATAKANA LETTER KI */
  { 0x04b8, 0x30af }, /* kana_KU ク KATAKANA LETTER KU */
  { 0x04b9, 0x30b1 }, /* kana_KE ケ KATAKANA LETTER KE */
  { 0x04ba, 0x30b3 }, /* kana_KO コ KATAKANA LETTER KO */
  { 0x04bb, 0x30b5 }, /* kana_SA サ KATAKANA LETTER SA */
  { 0x04bc, 0x30b7 }, /* kana_SHI シ KATAKANA LETTER SI */
  { 0x04bd, 0x30b9 }, /* kana_SU ス KATAKANA LETTER SU */
  { 0x04be, 0x30bb }, /* kana_SE セ KATAKANA LETTER SE */
  { 0x04bf, 0x30bd }, /* kana_SO ソ KATAKANA LETTER SO */
  { 0x04c0, 0x30bf }, /* kana_TA タ KATAKANA LETTER TA */
  { 0x04c1, 0x30c1 }, /* kana_CHI チ KATAKANA LETTER TI */
  { 0x04c2, 0x30c4 }, /* kana_TSU ツ KATAKANA LETTER TU */
  { 0x04c3, 0x30c6 }, /* kana_TE テ KATAKANA LETTER TE */
  { 0x04c4, 0x30c8 }, /* kana_TO ト KATAKANA LETTER TO */
  { 0x04c5, 0x30ca }, /* kana_NA ナ KATAKANA LETTER NA */
  { 0x04c6, 0x30cb }, /* kana_NI ニ KATAKANA LETTER NI */
  { 0x04c7, 0x30cc }, /* kana_NU ヌ KATAKANA LETTER NU */
  { 0x04c8, 0x30cd }, /* kana_NE ネ KATAKANA LETTER NE */
  { 0x04c9, 0x30ce }, /* kana_NO ノ KATAKANA LETTER NO */
  { 0x04ca, 0x30cf }, /* kana_HA ハ KATAKANA LETTER HA */
  { 0x04cb, 0x30d2 }, /* kana_HI ヒ KATAKANA LETTER HI */
  { 0x04cc, 0x30d5 }, /* kana_FU フ KATAKANA LETTER HU */
  { 0x04cd, 0x30d8 }, /* kana_HE ヘ KATAKANA LETTER HE */
  { 0x04ce, 0x30db }, /* kana_HO ホ KATAKANA LETTER HO */
  { 0x04cf, 0x30de }, /* kana_MA マ KATAKANA LETTER MA */
  { 0x04d0, 0x30df }, /* kana_MI ミ KATAKANA LETTER MI */
  { 0x04d1, 0x30e0 }, /* kana_MU ム KATAKANA LETTER MU */
  { 0x04d2, 0x30e1 }, /* kana_ME メ KATAKANA LETTER ME */
  { 0x04d3, 0x30e2 }, /* kana_MO モ KATAKANA LETTER MO */
  { 0x04d4, 0x30e4 }, /* kana_YA ヤ KATAKANA LETTER YA */
  { 0x04d5, 0x30e6 }, /* kana_YU ユ KATAKANA LETTER YU */
  { 0x04d6, 0x30e8 }, /* kana_YO ヨ KATAKANA LETTER YO */
  { 0x04d7, 0x30e9 }, /* kana_RA ラ KATAKANA LETTER RA */
  { 0x04d8, 0x30ea }, /* kana_RI リ KATAKANA LETTER RI */
  { 0x04d9, 0x30eb }, /* kana_RU ル KATAKANA LETTER RU */
  { 0x04da, 0x30ec }, /* kana_RE レ KATAKANA LETTER RE */
  { 0x04db, 0x30ed }, /* kana_RO ロ KATAKANA LETTER RO */
  { 0x04dc, 0x30ef }, /* kana_WA ワ KATAKANA LETTER WA */
  { 0x04dd, 0x30f3 }, /* kana_N ン KATAKANA LETTER N */
  { 0x04de, 0x309b }, /* voicedsound ゛ KATAKANA-HIRAGANA VOICED SOUND MARK */
  { 0x04df, 0x309c }, /* semivoicedsound ゜ KATAKANA-HIRAGANA SEMI-VOICED SOUND MARK */
  { 0x05ac, 0x060c }, /* Arabic_comma ، ARABIC COMMA */
  { 0x05bb, 0x061b }, /* Arabic_semicolon ؛ ARABIC SEMICOLON */
  { 0x05bf, 0x061f }, /* Arabic_question_mark ؟ ARABIC QUESTION MARK */
  { 0x05c1, 0x0621 }, /* Arabic_hamza ء ARABIC LETTER HAMZA */
  { 0x05c2, 0x0622 }, /* Arabic_maddaonalef آ ARABIC LETTER ALEF WITH MADDA ABOVE */
  { 0x05c3, 0x0623 }, /* Arabic_hamzaonalef أ ARABIC LETTER ALEF WITH HAMZA ABOVE */
  { 0x05c4, 0x0624 }, /* Arabic_hamzaonwaw ؤ ARABIC LETTER WAW WITH HAMZA ABOVE */
  { 0x05c5, 0x0625 }, /* Arabic_hamzaunderalef إ ARABIC LETTER ALEF WITH HAMZA BELOW */
  { 0x05c6, 0x0626 }, /* Arabic_hamzaonyeh ئ ARABIC LETTER YEH WITH HAMZA ABOVE */
  { 0x05c7, 0x0627 }, /* Arabic_alef ا ARABIC LETTER ALEF */
  { 0x05c8, 0x0628 }, /* Arabic_beh ب ARABIC LETTER BEH */
  { 0x05c9, 0x0629 }, /* Arabic_tehmarbuta ة ARABIC LETTER TEH MARBUTA */
  { 0x05ca, 0x062a }, /* Arabic_teh ت ARABIC LETTER TEH */
  { 0x05cb, 0x062b }, /* Arabic_theh ث ARABIC LETTER THEH */
  { 0x05cc, 0x062c }, /* Arabic_jeem ج ARABIC LETTER JEEM */
  { 0x05cd, 0x062d }, /* Arabic_hah ح ARABIC LETTER HAH */
  { 0x05ce, 0x062e }, /* Arabic_khah خ ARABIC LETTER KHAH */
  { 0x05cf, 0x062f }, /* Arabic_dal د ARABIC LETTER DAL */
  { 0x05d0, 0x0630 }, /* Arabic_thal ذ ARABIC LETTER THAL */
  { 0x05d1, 0x0631 }, /* Arabic_ra ر ARABIC LETTER REH */
  { 0x05d2, 0x0632 }, /* Arabic_zain ز ARABIC LETTER ZAIN */
  { 0x05d3, 0x0633 }, /* Arabic_seen س ARABIC LETTER SEEN */
  { 0x05d4, 0x0634 }, /* Arabic_sheen ش ARABIC LETTER SHEEN */
  { 0x05d5, 0x0635 }, /* Arabic_sad ص ARABIC LETTER SAD */
  { 0x05d6, 0x0636 }, /* Arabic_dad ض ARABIC LETTER DAD */
  { 0x05d7, 0x0637 }, /* Arabic_tah ط ARABIC LETTER TAH */
  { 0x05d8, 0x0638 }, /* Arabic_zah ظ ARABIC LETTER ZAH */
  { 0x05d9, 0x0639 }, /* Arabic_ain ع ARABIC LETTER AIN */
  { 0x05da, 0x063a }, /* Arabic_ghain غ ARABIC LETTER GHAIN */
  { 0x05e0, 0x0640 }, /* Arabic_tatweel ـ ARABIC TATWEEL */
  { 0x05e1, 0x0641 }, /* Arabic_feh ف ARABIC LETTER FEH */
  { 0x05e2, 0x0642 }, /* Arabic_qaf ق ARABIC LETTER QAF */
  { 0x05e3, 0x0643 }, /* Arabic_kaf ك ARABIC LETTER KAF */
  { 0x05e4, 0x0644 }, /* Arabic_lam ل ARABIC LETTER LAM */
  { 0x05e5, 0x0645 }, /* Arabic_meem م ARABIC LETTER MEEM */
  { 0x05e6, 0x0646 }, /* Arabic_noon ن ARABIC LETTER NOON */
  { 0x05e7, 0x0647 }, /* Arabic_ha ه ARABIC LETTER HEH */
  { 0x05e8, 0x0648 }, /* Arabic_waw و ARABIC LETTER WAW */
  { 0x05e9, 0x0649 }, /* Arabic_alefmaksura ى ARABIC LETTER ALEF MAKSURA */
  { 0x05ea, 0x064a }, /* Arabic_yeh ي ARABIC LETTER YEH */
  { 0x05eb, 0x064b }, /* Arabic_fathatan ً ARABIC FATHATAN */
  { 0x05ec, 0x064c }, /* Arabic_dammatan ٌ ARABIC DAMMATAN */
  { 0x05ed, 0x064d }, /* Arabic_kasratan ٍ ARABIC KASRATAN */
  { 0x05ee, 0x064e }, /* Arabic_fatha َ ARABIC FATHA */
  { 0x05ef, 0x064f }, /* Arabic_damma ُ ARABIC DAMMA */
  { 0x05f0, 0x0650 }, /* Arabic_kasra ِ ARABIC KASRA */
  { 0x05f1, 0x0651 }, /* Arabic_shadda ّ ARABIC SHADDA */
  { 0x05f2, 0x0652 }, /* Arabic_sukun ْ ARABIC SUKUN */
  { 0x06a1, 0x0452 }, /* Serbian_dje ђ CYRILLIC SMALL LETTER DJE */
  { 0x06a2, 0x0453 }, /* Macedonia_gje ѓ CYRILLIC SMALL LETTER GJE */
  { 0x06a3, 0x0451 }, /* Cyrillic_io ё CYRILLIC SMALL LETTER IO */
  { 0x06a4, 0x0454 }, /* Ukrainian_ie є CYRILLIC SMALL LETTER UKRAINIAN IE */
  { 0x06a5, 0x0455 }, /* Macedonia_dse ѕ CYRILLIC SMALL LETTER DZE */
  { 0x06a6, 0x0456 }, /* Ukrainian_i і CYRILLIC SMALL LETTER BYELORUSSIAN-UKRAINIAN I */
  { 0x06a7, 0x0457 }, /* Ukrainian_yi ї CYRILLIC SMALL LETTER YI */
  { 0x06a8, 0x0458 }, /* Cyrillic_je ј CYRILLIC SMALL LETTER JE */
  { 0x06a9, 0x0459 }, /* Cyrillic_lje љ CYRILLIC SMALL LETTER LJE */
  { 0x06aa, 0x045a }, /* Cyrillic_nje њ CYRILLIC SMALL LETTER NJE */
  { 0x06ab, 0x045b }, /* Serbian_tshe ћ CYRILLIC SMALL LETTER TSHE */
  { 0x06ac, 0x045c }, /* Macedonia_kje ќ CYRILLIC SMALL LETTER KJE */
  { 0x06ae, 0x045e }, /* Byelorussian_shortu ў CYRILLIC SMALL LETTER SHORT U */
  { 0x06af, 0x045f }, /* Cyrillic_dzhe џ CYRILLIC SMALL LETTER DZHE */
  { 0x06b0, 0x2116 }, /* numerosign № NUMERO SIGN */
  { 0x06b1, 0x0402 }, /* Serbian_DJE Ђ CYRILLIC CAPITAL LETTER DJE */
  { 0x06b2, 0x0403 }, /* Macedonia_GJE Ѓ CYRILLIC CAPITAL LETTER GJE */
  { 0x06b3, 0x0401 }, /* Cyrillic_IO Ё CYRILLIC CAPITAL LETTER IO */
  { 0x06b4, 0x0404 }, /* Ukrainian_IE Є CYRILLIC CAPITAL LETTER UKRAINIAN IE */
  { 0x06b5, 0x0405 }, /* Macedonia_DSE Ѕ CYRILLIC CAPITAL LETTER DZE */
  { 0x06b6, 0x0406 }, /* Ukrainian_I І CYRILLIC CAPITAL LETTER BYELORUSSIAN-UKRAINIAN I */
  { 0x06b7, 0x0407 }, /* Ukrainian_YI Ї CYRILLIC CAPITAL LETTER YI */
  { 0x06b8, 0x0408 }, /* Cyrillic_JE Ј CYRILLIC CAPITAL LETTER JE */
  { 0x06b9, 0x0409 }, /* Cyrillic_LJE Љ CYRILLIC CAPITAL LETTER LJE */
  { 0x06ba, 0x040a }, /* Cyrillic_NJE Њ CYRILLIC CAPITAL LETTER NJE */
  { 0x06bb, 0x040b }, /* Serbian_TSHE Ћ CYRILLIC CAPITAL LETTER TSHE */
  { 0x06bc, 0x040c }, /* Macedonia_KJE Ќ CYRILLIC CAPITAL LETTER KJE */
  { 0x06be, 0x040e }, /* Byelorussian_SHORTU Ў CYRILLIC CAPITAL LETTER SHORT U */
  { 0x06bf, 0x040f }, /* Cyrillic_DZHE Џ CYRILLIC CAPITAL LETTER DZHE */
  { 0x06c0, 0x044e }, /* Cyrillic_yu ю CYRILLIC SMALL LETTER YU */
  { 0x06c1, 0x0430 }, /* Cyrillic_a а CYRILLIC SMALL LETTER A */
  { 0x06c2, 0x0431 }, /* Cyrillic_be б CYRILLIC SMALL LETTER BE */
  { 0x06c3, 0x0446 }, /* Cyrillic_tse ц CYRILLIC SMALL LETTER TSE */
  { 0x06c4, 0x0434 }, /* Cyrillic_de д CYRILLIC SMALL LETTER DE */
  { 0x06c5, 0x0435 }, /* Cyrillic_ie е CYRILLIC SMALL LETTER IE */
  { 0x06c6, 0x0444 }, /* Cyrillic_ef ф CYRILLIC SMALL LETTER EF */
  { 0x06c7, 0x0433 }, /* Cyrillic_ghe г CYRILLIC SMALL LETTER GHE */
  { 0x06c8, 0x0445 }, /* Cyrillic_ha х CYRILLIC SMALL LETTER HA */
  { 0x06c9, 0x0438 }, /* Cyrillic_i и CYRILLIC SMALL LETTER I */
  { 0x06ca, 0x0439 }, /* Cyrillic_shorti й CYRILLIC SMALL LETTER SHORT I */
  { 0x06cb, 0x043a }, /* Cyrillic_ka к CYRILLIC SMALL LETTER KA */
  { 0x06cc, 0x043b }, /* Cyrillic_el л CYRILLIC SMALL LETTER EL */
  { 0x06cd, 0x043c }, /* Cyrillic_em м CYRILLIC SMALL LETTER EM */
  { 0x06ce, 0x043d }, /* Cyrillic_en н CYRILLIC SMALL LETTER EN */
  { 0x06cf, 0x043e }, /* Cyrillic_o о CYRILLIC SMALL LETTER O */
  { 0x06d0, 0x043f }, /* Cyrillic_pe п CYRILLIC SMALL LETTER PE */
  { 0x06d1, 0x044f }, /* Cyrillic_ya я CYRILLIC SMALL LETTER YA */
  { 0x06d2, 0x0440 }, /* Cyrillic_er р CYRILLIC SMALL LETTER ER */
  { 0x06d3, 0x0441 }, /* Cyrillic_es с CYRILLIC SMALL LETTER ES */
  { 0x06d4, 0x0442 }, /* Cyrillic_te т CYRILLIC SMALL LETTER TE */
  { 0x06d5, 0x0443 }, /* Cyrillic_u у CYRILLIC SMALL LETTER U */
  { 0x06d6, 0x0436 }, /* Cyrillic_zhe ж CYRILLIC SMALL LETTER ZHE */
  { 0x06d7, 0x0432 }, /* Cyrillic_ve в CYRILLIC SMALL LETTER VE */
  { 0x06d8, 0x044c }, /* Cyrillic_softsign ь CYRILLIC SMALL LETTER SOFT SIGN */
  { 0x06d9, 0x044b }, /* Cyrillic_yeru ы CYRILLIC SMALL LETTER YERU */
  { 0x06da, 0x0437 }, /* Cyrillic_ze з CYRILLIC SMALL LETTER ZE */
  { 0x06db, 0x0448 }, /* Cyrillic_sha ш CYRILLIC SMALL LETTER SHA */
  { 0x06dc, 0x044d }, /* Cyrillic_e э CYRILLIC SMALL LETTER E */
  { 0x06dd, 0x0449 }, /* Cyrillic_shcha щ CYRILLIC SMALL LETTER SHCHA */
  { 0x06de, 0x0447 }, /* Cyrillic_che ч CYRILLIC SMALL LETTER CHE */
  { 0x06df, 0x044a }, /* Cyrillic_hardsign ъ CYRILLIC SMALL LETTER HARD SIGN */
  { 0x06e0, 0x042e }, /* Cyrillic_YU Ю CYRILLIC CAPITAL LETTER YU */
  { 0x06e1, 0x0410 }, /* Cyrillic_A А CYRILLIC CAPITAL LETTER A */
  { 0x06e2, 0x0411 }, /* Cyrillic_BE Б CYRILLIC CAPITAL LETTER BE */
  { 0x06e3, 0x0426 }, /* Cyrillic_TSE Ц CYRILLIC CAPITAL LETTER TSE */
  { 0x06e4, 0x0414 }, /* Cyrillic_DE Д CYRILLIC CAPITAL LETTER DE */
  { 0x06e5, 0x0415 }, /* Cyrillic_IE Е CYRILLIC CAPITAL LETTER IE */
  { 0x06e6, 0x0424 }, /* Cyrillic_EF Ф CYRILLIC CAPITAL LETTER EF */
  { 0x06e7, 0x0413 }, /* Cyrillic_GHE Г CYRILLIC CAPITAL LETTER GHE */
  { 0x06e8, 0x0425 }, /* Cyrillic_HA Х CYRILLIC CAPITAL LETTER HA */
  { 0x06e9, 0x0418 }, /* Cyrillic_I И CYRILLIC CAPITAL LETTER I */
  { 0x06ea, 0x0419 }, /* Cyrillic_SHORTI Й CYRILLIC CAPITAL LETTER SHORT I */
  { 0x06eb, 0x041a }, /* Cyrillic_KA К CYRILLIC CAPITAL LETTER KA */
  { 0x06ec, 0x041b }, /* Cyrillic_EL Л CYRILLIC CAPITAL LETTER EL */
  { 0x06ed, 0x041c }, /* Cyrillic_EM М CYRILLIC CAPITAL LETTER EM */
  { 0x06ee, 0x041d }, /* Cyrillic_EN Н CYRILLIC CAPITAL LETTER EN */
  { 0x06ef, 0x041e }, /* Cyrillic_O О CYRILLIC CAPITAL LETTER O */
  { 0x06f0, 0x041f }, /* Cyrillic_PE П CYRILLIC CAPITAL LETTER PE */
  { 0x06f1, 0x042f }, /* Cyrillic_YA Я CYRILLIC CAPITAL LETTER YA */
  { 0x06f2, 0x0420 }, /* Cyrillic_ER Р CYRILLIC CAPITAL LETTER ER */
  { 0x06f3, 0x0421 }, /* Cyrillic_ES С CYRILLIC CAPITAL LETTER ES */
  { 0x06f4, 0x0422 }, /* Cyrillic_TE Т CYRILLIC CAPITAL LETTER TE */
  { 0x06f5, 0x0423 }, /* Cyrillic_U У CYRILLIC CAPITAL LETTER U */
  { 0x06f6, 0x0416 }, /* Cyrillic_ZHE Ж CYRILLIC CAPITAL LETTER ZHE */
  { 0x06f7, 0x0412 }, /* Cyrillic_VE В CYRILLIC CAPITAL LETTER VE */
  { 0x06f8, 0x042c }, /* Cyrillic_SOFTSIGN Ь CYRILLIC CAPITAL LETTER SOFT SIGN */
  { 0x06f9, 0x042b }, /* Cyrillic_YERU Ы CYRILLIC CAPITAL LETTER YERU */
  { 0x06fa, 0x0417 }, /* Cyrillic_ZE З CYRILLIC CAPITAL LETTER ZE */
  { 0x06fb, 0x0428 }, /* Cyrillic_SHA Ш CYRILLIC CAPITAL LETTER SHA */
  { 0x06fc, 0x042d }, /* Cyrillic_E Э CYRILLIC CAPITAL LETTER E */
  { 0x06fd, 0x0429 }, /* Cyrillic_SHCHA Щ CYRILLIC CAPITAL LETTER SHCHA */
  { 0x06fe, 0x0427 }, /* Cyrillic_CHE Ч CYRILLIC CAPITAL LETTER CHE */
  { 0x06ff, 0x042a }, /* Cyrillic_HARDSIGN Ъ CYRILLIC CAPITAL LETTER HARD SIGN */
  { 0x07a1, 0x0386 }, /* Greek_ALPHAaccent Ά GREEK CAPITAL LETTER ALPHA WITH TONOS */
  { 0x07a2, 0x0388 }, /* Greek_EPSILONaccent Έ GREEK CAPITAL LETTER EPSILON WITH TONOS */
  { 0x07a3, 0x0389 }, /* Greek_ETAaccent Ή GREEK CAPITAL LETTER ETA WITH TONOS */
  { 0x07a4, 0x038a }, /* Greek_IOTAaccent Ί GREEK CAPITAL LETTER IOTA WITH TONOS */
  { 0x07a5, 0x03aa }, /* Greek_IOTAdiaeresis Ϊ GREEK CAPITAL LETTER IOTA WITH DIALYTIKA */
  { 0x07a7, 0x038c }, /* Greek_OMICRONaccent Ό GREEK CAPITAL LETTER OMICRON WITH TONOS */
  { 0x07a8, 0x038e }, /* Greek_UPSILONaccent Ύ GREEK CAPITAL LETTER UPSILON WITH TONOS */
  { 0x07a9, 0x03ab }, /* Greek_UPSILONdieresis Ϋ GREEK CAPITAL LETTER UPSILON WITH DIALYTIKA */
  { 0x07ab, 0x038f }, /* Greek_OMEGAaccent Ώ GREEK CAPITAL LETTER OMEGA WITH TONOS */
  { 0x07ae, 0x0385 }, /* Greek_accentdieresis ΅ GREEK DIALYTIKA TONOS */
  { 0x07af, 0x2015 }, /* Greek_horizbar ― HORIZONTAL BAR */
  { 0x07b1, 0x03ac }, /* Greek_alphaaccent ά GREEK SMALL LETTER ALPHA WITH TONOS */
  { 0x07b2, 0x03ad }, /* Greek_epsilonaccent έ GREEK SMALL LETTER EPSILON WITH TONOS */
  { 0x07b3, 0x03ae }, /* Greek_etaaccent ή GREEK SMALL LETTER ETA WITH TONOS */
  { 0x07b4, 0x03af }, /* Greek_iotaaccent ί GREEK SMALL LETTER IOTA WITH TONOS */
  { 0x07b5, 0x03ca }, /* Greek_iotadieresis ϊ GREEK SMALL LETTER IOTA WITH DIALYTIKA */
  { 0x07b6, 0x0390 }, /* Greek_iotaaccentdieresis ΐ GREEK SMALL LETTER IOTA WITH DIALYTIKA AND TONOS */
  { 0x07b7, 0x03cc }, /* Greek_omicronaccent ό GREEK SMALL LETTER OMICRON WITH TONOS */
  { 0x07b8, 0x03cd }, /* Greek_upsilonaccent ύ GREEK SMALL LETTER UPSILON WITH TONOS */
  { 0x07b9, 0x03cb }, /* Greek_upsilondieresis ϋ GREEK SMALL LETTER UPSILON WITH DIALYTIKA */
  { 0x07ba, 0x03b0 }, /* Greek_upsilonaccentdieresis ΰ GREEK SMALL LETTER UPSILON WITH DIALYTIKA AND TONOS */
  { 0x07bb, 0x03ce }, /* Greek_omegaaccent ώ GREEK SMALL LETTER OMEGA WITH TONOS */
  { 0x07c1, 0x0391 }, /* Greek_ALPHA Α GREEK CAPITAL LETTER ALPHA */
  { 0x07c2, 0x0392 }, /* Greek_BETA Β GREEK CAPITAL LETTER BETA */
  { 0x07c3, 0x0393 }, /* Greek_GAMMA Γ GREEK CAPITAL LETTER GAMMA */
  { 0x07c4, 0x0394 }, /* Greek_DELTA Δ GREEK CAPITAL LETTER DELTA */
  { 0x07c5, 0x0395 }, /* Greek_EPSILON Ε GREEK CAPITAL LETTER EPSILON */
  { 0x07c6, 0x0396 }, /* Greek_ZETA Ζ GREEK CAPITAL LETTER ZETA */
  { 0x07c7, 0x0397 }, /* Greek_ETA Η GREEK CAPITAL LETTER ETA */
  { 0x07c8, 0x0398 }, /* Greek_THETA Θ GREEK CAPITAL LETTER THETA */
  { 0x07c9, 0x0399 }, /* Greek_IOTA Ι GREEK CAPITAL LETTER IOTA */
  { 0x07ca, 0x039a }, /* Greek_KAPPA Κ GREEK CAPITAL LETTER KAPPA */
  { 0x07cb, 0x039b }, /* Greek_LAMBDA Λ GREEK CAPITAL LETTER LAMDA */
  { 0x07cc, 0x039c }, /* Greek_MU Μ GREEK CAPITAL LETTER MU */
  { 0x07cd, 0x039d }, /* Greek_NU Ν GREEK CAPITAL LETTER NU */
  { 0x07ce, 0x039e }, /* Greek_XI Ξ GREEK CAPITAL LETTER XI */
  { 0x07cf, 0x039f }, /* Greek_OMICRON Ο GREEK CAPITAL LETTER OMICRON */
  { 0x07d0, 0x03a0 }, /* Greek_PI Π GREEK CAPITAL LETTER PI */
  { 0x07d1, 0x03a1 }, /* Greek_RHO Ρ GREEK CAPITAL LETTER RHO */
  { 0x07d2, 0x03a3 }, /* Greek_SIGMA Σ GREEK CAPITAL LETTER SIGMA */
  { 0x07d4, 0x03a4 }, /* Greek_TAU Τ GREEK CAPITAL LETTER TAU */
  { 0x07d5, 0x03a5 }, /* Greek_UPSILON Υ GREEK CAPITAL LETTER UPSILON */
  { 0x07d6, 0x03a6 }, /* Greek_PHI Φ GREEK CAPITAL LETTER PHI */
  { 0x07d7, 0x03a7 }, /* Greek_CHI Χ GREEK CAPITAL LETTER CHI */
  { 0x07d8, 0x03a8 }, /* Greek_PSI Ψ GREEK CAPITAL LETTER PSI */
  { 0x07d9, 0x03a9 }, /* Greek_OMEGA Ω GREEK CAPITAL LETTER OMEGA */
  { 0x07e1, 0x03b1 }, /* Greek_alpha α GREEK SMALL LETTER ALPHA */
  { 0x07e2, 0x03b2 }, /* Greek_beta β GREEK SMALL LETTER BETA */
  { 0x07e3, 0x03b3 }, /* Greek_gamma γ GREEK SMALL LETTER GAMMA */
  { 0x07e4, 0x03b4 }, /* Greek_delta δ GREEK SMALL LETTER DELTA */
  { 0x07e5, 0x03b5 }, /* Greek_epsilon ε GREEK SMALL LETTER EPSILON */
  { 0x07e6, 0x03b6 }, /* Greek_zeta ζ GREEK SMALL LETTER ZETA */
  { 0x07e7, 0x03b7 }, /* Greek_eta η GREEK SMALL LETTER ETA */
  { 0x07e8, 0x03b8 }, /* Greek_theta θ GREEK SMALL LETTER THETA */
  { 0x07e9, 0x03b9 }, /* Greek_iota ι GREEK SMALL LETTER IOTA */
  { 0x07ea, 0x03ba }, /* Greek_kappa κ GREEK SMALL LETTER KAPPA */
  { 0x07eb, 0x03bb }, /* Greek_lambda λ GREEK SMALL LETTER LAMDA */
  { 0x07ec, 0x03bc }, /* Greek_mu μ GREEK SMALL LETTER MU */
  { 0x07ed, 0x03bd }, /* Greek_nu ν GREEK SMALL LETTER NU */
  { 0x07ee, 0x03be }, /* Greek_xi ξ GREEK SMALL LETTER XI */
  { 0x07ef, 0x03bf }, /* Greek_omicron ο GREEK SMALL LETTER OMICRON */
  { 0x07f0, 0x03c0 }, /* Greek_pi π GREEK SMALL LETTER PI */
  { 0x07f1, 0x03c1 }, /* Greek_rho ρ GREEK SMALL LETTER RHO */
  { 0x07f2, 0x03c3 }, /* Greek_sigma σ GREEK SMALL LETTER SIGMA */
  { 0x07f3, 0x03c2 }, /* Greek_finalsmallsigma ς GREEK SMALL LETTER FINAL SIGMA */
  { 0x07f4, 0x03c4 }, /* Greek_tau τ GREEK SMALL LETTER TAU */
  { 0x07f5, 0x03c5 }, /* Greek_upsilon υ GREEK SMALL LETTER UPSILON */
  { 0x07f6, 0x03c6 }, /* Greek_phi φ GREEK SMALL LETTER PHI */
  { 0x07f7, 0x03c7 }, /* Greek_chi χ GREEK SMALL LETTER CHI */
  { 0x07f8, 0x03c8 }, /* Greek_psi ψ GREEK SMALL LETTER PSI */
  { 0x07f9, 0x03c9 }, /* Greek_omega ω GREEK SMALL LETTER OMEGA */
/* 0x08a1 leftradical ? ??? */
/* 0x08a2 topleftradical ? ??? */
/* 0x08a3 horizconnector ? ??? */
  { 0x08a4, 0x2320 }, /* topintegral ⌠ TOP HALF INTEGRAL */
  { 0x08a5, 0x2321 }, /* botintegral ⌡ BOTTOM HALF INTEGRAL */
  { 0x08a6, 0x2502 }, /* vertconnector │ BOX DRAWINGS LIGHT VERTICAL */
/* 0x08a7 topleftsqbracket ? ??? */
/* 0x08a8 botleftsqbracket ? ??? */
/* 0x08a9 toprightsqbracket ? ??? */
/* 0x08aa botrightsqbracket ? ??? */
/* 0x08ab topleftparens ? ??? */
/* 0x08ac botleftparens ? ??? */
/* 0x08ad toprightparens ? ??? */
/* 0x08ae botrightparens ? ??? */
/* 0x08af leftmiddlecurlybrace ? ??? */
/* 0x08b0 rightmiddlecurlybrace ? ??? */
/* 0x08b1 topleftsummation ? ??? */
/* 0x08b2 botleftsummation ? ??? */
/* 0x08b3 topvertsummationconnector ? ??? */
/* 0x08b4 botvertsummationconnector ? ??? */
/* 0x08b5 toprightsummation ? ??? */
/* 0x08b6 botrightsummation ? ??? */
/* 0x08b7 rightmiddlesummation ? ??? */
  { 0x08bc, 0x2264 }, /* lessthanequal ≤ LESS-THAN OR EQUAL TO */
  { 0x08bd, 0x2260 }, /* notequal ≠ NOT EQUAL TO */
  { 0x08be, 0x2265 }, /* greaterthanequal ≥ GREATER-THAN OR EQUAL TO */
  { 0x08bf, 0x222b }, /* integral ∫ INTEGRAL */
  { 0x08c0, 0x2234 }, /* therefore ∴ THEREFORE */
  { 0x08c1, 0x221d }, /* variation ∝ PROPORTIONAL TO */
  { 0x08c2, 0x221e }, /* infinity ∞ INFINITY */
  { 0x08c5, 0x2207 }, /* nabla ∇ NABLA */
  { 0x08c8, 0x2245 }, /* approximate ≅ APPROXIMATELY EQUAL TO */
/* 0x08c9 similarequal ? ??? */
  { 0x08cd, 0x21d4 }, /* ifonlyif ⇔ LEFT RIGHT DOUBLE ARROW */
  { 0x08ce, 0x21d2 }, /* implies ⇒ RIGHTWARDS DOUBLE ARROW */
  { 0x08cf, 0x2261 }, /* identical ≡ IDENTICAL TO */
  { 0x08d6, 0x221a }, /* radical √ SQUARE ROOT */
  { 0x08da, 0x2282 }, /* includedin ⊂ SUBSET OF */
  { 0x08db, 0x2283 }, /* includes ⊃ SUPERSET OF */
  { 0x08dc, 0x2229 }, /* intersection ∩ INTERSECTION */
  { 0x08dd, 0x222a }, /* union ∪ UNION */
  { 0x08de, 0x2227 }, /* logicaland ∧ LOGICAL AND */
  { 0x08df, 0x2228 }, /* logicalor ∨ LOGICAL OR */
  { 0x08ef, 0x2202 }, /* partialderivative ∂ PARTIAL DIFFERENTIAL */
  { 0x08f6, 0x0192 }, /* function ƒ LATIN SMALL LETTER F WITH HOOK */
  { 0x08fb, 0x2190 }, /* leftarrow ← LEFTWARDS ARROW */
  { 0x08fc, 0x2191 }, /* uparrow ↑ UPWARDS ARROW */
  { 0x08fd, 0x2192 }, /* rightarrow → RIGHTWARDS ARROW */
  { 0x08fe, 0x2193 }, /* downarrow ↓ DOWNWARDS ARROW */
  { 0x09df, 0x2422 }, /* blank ␢ BLANK SYMBOL */
  { 0x09e0, 0x25c6 }, /* soliddiamond ◆ BLACK DIAMOND */
  { 0x09e1, 0x2592 }, /* checkerboard ▒ MEDIUM SHADE */
  { 0x09e2, 0x2409 }, /* ht ␉ SYMBOL FOR HORIZONTAL TABULATION */
  { 0x09e3, 0x240c }, /* ff ␌ SYMBOL FOR FORM FEED */
  { 0x09e4, 0x240d }, /* cr ␍ SYMBOL FOR CARRIAGE RETURN */
  { 0x09e5, 0x240a }, /* lf ␊ SYMBOL FOR LINE FEED */
  { 0x09e8, 0x2424 }, /* nl ␤ SYMBOL FOR NEWLINE */
  { 0x09e9, 0x240b }, /* vt ␋ SYMBOL FOR VERTICAL TABULATION */
  { 0x09ea, 0x2518 }, /* lowrightcorner ┘ BOX DRAWINGS LIGHT UP AND LEFT */
  { 0x09eb, 0x2510 }, /* uprightcorner ┐ BOX DRAWINGS LIGHT DOWN AND LEFT */
  { 0x09ec, 0x250c }, /* upleftcorner ┌ BOX DRAWINGS LIGHT DOWN AND RIGHT */
  { 0x09ed, 0x2514 }, /* lowleftcorner └ BOX DRAWINGS LIGHT UP AND RIGHT */
  { 0x09ee, 0x253c }, /* crossinglines ┼ BOX DRAWINGS LIGHT VERTICAL AND HORIZONTAL */
/* 0x09ef horizlinescan1 ? ??? */
/* 0x09f0 horizlinescan3 ? ??? */
  { 0x09f1, 0x2500 }, /* horizlinescan5 ─ BOX DRAWINGS LIGHT HORIZONTAL */
/* 0x09f2 horizlinescan7 ? ??? */
/* 0x09f3 horizlinescan9 ? ??? */
  { 0x09f4, 0x251c }, /* leftt ├ BOX DRAWINGS LIGHT VERTICAL AND RIGHT */
  { 0x09f5, 0x2524 }, /* rightt ┤ BOX DRAWINGS LIGHT VERTICAL AND LEFT */
  { 0x09f6, 0x2534 }, /* bott ┴ BOX DRAWINGS LIGHT UP AND HORIZONTAL */
  { 0x09f7, 0x252c }, /* topt ┬ BOX DRAWINGS LIGHT DOWN AND HORIZONTAL */
  { 0x09f8, 0x2502 }, /* vertbar │ BOX DRAWINGS LIGHT VERTICAL */
  { 0x0aa1, 0x2003 }, /* emspace   EM SPACE */
  { 0x0aa2, 0x2002 }, /* enspace   EN SPACE */
  { 0x0aa3, 0x2004 }, /* em3space   THREE-PER-EM SPACE */
  { 0x0aa4, 0x2005 }, /* em4space   FOUR-PER-EM SPACE */
  { 0x0aa5, 0x2007 }, /* digitspace   FIGURE SPACE */
  { 0x0aa6, 0x2008 }, /* punctspace   PUNCTUATION SPACE */
  { 0x0aa7, 0x2009 }, /* thinspace   THIN SPACE */
  { 0x0aa8, 0x200a }, /* hairspace   HAIR SPACE */
  { 0x0aa9, 0x2014 }, /* emdash — EM DASH */
  { 0x0aaa, 0x2013 }, /* endash – EN DASH */
/* 0x0aac signifblank ? ??? */
  { 0x0aae, 0x2026 }, /* ellipsis … HORIZONTAL ELLIPSIS */
/* 0x0aaf doubbaselinedot ? ??? */
  { 0x0ab0, 0x2153 }, /* onethird ⅓ VULGAR FRACTION ONE THIRD */
  { 0x0ab1, 0x2154 }, /* twothirds ⅔ VULGAR FRACTION TWO THIRDS */
  { 0x0ab2, 0x2155 }, /* onefifth ⅕ VULGAR FRACTION ONE FIFTH */
  { 0x0ab3, 0x2156 }, /* twofifths ⅖ VULGAR FRACTION TWO FIFTHS */
  { 0x0ab4, 0x2157 }, /* threefifths ⅗ VULGAR FRACTION THREE FIFTHS */
  { 0x0ab5, 0x2158 }, /* fourfifths ⅘ VULGAR FRACTION FOUR FIFTHS */
  { 0x0ab6, 0x2159 }, /* onesixth ⅙ VULGAR FRACTION ONE SIXTH */
  { 0x0ab7, 0x215a }, /* fivesixths ⅚ VULGAR FRACTION FIVE SIXTHS */
  { 0x0ab8, 0x2105 }, /* careof ℅ CARE OF */
  { 0x0abb, 0x2012 }, /* figdash ‒ FIGURE DASH */
  { 0x0abc, 0x2329 }, /* leftanglebracket 〈 LEFT-POINTING ANGLE BRACKET */
  { 0x0abd, 0x002e }, /* decimalpoint . FULL STOP */
  { 0x0abe, 0x232a }, /* rightanglebracket 〉 RIGHT-POINTING ANGLE BRACKET */
/* 0x0abf marker ? ??? */
  { 0x0ac3, 0x215b }, /* oneeighth ⅛ VULGAR FRACTION ONE EIGHTH */
  { 0x0ac4, 0x215c }, /* threeeighths ⅜ VULGAR FRACTION THREE EIGHTHS */
  { 0x0ac5, 0x215d }, /* fiveeighths ⅝ VULGAR FRACTION FIVE EIGHTHS */
  { 0x0ac6, 0x215e }, /* seveneighths ⅞ VULGAR FRACTION SEVEN EIGHTHS */
  { 0x0ac9, 0x2122 }, /* trademark ™ TRADE MARK SIGN */
  { 0x0aca, 0x2613 }, /* signaturemark ☓ SALTIRE */
/* 0x0acb trademarkincircle ? ??? */
  { 0x0acc, 0x25c1 }, /* leftopentriangle ◁ WHITE LEFT-POINTING TRIANGLE */
  { 0x0acd, 0x25b7 }, /* rightopentriangle ▷ WHITE RIGHT-POINTING TRIANGLE */
  { 0x0ace, 0x25cb }, /* emopencircle ○ WHITE CIRCLE */
  { 0x0acf, 0x25a1 }, /* emopenrectangle □ WHITE SQUARE */
  { 0x0ad0, 0x2018 }, /* leftsinglequotemark ‘ LEFT SINGLE QUOTATION MARK */
  { 0x0ad1, 0x2019 }, /* rightsinglequotemark ’ RIGHT SINGLE QUOTATION MARK */
  { 0x0ad2, 0x201c }, /* leftdoublequotemark “ LEFT DOUBLE QUOTATION MARK */
  { 0x0ad3, 0x201d }, /* rightdoublequotemark ” RIGHT DOUBLE QUOTATION MARK */
  { 0x0ad4, 0x211e }, /* prescription ℞ PRESCRIPTION TAKE */
  { 0x0ad6, 0x2032 }, /* minutes ′ PRIME */
  { 0x0ad7, 0x2033 }, /* seconds ″ DOUBLE PRIME */
  { 0x0ad9, 0x271d }, /* latincross ✝ LATIN CROSS */
/* 0x0ada hexagram ? ??? */
  { 0x0adb, 0x25ac }, /* filledrectbullet ▬ BLACK RECTANGLE */
  { 0x0adc, 0x25c0 }, /* filledlefttribullet ◀ BLACK LEFT-POINTING TRIANGLE */
  { 0x0add, 0x25b6 }, /* filledrighttribullet ▶ BLACK RIGHT-POINTING TRIANGLE */
  { 0x0ade, 0x25cf }, /* emfilledcircle ● BLACK CIRCLE */
  { 0x0adf, 0x25a0 }, /* emfilledrect ■ BLACK SQUARE */
  { 0x0ae0, 0x25e6 }, /* enopencircbullet ◦ WHITE BULLET */
  { 0x0ae1, 0x25ab }, /* enopensquarebullet ▫ WHITE SMALL SQUARE */
  { 0x0ae2, 0x25ad }, /* openrectbullet ▭ WHITE RECTANGLE */
  { 0x0ae3, 0x25b3 }, /* opentribulletup △ WHITE UP-POINTING TRIANGLE */
  { 0x0ae4, 0x25bd }, /* opentribulletdown ▽ WHITE DOWN-POINTING TRIANGLE */
  { 0x0ae5, 0x2606 }, /* openstar ☆ WHITE STAR */
  { 0x0ae6, 0x2022 }, /* enfilledcircbullet • BULLET */
  { 0x0ae7, 0x25aa }, /* enfilledsqbullet ▪ BLACK SMALL SQUARE */
  { 0x0ae8, 0x25b2 }, /* filledtribulletup ▲ BLACK UP-POINTING TRIANGLE */
  { 0x0ae9, 0x25bc }, /* filledtribulletdown ▼ BLACK DOWN-POINTING TRIANGLE */
  { 0x0aea, 0x261c }, /* leftpointer ☜ WHITE LEFT POINTING INDEX */
  { 0x0aeb, 0x261e }, /* rightpointer ☞ WHITE RIGHT POINTING INDEX */
  { 0x0aec, 0x2663 }, /* club ♣ BLACK CLUB SUIT */
  { 0x0aed, 0x2666 }, /* diamond ♦ BLACK DIAMOND SUIT */
  { 0x0aee, 0x2665 }, /* heart ♥ BLACK HEART SUIT */
  { 0x0af0, 0x2720 }, /* maltesecross ✠ MALTESE CROSS */
  { 0x0af1, 0x2020 }, /* dagger † DAGGER */
  { 0x0af2, 0x2021 }, /* doubledagger ‡ DOUBLE DAGGER */
  { 0x0af3, 0x2713 }, /* checkmark ✓ CHECK MARK */
  { 0x0af4, 0x2717 }, /* ballotcross ✗ BALLOT X */
  { 0x0af5, 0x266f }, /* musicalsharp ♯ MUSIC SHARP SIGN */
  { 0x0af6, 0x266d }, /* musicalflat ♭ MUSIC FLAT SIGN */
  { 0x0af7, 0x2642 }, /* malesymbol ♂ MALE SIGN */
  { 0x0af8, 0x2640 }, /* femalesymbol ♀ FEMALE SIGN */
  { 0x0af9, 0x260e }, /* telephone ☎ BLACK TELEPHONE */
  { 0x0afa, 0x2315 }, /* telephonerecorder ⌕ TELEPHONE RECORDER */
  { 0x0afb, 0x2117 }, /* phonographcopyright ℗ SOUND RECORDING COPYRIGHT */
  { 0x0afc, 0x2038 }, /* caret ‸ CARET */
  { 0x0afd, 0x201a }, /* singlelowquotemark ‚ SINGLE LOW-9 QUOTATION MARK */
  { 0x0afe, 0x201e }, /* doublelowquotemark „ DOUBLE LOW-9 QUOTATION MARK */
/* 0x0aff cursor ? ??? */
  { 0x0ba3, 0x003c }, /* leftcaret < LESS-THAN SIGN */
  { 0x0ba6, 0x003e }, /* rightcaret > GREATER-THAN SIGN */
  { 0x0ba8, 0x2228 }, /* downcaret ∨ LOGICAL OR */
  { 0x0ba9, 0x2227 }, /* upcaret ∧ LOGICAL AND */
  { 0x0bc0, 0x00af }, /* overbar ¯ MACRON */
  { 0x0bc2, 0x22a4 }, /* downtack ⊤ DOWN TACK */
  { 0x0bc3, 0x2229 }, /* upshoe ∩ INTERSECTION */
  { 0x0bc4, 0x230a }, /* downstile ⌊ LEFT FLOOR */
  { 0x0bc6, 0x005f }, /* underbar _ LOW LINE */
  { 0x0bca, 0x2218 }, /* jot ∘ RING OPERATOR */
  { 0x0bcc, 0x2395 }, /* quad ⎕ APL FUNCTIONAL SYMBOL QUAD (Unicode 3.0) */
  { 0x0bce, 0x22a5 }, /* uptack ⊥ UP TACK */
  { 0x0bcf, 0x25cb }, /* circle ○ WHITE CIRCLE */
  { 0x0bd3, 0x2308 }, /* upstile ⌈ LEFT CEILING */
  { 0x0bd6, 0x222a }, /* downshoe ∪ UNION */
  { 0x0bd8, 0x2283 }, /* rightshoe ⊃ SUPERSET OF */
  { 0x0bda, 0x2282 }, /* leftshoe ⊂ SUBSET OF */
  { 0x0bdc, 0x22a3 }, /* lefttack ⊣ LEFT TACK */
  { 0x0bfc, 0x22a2 }, /* righttack ⊢ RIGHT TACK */
  { 0x0cdf, 0x2017 }, /* hebrew_doublelowline ‗ DOUBLE LOW LINE */
  { 0x0ce0, 0x05d0 }, /* hebrew_aleph א HEBREW LETTER ALEF */
  { 0x0ce1, 0x05d1 }, /* hebrew_bet ב HEBREW LETTER BET */
  { 0x0ce2, 0x05d2 }, /* hebrew_gimel ג HEBREW LETTER GIMEL */
  { 0x0ce3, 0x05d3 }, /* hebrew_dalet ד HEBREW LETTER DALET */
  { 0x0ce4, 0x05d4 }, /* hebrew_he ה HEBREW LETTER HE */
  { 0x0ce5, 0x05d5 }, /* hebrew_waw ו HEBREW LETTER VAV */
  { 0x0ce6, 0x05d6 }, /* hebrew_zain ז HEBREW LETTER ZAYIN */
  { 0x0ce7, 0x05d7 }, /* hebrew_chet ח HEBREW LETTER HET */
  { 0x0ce8, 0x05d8 }, /* hebrew_tet ט HEBREW LETTER TET */
  { 0x0ce9, 0x05d9 }, /* hebrew_yod י HEBREW LETTER YOD */
  { 0x0cea, 0x05da }, /* hebrew_finalkaph ך HEBREW LETTER FINAL KAF */
  { 0x0ceb, 0x05db }, /* hebrew_kaph כ HEBREW LETTER KAF */
  { 0x0cec, 0x05dc }, /* hebrew_lamed ל HEBREW LETTER LAMED */
  { 0x0ced, 0x05dd }, /* hebrew_finalmem ם HEBREW LETTER FINAL MEM */
  { 0x0cee, 0x05de }, /* hebrew_mem מ HEBREW LETTER MEM */
  { 0x0cef, 0x05df }, /* hebrew_finalnun ן HEBREW LETTER FINAL NUN */
  { 0x0cf0, 0x05e0 }, /* hebrew_nun נ HEBREW LETTER NUN */
  { 0x0cf1, 0x05e1 }, /* hebrew_samech ס HEBREW LETTER SAMEKH */
  { 0x0cf2, 0x05e2 }, /* hebrew_ayin ע HEBREW LETTER AYIN */
  { 0x0cf3, 0x05e3 }, /* hebrew_finalpe ף HEBREW LETTER FINAL PE */
  { 0x0cf4, 0x05e4 }, /* hebrew_pe פ HEBREW LETTER PE */
  { 0x0cf5, 0x05e5 }, /* hebrew_finalzade ץ HEBREW LETTER FINAL TSADI */
  { 0x0cf6, 0x05e6 }, /* hebrew_zade צ HEBREW LETTER TSADI */
  { 0x0cf7, 0x05e7 }, /* hebrew_qoph ק HEBREW LETTER QOF */
  { 0x0cf8, 0x05e8 }, /* hebrew_resh ר HEBREW LETTER RESH */
  { 0x0cf9, 0x05e9 }, /* hebrew_shin ש HEBREW LETTER SHIN */
  { 0x0cfa, 0x05ea }, /* hebrew_taw ת HEBREW LETTER TAV */
  { 0x0da1, 0x0e01 }, /* Thai_kokai ก THAI CHARACTER KO KAI */
  { 0x0da2, 0x0e02 }, /* Thai_khokhai ข THAI CHARACTER KHO KHAI */
  { 0x0da3, 0x0e03 }, /* Thai_khokhuat ฃ THAI CHARACTER KHO KHUAT */
  { 0x0da4, 0x0e04 }, /* Thai_khokhwai ค THAI CHARACTER KHO KHWAI */
  { 0x0da5, 0x0e05 }, /* Thai_khokhon ฅ THAI CHARACTER KHO KHON */
  { 0x0da6, 0x0e06 }, /* Thai_khorakhang ฆ THAI CHARACTER KHO RAKHANG */
  { 0x0da7, 0x0e07 }, /* Thai_ngongu ง THAI CHARACTER NGO NGU */
  { 0x0da8, 0x0e08 }, /* Thai_chochan จ THAI CHARACTER CHO CHAN */
  { 0x0da9, 0x0e09 }, /* Thai_choching ฉ THAI CHARACTER CHO CHING */
  { 0x0daa, 0x0e0a }, /* Thai_chochang ช THAI CHARACTER CHO CHANG */
  { 0x0dab, 0x0e0b }, /* Thai_soso ซ THAI CHARACTER SO SO */
  { 0x0dac, 0x0e0c }, /* Thai_chochoe ฌ THAI CHARACTER CHO CHOE */
  { 0x0dad, 0x0e0d }, /* Thai_yoying ญ THAI CHARACTER YO YING */
  { 0x0dae, 0x0e0e }, /* Thai_dochada ฎ THAI CHARACTER DO CHADA */
  { 0x0daf, 0x0e0f }, /* Thai_topatak ฏ THAI CHARACTER TO PATAK */
  { 0x0db0, 0x0e10 }, /* Thai_thothan ฐ THAI CHARACTER THO THAN */
  { 0x0db1, 0x0e11 }, /* Thai_thonangmontho ฑ THAI CHARACTER THO NANGMONTHO */
  { 0x0db2, 0x0e12 }, /* Thai_thophuthao ฒ THAI CHARACTER THO PHUTHAO */
  { 0x0db3, 0x0e13 }, /* Thai_nonen ณ THAI CHARACTER NO NEN */
  { 0x0db4, 0x0e14 }, /* Thai_dodek ด THAI CHARACTER DO DEK */
  { 0x0db5, 0x0e15 }, /* Thai_totao ต THAI CHARACTER TO TAO */
  { 0x0db6, 0x0e16 }, /* Thai_thothung ถ THAI CHARACTER THO THUNG */
  { 0x0db7, 0x0e17 }, /* Thai_thothahan ท THAI CHARACTER THO THAHAN */
  { 0x0db8, 0x0e18 }, /* Thai_thothong ธ THAI CHARACTER THO THONG */
  { 0x0db9, 0x0e19 }, /* Thai_nonu น THAI CHARACTER NO NU */
  { 0x0dba, 0x0e1a }, /* Thai_bobaimai บ THAI CHARACTER BO BAIMAI */
  { 0x0dbb, 0x0e1b }, /* Thai_popla ป THAI CHARACTER PO PLA */
  { 0x0dbc, 0x0e1c }, /* Thai_phophung ผ THAI CHARACTER PHO PHUNG */
  { 0x0dbd, 0x0e1d }, /* Thai_fofa ฝ THAI CHARACTER FO FA */
  { 0x0dbe, 0x0e1e }, /* Thai_phophan พ THAI CHARACTER PHO PHAN */
  { 0x0dbf, 0x0e1f }, /* Thai_fofan ฟ THAI CHARACTER FO FAN */
  { 0x0dc0, 0x0e20 }, /* Thai_phosamphao ภ THAI CHARACTER PHO SAMPHAO */
  { 0x0dc1, 0x0e21 }, /* Thai_moma ม THAI CHARACTER MO MA */
  { 0x0dc2, 0x0e22 }, /* Thai_yoyak ย THAI CHARACTER YO YAK */
  { 0x0dc3, 0x0e23 }, /* Thai_rorua ร THAI CHARACTER RO RUA */
  { 0x0dc4, 0x0e24 }, /* Thai_ru ฤ THAI CHARACTER RU */
  { 0x0dc5, 0x0e25 }, /* Thai_loling ล THAI CHARACTER LO LING */
  { 0x0dc6, 0x0e26 }, /* Thai_lu ฦ THAI CHARACTER LU */
  { 0x0dc7, 0x0e27 }, /* Thai_wowaen ว THAI CHARACTER WO WAEN */
  { 0x0dc8, 0x0e28 }, /* Thai_sosala ศ THAI CHARACTER SO SALA */
  { 0x0dc9, 0x0e29 }, /* Thai_sorusi ษ THAI CHARACTER SO RUSI */
  { 0x0dca, 0x0e2a }, /* Thai_sosua ส THAI CHARACTER SO SUA */
  { 0x0dcb, 0x0e2b }, /* Thai_hohip ห THAI CHARACTER HO HIP */
  { 0x0dcc, 0x0e2c }, /* Thai_lochula ฬ THAI CHARACTER LO CHULA */
  { 0x0dcd, 0x0e2d }, /* Thai_oang อ THAI CHARACTER O ANG */
  { 0x0dce, 0x0e2e }, /* Thai_honokhuk ฮ THAI CHARACTER HO NOKHUK */
  { 0x0dcf, 0x0e2f }, /* Thai_paiyannoi ฯ THAI CHARACTER PAIYANNOI */
  { 0x0dd0, 0x0e30 }, /* Thai_saraa ะ THAI CHARACTER SARA A */
  { 0x0dd1, 0x0e31 }, /* Thai_maihanakat ั THAI CHARACTER MAI HAN-AKAT */
  { 0x0dd2, 0x0e32 }, /* Thai_saraaa า THAI CHARACTER SARA AA */
  { 0x0dd3, 0x0e33 }, /* Thai_saraam ำ THAI CHARACTER SARA AM */
  { 0x0dd4, 0x0e34 }, /* Thai_sarai ิ THAI CHARACTER SARA I */
  { 0x0dd5, 0x0e35 }, /* Thai_saraii ี THAI CHARACTER SARA II */
  { 0x0dd6, 0x0e36 }, /* Thai_saraue ึ THAI CHARACTER SARA UE */
  { 0x0dd7, 0x0e37 }, /* Thai_sarauee ื THAI CHARACTER SARA UEE */
  { 0x0dd8, 0x0e38 }, /* Thai_sarau ุ THAI CHARACTER SARA U */
  { 0x0dd9, 0x0e39 }, /* Thai_sarauu ู THAI CHARACTER SARA UU */
  { 0x0dda, 0x0e3a }, /* Thai_phinthu ฺ THAI CHARACTER PHINTHU */
  { 0x0dde, 0x0e3e }, /* Thai_maihanakat_maitho ฾ ??? */
  { 0x0ddf, 0x0e3f }, /* Thai_baht ฿ THAI CURRENCY SYMBOL BAHT */
  { 0x0de0, 0x0e40 }, /* Thai_sarae เ THAI CHARACTER SARA E */
  { 0x0de1, 0x0e41 }, /* Thai_saraae แ THAI CHARACTER SARA AE */
  { 0x0de2, 0x0e42 }, /* Thai_sarao โ THAI CHARACTER SARA O */
  { 0x0de3, 0x0e43 }, /* Thai_saraaimaimuan ใ THAI CHARACTER SARA AI MAIMUAN */
  { 0x0de4, 0x0e44 }, /* Thai_saraaimaimalai ไ THAI CHARACTER SARA AI MAIMALAI */
  { 0x0de5, 0x0e45 }, /* Thai_lakkhangyao ๅ THAI CHARACTER LAKKHANGYAO */
  { 0x0de6, 0x0e46 }, /* Thai_maiyamok ๆ THAI CHARACTER MAIYAMOK */
  { 0x0de7, 0x0e47 }, /* Thai_maitaikhu ็ THAI CHARACTER MAITAIKHU */
  { 0x0de8, 0x0e48 }, /* Thai_maiek ่ THAI CHARACTER MAI EK */
  { 0x0de9, 0x0e49 }, /* Thai_maitho ้ THAI CHARACTER MAI THO */
  { 0x0dea, 0x0e4a }, /* Thai_maitri ๊ THAI CHARACTER MAI TRI */
  { 0x0deb, 0x0e4b }, /* Thai_maichattawa ๋ THAI CHARACTER MAI CHATTAWA */
  { 0x0dec, 0x0e4c }, /* Thai_thanthakhat ์ THAI CHARACTER THANTHAKHAT */
  { 0x0ded, 0x0e4d }, /* Thai_nikhahit ํ THAI CHARACTER NIKHAHIT */
  { 0x0df0, 0x0e50 }, /* Thai_leksun ๐ THAI DIGIT ZERO */
  { 0x0df1, 0x0e51 }, /* Thai_leknung ๑ THAI DIGIT ONE */
  { 0x0df2, 0x0e52 }, /* Thai_leksong ๒ THAI DIGIT TWO */
  { 0x0df3, 0x0e53 }, /* Thai_leksam ๓ THAI DIGIT THREE */
  { 0x0df4, 0x0e54 }, /* Thai_leksi ๔ THAI DIGIT FOUR */
  { 0x0df5, 0x0e55 }, /* Thai_lekha ๕ THAI DIGIT FIVE */
  { 0x0df6, 0x0e56 }, /* Thai_lekhok ๖ THAI DIGIT SIX */
  { 0x0df7, 0x0e57 }, /* Thai_lekchet ๗ THAI DIGIT SEVEN */
  { 0x0df8, 0x0e58 }, /* Thai_lekpaet ๘ THAI DIGIT EIGHT */
  { 0x0df9, 0x0e59 }, /* Thai_lekkao ๙ THAI DIGIT NINE */
  { 0x0ea1, 0x3131 }, /* Hangul_Kiyeog ㄱ HANGUL LETTER KIYEOK */
  { 0x0ea2, 0x3132 }, /* Hangul_SsangKiyeog ㄲ HANGUL LETTER SSANGKIYEOK */
  { 0x0ea3, 0x3133 }, /* Hangul_KiyeogSios ㄳ HANGUL LETTER KIYEOK-SIOS */
  { 0x0ea4, 0x3134 }, /* Hangul_Nieun ㄴ HANGUL LETTER NIEUN */
  { 0x0ea5, 0x3135 }, /* Hangul_NieunJieuj ㄵ HANGUL LETTER NIEUN-CIEUC */
  { 0x0ea6, 0x3136 }, /* Hangul_NieunHieuh ㄶ HANGUL LETTER NIEUN-HIEUH */
  { 0x0ea7, 0x3137 }, /* Hangul_Dikeud ㄷ HANGUL LETTER TIKEUT */
  { 0x0ea8, 0x3138 }, /* Hangul_SsangDikeud ㄸ HANGUL LETTER SSANGTIKEUT */
  { 0x0ea9, 0x3139 }, /* Hangul_Rieul ㄹ HANGUL LETTER RIEUL */
  { 0x0eaa, 0x313a }, /* Hangul_RieulKiyeog ㄺ HANGUL LETTER RIEUL-KIYEOK */
  { 0x0eab, 0x313b }, /* Hangul_RieulMieum ㄻ HANGUL LETTER RIEUL-MIEUM */
  { 0x0eac, 0x313c }, /* Hangul_RieulPieub ㄼ HANGUL LETTER RIEUL-PIEUP */
  { 0x0ead, 0x313d }, /* Hangul_RieulSios ㄽ HANGUL LETTER RIEUL-SIOS */
  { 0x0eae, 0x313e }, /* Hangul_RieulTieut ㄾ HANGUL LETTER RIEUL-THIEUTH */
  { 0x0eaf, 0x313f }, /* Hangul_RieulPhieuf ㄿ HANGUL LETTER RIEUL-PHIEUPH */
  { 0x0eb0, 0x3140 }, /* Hangul_RieulHieuh ㅀ HANGUL LETTER RIEUL-HIEUH */
  { 0x0eb1, 0x3141 }, /* Hangul_Mieum ㅁ HANGUL LETTER MIEUM */
  { 0x0eb2, 0x3142 }, /* Hangul_Pieub ㅂ HANGUL LETTER PIEUP */
  { 0x0eb3, 0x3143 }, /* Hangul_SsangPieub ㅃ HANGUL LETTER SSANGPIEUP */
  { 0x0eb4, 0x3144 }, /* Hangul_PieubSios ㅄ HANGUL LETTER PIEUP-SIOS */
  { 0x0eb5, 0x3145 }, /* Hangul_Sios ㅅ HANGUL LETTER SIOS */
  { 0x0eb6, 0x3146 }, /* Hangul_SsangSios ㅆ HANGUL LETTER SSANGSIOS */
  { 0x0eb7, 0x3147 }, /* Hangul_Ieung ㅇ HANGUL LETTER IEUNG */
  { 0x0eb8, 0x3148 }, /* Hangul_Jieuj ㅈ HANGUL LETTER CIEUC */
  { 0x0eb9, 0x3149 }, /* Hangul_SsangJieuj ㅉ HANGUL LETTER SSANGCIEUC */
  { 0x0eba, 0x314a }, /* Hangul_Cieuc ㅊ HANGUL LETTER CHIEUCH */
  { 0x0ebb, 0x314b }, /* Hangul_Khieuq ㅋ HANGUL LETTER KHIEUKH */
  { 0x0ebc, 0x314c }, /* Hangul_Tieut ㅌ HANGUL LETTER THIEUTH */
  { 0x0ebd, 0x314d }, /* Hangul_Phieuf ㅍ HANGUL LETTER PHIEUPH */
  { 0x0ebe, 0x314e }, /* Hangul_Hieuh ㅎ HANGUL LETTER HIEUH */
  { 0x0ebf, 0x314f }, /* Hangul_A ㅏ HANGUL LETTER A */
  { 0x0ec0, 0x3150 }, /* Hangul_AE ㅐ HANGUL LETTER AE */
  { 0x0ec1, 0x3151 }, /* Hangul_YA ㅑ HANGUL LETTER YA */
  { 0x0ec2, 0x3152 }, /* Hangul_YAE ㅒ HANGUL LETTER YAE */
  { 0x0ec3, 0x3153 }, /* Hangul_EO ㅓ HANGUL LETTER EO */
  { 0x0ec4, 0x3154 }, /* Hangul_E ㅔ HANGUL LETTER E */
  { 0x0ec5, 0x3155 }, /* Hangul_YEO ㅕ HANGUL LETTER YEO */
  { 0x0ec6, 0x3156 }, /* Hangul_YE ㅖ HANGUL LETTER YE */
  { 0x0ec7, 0x3157 }, /* Hangul_O ㅗ HANGUL LETTER O */
  { 0x0ec8, 0x3158 }, /* Hangul_WA ㅘ HANGUL LETTER WA */
  { 0x0ec9, 0x3159 }, /* Hangul_WAE ㅙ HANGUL LETTER WAE */
  { 0x0eca, 0x315a }, /* Hangul_OE ㅚ HANGUL LETTER OE */
  { 0x0ecb, 0x315b }, /* Hangul_YO ㅛ HANGUL LETTER YO */
  { 0x0ecc, 0x315c }, /* Hangul_U ㅜ HANGUL LETTER U */
  { 0x0ecd, 0x315d }, /* Hangul_WEO ㅝ HANGUL LETTER WEO */
  { 0x0ece, 0x315e }, /* Hangul_WE ㅞ HANGUL LETTER WE */
  { 0x0ecf, 0x315f }, /* Hangul_WI ㅟ HANGUL LETTER WI */
  { 0x0ed0, 0x3160 }, /* Hangul_YU ㅠ HANGUL LETTER YU */
  { 0x0ed1, 0x3161 }, /* Hangul_EU ㅡ HANGUL LETTER EU */
  { 0x0ed2, 0x3162 }, /* Hangul_YI ㅢ HANGUL LETTER YI */
  { 0x0ed3, 0x3163 }, /* Hangul_I ㅣ HANGUL LETTER I */
  { 0x0ed4, 0x11a8 }, /* Hangul_J_Kiyeog ᆨ HANGUL JONGSEONG KIYEOK */
  { 0x0ed5, 0x11a9 }, /* Hangul_J_SsangKiyeog ᆩ HANGUL JONGSEONG SSANGKIYEOK */
  { 0x0ed6, 0x11aa }, /* Hangul_J_KiyeogSios ᆪ HANGUL JONGSEONG KIYEOK-SIOS */
  { 0x0ed7, 0x11ab }, /* Hangul_J_Nieun ᆫ HANGUL JONGSEONG NIEUN */
  { 0x0ed8, 0x11ac }, /* Hangul_J_NieunJieuj ᆬ HANGUL JONGSEONG NIEUN-CIEUC */
  { 0x0ed9, 0x11ad }, /* Hangul_J_NieunHieuh ᆭ HANGUL JONGSEONG NIEUN-HIEUH */
  { 0x0eda, 0x11ae }, /* Hangul_J_Dikeud ᆮ HANGUL JONGSEONG TIKEUT */
  { 0x0edb, 0x11af }, /* Hangul_J_Rieul ᆯ HANGUL JONGSEONG RIEUL */
  { 0x0edc, 0x11b0 }, /* Hangul_J_RieulKiyeog ᆰ HANGUL JONGSEONG RIEUL-KIYEOK */
  { 0x0edd, 0x11b1 }, /* Hangul_J_RieulMieum ᆱ HANGUL JONGSEONG RIEUL-MIEUM */
  { 0x0ede, 0x11b2 }, /* Hangul_J_RieulPieub ᆲ HANGUL JONGSEONG RIEUL-PIEUP */
  { 0x0edf, 0x11b3 }, /* Hangul_J_RieulSios ᆳ HANGUL JONGSEONG RIEUL-SIOS */
  { 0x0ee0, 0x11b4 }, /* Hangul_J_RieulTieut ᆴ HANGUL JONGSEONG RIEUL-THIEUTH */
  { 0x0ee1, 0x11b5 }, /* Hangul_J_RieulPhieuf ᆵ HANGUL JONGSEONG RIEUL-PHIEUPH */
  { 0x0ee2, 0x11b6 }, /* Hangul_J_RieulHieuh ᆶ HANGUL JONGSEONG RIEUL-HIEUH */
  { 0x0ee3, 0x11b7 }, /* Hangul_J_Mieum ᆷ HANGUL JONGSEONG MIEUM */
  { 0x0ee4, 0x11b8 }, /* Hangul_J_Pieub ᆸ HANGUL JONGSEONG PIEUP */
  { 0x0ee5, 0x11b9 }, /* Hangul_J_PieubSios ᆹ HANGUL JONGSEONG PIEUP-SIOS */
  { 0x0ee6, 0x11ba }, /* Hangul_J_Sios ᆺ HANGUL JONGSEONG SIOS */
  { 0x0ee7, 0x11bb }, /* Hangul_J_SsangSios ᆻ HANGUL JONGSEONG SSANGSIOS */
  { 0x0ee8, 0x11bc }, /* Hangul_J_Ieung ᆼ HANGUL JONGSEONG IEUNG */
  { 0x0ee9, 0x11bd }, /* Hangul_J_Jieuj ᆽ HANGUL JONGSEONG CIEUC */
  { 0x0eea, 0x11be }, /* Hangul_J_Cieuc ᆾ HANGUL JONGSEONG CHIEUCH */
  { 0x0eeb, 0x11bf }, /* Hangul_J_Khieuq ᆿ HANGUL JONGSEONG KHIEUKH */
  { 0x0eec, 0x11c0 }, /* Hangul_J_Tieut ᇀ HANGUL JONGSEONG THIEUTH */
  { 0x0eed, 0x11c1 }, /* Hangul_J_Phieuf ᇁ HANGUL JONGSEONG PHIEUPH */
  { 0x0eee, 0x11c2 }, /* Hangul_J_Hieuh ᇂ HANGUL JONGSEONG HIEUH */
  { 0x0eef, 0x316d }, /* Hangul_RieulYeorinHieuh ㅭ HANGUL LETTER RIEUL-YEORINHIEUH */
  { 0x0ef0, 0x3171 }, /* Hangul_SunkyeongeumMieum ㅱ HANGUL LETTER KAPYEOUNMIEUM */
  { 0x0ef1, 0x3178 }, /* Hangul_SunkyeongeumPieub ㅸ HANGUL LETTER KAPYEOUNPIEUP */
  { 0x0ef2, 0x317f }, /* Hangul_PanSios ㅿ HANGUL LETTER PANSIOS */
/* 0x0ef3 Hangul_KkogjiDalrinIeung ? ??? */
  { 0x0ef4, 0x3184 }, /* Hangul_SunkyeongeumPhieuf ㆄ HANGUL LETTER KAPYEOUNPHIEUPH */
  { 0x0ef5, 0x3186 }, /* Hangul_YeorinHieuh ㆆ HANGUL LETTER YEORINHIEUH */
  { 0x0ef6, 0x318d }, /* Hangul_AraeA ㆍ HANGUL LETTER ARAEA */
  { 0x0ef7, 0x318e }, /* Hangul_AraeAE ㆎ HANGUL LETTER ARAEAE */
  { 0x0ef8, 0x11eb }, /* Hangul_J_PanSios ᇫ HANGUL JONGSEONG PANSIOS */
/* 0x0ef9 Hangul_J_KkogjiDalrinIeung ? ??? */
  { 0x0efa, 0x11f9 }, /* Hangul_J_YeorinHieuh ᇹ HANGUL JONGSEONG YEORINHIEUH */
  { 0x0eff, 0x20a9 }, /* Korean_Won ₩ WON SIGN */
  { 0x13bc, 0x0152 }, /* OE Œ LATIN CAPITAL LIGATURE OE */
  { 0x13bd, 0x0153 }, /* oe œ LATIN SMALL LIGATURE OE */
  { 0x13be, 0x0178 }, /* Ydiaeresis Ÿ LATIN CAPITAL LETTER Y WITH DIAERESIS */
  { 0x20a0, 0x20a0 }, /* EcuSign ₠ EURO-CURRENCY SIGN */
  { 0x20a1, 0x20a1 }, /* ColonSign ₡ COLON SIGN */
  { 0x20a2, 0x20a2 }, /* CruzeiroSign ₢ CRUZEIRO SIGN */
  { 0x20a3, 0x20a3 }, /* FFrancSign ₣ FRENCH FRANC SIGN */
  { 0x20a4, 0x20a4 }, /* LiraSign ₤ LIRA SIGN */
  { 0x20a5, 0x20a5 }, /* MillSign ₥ MILL SIGN */
  { 0x20a6, 0x20a6 }, /* NairaSign ₦ NAIRA SIGN */
  { 0x20a7, 0x20a7 }, /* PesetaSign ₧ PESETA SIGN */
  { 0x20a8, 0x20a8 }, /* RupeeSign ₨ RUPEE SIGN */
  { 0x20a9, 0x20a9 }, /* WonSign ₩ WON SIGN */
  { 0x20aa, 0x20aa }, /* NewSheqelSign ₪ NEW SHEQEL SIGN */
  { 0x20ab, 0x20ab }, /* DongSign ₫ DONG SIGN */
  { 0x20ac, 0x20ac }, /* EuroSign € EURO SIGN */
};

/** END KEYSYMTAB **/


static x_keyboard_t *x_keyboard;

#endif
#ifdef GFX_FB
static int      x_bpl;
static uint32_t *x_image;
static uint8_t  *fb_mem;
static int      fb_fd;
static int      gfrot;


static int McursorX, McursorY;
static struct termios tty_settings;
static int tty_settings_valid;


static int RAWIfd_kb, RAWIfd_mo;
static kbmap_t kbmap[256];


static int mouse_proto;
static char *kb_device, *mo_device;
static int gfx_m_minx, gfx_m_miny, gfx_m_maxx, gfx_m_maxy,
           gfx_m_xresol, gfx_m_yresol;

#endif
#ifdef GFX_ANDROID

static app_t *my_app;
void (*gfx_app_stop)();


/***********************************************************************
 *##C                                                                  *
 *                          Application Init                           *
 *                                                                     *
 ***********************************************************************
  During the initialization, we need to do the following:
   - create a pipe for the asynchronous messages coming in
   - create a mutex and a condition variable for protecting shared memory
   - create a worker thread

  The onCreate function is the entry point from the Java world. We 
  initialize the 'activity' object with the system event handler functions.
 ***********************************************************************/


static uint32_t *Gpixels;
static int display_dpi;

#endif

 // On Android, these are constants
#ifndef GFX_ANDROID
static uint32_t x_red_mask, x_red_shift,
                x_green_mask, x_green_shift,
                x_blue_mask, x_blue_shift;
#endif
static int      x_window_width, x_window_height;
static uint32_t **x_image_data;


static file_monitor_t fmon[100]; // safe limit, I guess
static int n_fmon;


static widget_t *widgets[_XX_WIDGETS_END];


static screen_t *screen; // top of the stack


static int screen_op_count;

#define STB_TRUETYPE_IMPLEMENTATION
#define STBTT_STATIC      

// stb_truetype.h - v1.21 - public domain
// authored from 2009-2016 by Sean Barrett / RAD Game Tools
//
//   This library processes TrueType files:
//        parse files
//        extract glyph metrics
//        extract glyph shapes
//        render glyphs to one-channel bitmaps with antialiasing (box filter)
//        render glyphs to one-channel SDF bitmaps (signed-distance field/function)
//
//   Todo:
//        non-MS cmaps
//        crashproof on bad data
//        hinting? (no longer patented)
//        cleartype-style AA?
//        optimize: use simple memory allocator for intermediates
//        optimize: build edge-list directly from curves
//        optimize: rasterize directly from curves?
//
// ADDITIONAL CONTRIBUTORS
//
//   Mikko Mononen: compound shape support, more cmap formats
//   Tor Andersson: kerning, subpixel rendering
//   Dougall Johnson: OpenType / Type 2 font handling
//   Daniel Ribeiro Maciel: basic GPOS-based kerning
//
//   Misc other:
//       Ryan Gordon
//       Simon Glass
//       github:IntellectualKitty
//       Imanol Celaya
//       Daniel Ribeiro Maciel
//
//   Bug/warning reports/fixes:
//       "Zer" on mollyrocket       Fabian "ryg" Giesen
//       Cass Everitt               Martins Mozeiko
//       stoiko (Haemimont Games)   Cap Petschulat
//       Brian Hook                 Omar Cornut
//       Walter van Niftrik         github:aloucks
//       David Gow                  Peter LaValle
//       David Given                Sergey Popov
//       Ivan-Assen Ivanov          Giumo X. Clanjor
//       Anthony Pesch              Higor Euripedes
//       Johan Duparc               Thomas Fields
//       Hou Qiming                 Derek Vinyard
//       Rob Loach                  Cort Stratton
//       Kenney Phillis Jr.         github:oyvindjam
//       Brian Costabile            github:vassvik
//       
// VERSION HISTORY
//
//   1.21 (2019-02-25) fix warning
//   1.20 (2019-02-07) PackFontRange skips missing codepoints; GetScaleFontVMetrics()
//   1.19 (2018-02-11) GPOS kerning, STBTT_fmod
//   1.18 (2018-01-29) add missing function
//   1.17 (2017-07-23) make more arguments const; doc fix
//   1.16 (2017-07-12) SDF support
//   1.15 (2017-03-03) make more arguments const
//   1.14 (2017-01-16) num-fonts-in-TTC function
//   1.13 (2017-01-02) support OpenType fonts, certain Apple fonts
//   1.12 (2016-10-25) suppress warnings about casting away const with -Wcast-qual
//   1.11 (2016-04-02) fix unused-variable warning
//   1.10 (2016-04-02) user-defined fabs(); rare memory leak; remove duplicate typedef
//   1.09 (2016-01-16) warning fix; avoid crash on outofmem; use allocation userdata properly
//   1.08 (2015-09-13) document stbtt_Rasterize(); fixes for vertical & horizontal edges
//   1.07 (2015-08-01) allow PackFontRanges to accept arrays of sparse codepoints;
//                     variant PackFontRanges to pack and render in separate phases;
//                     fix stbtt_GetFontOFfsetForIndex (never worked for non-0 input?);
//                     fixed an assert() bug in the new rasterizer
//                     replace assert() with STBTT_assert() in new rasterizer
//
//   Full history can be found at the end of this file.
//
// LICENSE
//
//   See end of file for license information.
//
// USAGE
//
//   Include this file in whatever places need to refer to it. In ONE C/C++
//   file, write:
//      #define STB_TRUETYPE_IMPLEMENTATION
//   before the #include of this file. This expands out the actual
//   implementation into that C/C++ file.
//
//   To make the implementation private to the file that generates the implementation,
//      #define STBTT_STATIC
//
//   Simple 3D API (don't ship this, but it's fine for tools and quick start)
//           stbtt_BakeFontBitmap()               -- bake a font to a bitmap for use as texture
//           stbtt_GetBakedQuad()                 -- compute quad to draw for a given char
//
//   Improved 3D API (more shippable):
//           #include "stb_rect_pack.h"           -- optional, but you really want it
//           stbtt_PackBegin()
//           stbtt_PackSetOversampling()          -- for improved quality on small fonts
//           stbtt_PackFontRanges()               -- pack and renders
//           stbtt_PackEnd()
//           stbtt_GetPackedQuad()
//
//   "Load" a font file from a memory buffer (you have to keep the buffer loaded)
//           stbtt_InitFont()
//           stbtt_GetFontOffsetForIndex()        -- indexing for TTC font collections
//           stbtt_GetNumberOfFonts()             -- number of fonts for TTC font collections
//
//   Render a unicode codepoint to a bitmap
//           stbtt_GetCodepointBitmap()           -- allocates and returns a bitmap
//           stbtt_MakeCodepointBitmap()          -- renders into bitmap you provide
//           stbtt_GetCodepointBitmapBox()        -- how big the bitmap must be
//
//   Character advance/positioning
//           stbtt_GetCodepointHMetrics()
//           stbtt_GetFontVMetrics()
//           stbtt_GetFontVMetricsOS2()
//           stbtt_GetCodepointKernAdvance()
//
//   Starting with version 1.06, the rasterizer was replaced with a new,
//   faster and generally-more-precise rasterizer. The new rasterizer more
//   accurately measures pixel coverage for anti-aliasing, except in the case
//   where multiple shapes overlap, in which case it overestimates the AA pixel
//   coverage. Thus, anti-aliasing of intersecting shapes may look wrong. If
//   this turns out to be a problem, you can re-enable the old rasterizer with
//        #define STBTT_RASTERIZER_VERSION 1
//   which will incur about a 15% speed hit.
//
// ADDITIONAL DOCUMENTATION
//
//   Immediately after this block comment are a series of sample programs.
//
//   After the sample programs is the "header file" section. This section
//   includes documentation for each API function.
//
//   Some important concepts to understand to use this library:
//
//      Codepoint
//         Characters are defined by unicode codepoints, e.g. 65 is
//         uppercase A, 231 is lowercase c with a cedilla, 0x7e30 is
//         the hiragana for "ma".
//
//      Glyph
//         A visual character shape (every codepoint is rendered as
//         some glyph)
//
//      Glyph index
//         A font-specific integer ID representing a glyph
//
//      Baseline
//         Glyph shapes are defined relative to a baseline, which is the
//         bottom of uppercase characters. Characters extend both above
//         and below the baseline.
//
//      Current Point
//         As you draw text to the screen, you keep track of a "current point"
//         which is the origin of each character. The current point's vertical
//         position is the baseline. Even "baked fonts" use this model.
//
//      Vertical Font Metrics
//         The vertical qualities of the font, used to vertically position
//         and space the characters. See docs for stbtt_GetFontVMetrics.
//
//      Font Size in Pixels or Points
//         The preferred interface for specifying font sizes in stb_truetype
//         is to specify how tall the font's vertical extent should be in pixels.
//         If that sounds good enough, skip the next paragraph.
//
//         Most font APIs instead use "points", which are a common typographic
//         measurement for describing font size, defined as 72 points per inch.
//         stb_truetype provides a point API for compatibility. However, true
//         "per inch" conventions don't make much sense on computer displays
//         since different monitors have different number of pixels per
//         inch. For example, Windows traditionally uses a convention that
//         there are 96 pixels per inch, thus making 'inch' measurements have
//         nothing to do with inches, and thus effectively defining a point to
//         be 1.333 pixels. Additionally, the TrueType font data provides
//         an explicit scale factor to scale a given font's glyphs to points,
//         but the author has observed that this scale factor is often wrong
//         for non-commercial fonts, thus making fonts scaled in points
//         according to the TrueType spec incoherently sized in practice.
//
// DETAILED USAGE:
//
//  Scale:
//    Select how high you want the font to be, in points or pixels.
//    Call ScaleForPixelHeight or ScaleForMappingEmToPixels to compute
//    a scale factor SF that will be used by all other functions.
//
//  Baseline:
//    You need to select a y-coordinate that is the baseline of where
//    your text will appear. Call GetFontBoundingBox to get the baseline-relative
//    bounding box for all characters. SF*-y0 will be the distance in pixels
//    that the worst-case character could extend above the baseline, so if
//    you want the top edge of characters to appear at the top of the
//    screen where y=0, then you would set the baseline to SF*-y0.
//
//  Current point:
//    Set the current point where the first character will appear. The
//    first character could extend left of the current point; this is font
//    dependent. You can either choose a current point that is the leftmost
//    point and hope, or add some padding, or check the bounding box or
//    left-side-bearing of the first character to be displayed and set
//    the current point based on that.
//
//  Displaying a character:
//    Compute the bounding box of the character. It will contain signed values
//    relative to <current_point, baseline>. I.e. if it returns x0,y0,x1,y1,
//    then the character should be displayed in the rectangle from
//    <current_point+SF*x0, baseline+SF*y0> to <current_point+SF*x1,baseline+SF*y1).
//
//  Advancing for the next character:
//    Call GlyphHMetrics, and compute 'current_point += SF * advance'.
// 
//
// ADVANCED USAGE
//
//   Quality:
//
//    - Use the functions with Subpixel at the end to allow your characters
//      to have subpixel positioning. Since the font is anti-aliased, not
//      hinted, this is very import for quality. (This is not possible with
//      baked fonts.)
//
//    - Kerning is now supported, and if you're supporting subpixel rendering
//      then kerning is worth using to give your text a polished look.
//
//   Performance:
//
//    - Convert Unicode codepoints to glyph indexes and operate on the glyphs;
//      if you don't do this, stb_truetype is forced to do the conversion on
//      every call.
//
//    - There are a lot of memory allocations. We should modify it to take
//      a temp buffer and allocate from the temp buffer (without freeing),
//      should help performance a lot.
//
// NOTES
//
//   The system uses the raw data found in the .ttf file without changing it
//   and without building auxiliary data structures. This is a bit inefficient
//   on little-endian systems (the data is big-endian), but assuming you're
//   caching the bitmaps or glyph shapes this shouldn't be a big deal.
//
//   It appears to be very hard to programmatically determine what font a
//   given file is in a general way. I provide an API for this, but I don't
//   recommend it.
//
//
// PERFORMANCE MEASUREMENTS FOR 1.06:
//
//                      32-bit     64-bit
//   Previous release:  8.83 s     7.68 s
//   Pool allocations:  7.72 s     6.34 s
//   Inline sort     :  6.54 s     5.65 s
//   New rasterizer  :  5.63 s     5.00 s

//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////
////
////  SAMPLE PROGRAMS
////
//
//  Incomplete text-in-3d-api example, which draws quads properly aligned to be lossless
//
#if 0
#define STB_TRUETYPE_IMPLEMENTATION  // force following include to generate implementation
#include "stb_truetype.h"

unsigned char ttf_buffer[1<<20];
unsigned char temp_bitmap[512*512];

stbtt_bakedchar cdata[96]; // ASCII 32..126 is 95 glyphs
GLuint ftex;

void my_stbtt_initfont(void)
{
   fread(ttf_buffer, 1, 1<<20, fopen("c:/windows/fonts/times.ttf", "rb"));
   stbtt_BakeFontBitmap(ttf_buffer,0, 32.0, temp_bitmap,512,512, 32,96, cdata); // no guarantee this fits!
   // can free ttf_buffer at this point
   glGenTextures(1, &ftex);
   glBindTexture(GL_TEXTURE_2D, ftex);
   glTexImage2D(GL_TEXTURE_2D, 0, GL_ALPHA, 512,512, 0, GL_ALPHA, GL_UNSIGNED_BYTE, temp_bitmap);
   // can free temp_bitmap at this point
   glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
}

void my_stbtt_print(float x, float y, char *text)
{
   // assume orthographic projection with units = screen pixels, origin at top left
   glEnable(GL_TEXTURE_2D);
   glBindTexture(GL_TEXTURE_2D, ftex);
   glBegin(GL_QUADS);
   while (*text) {
      if (*text >= 32 && *text < 128) {
         stbtt_aligned_quad q;
         stbtt_GetBakedQuad(cdata, 512,512, *text-32, &x,&y,&q,1);//1=opengl & d3d10+,0=d3d9
         glTexCoord2f(q.s0,q.t1); glVertex2f(q.x0,q.y0);
         glTexCoord2f(q.s1,q.t1); glVertex2f(q.x1,q.y0);
         glTexCoord2f(q.s1,q.t0); glVertex2f(q.x1,q.y1);
         glTexCoord2f(q.s0,q.t0); glVertex2f(q.x0,q.y1);
      }
      ++text;
   }
   glEnd();
}
#endif
//
//
//////////////////////////////////////////////////////////////////////////////
//
// Complete program (this compiles): get a single bitmap, print as ASCII art
//
#if 0
#include <stdio.h>
#define STB_TRUETYPE_IMPLEMENTATION  // force following include to generate implementation
#include "stb_truetype.h"

char ttf_buffer[1<<25];

int main(int argc, char **argv)
{
   stbtt_fontinfo font;
   unsigned char *bitmap;
   int w,h,i,j,c = (argc > 1 ? atoi(argv[1]) : 'a'), s = (argc > 2 ? atoi(argv[2]) : 20);

   fread(ttf_buffer, 1, 1<<25, fopen(argc > 3 ? argv[3] : "c:/windows/fonts/arialbd.ttf", "rb"));

   stbtt_InitFont(&font, ttf_buffer, stbtt_GetFontOffsetForIndex(ttf_buffer,0));
   bitmap = stbtt_GetCodepointBitmap(&font, 0,stbtt_ScaleForPixelHeight(&font, s), c, &w, &h, 0,0);

   for (j=0; j < h; ++j) {
      for (i=0; i < w; ++i)
         putchar(" .:ioVM@"[bitmap[j*w+i]>>5]);
      putchar('\n');
   }
   return 0;
}
#endif 
//
// Output:
//
//     .ii.
//    @@@@@@.
//   V@Mio@@o
//   :i.  V@V
//     :oM@@M
//   :@@@MM@M
//   @@o  o@M
//  :@@.  M@M
//   @@@o@@@@
//   :M@@V:@@.
//  
//////////////////////////////////////////////////////////////////////////////
// 
// Complete program: print "Hello World!" banner, with bugs
//
#if 0
char buffer[24<<20];
unsigned char screen[20][79];

int main(int arg, char **argv)
{
   stbtt_fontinfo font;
   int i,j,ascent,baseline,ch=0;
   float scale, xpos=2; // leave a little padding in case the character extends left
   char *text = "Heljo World!"; // intentionally misspelled to show 'lj' brokenness

   fread(buffer, 1, 1000000, fopen("c:/windows/fonts/arialbd.ttf", "rb"));
   stbtt_InitFont(&font, buffer, 0);

   scale = stbtt_ScaleForPixelHeight(&font, 15);
   stbtt_GetFontVMetrics(&font, &ascent,0,0);
   baseline = (int) (ascent*scale);

   while (text[ch]) {
      int advance,lsb,x0,y0,x1,y1;
      float x_shift = xpos - (float) floor(xpos);
      stbtt_GetCodepointHMetrics(&font, text[ch], &advance, &lsb);
      stbtt_GetCodepointBitmapBoxSubpixel(&font, text[ch], scale,scale,x_shift,0, &x0,&y0,&x1,&y1);
      stbtt_MakeCodepointBitmapSubpixel(&font, &screen[baseline + y0][(int) xpos + x0], x1-x0,y1-y0, 79, scale,scale,x_shift,0, text[ch]);
      // note that this stomps the old data, so where character boxes overlap (e.g. 'lj') it's wrong
      // because this API is really for baking character bitmaps into textures. if you want to render
      // a sequence of characters, you really need to render each bitmap to a temp buffer, then
      // "alpha blend" that into the working buffer
      xpos += (advance * scale);
      if (text[ch+1])
         xpos += scale*stbtt_GetCodepointKernAdvance(&font, text[ch],text[ch+1]);
      ++ch;
   }

   for (j=0; j < 20; ++j) {
      for (i=0; i < 78; ++i)
         putchar(" .:ioVM@"[screen[j][i]>>5]);
      putchar('\n');
   }

   return 0;
}
#endif


//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////
////
////   INTEGRATION WITH YOUR CODEBASE
////
////   The following sections allow you to supply alternate definitions
////   of C library functions used by stb_truetype, e.g. if you don't
////   link with the C runtime library.

#ifdef STB_TRUETYPE_IMPLEMENTATION
   // #define your own (u)stbtt_int8/16/32 before including to override this
   #ifndef stbtt_uint8
   typedef unsigned char   stbtt_uint8;
   typedef signed   char   stbtt_int8;
   typedef unsigned short  stbtt_uint16;
   typedef signed   short  stbtt_int16;
   typedef unsigned int    stbtt_uint32;
   typedef signed   int    stbtt_int32;
   #endif

   typedef char stbtt__check_size32[sizeof(stbtt_int32)==4 ? 1 : -1];
   typedef char stbtt__check_size16[sizeof(stbtt_int16)==2 ? 1 : -1];

   // e.g. #define your own STBTT_ifloor/STBTT_iceil() to avoid math.h
   #ifndef STBTT_ifloor
   #include <math.h>
   #define STBTT_ifloor(x)   ((int) floor(x))
   #define STBTT_iceil(x)    ((int) ceil(x))
   #endif

   #ifndef STBTT_sqrt
   #include <math.h>
   #define STBTT_sqrt(x)      sqrt(x)
   #define STBTT_pow(x,y)     pow(x,y)
   #endif

   #ifndef STBTT_fmod
   #include <math.h>
   #define STBTT_fmod(x,y)    fmod(x,y)
   #endif

   #ifndef STBTT_cos
   #include <math.h>
   #define STBTT_cos(x)       cos(x)
   #define STBTT_acos(x)      acos(x)
   #endif

   #ifndef STBTT_fabs
   #include <math.h>
   #define STBTT_fabs(x)      fabs(x)
   #endif

   // #define your own functions "STBTT_malloc" / "STBTT_free" to avoid malloc.h
   #ifndef STBTT_malloc
   #include <stdlib.h>
   #define STBTT_malloc(x,u)  ((void)(u),malloc(x))
   #define STBTT_free(x,u)    ((void)(u),free(x))
   #endif

   #ifndef STBTT_assert
   #include <assert.h>
   #define STBTT_assert(x)    assert(x)
   #endif

   #ifndef STBTT_strlen
   #include <string.h>
   #define STBTT_strlen(x)    strlen(x)
   #endif

   #ifndef STBTT_memcpy
   #include <string.h>
   #define STBTT_memcpy       memcpy
   #define STBTT_memset       memset
   #endif
#endif

///////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////
////
////   INTERFACE
////
////

#ifndef __STB_INCLUDE_STB_TRUETYPE_H__
#define __STB_INCLUDE_STB_TRUETYPE_H__

#ifdef STBTT_STATIC
#define STBTT_DEF static
#else
#define STBTT_DEF extern
#endif

#ifdef __cplusplus
extern "C" {
#endif

// private structure
typedef struct
{
   unsigned char *data;
   int cursor;
   int size;
} stbtt__buf;

//////////////////////////////////////////////////////////////////////////////
//
// TEXTURE BAKING API
//
// If you use this API, you only have to call two functions ever.
//

typedef struct
{
   unsigned short x0,y0,x1,y1; // coordinates of bbox in bitmap
   float xoff,yoff,xadvance;
} stbtt_bakedchar;

STBTT_DEF int stbtt_BakeFontBitmap(const unsigned char *data, int offset,  // font location (use offset=0 for plain .ttf)
                                float pixel_height,                     // height of font in pixels
                                unsigned char *pixels, int pw, int ph,  // bitmap to be filled in
                                int first_char, int num_chars,          // characters to bake
                                stbtt_bakedchar *chardata);             // you allocate this, it's num_chars long
// if return is positive, the first unused row of the bitmap
// if return is negative, returns the negative of the number of characters that fit
// if return is 0, no characters fit and no rows were used
// This uses a very crappy packing.

typedef struct
{
   float x0,y0,s0,t0; // top-left
   float x1,y1,s1,t1; // bottom-right
} stbtt_aligned_quad;

STBTT_DEF void stbtt_GetBakedQuad(const stbtt_bakedchar *chardata, int pw, int ph,  // same data as above
                               int char_index,             // character to display
                               float *xpos, float *ypos,   // pointers to current position in screen pixel space
                               stbtt_aligned_quad *q,      // output: quad to draw
                               int opengl_fillrule);       // true if opengl fill rule; false if DX9 or earlier
// Call GetBakedQuad with char_index = 'character - first_char', and it
// creates the quad you need to draw and advances the current position.
//
// The coordinate system used assumes y increases downwards.
//
// Characters will extend both above and below the current position;
// see discussion of "BASELINE" above.
//
// It's inefficient; you might want to c&p it and optimize it.

STBTT_DEF void stbtt_GetScaledFontVMetrics(const unsigned char *fontdata, int index, float size, float *ascent, float *descent, float *lineGap);
// Query the font vertical metrics without having to create a font first.


//////////////////////////////////////////////////////////////////////////////
//
// NEW TEXTURE BAKING API
//
// This provides options for packing multiple fonts into one atlas, not
// perfectly but better than nothing.

typedef struct
{
   unsigned short x0,y0,x1,y1; // coordinates of bbox in bitmap
   float xoff,yoff,xadvance;
   float xoff2,yoff2;
} stbtt_packedchar;

typedef struct stbtt_pack_context stbtt_pack_context;
typedef struct stbtt_fontinfo stbtt_fontinfo;
#ifndef STB_RECT_PACK_VERSION
typedef struct stbrp_rect stbrp_rect;
#endif

STBTT_DEF int  stbtt_PackBegin(stbtt_pack_context *spc, unsigned char *pixels, int width, int height, int stride_in_bytes, int padding, void *alloc_context);
// Initializes a packing context stored in the passed-in stbtt_pack_context.
// Future calls using this context will pack characters into the bitmap passed
// in here: a 1-channel bitmap that is width * height. stride_in_bytes is
// the distance from one row to the next (or 0 to mean they are packed tightly
// together). "padding" is the amount of padding to leave between each
// character (normally you want '1' for bitmaps you'll use as textures with
// bilinear filtering).
//
// Returns 0 on failure, 1 on success.

STBTT_DEF void stbtt_PackEnd  (stbtt_pack_context *spc);
// Cleans up the packing context and frees all memory.

#define STBTT_POINT_SIZE(x)   (-(x))

STBTT_DEF int  stbtt_PackFontRange(stbtt_pack_context *spc, const unsigned char *fontdata, int font_index, float font_size,
                                int first_unicode_char_in_range, int num_chars_in_range, stbtt_packedchar *chardata_for_range);
// Creates character bitmaps from the font_index'th font found in fontdata (use
// font_index=0 if you don't know what that is). It creates num_chars_in_range
// bitmaps for characters with unicode values starting at first_unicode_char_in_range
// and increasing. Data for how to render them is stored in chardata_for_range;
// pass these to stbtt_GetPackedQuad to get back renderable quads.
//
// font_size is the full height of the character from ascender to descender,
// as computed by stbtt_ScaleForPixelHeight. To use a point size as computed
// by stbtt_ScaleForMappingEmToPixels, wrap the point size in STBTT_POINT_SIZE()
// and pass that result as 'font_size':
//       ...,                  20 , ... // font max minus min y is 20 pixels tall
//       ..., STBTT_POINT_SIZE(20), ... // 'M' is 20 pixels tall

typedef struct
{
   float font_size;
   int first_unicode_codepoint_in_range;  // if non-zero, then the chars are continuous, and this is the first codepoint
   int *array_of_unicode_codepoints;       // if non-zero, then this is an array of unicode codepoints
   int num_chars;
   stbtt_packedchar *chardata_for_range; // output
   unsigned char h_oversample, v_oversample; // don't set these, they're used internally
} stbtt_pack_range;

STBTT_DEF int  stbtt_PackFontRanges(stbtt_pack_context *spc, const unsigned char *fontdata, int font_index, stbtt_pack_range *ranges, int num_ranges);
// Creates character bitmaps from multiple ranges of characters stored in
// ranges. This will usually create a better-packed bitmap than multiple
// calls to stbtt_PackFontRange. Note that you can call this multiple
// times within a single PackBegin/PackEnd.

STBTT_DEF void stbtt_PackSetOversampling(stbtt_pack_context *spc, unsigned int h_oversample, unsigned int v_oversample);
// Oversampling a font increases the quality by allowing higher-quality subpixel
// positioning, and is especially valuable at smaller text sizes.
//
// This function sets the amount of oversampling for all following calls to
// stbtt_PackFontRange(s) or stbtt_PackFontRangesGatherRects for a given
// pack context. The default (no oversampling) is achieved by h_oversample=1
// and v_oversample=1. The total number of pixels required is
// h_oversample*v_oversample larger than the default; for example, 2x2
// oversampling requires 4x the storage of 1x1. For best results, render
// oversampled textures with bilinear filtering. Look at the readme in
// stb/tests/oversample for information about oversampled fonts
//
// To use with PackFontRangesGather etc., you must set it before calls
// call to PackFontRangesGatherRects.

STBTT_DEF void stbtt_PackSetSkipMissingCodepoints(stbtt_pack_context *spc, int skip);
// If skip != 0, this tells stb_truetype to skip any codepoints for which
// there is no corresponding glyph. If skip=0, which is the default, then
// codepoints without a glyph recived the font's "missing character" glyph,
// typically an empty box by convention.

STBTT_DEF void stbtt_GetPackedQuad(const stbtt_packedchar *chardata, int pw, int ph,  // same data as above
                               int char_index,             // character to display
                               float *xpos, float *ypos,   // pointers to current position in screen pixel space
                               stbtt_aligned_quad *q,      // output: quad to draw
                               int align_to_integer);

STBTT_DEF int  stbtt_PackFontRangesGatherRects(stbtt_pack_context *spc, const stbtt_fontinfo *info, stbtt_pack_range *ranges, int num_ranges, stbrp_rect *rects);
STBTT_DEF void stbtt_PackFontRangesPackRects(stbtt_pack_context *spc, stbrp_rect *rects, int num_rects);
STBTT_DEF int  stbtt_PackFontRangesRenderIntoRects(stbtt_pack_context *spc, const stbtt_fontinfo *info, stbtt_pack_range *ranges, int num_ranges, stbrp_rect *rects);
// Calling these functions in sequence is roughly equivalent to calling
// stbtt_PackFontRanges(). If you more control over the packing of multiple
// fonts, or if you want to pack custom data into a font texture, take a look
// at the source to of stbtt_PackFontRanges() and create a custom version 
// using these functions, e.g. call GatherRects multiple times,
// building up a single array of rects, then call PackRects once,
// then call RenderIntoRects repeatedly. This may result in a
// better packing than calling PackFontRanges multiple times
// (or it may not).

// this is an opaque structure that you shouldn't mess with which holds
// all the context needed from PackBegin to PackEnd.
struct stbtt_pack_context {
   void *user_allocator_context;
   void *pack_info;
   int   width;
   int   height;
   int   stride_in_bytes;
   int   padding;
   int   skip_missing;
   unsigned int   h_oversample, v_oversample;
   unsigned char *pixels;
   void  *nodes;
};

//////////////////////////////////////////////////////////////////////////////
//
// FONT LOADING
//
//

STBTT_DEF int stbtt_GetNumberOfFonts(const unsigned char *data);
// This function will determine the number of fonts in a font file.  TrueType
// collection (.ttc) files may contain multiple fonts, while TrueType font
// (.ttf) files only contain one font. The number of fonts can be used for
// indexing with the previous function where the index is between zero and one
// less than the total fonts. If an error occurs, -1 is returned.

STBTT_DEF int stbtt_GetFontOffsetForIndex(const unsigned char *data, int index);
// Each .ttf/.ttc file may have more than one font. Each font has a sequential
// index number starting from 0. Call this function to get the font offset for
// a given index; it returns -1 if the index is out of range. A regular .ttf
// file will only define one font and it always be at offset 0, so it will
// return '0' for index 0, and -1 for all other indices.

// The following structure is defined publicly so you can declare one on
// the stack or as a global or etc, but you should treat it as opaque.
struct stbtt_fontinfo
{
   void           * userdata;
   unsigned char  * data;              // pointer to .ttf file
   int              fontstart;         // offset of start of font

   int numGlyphs;                     // number of glyphs, needed for range checking

   int loca,head,glyf,hhea,hmtx,kern,gpos; // table locations as offset from start of .ttf
   int index_map;                     // a cmap mapping for our chosen character encoding
   int indexToLocFormat;              // format needed to map from glyph index to glyph

   stbtt__buf cff;                    // cff font data
   stbtt__buf charstrings;            // the charstring index
   stbtt__buf gsubrs;                 // global charstring subroutines index
   stbtt__buf subrs;                  // private charstring subroutines index
   stbtt__buf fontdicts;              // array of font dicts
   stbtt__buf fdselect;               // map from glyph to fontdict
};

STBTT_DEF int stbtt_InitFont(stbtt_fontinfo *info, const unsigned char *data, int offset);
// Given an offset into the file that defines a font, this function builds
// the necessary cached info for the rest of the system. You must allocate
// the stbtt_fontinfo yourself, and stbtt_InitFont will fill it out. You don't
// need to do anything special to free it, because the contents are pure
// value data with no additional data structures. Returns 0 on failure.


//////////////////////////////////////////////////////////////////////////////
//
// CHARACTER TO GLYPH-INDEX CONVERSIOn

STBTT_DEF int stbtt_FindGlyphIndex(const stbtt_fontinfo *info, int unicode_codepoint);
// If you're going to perform multiple operations on the same character
// and you want a speed-up, call this function with the character you're
// going to process, then use glyph-based functions instead of the
// codepoint-based functions.
// Returns 0 if the character codepoint is not defined in the font.


//////////////////////////////////////////////////////////////////////////////
//
// CHARACTER PROPERTIES
//

STBTT_DEF float stbtt_ScaleForPixelHeight(const stbtt_fontinfo *info, float pixels);
// computes a scale factor to produce a font whose "height" is 'pixels' tall.
// Height is measured as the distance from the highest ascender to the lowest
// descender; in other words, it's equivalent to calling stbtt_GetFontVMetrics
// and computing:
//       scale = pixels / (ascent - descent)
// so if you prefer to measure height by the ascent only, use a similar calculation.

STBTT_DEF float stbtt_ScaleForMappingEmToPixels(const stbtt_fontinfo *info, float pixels);
// computes a scale factor to produce a font whose EM size is mapped to
// 'pixels' tall. This is probably what traditional APIs compute, but
// I'm not positive.

STBTT_DEF void stbtt_GetFontVMetrics(const stbtt_fontinfo *info, int *ascent, int *descent, int *lineGap);
// ascent is the coordinate above the baseline the font extends; descent
// is the coordinate below the baseline the font extends (i.e. it is typically negative)
// lineGap is the spacing between one row's descent and the next row's ascent...
// so you should advance the vertical position by "*ascent - *descent + *lineGap"
//   these are expressed in unscaled coordinates, so you must multiply by
//   the scale factor for a given size

STBTT_DEF int  stbtt_GetFontVMetricsOS2(const stbtt_fontinfo *info, int *typoAscent, int *typoDescent, int *typoLineGap);
// analogous to GetFontVMetrics, but returns the "typographic" values from the OS/2
// table (specific to MS/Windows TTF files).
//
// Returns 1 on success (table present), 0 on failure.

STBTT_DEF void stbtt_GetFontBoundingBox(const stbtt_fontinfo *info, int *x0, int *y0, int *x1, int *y1);
// the bounding box around all possible characters

STBTT_DEF void stbtt_GetCodepointHMetrics(const stbtt_fontinfo *info, int codepoint, int *advanceWidth, int *leftSideBearing);
// leftSideBearing is the offset from the current horizontal position to the left edge of the character
// advanceWidth is the offset from the current horizontal position to the next horizontal position
//   these are expressed in unscaled coordinates

STBTT_DEF int  stbtt_GetCodepointKernAdvance(const stbtt_fontinfo *info, int ch1, int ch2);
// an additional amount to add to the 'advance' value between ch1 and ch2

STBTT_DEF int stbtt_GetCodepointBox(const stbtt_fontinfo *info, int codepoint, int *x0, int *y0, int *x1, int *y1);
// Gets the bounding box of the visible part of the glyph, in unscaled coordinates

STBTT_DEF void stbtt_GetGlyphHMetrics(const stbtt_fontinfo *info, int glyph_index, int *advanceWidth, int *leftSideBearing);
STBTT_DEF int  stbtt_GetGlyphKernAdvance(const stbtt_fontinfo *info, int glyph1, int glyph2);
STBTT_DEF int  stbtt_GetGlyphBox(const stbtt_fontinfo *info, int glyph_index, int *x0, int *y0, int *x1, int *y1);
// as above, but takes one or more glyph indices for greater efficiency


//////////////////////////////////////////////////////////////////////////////
//
// GLYPH SHAPES (you probably don't need these, but they have to go before
// the bitmaps for C declaration-order reasons)
//

#ifndef STBTT_vmove // you can predefine these to use different values (but why?)
   enum {
      STBTT_vmove=1,
      STBTT_vline,
      STBTT_vcurve,
      STBTT_vcubic
   };
#endif

#ifndef stbtt_vertex // you can predefine this to use different values
                   // (we share this with other code at RAD)
   #define stbtt_vertex_type short // can't use stbtt_int16 because that's not visible in the header file
   typedef struct
   {
      stbtt_vertex_type x,y,cx,cy,cx1,cy1;
      unsigned char type,padding;
   } stbtt_vertex;
#endif

STBTT_DEF int stbtt_IsGlyphEmpty(const stbtt_fontinfo *info, int glyph_index);
// returns non-zero if nothing is drawn for this glyph

STBTT_DEF int stbtt_GetCodepointShape(const stbtt_fontinfo *info, int unicode_codepoint, stbtt_vertex **vertices);
STBTT_DEF int stbtt_GetGlyphShape(const stbtt_fontinfo *info, int glyph_index, stbtt_vertex **vertices);
// returns # of vertices and fills *vertices with the pointer to them
//   these are expressed in "unscaled" coordinates
//
// The shape is a series of contours. Each one starts with
// a STBTT_moveto, then consists of a series of mixed
// STBTT_lineto and STBTT_curveto segments. A lineto
// draws a line from previous endpoint to its x,y; a curveto
// draws a quadratic bezier from previous endpoint to
// its x,y, using cx,cy as the bezier control point.

STBTT_DEF void stbtt_FreeShape(const stbtt_fontinfo *info, stbtt_vertex *vertices);
// frees the data allocated above

//////////////////////////////////////////////////////////////////////////////
//
// BITMAP RENDERING
//

STBTT_DEF void stbtt_FreeBitmap(unsigned char *bitmap, void *userdata);
// frees the bitmap allocated below

STBTT_DEF unsigned char *stbtt_GetCodepointBitmap(const stbtt_fontinfo *info, float scale_x, float scale_y, int codepoint, int *width, int *height, int *xoff, int *yoff);
// allocates a large-enough single-channel 8bpp bitmap and renders the
// specified character/glyph at the specified scale into it, with
// antialiasing. 0 is no coverage (transparent), 255 is fully covered (opaque).
// *width & *height are filled out with the width & height of the bitmap,
// which is stored left-to-right, top-to-bottom.
//
// xoff/yoff are the offset it pixel space from the glyph origin to the top-left of the bitmap

STBTT_DEF unsigned char *stbtt_GetCodepointBitmapSubpixel(const stbtt_fontinfo *info, float scale_x, float scale_y, float shift_x, float shift_y, int codepoint, int *width, int *height, int *xoff, int *yoff);
// the same as stbtt_GetCodepoitnBitmap, but you can specify a subpixel
// shift for the character

STBTT_DEF void stbtt_MakeCodepointBitmap(const stbtt_fontinfo *info, unsigned char *output, int out_w, int out_h, int out_stride, float scale_x, float scale_y, int codepoint);
// the same as stbtt_GetCodepointBitmap, but you pass in storage for the bitmap
// in the form of 'output', with row spacing of 'out_stride' bytes. the bitmap
// is clipped to out_w/out_h bytes. Call stbtt_GetCodepointBitmapBox to get the
// width and height and positioning info for it first.

STBTT_DEF void stbtt_MakeCodepointBitmapSubpixel(const stbtt_fontinfo *info, unsigned char *output, int out_w, int out_h, int out_stride, float scale_x, float scale_y, float shift_x, float shift_y, int codepoint);
// same as stbtt_MakeCodepointBitmap, but you can specify a subpixel
// shift for the character

STBTT_DEF void stbtt_MakeCodepointBitmapSubpixelPrefilter(const stbtt_fontinfo *info, unsigned char *output, int out_w, int out_h, int out_stride, float scale_x, float scale_y, float shift_x, float shift_y, int oversample_x, int oversample_y, float *sub_x, float *sub_y, int codepoint);
// same as stbtt_MakeCodepointBitmapSubpixel, but prefiltering
// is performed (see stbtt_PackSetOversampling)

STBTT_DEF void stbtt_GetCodepointBitmapBox(const stbtt_fontinfo *font, int codepoint, float scale_x, float scale_y, int *ix0, int *iy0, int *ix1, int *iy1);
// get the bbox of the bitmap centered around the glyph origin; so the
// bitmap width is ix1-ix0, height is iy1-iy0, and location to place
// the bitmap top left is (leftSideBearing*scale,iy0).
// (Note that the bitmap uses y-increases-down, but the shape uses
// y-increases-up, so CodepointBitmapBox and CodepointBox are inverted.)

STBTT_DEF void stbtt_GetCodepointBitmapBoxSubpixel(const stbtt_fontinfo *font, int codepoint, float scale_x, float scale_y, float shift_x, float shift_y, int *ix0, int *iy0, int *ix1, int *iy1);
// same as stbtt_GetCodepointBitmapBox, but you can specify a subpixel
// shift for the character

// the following functions are equivalent to the above functions, but operate
// on glyph indices instead of Unicode codepoints (for efficiency)
STBTT_DEF unsigned char *stbtt_GetGlyphBitmap(const stbtt_fontinfo *info, float scale_x, float scale_y, int glyph, int *width, int *height, int *xoff, int *yoff);
STBTT_DEF unsigned char *stbtt_GetGlyphBitmapSubpixel(const stbtt_fontinfo *info, float scale_x, float scale_y, float shift_x, float shift_y, int glyph, int *width, int *height, int *xoff, int *yoff);
STBTT_DEF void stbtt_MakeGlyphBitmap(const stbtt_fontinfo *info, unsigned char *output, int out_w, int out_h, int out_stride, float scale_x, float scale_y, int glyph);
STBTT_DEF void stbtt_MakeGlyphBitmapSubpixel(const stbtt_fontinfo *info, unsigned char *output, int out_w, int out_h, int out_stride, float scale_x, float scale_y, float shift_x, float shift_y, int glyph);
STBTT_DEF void stbtt_MakeGlyphBitmapSubpixelPrefilter(const stbtt_fontinfo *info, unsigned char *output, int out_w, int out_h, int out_stride, float scale_x, float scale_y, float shift_x, float shift_y, int oversample_x, int oversample_y, float *sub_x, float *sub_y, int glyph);
STBTT_DEF void stbtt_GetGlyphBitmapBox(const stbtt_fontinfo *font, int glyph, float scale_x, float scale_y, int *ix0, int *iy0, int *ix1, int *iy1);
STBTT_DEF void stbtt_GetGlyphBitmapBoxSubpixel(const stbtt_fontinfo *font, int glyph, float scale_x, float scale_y,float shift_x, float shift_y, int *ix0, int *iy0, int *ix1, int *iy1);


// @TODO: don't expose this structure
typedef struct
{
   int w,h,stride;
   unsigned char *pixels;
} stbtt__bitmap;

// rasterize a shape with quadratic beziers into a bitmap
STBTT_DEF void stbtt_Rasterize(stbtt__bitmap *result,        // 1-channel bitmap to draw into
                               float flatness_in_pixels,     // allowable error of curve in pixels
                               stbtt_vertex *vertices,       // array of vertices defining shape
                               int num_verts,                // number of vertices in above array
                               float scale_x, float scale_y, // scale applied to input vertices
                               float shift_x, float shift_y, // translation applied to input vertices
                               int x_off, int y_off,         // another translation applied to input
                               int invert,                   // if non-zero, vertically flip shape
                               void *userdata);              // context for to STBTT_MALLOC

//////////////////////////////////////////////////////////////////////////////
//
// Signed Distance Function (or Field) rendering

STBTT_DEF void stbtt_FreeSDF(unsigned char *bitmap, void *userdata);
// frees the SDF bitmap allocated below

STBTT_DEF unsigned char * stbtt_GetGlyphSDF(const stbtt_fontinfo *info, float scale, int glyph, int padding, unsigned char onedge_value, float pixel_dist_scale, int *width, int *height, int *xoff, int *yoff);
STBTT_DEF unsigned char * stbtt_GetCodepointSDF(const stbtt_fontinfo *info, float scale, int codepoint, int padding, unsigned char onedge_value, float pixel_dist_scale, int *width, int *height, int *xoff, int *yoff);
// These functions compute a discretized SDF field for a single character, suitable for storing
// in a single-channel texture, sampling with bilinear filtering, and testing against
// larger than some threshold to produce scalable fonts.
//        info              --  the font
//        scale             --  controls the size of the resulting SDF bitmap, same as it would be creating a regular bitmap
//        glyph/codepoint   --  the character to generate the SDF for
//        padding           --  extra "pixels" around the character which are filled with the distance to the character (not 0),
//                                 which allows effects like bit outlines
//        onedge_value      --  value 0-255 to test the SDF against to reconstruct the character (i.e. the isocontour of the character)
//        pixel_dist_scale  --  what value the SDF should increase by when moving one SDF "pixel" away from the edge (on the 0..255 scale)
//                                 if positive, > onedge_value is inside; if negative, < onedge_value is inside
//        width,height      --  output height & width of the SDF bitmap (including padding)
//        xoff,yoff         --  output origin of the character
//        return value      --  a 2D array of bytes 0..255, width*height in size
//
// pixel_dist_scale & onedge_value are a scale & bias that allows you to make
// optimal use of the limited 0..255 for your application, trading off precision
// and special effects. SDF values outside the range 0..255 are clamped to 0..255.
//
// Example:
//      scale = stbtt_ScaleForPixelHeight(22)
//      padding = 5
//      onedge_value = 180
//      pixel_dist_scale = 180/5.0 = 36.0
//
//      This will create an SDF bitmap in which the character is about 22 pixels
//      high but the whole bitmap is about 22+5+5=32 pixels high. To produce a filled
//      shape, sample the SDF at each pixel and fill the pixel if the SDF value
//      is greater than or equal to 180/255. (You'll actually want to antialias,
//      which is beyond the scope of this example.) Additionally, you can compute
//      offset outlines (e.g. to stroke the character border inside & outside,
//      or only outside). For example, to fill outside the character up to 3 SDF
//      pixels, you would compare against (180-36.0*3)/255 = 72/255. The above
//      choice of variables maps a range from 5 pixels outside the shape to
//      2 pixels inside the shape to 0..255; this is intended primarily for apply
//      outside effects only (the interior range is needed to allow proper
//      antialiasing of the font at *smaller* sizes)
//
// The function computes the SDF analytically at each SDF pixel, not by e.g.
// building a higher-res bitmap and approximating it. In theory the quality
// should be as high as possible for an SDF of this size & representation, but
// unclear if this is true in practice (perhaps building a higher-res bitmap
// and computing from that can allow drop-out prevention).
//
// The algorithm has not been optimized at all, so expect it to be slow
// if computing lots of characters or very large sizes. 



//////////////////////////////////////////////////////////////////////////////
//
// Finding the right font...
//
// You should really just solve this offline, keep your own tables
// of what font is what, and don't try to get it out of the .ttf file.
// That's because getting it out of the .ttf file is really hard, because
// the names in the file can appear in many possible encodings, in many
// possible languages, and e.g. if you need a case-insensitive comparison,
// the details of that depend on the encoding & language in a complex way
// (actually underspecified in truetype, but also gigantic).
//
// But you can use the provided functions in two possible ways:
//     stbtt_FindMatchingFont() will use *case-sensitive* comparisons on
//             unicode-encoded names to try to find the font you want;
//             you can run this before calling stbtt_InitFont()
//
//     stbtt_GetFontNameString() lets you get any of the various strings
//             from the file yourself and do your own comparisons on them.
//             You have to have called stbtt_InitFont() first.


STBTT_DEF int stbtt_FindMatchingFont(const unsigned char *fontdata, const char *name, int flags);
// returns the offset (not index) of the font that matches, or -1 if none
//   if you use STBTT_MACSTYLE_DONTCARE, use a font name like "Arial Bold".
//   if you use any other flag, use a font name like "Arial"; this checks
//     the 'macStyle' header field; i don't know if fonts set this consistently
#define STBTT_MACSTYLE_DONTCARE     0
#define STBTT_MACSTYLE_BOLD         1
#define STBTT_MACSTYLE_ITALIC       2
#define STBTT_MACSTYLE_UNDERSCORE   4
#define STBTT_MACSTYLE_NONE         8   // <= not same as 0, this makes us check the bitfield is 0

STBTT_DEF int stbtt_CompareUTF8toUTF16_bigendian(const char *s1, int len1, const char *s2, int len2);
// returns 1/0 whether the first string interpreted as utf8 is identical to
// the second string interpreted as big-endian utf16... useful for strings from next func

STBTT_DEF const char *stbtt_GetFontNameString(const stbtt_fontinfo *font, int *length, int platformID, int encodingID, int languageID, int nameID);
// returns the string (which may be big-endian double byte, e.g. for unicode)
// and puts the length in bytes in *length.
//
// some of the values for the IDs are below; for more see the truetype spec:
//     http://developer.apple.com/textfonts/TTRefMan/RM06/Chap6name.html
//     http://www.microsoft.com/typography/otspec/name.htm

enum { // platformID
   STBTT_PLATFORM_ID_UNICODE   =0,
   STBTT_PLATFORM_ID_MAC       =1,
   STBTT_PLATFORM_ID_ISO       =2,
   STBTT_PLATFORM_ID_MICROSOFT =3
};

enum { // encodingID for STBTT_PLATFORM_ID_UNICODE
   STBTT_UNICODE_EID_UNICODE_1_0    =0,
   STBTT_UNICODE_EID_UNICODE_1_1    =1,
   STBTT_UNICODE_EID_ISO_10646      =2,
   STBTT_UNICODE_EID_UNICODE_2_0_BMP=3,
   STBTT_UNICODE_EID_UNICODE_2_0_FULL=4
};

enum { // encodingID for STBTT_PLATFORM_ID_MICROSOFT
   STBTT_MS_EID_SYMBOL        =0,
   STBTT_MS_EID_UNICODE_BMP   =1,
   STBTT_MS_EID_SHIFTJIS      =2,
   STBTT_MS_EID_UNICODE_FULL  =10
};

enum { // encodingID for STBTT_PLATFORM_ID_MAC; same as Script Manager codes
   STBTT_MAC_EID_ROMAN        =0,   STBTT_MAC_EID_ARABIC       =4,
   STBTT_MAC_EID_JAPANESE     =1,   STBTT_MAC_EID_HEBREW       =5,
   STBTT_MAC_EID_CHINESE_TRAD =2,   STBTT_MAC_EID_GREEK        =6,
   STBTT_MAC_EID_KOREAN       =3,   STBTT_MAC_EID_RUSSIAN      =7
};

enum { // languageID for STBTT_PLATFORM_ID_MICROSOFT; same as LCID...
       // problematic because there are e.g. 16 english LCIDs and 16 arabic LCIDs
   STBTT_MS_LANG_ENGLISH     =0x0409,   STBTT_MS_LANG_ITALIAN     =0x0410,
   STBTT_MS_LANG_CHINESE     =0x0804,   STBTT_MS_LANG_JAPANESE    =0x0411,
   STBTT_MS_LANG_DUTCH       =0x0413,   STBTT_MS_LANG_KOREAN      =0x0412,
   STBTT_MS_LANG_FRENCH      =0x040c,   STBTT_MS_LANG_RUSSIAN     =0x0419,
   STBTT_MS_LANG_GERMAN      =0x0407,   STBTT_MS_LANG_SPANISH     =0x0409,
   STBTT_MS_LANG_HEBREW      =0x040d,   STBTT_MS_LANG_SWEDISH     =0x041D
};

enum { // languageID for STBTT_PLATFORM_ID_MAC
   STBTT_MAC_LANG_ENGLISH      =0 ,   STBTT_MAC_LANG_JAPANESE     =11,
   STBTT_MAC_LANG_ARABIC       =12,   STBTT_MAC_LANG_KOREAN       =23,
   STBTT_MAC_LANG_DUTCH        =4 ,   STBTT_MAC_LANG_RUSSIAN      =32,
   STBTT_MAC_LANG_FRENCH       =1 ,   STBTT_MAC_LANG_SPANISH      =6 ,
   STBTT_MAC_LANG_GERMAN       =2 ,   STBTT_MAC_LANG_SWEDISH      =5 ,
   STBTT_MAC_LANG_HEBREW       =10,   STBTT_MAC_LANG_CHINESE_SIMPLIFIED =33,
   STBTT_MAC_LANG_ITALIAN      =3 ,   STBTT_MAC_LANG_CHINESE_TRAD =19
};

#ifdef __cplusplus
}
#endif

#endif // __STB_INCLUDE_STB_TRUETYPE_H__

///////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////
////
////   IMPLEMENTATION
////
////

#ifdef STB_TRUETYPE_IMPLEMENTATION

#ifndef STBTT_MAX_OVERSAMPLE
#define STBTT_MAX_OVERSAMPLE   8
#endif

#if STBTT_MAX_OVERSAMPLE > 255
#error "STBTT_MAX_OVERSAMPLE cannot be > 255"
#endif

typedef int stbtt__test_oversample_pow2[(STBTT_MAX_OVERSAMPLE & (STBTT_MAX_OVERSAMPLE-1)) == 0 ? 1 : -1];

#ifndef STBTT_RASTERIZER_VERSION
#define STBTT_RASTERIZER_VERSION 2
#endif

#ifdef _MSC_VER
#define STBTT__NOTUSED(v)  (void)(v)
#else
#define STBTT__NOTUSED(v)  (void)sizeof(v)
#endif

//////////////////////////////////////////////////////////////////////////
//
// stbtt__buf helpers to parse data from file
//

static stbtt_uint8 stbtt__buf_get8(stbtt__buf *b)
{
   if (b->cursor >= b->size)
      return 0;
   return b->data[b->cursor++];
}

static stbtt_uint8 stbtt__buf_peek8(stbtt__buf *b)
{
   if (b->cursor >= b->size)
      return 0;
   return b->data[b->cursor];
}

static void stbtt__buf_seek(stbtt__buf *b, int o)
{
   STBTT_assert(!(o > b->size || o < 0));
   b->cursor = (o > b->size || o < 0) ? b->size : o;
}

static void stbtt__buf_skip(stbtt__buf *b, int o)
{
   stbtt__buf_seek(b, b->cursor + o);
}

static stbtt_uint32 stbtt__buf_get(stbtt__buf *b, int n)
{
   stbtt_uint32 v = 0;
   int i;
   STBTT_assert(n >= 1 && n <= 4);
   for (i = 0; i < n; i++)
      v = (v << 8) | stbtt__buf_get8(b);
   return v;
}

static stbtt__buf stbtt__new_buf(const void *p, size_t size)
{
   stbtt__buf r;
   STBTT_assert(size < 0x40000000);
   r.data = (stbtt_uint8*) p;
   r.size = (int) size;
   r.cursor = 0;
   return r;
}

#define stbtt__buf_get16(b)  stbtt__buf_get((b), 2)
#define stbtt__buf_get32(b)  stbtt__buf_get((b), 4)

static stbtt__buf stbtt__buf_range(const stbtt__buf *b, int o, int s)
{
   stbtt__buf r = stbtt__new_buf(NULL, 0);
   if (o < 0 || s < 0 || o > b->size || s > b->size - o) return r;
   r.data = b->data + o;
   r.size = s;
   return r;
}

static stbtt__buf stbtt__cff_get_index(stbtt__buf *b)
{
   int count, start, offsize;
   start = b->cursor;
   count = stbtt__buf_get16(b);
   if (count) {
      offsize = stbtt__buf_get8(b);
      STBTT_assert(offsize >= 1 && offsize <= 4);
      stbtt__buf_skip(b, offsize * count);
      stbtt__buf_skip(b, stbtt__buf_get(b, offsize) - 1);
   }
   return stbtt__buf_range(b, start, b->cursor - start);
}

static stbtt_uint32 stbtt__cff_int(stbtt__buf *b)
{
   int b0 = stbtt__buf_get8(b);
   if (b0 >= 32 && b0 <= 246)       return b0 - 139;
   else if (b0 >= 247 && b0 <= 250) return (b0 - 247)*256 + stbtt__buf_get8(b) + 108;
   else if (b0 >= 251 && b0 <= 254) return -(b0 - 251)*256 - stbtt__buf_get8(b) - 108;
   else if (b0 == 28)               return stbtt__buf_get16(b);
   else if (b0 == 29)               return stbtt__buf_get32(b);
   STBTT_assert(0);
   return 0;
}

static void stbtt__cff_skip_operand(stbtt__buf *b) {
   int v, b0 = stbtt__buf_peek8(b);
   STBTT_assert(b0 >= 28);
   if (b0 == 30) {
      stbtt__buf_skip(b, 1);
      while (b->cursor < b->size) {
         v = stbtt__buf_get8(b);
         if ((v & 0xF) == 0xF || (v >> 4) == 0xF)
            break;
      }
   } else {
      stbtt__cff_int(b);
   }
}

static stbtt__buf stbtt__dict_get(stbtt__buf *b, int key)
{
   stbtt__buf_seek(b, 0);
   while (b->cursor < b->size) {
      int start = b->cursor, end, op;
      while (stbtt__buf_peek8(b) >= 28)
         stbtt__cff_skip_operand(b);
      end = b->cursor;
      op = stbtt__buf_get8(b);
      if (op == 12)  op = stbtt__buf_get8(b) | 0x100;
      if (op == key) return stbtt__buf_range(b, start, end-start);
   }
   return stbtt__buf_range(b, 0, 0);
}

static void stbtt__dict_get_ints(stbtt__buf *b, int key, int outcount, stbtt_uint32 *out)
{
   int i;
   stbtt__buf operands = stbtt__dict_get(b, key);
   for (i = 0; i < outcount && operands.cursor < operands.size; i++)
      out[i] = stbtt__cff_int(&operands);
}

static int stbtt__cff_index_count(stbtt__buf *b)
{
   stbtt__buf_seek(b, 0);
   return stbtt__buf_get16(b);
}

static stbtt__buf stbtt__cff_index_get(stbtt__buf b, int i)
{
   int count, offsize, start, end;
   stbtt__buf_seek(&b, 0);
   count = stbtt__buf_get16(&b);
   offsize = stbtt__buf_get8(&b);
   STBTT_assert(i >= 0 && i < count);
   STBTT_assert(offsize >= 1 && offsize <= 4);
   stbtt__buf_skip(&b, i*offsize);
   start = stbtt__buf_get(&b, offsize);
   end = stbtt__buf_get(&b, offsize);
   return stbtt__buf_range(&b, 2+(count+1)*offsize+start, end - start);
}

//////////////////////////////////////////////////////////////////////////
//
// accessors to parse data from file
//

// on platforms that don't allow misaligned reads, if we want to allow
// truetype fonts that aren't padded to alignment, define ALLOW_UNALIGNED_TRUETYPE

#define ttBYTE(p)     (* (stbtt_uint8 *) (p))
#define ttCHAR(p)     (* (stbtt_int8 *) (p))
#define ttFixed(p)    ttLONG(p)

static stbtt_uint16 ttUSHORT(stbtt_uint8 *p) { return p[0]*256 + p[1]; }
static stbtt_int16 ttSHORT(stbtt_uint8 *p)   { return p[0]*256 + p[1]; }
static stbtt_uint32 ttULONG(stbtt_uint8 *p)  { return (p[0]<<24) + (p[1]<<16) + (p[2]<<8) + p[3]; }
static stbtt_int32 ttLONG(stbtt_uint8 *p)    { return (p[0]<<24) + (p[1]<<16) + (p[2]<<8) + p[3]; }

#define stbtt_tag4(p,c0,c1,c2,c3) ((p)[0] == (c0) && (p)[1] == (c1) && (p)[2] == (c2) && (p)[3] == (c3))
#define stbtt_tag(p,str)           stbtt_tag4(p,str[0],str[1],str[2],str[3])

static int stbtt__isfont(stbtt_uint8 *font)
{
   // check the version number
   if (stbtt_tag4(font, '1',0,0,0))  return 1; // TrueType 1
   if (stbtt_tag(font, "typ1"))   return 1; // TrueType with type 1 font -- we don't support this!
   if (stbtt_tag(font, "OTTO"))   return 1; // OpenType with CFF
   if (stbtt_tag4(font, 0,1,0,0)) return 1; // OpenType 1.0
   if (stbtt_tag(font, "true"))   return 1; // Apple specification for TrueType fonts
   return 0;
}

// @OPTIMIZE: binary search
static stbtt_uint32 stbtt__find_table(stbtt_uint8 *data, stbtt_uint32 fontstart, const char *tag)
{
   stbtt_int32 num_tables = ttUSHORT(data+fontstart+4);
   stbtt_uint32 tabledir = fontstart + 12;
   stbtt_int32 i;
   for (i=0; i < num_tables; ++i) {
      stbtt_uint32 loc = tabledir + 16*i;
      if (stbtt_tag(data+loc+0, tag))
         return ttULONG(data+loc+8);
   }
   return 0;
}

static int stbtt_GetFontOffsetForIndex_internal(unsigned char *font_collection, int index)
{
   // if it's just a font, there's only one valid index
   if (stbtt__isfont(font_collection))
      return index == 0 ? 0 : -1;

   // check if it's a TTC
   if (stbtt_tag(font_collection, "ttcf")) {
      // version 1?
      if (ttULONG(font_collection+4) == 0x00010000 || ttULONG(font_collection+4) == 0x00020000) {
         stbtt_int32 n = ttLONG(font_collection+8);
         if (index >= n)
            return -1;
         return ttULONG(font_collection+12+index*4);
      }
   }
   return -1;
}

static int stbtt_GetNumberOfFonts_internal(unsigned char *font_collection)
{
   // if it's just a font, there's only one valid font
   if (stbtt__isfont(font_collection))
      return 1;

   // check if it's a TTC
   if (stbtt_tag(font_collection, "ttcf")) {
      // version 1?
      if (ttULONG(font_collection+4) == 0x00010000 || ttULONG(font_collection+4) == 0x00020000) {
         return ttLONG(font_collection+8);
      }
   }
   return 0;
}

static stbtt__buf stbtt__get_subrs(stbtt__buf cff, stbtt__buf fontdict)
{
   stbtt_uint32 subrsoff = 0, private_loc[2] = { 0, 0 };
   stbtt__buf pdict;
   stbtt__dict_get_ints(&fontdict, 18, 2, private_loc);
   if (!private_loc[1] || !private_loc[0]) return stbtt__new_buf(NULL, 0);
   pdict = stbtt__buf_range(&cff, private_loc[1], private_loc[0]);
   stbtt__dict_get_ints(&pdict, 19, 1, &subrsoff);
   if (!subrsoff) return stbtt__new_buf(NULL, 0);
   stbtt__buf_seek(&cff, private_loc[1]+subrsoff);
   return stbtt__cff_get_index(&cff);
}

static int stbtt_InitFont_internal(stbtt_fontinfo *info, unsigned char *data, int fontstart)
{
   stbtt_uint32 cmap, t;
   stbtt_int32 i,numTables;

   info->data = data;
   info->fontstart = fontstart;
   info->cff = stbtt__new_buf(NULL, 0);

   cmap = stbtt__find_table(data, fontstart, "cmap");       // required
   info->loca = stbtt__find_table(data, fontstart, "loca"); // required
   info->head = stbtt__find_table(data, fontstart, "head"); // required
   info->glyf = stbtt__find_table(data, fontstart, "glyf"); // required
   info->hhea = stbtt__find_table(data, fontstart, "hhea"); // required
   info->hmtx = stbtt__find_table(data, fontstart, "hmtx"); // required
   info->kern = stbtt__find_table(data, fontstart, "kern"); // not required
   info->gpos = stbtt__find_table(data, fontstart, "GPOS"); // not required

   if (!cmap || !info->head || !info->hhea || !info->hmtx)
      return 0;
   if (info->glyf) {
      // required for truetype
      if (!info->loca) return 0;
   } else {
      // initialization for CFF / Type2 fonts (OTF)
      stbtt__buf b, topdict, topdictidx;
      stbtt_uint32 cstype = 2, charstrings = 0, fdarrayoff = 0, fdselectoff = 0;
      stbtt_uint32 cff;

      cff = stbtt__find_table(data, fontstart, "CFF ");
      if (!cff) return 0;

      info->fontdicts = stbtt__new_buf(NULL, 0);
      info->fdselect = stbtt__new_buf(NULL, 0);

      // @TODO this should use size from table (not 512MB)
      info->cff = stbtt__new_buf(data+cff, 512*1024*1024);
      b = info->cff;

      // read the header
      stbtt__buf_skip(&b, 2);
      stbtt__buf_seek(&b, stbtt__buf_get8(&b)); // hdrsize

      // @TODO the name INDEX could list multiple fonts,
      // but we just use the first one.
      stbtt__cff_get_index(&b);  // name INDEX
      topdictidx = stbtt__cff_get_index(&b);
      topdict = stbtt__cff_index_get(topdictidx, 0);
      stbtt__cff_get_index(&b);  // string INDEX
      info->gsubrs = stbtt__cff_get_index(&b);

      stbtt__dict_get_ints(&topdict, 17, 1, &charstrings);
      stbtt__dict_get_ints(&topdict, 0x100 | 6, 1, &cstype);
      stbtt__dict_get_ints(&topdict, 0x100 | 36, 1, &fdarrayoff);
      stbtt__dict_get_ints(&topdict, 0x100 | 37, 1, &fdselectoff);
      info->subrs = stbtt__get_subrs(b, topdict);

      // we only support Type 2 charstrings
      if (cstype != 2) return 0;
      if (charstrings == 0) return 0;

      if (fdarrayoff) {
         // looks like a CID font
         if (!fdselectoff) return 0;
         stbtt__buf_seek(&b, fdarrayoff);
         info->fontdicts = stbtt__cff_get_index(&b);
         info->fdselect = stbtt__buf_range(&b, fdselectoff, b.size-fdselectoff);
      }

      stbtt__buf_seek(&b, charstrings);
      info->charstrings = stbtt__cff_get_index(&b);
   }

   t = stbtt__find_table(data, fontstart, "maxp");
   if (t)
      info->numGlyphs = ttUSHORT(data+t+4);
   else
      info->numGlyphs = 0xffff;

   // find a cmap encoding table we understand *now* to avoid searching
   // later. (todo: could make this installable)
   // the same regardless of glyph.
   numTables = ttUSHORT(data + cmap + 2);
   info->index_map = 0;
   for (i=0; i < numTables; ++i) {
      stbtt_uint32 encoding_record = cmap + 4 + 8 * i;
      // find an encoding we understand:
      switch(ttUSHORT(data+encoding_record)) {
         case STBTT_PLATFORM_ID_MICROSOFT:
            switch (ttUSHORT(data+encoding_record+2)) {
               case STBTT_MS_EID_UNICODE_BMP:
               case STBTT_MS_EID_UNICODE_FULL:
                  // MS/Unicode
                  info->index_map = cmap + ttULONG(data+encoding_record+4);
                  break;
            }
            break;
        case STBTT_PLATFORM_ID_UNICODE:
            // Mac/iOS has these
            // all the encodingIDs are unicode, so we don't bother to check it
            info->index_map = cmap + ttULONG(data+encoding_record+4);
            break;
      }
   }
   if (info->index_map == 0)
      return 0;

   info->indexToLocFormat = ttUSHORT(data+info->head + 50);
   return 1;
}

STBTT_DEF int stbtt_FindGlyphIndex(const stbtt_fontinfo *info, int unicode_codepoint)
{
   stbtt_uint8 *data = info->data;
   stbtt_uint32 index_map = info->index_map;

   stbtt_uint16 format = ttUSHORT(data + index_map + 0);
   if (format == 0) { // apple byte encoding
      stbtt_int32 bytes = ttUSHORT(data + index_map + 2);
      if (unicode_codepoint < bytes-6)
         return ttBYTE(data + index_map + 6 + unicode_codepoint);
      return 0;
   } else if (format == 6) {
      stbtt_uint32 first = ttUSHORT(data + index_map + 6);
      stbtt_uint32 count = ttUSHORT(data + index_map + 8);
      if ((stbtt_uint32) unicode_codepoint >= first && (stbtt_uint32) unicode_codepoint < first+count)
         return ttUSHORT(data + index_map + 10 + (unicode_codepoint - first)*2);
      return 0;
   } else if (format == 2) {
      STBTT_assert(0); // @TODO: high-byte mapping for japanese/chinese/korean
      return 0;
   } else if (format == 4) { // standard mapping for windows fonts: binary search collection of ranges
      stbtt_uint16 segcount = ttUSHORT(data+index_map+6) >> 1;
      stbtt_uint16 searchRange = ttUSHORT(data+index_map+8) >> 1;
      stbtt_uint16 entrySelector = ttUSHORT(data+index_map+10);
      stbtt_uint16 rangeShift = ttUSHORT(data+index_map+12) >> 1;

      // do a binary search of the segments
      stbtt_uint32 endCount = index_map + 14;
      stbtt_uint32 search = endCount;

      if (unicode_codepoint > 0xffff)
         return 0;

      // they lie from endCount .. endCount + segCount
      // but searchRange is the nearest power of two, so...
      if (unicode_codepoint >= ttUSHORT(data + search + rangeShift*2))
         search += rangeShift*2;

      // now decrement to bias correctly to find smallest
      search -= 2;
      while (entrySelector) {
         stbtt_uint16 end;
         searchRange >>= 1;
         end = ttUSHORT(data + search + searchRange*2);
         if (unicode_codepoint > end)
            search += searchRange*2;
         --entrySelector;
      }
      search += 2;

      {
         stbtt_uint16 offset, start;
         stbtt_uint16 item = (stbtt_uint16) ((search - endCount) >> 1);

         STBTT_assert(unicode_codepoint <= ttUSHORT(data + endCount + 2*item));
         start = ttUSHORT(data + index_map + 14 + segcount*2 + 2 + 2*item);
         if (unicode_codepoint < start)
            return 0;

         offset = ttUSHORT(data + index_map + 14 + segcount*6 + 2 + 2*item);
         if (offset == 0)
            return (stbtt_uint16) (unicode_codepoint + ttSHORT(data + index_map + 14 + segcount*4 + 2 + 2*item));

         return ttUSHORT(data + offset + (unicode_codepoint-start)*2 + index_map + 14 + segcount*6 + 2 + 2*item);
      }
   } else if (format == 12 || format == 13) {
      stbtt_uint32 ngroups = ttULONG(data+index_map+12);
      stbtt_int32 low,high;
      low = 0; high = (stbtt_int32)ngroups;
      // Binary search the right group.
      while (low < high) {
         stbtt_int32 mid = low + ((high-low) >> 1); // rounds down, so low <= mid < high
         stbtt_uint32 start_char = ttULONG(data+index_map+16+mid*12);
         stbtt_uint32 end_char = ttULONG(data+index_map+16+mid*12+4);
         if ((stbtt_uint32) unicode_codepoint < start_char)
            high = mid;
         else if ((stbtt_uint32) unicode_codepoint > end_char)
            low = mid+1;
         else {
            stbtt_uint32 start_glyph = ttULONG(data+index_map+16+mid*12+8);
            if (format == 12)
               return start_glyph + unicode_codepoint-start_char;
            else // format == 13
               return start_glyph;
         }
      }
      return 0; // not found
   }
   // @TODO
   STBTT_assert(0);
   return 0;
}

STBTT_DEF int stbtt_GetCodepointShape(const stbtt_fontinfo *info, int unicode_codepoint, stbtt_vertex **vertices)
{
   return stbtt_GetGlyphShape(info, stbtt_FindGlyphIndex(info, unicode_codepoint), vertices);
}

static void stbtt_setvertex(stbtt_vertex *v, stbtt_uint8 type, stbtt_int32 x, stbtt_int32 y, stbtt_int32 cx, stbtt_int32 cy)
{
   v->type = type;
   v->x = (stbtt_int16) x;
   v->y = (stbtt_int16) y;
   v->cx = (stbtt_int16) cx;
   v->cy = (stbtt_int16) cy;
}

static int stbtt__GetGlyfOffset(const stbtt_fontinfo *info, int glyph_index)
{
   int g1,g2;

   STBTT_assert(!info->cff.size);

   if (glyph_index >= info->numGlyphs) return -1; // glyph index out of range
   if (info->indexToLocFormat >= 2)    return -1; // unknown index->glyph map format

   if (info->indexToLocFormat == 0) {
      g1 = info->glyf + ttUSHORT(info->data + info->loca + glyph_index * 2) * 2;
      g2 = info->glyf + ttUSHORT(info->data + info->loca + glyph_index * 2 + 2) * 2;
   } else {
      g1 = info->glyf + ttULONG (info->data + info->loca + glyph_index * 4);
      g2 = info->glyf + ttULONG (info->data + info->loca + glyph_index * 4 + 4);
   }

   return g1==g2 ? -1 : g1; // if length is 0, return -1
}

static int stbtt__GetGlyphInfoT2(const stbtt_fontinfo *info, int glyph_index, int *x0, int *y0, int *x1, int *y1);

STBTT_DEF int stbtt_GetGlyphBox(const stbtt_fontinfo *info, int glyph_index, int *x0, int *y0, int *x1, int *y1)
{
   if (info->cff.size) {
      stbtt__GetGlyphInfoT2(info, glyph_index, x0, y0, x1, y1);
   } else {
      int g = stbtt__GetGlyfOffset(info, glyph_index);
      if (g < 0) return 0;

      if (x0) *x0 = ttSHORT(info->data + g + 2);
      if (y0) *y0 = ttSHORT(info->data + g + 4);
      if (x1) *x1 = ttSHORT(info->data + g + 6);
      if (y1) *y1 = ttSHORT(info->data + g + 8);
   }
   return 1;
}

STBTT_DEF int stbtt_GetCodepointBox(const stbtt_fontinfo *info, int codepoint, int *x0, int *y0, int *x1, int *y1)
{
   return stbtt_GetGlyphBox(info, stbtt_FindGlyphIndex(info,codepoint), x0,y0,x1,y1);
}

STBTT_DEF int stbtt_IsGlyphEmpty(const stbtt_fontinfo *info, int glyph_index)
{
   stbtt_int16 numberOfContours;
   int g;
   if (info->cff.size)
      return stbtt__GetGlyphInfoT2(info, glyph_index, NULL, NULL, NULL, NULL) == 0;
   g = stbtt__GetGlyfOffset(info, glyph_index);
   if (g < 0) return 1;
   numberOfContours = ttSHORT(info->data + g);
   return numberOfContours == 0;
}

static int stbtt__close_shape(stbtt_vertex *vertices, int num_vertices, int was_off, int start_off,
    stbtt_int32 sx, stbtt_int32 sy, stbtt_int32 scx, stbtt_int32 scy, stbtt_int32 cx, stbtt_int32 cy)
{
   if (start_off) {
      if (was_off)
         stbtt_setvertex(&vertices[num_vertices++], STBTT_vcurve, (cx+scx)>>1, (cy+scy)>>1, cx,cy);
      stbtt_setvertex(&vertices[num_vertices++], STBTT_vcurve, sx,sy,scx,scy);
   } else {
      if (was_off)
         stbtt_setvertex(&vertices[num_vertices++], STBTT_vcurve,sx,sy,cx,cy);
      else
         stbtt_setvertex(&vertices[num_vertices++], STBTT_vline,sx,sy,0,0);
   }
   return num_vertices;
}

static int stbtt__GetGlyphShapeTT(const stbtt_fontinfo *info, int glyph_index, stbtt_vertex **pvertices)
{
   stbtt_int16 numberOfContours;
   stbtt_uint8 *endPtsOfContours;
   stbtt_uint8 *data = info->data;
   stbtt_vertex *vertices=0;
   int num_vertices=0;
   int g = stbtt__GetGlyfOffset(info, glyph_index);

   *pvertices = NULL;

   if (g < 0) return 0;

   numberOfContours = ttSHORT(data + g);

   if (numberOfContours > 0) {
      stbtt_uint8 flags=0,flagcount;
      stbtt_int32 ins, i,j=0,m,n, next_move, was_off=0, off, start_off=0;
      stbtt_int32 x,y,cx,cy,sx,sy, scx,scy;
      stbtt_uint8 *points;
      endPtsOfContours = (data + g + 10);
      ins = ttUSHORT(data + g + 10 + numberOfContours * 2);
      points = data + g + 10 + numberOfContours * 2 + 2 + ins;

      n = 1+ttUSHORT(endPtsOfContours + numberOfContours*2-2);

      m = n + 2*numberOfContours;  // a loose bound on how many vertices we might need
      vertices = (stbtt_vertex *) STBTT_malloc(m * sizeof(vertices[0]), info->userdata);
      if (vertices == 0)
         return 0;

      next_move = 0;
      flagcount=0;

      // in first pass, we load uninterpreted data into the allocated array
      // above, shifted to the end of the array so we won't overwrite it when
      // we create our final data starting from the front

      off = m - n; // starting offset for uninterpreted data, regardless of how m ends up being calculated

      // first load flags

      for (i=0; i < n; ++i) {
         if (flagcount == 0) {
            flags = *points++;
            if (flags & 8)
               flagcount = *points++;
         } else
            --flagcount;
         vertices[off+i].type = flags;
      }

      // now load x coordinates
      x=0;
      for (i=0; i < n; ++i) {
         flags = vertices[off+i].type;
         if (flags & 2) {
            stbtt_int16 dx = *points++;
            x += (flags & 16) ? dx : -dx; // ???
         } else {
            if (!(flags & 16)) {
               x = x + (stbtt_int16) (points[0]*256 + points[1]);
               points += 2;
            }
         }
         vertices[off+i].x = (stbtt_int16) x;
      }

      // now load y coordinates
      y=0;
      for (i=0; i < n; ++i) {
         flags = vertices[off+i].type;
         if (flags & 4) {
            stbtt_int16 dy = *points++;
            y += (flags & 32) ? dy : -dy; // ???
         } else {
            if (!(flags & 32)) {
               y = y + (stbtt_int16) (points[0]*256 + points[1]);
               points += 2;
            }
         }
         vertices[off+i].y = (stbtt_int16) y;
      }

      // now convert them to our format
      num_vertices=0;
      sx = sy = cx = cy = scx = scy = 0;
      for (i=0; i < n; ++i) {
         flags = vertices[off+i].type;
         x     = (stbtt_int16) vertices[off+i].x;
         y     = (stbtt_int16) vertices[off+i].y;

         if (next_move == i) {
            if (i != 0)
               num_vertices = stbtt__close_shape(vertices, num_vertices, was_off, start_off, sx,sy,scx,scy,cx,cy);

            // now start the new one               
            start_off = !(flags & 1);
            if (start_off) {
               // if we start off with an off-curve point, then when we need to find a point on the curve
               // where we can start, and we need to save some state for when we wraparound.
               scx = x;
               scy = y;
               if (!(vertices[off+i+1].type & 1)) {
                  // next point is also a curve point, so interpolate an on-point curve
                  sx = (x + (stbtt_int32) vertices[off+i+1].x) >> 1;
                  sy = (y + (stbtt_int32) vertices[off+i+1].y) >> 1;
               } else {
                  // otherwise just use the next point as our start point
                  sx = (stbtt_int32) vertices[off+i+1].x;
                  sy = (stbtt_int32) vertices[off+i+1].y;
                  ++i; // we're using point i+1 as the starting point, so skip it
               }
            } else {
               sx = x;
               sy = y;
            }
            stbtt_setvertex(&vertices[num_vertices++], STBTT_vmove,sx,sy,0,0);
            was_off = 0;
            next_move = 1 + ttUSHORT(endPtsOfContours+j*2);
            ++j;
         } else {
            if (!(flags & 1)) { // if it's a curve
               if (was_off) // two off-curve control points in a row means interpolate an on-curve midpoint
                  stbtt_setvertex(&vertices[num_vertices++], STBTT_vcurve, (cx+x)>>1, (cy+y)>>1, cx, cy);
               cx = x;
               cy = y;
               was_off = 1;
            } else {
               if (was_off)
                  stbtt_setvertex(&vertices[num_vertices++], STBTT_vcurve, x,y, cx, cy);
               else
                  stbtt_setvertex(&vertices[num_vertices++], STBTT_vline, x,y,0,0);
               was_off = 0;
            }
         }
      }
      num_vertices = stbtt__close_shape(vertices, num_vertices, was_off, start_off, sx,sy,scx,scy,cx,cy);
   } else if (numberOfContours == -1) {
      // Compound shapes.
      int more = 1;
      stbtt_uint8 *comp = data + g + 10;
      num_vertices = 0;
      vertices = 0;
      while (more) {
         stbtt_uint16 flags, gidx;
         int comp_num_verts = 0, i;
         stbtt_vertex *comp_verts = 0, *tmp = 0;
         float mtx[6] = {1,0,0,1,0,0}, m, n;
         
         flags = ttSHORT(comp); comp+=2;
         gidx = ttSHORT(comp); comp+=2;

         if (flags & 2) { // XY values
            if (flags & 1) { // shorts
               mtx[4] = ttSHORT(comp); comp+=2;
               mtx[5] = ttSHORT(comp); comp+=2;
            } else {
               mtx[4] = ttCHAR(comp); comp+=1;
               mtx[5] = ttCHAR(comp); comp+=1;
            }
         }
         else {
            // @TODO handle matching point
            STBTT_assert(0);
         }
         if (flags & (1<<3)) { // WE_HAVE_A_SCALE
            mtx[0] = mtx[3] = ttSHORT(comp)/16384.0f; comp+=2;
            mtx[1] = mtx[2] = 0;
         } else if (flags & (1<<6)) { // WE_HAVE_AN_X_AND_YSCALE
            mtx[0] = ttSHORT(comp)/16384.0f; comp+=2;
            mtx[1] = mtx[2] = 0;
            mtx[3] = ttSHORT(comp)/16384.0f; comp+=2;
         } else if (flags & (1<<7)) { // WE_HAVE_A_TWO_BY_TWO
            mtx[0] = ttSHORT(comp)/16384.0f; comp+=2;
            mtx[1] = ttSHORT(comp)/16384.0f; comp+=2;
            mtx[2] = ttSHORT(comp)/16384.0f; comp+=2;
            mtx[3] = ttSHORT(comp)/16384.0f; comp+=2;
         }
         
         // Find transformation scales.
         m = (float) STBTT_sqrt(mtx[0]*mtx[0] + mtx[1]*mtx[1]);
         n = (float) STBTT_sqrt(mtx[2]*mtx[2] + mtx[3]*mtx[3]);

         // Get indexed glyph.
         comp_num_verts = stbtt_GetGlyphShape(info, gidx, &comp_verts);
         if (comp_num_verts > 0) {
            // Transform vertices.
            for (i = 0; i < comp_num_verts; ++i) {
               stbtt_vertex* v = &comp_verts[i];
               stbtt_vertex_type x,y;
               x=v->x; y=v->y;
               v->x = (stbtt_vertex_type)(m * (mtx[0]*x + mtx[2]*y + mtx[4]));
               v->y = (stbtt_vertex_type)(n * (mtx[1]*x + mtx[3]*y + mtx[5]));
               x=v->cx; y=v->cy;
               v->cx = (stbtt_vertex_type)(m * (mtx[0]*x + mtx[2]*y + mtx[4]));
               v->cy = (stbtt_vertex_type)(n * (mtx[1]*x + mtx[3]*y + mtx[5]));
            }
            // Append vertices.
            tmp = (stbtt_vertex*)STBTT_malloc((num_vertices+comp_num_verts)*sizeof(stbtt_vertex), info->userdata);
            if (!tmp) {
               if (vertices) STBTT_free(vertices, info->userdata);
               if (comp_verts) STBTT_free(comp_verts, info->userdata);
               return 0;
            }
            if (num_vertices > 0) STBTT_memcpy(tmp, vertices, num_vertices*sizeof(stbtt_vertex));
            STBTT_memcpy(tmp+num_vertices, comp_verts, comp_num_verts*sizeof(stbtt_vertex));
            if (vertices) STBTT_free(vertices, info->userdata);
            vertices = tmp;
            STBTT_free(comp_verts, info->userdata);
            num_vertices += comp_num_verts;
         }
         // More components ?
         more = flags & (1<<5);
      }
   } else if (numberOfContours < 0) {
      // @TODO other compound variations?
      STBTT_assert(0);
   } else {
      // numberOfCounters == 0, do nothing
   }

   *pvertices = vertices;
   return num_vertices;
}

typedef struct
{
   int bounds;
   int started;
   float first_x, first_y;
   float x, y;
   stbtt_int32 min_x, max_x, min_y, max_y;

   stbtt_vertex *pvertices;
   int num_vertices;
} stbtt__csctx;

#define STBTT__CSCTX_INIT(bounds) {bounds,0, 0,0, 0,0, 0,0,0,0, NULL, 0}

static void stbtt__track_vertex(stbtt__csctx *c, stbtt_int32 x, stbtt_int32 y)
{
   if (x > c->max_x || !c->started) c->max_x = x;
   if (y > c->max_y || !c->started) c->max_y = y;
   if (x < c->min_x || !c->started) c->min_x = x;
   if (y < c->min_y || !c->started) c->min_y = y;
   c->started = 1;
}

static void stbtt__csctx_v(stbtt__csctx *c, stbtt_uint8 type, stbtt_int32 x, stbtt_int32 y, stbtt_int32 cx, stbtt_int32 cy, stbtt_int32 cx1, stbtt_int32 cy1)
{
   if (c->bounds) {
      stbtt__track_vertex(c, x, y);
      if (type == STBTT_vcubic) {
         stbtt__track_vertex(c, cx, cy);
         stbtt__track_vertex(c, cx1, cy1);
      }
   } else {
      stbtt_setvertex(&c->pvertices[c->num_vertices], type, x, y, cx, cy);
      c->pvertices[c->num_vertices].cx1 = (stbtt_int16) cx1;
      c->pvertices[c->num_vertices].cy1 = (stbtt_int16) cy1;
   }
   c->num_vertices++;
}

static void stbtt__csctx_close_shape(stbtt__csctx *ctx)
{
   if (ctx->first_x != ctx->x || ctx->first_y != ctx->y)
      stbtt__csctx_v(ctx, STBTT_vline, (int)ctx->first_x, (int)ctx->first_y, 0, 0, 0, 0);
}

static void stbtt__csctx_rmove_to(stbtt__csctx *ctx, float dx, float dy)
{
   stbtt__csctx_close_shape(ctx);
   ctx->first_x = ctx->x = ctx->x + dx;
   ctx->first_y = ctx->y = ctx->y + dy;
   stbtt__csctx_v(ctx, STBTT_vmove, (int)ctx->x, (int)ctx->y, 0, 0, 0, 0);
}

static void stbtt__csctx_rline_to(stbtt__csctx *ctx, float dx, float dy)
{
   ctx->x += dx;
   ctx->y += dy;
   stbtt__csctx_v(ctx, STBTT_vline, (int)ctx->x, (int)ctx->y, 0, 0, 0, 0);
}

static void stbtt__csctx_rccurve_to(stbtt__csctx *ctx, float dx1, float dy1, float dx2, float dy2, float dx3, float dy3)
{
   float cx1 = ctx->x + dx1;
   float cy1 = ctx->y + dy1;
   float cx2 = cx1 + dx2;
   float cy2 = cy1 + dy2;
   ctx->x = cx2 + dx3;
   ctx->y = cy2 + dy3;
   stbtt__csctx_v(ctx, STBTT_vcubic, (int)ctx->x, (int)ctx->y, (int)cx1, (int)cy1, (int)cx2, (int)cy2);
}

static stbtt__buf stbtt__get_subr(stbtt__buf idx, int n)
{
   int count = stbtt__cff_index_count(&idx);
   int bias = 107;
   if (count >= 33900)
      bias = 32768;
   else if (count >= 1240)
      bias = 1131;
   n += bias;
   if (n < 0 || n >= count)
      return stbtt__new_buf(NULL, 0);
   return stbtt__cff_index_get(idx, n);
}

static stbtt__buf stbtt__cid_get_glyph_subrs(const stbtt_fontinfo *info, int glyph_index)
{
   stbtt__buf fdselect = info->fdselect;
   int nranges, start, end, v, fmt, fdselector = -1, i;

   stbtt__buf_seek(&fdselect, 0);
   fmt = stbtt__buf_get8(&fdselect);
   if (fmt == 0) {
      // untested
      stbtt__buf_skip(&fdselect, glyph_index);
      fdselector = stbtt__buf_get8(&fdselect);
   } else if (fmt == 3) {
      nranges = stbtt__buf_get16(&fdselect);
      start = stbtt__buf_get16(&fdselect);
      for (i = 0; i < nranges; i++) {
         v = stbtt__buf_get8(&fdselect);
         end = stbtt__buf_get16(&fdselect);
         if (glyph_index >= start && glyph_index < end) {
            fdselector = v;
            break;
         }
         start = end;
      }
   }
   if (fdselector == -1) stbtt__new_buf(NULL, 0);
   return stbtt__get_subrs(info->cff, stbtt__cff_index_get(info->fontdicts, fdselector));
}

static int stbtt__run_charstring(const stbtt_fontinfo *info, int glyph_index, stbtt__csctx *c)
{
   int in_header = 1, maskbits = 0, subr_stack_height = 0, sp = 0, v, i, b0;
   int has_subrs = 0, clear_stack;
   float s[48];
   stbtt__buf subr_stack[10], subrs = info->subrs, b;
   float f;

#define STBTT__CSERR(s) (0)

   // this currently ignores the initial width value, which isn't needed if we have hmtx
   b = stbtt__cff_index_get(info->charstrings, glyph_index);
   while (b.cursor < b.size) {
      i = 0;
      clear_stack = 1;
      b0 = stbtt__buf_get8(&b);
      switch (b0) {
      // @TODO implement hinting
      case 0x13: // hintmask
      case 0x14: // cntrmask
         if (in_header)
            maskbits += (sp / 2); // implicit "vstem"
         in_header = 0;
         stbtt__buf_skip(&b, (maskbits + 7) / 8);
         break;

      case 0x01: // hstem
      case 0x03: // vstem
      case 0x12: // hstemhm
      case 0x17: // vstemhm
         maskbits += (sp / 2);
         break;

      case 0x15: // rmoveto
         in_header = 0;
         if (sp < 2) return STBTT__CSERR("rmoveto stack");
         stbtt__csctx_rmove_to(c, s[sp-2], s[sp-1]);
         break;
      case 0x04: // vmoveto
         in_header = 0;
         if (sp < 1) return STBTT__CSERR("vmoveto stack");
         stbtt__csctx_rmove_to(c, 0, s[sp-1]);
         break;
      case 0x16: // hmoveto
         in_header = 0;
         if (sp < 1) return STBTT__CSERR("hmoveto stack");
         stbtt__csctx_rmove_to(c, s[sp-1], 0);
         break;

      case 0x05: // rlineto
         if (sp < 2) return STBTT__CSERR("rlineto stack");
         for (; i + 1 < sp; i += 2)
            stbtt__csctx_rline_to(c, s[i], s[i+1]);
         break;

      // hlineto/vlineto and vhcurveto/hvcurveto alternate horizontal and vertical
      // starting from a different place.

      case 0x07: // vlineto
         if (sp < 1) return STBTT__CSERR("vlineto stack");
         goto vlineto;
      case 0x06: // hlineto
         if (sp < 1) return STBTT__CSERR("hlineto stack");
         for (;;) {
            if (i >= sp) break;
            stbtt__csctx_rline_to(c, s[i], 0);
            i++;
      vlineto:
            if (i >= sp) break;
            stbtt__csctx_rline_to(c, 0, s[i]);
            i++;
         }
         break;

      case 0x1F: // hvcurveto
         if (sp < 4) return STBTT__CSERR("hvcurveto stack");
         goto hvcurveto;
      case 0x1E: // vhcurveto
         if (sp < 4) return STBTT__CSERR("vhcurveto stack");
         for (;;) {
            if (i + 3 >= sp) break;
            stbtt__csctx_rccurve_to(c, 0, s[i], s[i+1], s[i+2], s[i+3], (sp - i == 5) ? s[i + 4] : 0.0f);
            i += 4;
      hvcurveto:
            if (i + 3 >= sp) break;
            stbtt__csctx_rccurve_to(c, s[i], 0, s[i+1], s[i+2], (sp - i == 5) ? s[i+4] : 0.0f, s[i+3]);
            i += 4;
         }
         break;

      case 0x08: // rrcurveto
         if (sp < 6) return STBTT__CSERR("rcurveline stack");
         for (; i + 5 < sp; i += 6)
            stbtt__csctx_rccurve_to(c, s[i], s[i+1], s[i+2], s[i+3], s[i+4], s[i+5]);
         break;

      case 0x18: // rcurveline
         if (sp < 8) return STBTT__CSERR("rcurveline stack");
         for (; i + 5 < sp - 2; i += 6)
            stbtt__csctx_rccurve_to(c, s[i], s[i+1], s[i+2], s[i+3], s[i+4], s[i+5]);
         if (i + 1 >= sp) return STBTT__CSERR("rcurveline stack");
         stbtt__csctx_rline_to(c, s[i], s[i+1]);
         break;

      case 0x19: // rlinecurve
         if (sp < 8) return STBTT__CSERR("rlinecurve stack");
         for (; i + 1 < sp - 6; i += 2)
            stbtt__csctx_rline_to(c, s[i], s[i+1]);
         if (i + 5 >= sp) return STBTT__CSERR("rlinecurve stack");
         stbtt__csctx_rccurve_to(c, s[i], s[i+1], s[i+2], s[i+3], s[i+4], s[i+5]);
         break;

      case 0x1A: // vvcurveto
      case 0x1B: // hhcurveto
         if (sp < 4) return STBTT__CSERR("(vv|hh)curveto stack");
         f = 0.0;
         if (sp & 1) { f = s[i]; i++; }
         for (; i + 3 < sp; i += 4) {
            if (b0 == 0x1B)
               stbtt__csctx_rccurve_to(c, s[i], f, s[i+1], s[i+2], s[i+3], 0.0);
            else
               stbtt__csctx_rccurve_to(c, f, s[i], s[i+1], s[i+2], 0.0, s[i+3]);
            f = 0.0;
         }
         break;

      case 0x0A: // callsubr
         if (!has_subrs) {
            if (info->fdselect.size)
               subrs = stbtt__cid_get_glyph_subrs(info, glyph_index);
            has_subrs = 1;
         }
         // fallthrough
      case 0x1D: // callgsubr
         if (sp < 1) return STBTT__CSERR("call(g|)subr stack");
         v = (int) s[--sp];
         if (subr_stack_height >= 10) return STBTT__CSERR("recursion limit");
         subr_stack[subr_stack_height++] = b;
         b = stbtt__get_subr(b0 == 0x0A ? subrs : info->gsubrs, v);
         if (b.size == 0) return STBTT__CSERR("subr not found");
         b.cursor = 0;
         clear_stack = 0;
         break;

      case 0x0B: // return
         if (subr_stack_height <= 0) return STBTT__CSERR("return outside subr");
         b = subr_stack[--subr_stack_height];
         clear_stack = 0;
         break;

      case 0x0E: // endchar
         stbtt__csctx_close_shape(c);
         return 1;

      case 0x0C: { // two-byte escape
         float dx1, dx2, dx3, dx4, dx5, dx6, dy1, dy2, dy3, dy4, dy5, dy6;
         float dx, dy;
         int b1 = stbtt__buf_get8(&b);
         switch (b1) {
         // @TODO These "flex" implementations ignore the flex-depth and resolution,
         // and always draw beziers.
         case 0x22: // hflex
            if (sp < 7) return STBTT__CSERR("hflex stack");
            dx1 = s[0];
            dx2 = s[1];
            dy2 = s[2];
            dx3 = s[3];
            dx4 = s[4];
            dx5 = s[5];
            dx6 = s[6];
            stbtt__csctx_rccurve_to(c, dx1, 0, dx2, dy2, dx3, 0);
            stbtt__csctx_rccurve_to(c, dx4, 0, dx5, -dy2, dx6, 0);
            break;

         case 0x23: // flex
            if (sp < 13) return STBTT__CSERR("flex stack");
            dx1 = s[0];
            dy1 = s[1];
            dx2 = s[2];
            dy2 = s[3];
            dx3 = s[4];
            dy3 = s[5];
            dx4 = s[6];
            dy4 = s[7];
            dx5 = s[8];
            dy5 = s[9];
            dx6 = s[10];
            dy6 = s[11];
            //fd is s[12]
            stbtt__csctx_rccurve_to(c, dx1, dy1, dx2, dy2, dx3, dy3);
            stbtt__csctx_rccurve_to(c, dx4, dy4, dx5, dy5, dx6, dy6);
            break;

         case 0x24: // hflex1
            if (sp < 9) return STBTT__CSERR("hflex1 stack");
            dx1 = s[0];
            dy1 = s[1];
            dx2 = s[2];
            dy2 = s[3];
            dx3 = s[4];
            dx4 = s[5];
            dx5 = s[6];
            dy5 = s[7];
            dx6 = s[8];
            stbtt__csctx_rccurve_to(c, dx1, dy1, dx2, dy2, dx3, 0);
            stbtt__csctx_rccurve_to(c, dx4, 0, dx5, dy5, dx6, -(dy1+dy2+dy5));
            break;

         case 0x25: // flex1
            if (sp < 11) return STBTT__CSERR("flex1 stack");
            dx1 = s[0];
            dy1 = s[1];
            dx2 = s[2];
            dy2 = s[3];
            dx3 = s[4];
            dy3 = s[5];
            dx4 = s[6];
            dy4 = s[7];
            dx5 = s[8];
            dy5 = s[9];
            dx6 = dy6 = s[10];
            dx = dx1+dx2+dx3+dx4+dx5;
            dy = dy1+dy2+dy3+dy4+dy5;
            if (STBTT_fabs(dx) > STBTT_fabs(dy))
               dy6 = -dy;
            else
               dx6 = -dx;
            stbtt__csctx_rccurve_to(c, dx1, dy1, dx2, dy2, dx3, dy3);
            stbtt__csctx_rccurve_to(c, dx4, dy4, dx5, dy5, dx6, dy6);
            break;

         default:
            return STBTT__CSERR("unimplemented");
         }
      } break;

      default:
         if (b0 != 255 && b0 != 28 && (b0 < 32 || b0 > 254))
            return STBTT__CSERR("reserved operator");

         // push immediate
         if (b0 == 255) {
            f = (float)(stbtt_int32)stbtt__buf_get32(&b) / 0x10000;
         } else {
            stbtt__buf_skip(&b, -1);
            f = (float)(stbtt_int16)stbtt__cff_int(&b);
         }
         if (sp >= 48) return STBTT__CSERR("push stack overflow");
         s[sp++] = f;
         clear_stack = 0;
         break;
      }
      if (clear_stack) sp = 0;
   }
   return STBTT__CSERR("no endchar");

#undef STBTT__CSERR
}

static int stbtt__GetGlyphShapeT2(const stbtt_fontinfo *info, int glyph_index, stbtt_vertex **pvertices)
{
   // runs the charstring twice, once to count and once to output (to avoid realloc)
   stbtt__csctx count_ctx = STBTT__CSCTX_INIT(1);
   stbtt__csctx output_ctx = STBTT__CSCTX_INIT(0);
   if (stbtt__run_charstring(info, glyph_index, &count_ctx)) {
      *pvertices = (stbtt_vertex*)STBTT_malloc(count_ctx.num_vertices*sizeof(stbtt_vertex), info->userdata);
      output_ctx.pvertices = *pvertices;
      if (stbtt__run_charstring(info, glyph_index, &output_ctx)) {
         STBTT_assert(output_ctx.num_vertices == count_ctx.num_vertices);
         return output_ctx.num_vertices;
      }
   }
   *pvertices = NULL;
   return 0;
}

static int stbtt__GetGlyphInfoT2(const stbtt_fontinfo *info, int glyph_index, int *x0, int *y0, int *x1, int *y1)
{
   stbtt__csctx c = STBTT__CSCTX_INIT(1);
   int r = stbtt__run_charstring(info, glyph_index, &c);
   if (x0)  *x0 = r ? c.min_x : 0;
   if (y0)  *y0 = r ? c.min_y : 0;
   if (x1)  *x1 = r ? c.max_x : 0;
   if (y1)  *y1 = r ? c.max_y : 0;
   return r ? c.num_vertices : 0;
}

STBTT_DEF int stbtt_GetGlyphShape(const stbtt_fontinfo *info, int glyph_index, stbtt_vertex **pvertices)
{
   if (!info->cff.size)
      return stbtt__GetGlyphShapeTT(info, glyph_index, pvertices);
   else
      return stbtt__GetGlyphShapeT2(info, glyph_index, pvertices);
}

STBTT_DEF void stbtt_GetGlyphHMetrics(const stbtt_fontinfo *info, int glyph_index, int *advanceWidth, int *leftSideBearing)
{
   stbtt_uint16 numOfLongHorMetrics = ttUSHORT(info->data+info->hhea + 34);
   if (glyph_index < numOfLongHorMetrics) {
      if (advanceWidth)     *advanceWidth    = ttSHORT(info->data + info->hmtx + 4*glyph_index);
      if (leftSideBearing)  *leftSideBearing = ttSHORT(info->data + info->hmtx + 4*glyph_index + 2);
   } else {
      if (advanceWidth)     *advanceWidth    = ttSHORT(info->data + info->hmtx + 4*(numOfLongHorMetrics-1));
      if (leftSideBearing)  *leftSideBearing = ttSHORT(info->data + info->hmtx + 4*numOfLongHorMetrics + 2*(glyph_index - numOfLongHorMetrics));
   }
}

static int  stbtt__GetGlyphKernInfoAdvance(const stbtt_fontinfo *info, int glyph1, int glyph2)
{
   stbtt_uint8 *data = info->data + info->kern;
   stbtt_uint32 needle, straw;
   int l, r, m;

   // we only look at the first table. it must be 'horizontal' and format 0.
   if (!info->kern)
      return 0;
   if (ttUSHORT(data+2) < 1) // number of tables, need at least 1
      return 0;
   if (ttUSHORT(data+8) != 1) // horizontal flag must be set in format
      return 0;

   l = 0;
   r = ttUSHORT(data+10) - 1;
   needle = glyph1 << 16 | glyph2;
   while (l <= r) {
      m = (l + r) >> 1;
      straw = ttULONG(data+18+(m*6)); // note: unaligned read
      if (needle < straw)
         r = m - 1;
      else if (needle > straw)
         l = m + 1;
      else
         return ttSHORT(data+22+(m*6));
   }
   return 0;
}

static stbtt_int32  stbtt__GetCoverageIndex(stbtt_uint8 *coverageTable, int glyph)
{
    stbtt_uint16 coverageFormat = ttUSHORT(coverageTable);
    switch(coverageFormat) {
        case 1: {
            stbtt_uint16 glyphCount = ttUSHORT(coverageTable + 2);

            // Binary search.
            stbtt_int32 l=0, r=glyphCount-1, m;
            int straw, needle=glyph;
            while (l <= r) {
                stbtt_uint8 *glyphArray = coverageTable + 4;
                stbtt_uint16 glyphID;
                m = (l + r) >> 1;
                glyphID = ttUSHORT(glyphArray + 2 * m);
                straw = glyphID;
                if (needle < straw)
                    r = m - 1;
                else if (needle > straw)
                    l = m + 1;
                else {
                     return m;
                }
            }
        } break;

        case 2: {
            stbtt_uint16 rangeCount = ttUSHORT(coverageTable + 2);
            stbtt_uint8 *rangeArray = coverageTable + 4;

            // Binary search.
            stbtt_int32 l=0, r=rangeCount-1, m;
            int strawStart, strawEnd, needle=glyph;
            while (l <= r) {
                stbtt_uint8 *rangeRecord;
                m = (l + r) >> 1;
                rangeRecord = rangeArray + 6 * m;
                strawStart = ttUSHORT(rangeRecord);
                strawEnd = ttUSHORT(rangeRecord + 2);
                if (needle < strawStart)
                    r = m - 1;
                else if (needle > strawEnd)
                    l = m + 1;
                else {
                    stbtt_uint16 startCoverageIndex = ttUSHORT(rangeRecord + 4);
                    return startCoverageIndex + glyph - strawStart;
                }
            }
        } break;

        default: {
            // There are no other cases.
            STBTT_assert(0);
        } break;
    }

    return -1;
}

static stbtt_int32  stbtt__GetGlyphClass(stbtt_uint8 *classDefTable, int glyph)
{
    stbtt_uint16 classDefFormat = ttUSHORT(classDefTable);
    switch(classDefFormat)
    {
        case 1: {
            stbtt_uint16 startGlyphID = ttUSHORT(classDefTable + 2);
            stbtt_uint16 glyphCount = ttUSHORT(classDefTable + 4);
            stbtt_uint8 *classDef1ValueArray = classDefTable + 6;

            if (glyph >= startGlyphID && glyph < startGlyphID + glyphCount)
                return (stbtt_int32)ttUSHORT(classDef1ValueArray + 2 * (glyph - startGlyphID));

            classDefTable = classDef1ValueArray + 2 * glyphCount;
        } break;

        case 2: {
            stbtt_uint16 classRangeCount = ttUSHORT(classDefTable + 2);
            stbtt_uint8 *classRangeRecords = classDefTable + 4;

            // Binary search.
            stbtt_int32 l=0, r=classRangeCount-1, m;
            int strawStart, strawEnd, needle=glyph;
            while (l <= r) {
                stbtt_uint8 *classRangeRecord;
                m = (l + r) >> 1;
                classRangeRecord = classRangeRecords + 6 * m;
                strawStart = ttUSHORT(classRangeRecord);
                strawEnd = ttUSHORT(classRangeRecord + 2);
                if (needle < strawStart)
                    r = m - 1;
                else if (needle > strawEnd)
                    l = m + 1;
                else
                    return (stbtt_int32)ttUSHORT(classRangeRecord + 4);
            }

            classDefTable = classRangeRecords + 6 * classRangeCount;
        } break;

        default: {
            // There are no other cases.
            STBTT_assert(0);
        } break;
    }

    return -1;
}

// Define to STBTT_assert(x) if you want to break on unimplemented formats.
#define STBTT_GPOS_TODO_assert(x)

static stbtt_int32  stbtt__GetGlyphGPOSInfoAdvance(const stbtt_fontinfo *info, int glyph1, int glyph2)
{
    stbtt_uint16 lookupListOffset;
    stbtt_uint8 *lookupList;
    stbtt_uint16 lookupCount;
    stbtt_uint8 *data;
    stbtt_int32 i;

    if (!info->gpos) return 0;

    data = info->data + info->gpos;

    if (ttUSHORT(data+0) != 1) return 0; // Major version 1
    if (ttUSHORT(data+2) != 0) return 0; // Minor version 0

    lookupListOffset = ttUSHORT(data+8);
    lookupList = data + lookupListOffset;
    lookupCount = ttUSHORT(lookupList);

    for (i=0; i<lookupCount; ++i) {
        stbtt_uint16 lookupOffset = ttUSHORT(lookupList + 2 + 2 * i);
        stbtt_uint8 *lookupTable = lookupList + lookupOffset;

        stbtt_uint16 lookupType = ttUSHORT(lookupTable);
        stbtt_uint16 subTableCount = ttUSHORT(lookupTable + 4);
        stbtt_uint8 *subTableOffsets = lookupTable + 6;
        switch(lookupType) {
            case 2: { // Pair Adjustment Positioning Subtable
                stbtt_int32 sti;
                for (sti=0; sti<subTableCount; sti++) {
                    stbtt_uint16 subtableOffset = ttUSHORT(subTableOffsets + 2 * sti);
                    stbtt_uint8 *table = lookupTable + subtableOffset;
                    stbtt_uint16 posFormat = ttUSHORT(table);
                    stbtt_uint16 coverageOffset = ttUSHORT(table + 2);
                    stbtt_int32 coverageIndex = stbtt__GetCoverageIndex(table + coverageOffset, glyph1);
                    if (coverageIndex == -1) continue;

                    switch (posFormat) {
                        case 1: {
                            stbtt_int32 l, r, m;
                            int straw, needle;
                            stbtt_uint16 valueFormat1 = ttUSHORT(table + 4);
                            stbtt_uint16 valueFormat2 = ttUSHORT(table + 6);
                            stbtt_int32 valueRecordPairSizeInBytes = 2;
                            stbtt_uint16 pairSetCount = ttUSHORT(table + 8);
                            stbtt_uint16 pairPosOffset = ttUSHORT(table + 10 + 2 * coverageIndex);
                            stbtt_uint8 *pairValueTable = table + pairPosOffset;
                            stbtt_uint16 pairValueCount = ttUSHORT(pairValueTable);
                            stbtt_uint8 *pairValueArray = pairValueTable + 2;
                            // TODO: Support more formats.
                            STBTT_GPOS_TODO_assert(valueFormat1 == 4);
                            if (valueFormat1 != 4) return 0;
                            STBTT_GPOS_TODO_assert(valueFormat2 == 0);
                            if (valueFormat2 != 0) return 0;

                            STBTT_assert(coverageIndex < pairSetCount);
                            STBTT__NOTUSED(pairSetCount);

                            needle=glyph2;
                            r=pairValueCount-1;
                            l=0;

                            // Binary search.
                            while (l <= r) {
                                stbtt_uint16 secondGlyph;
                                stbtt_uint8 *pairValue;
                                m = (l + r) >> 1;
                                pairValue = pairValueArray + (2 + valueRecordPairSizeInBytes) * m;
                                secondGlyph = ttUSHORT(pairValue);
                                straw = secondGlyph;
                                if (needle < straw)
                                    r = m - 1;
                                else if (needle > straw)
                                    l = m + 1;
                                else {
                                    stbtt_int16 xAdvance = ttSHORT(pairValue + 2);
                                    return xAdvance;
                                }
                            }
                        } break;

                        case 2: {
                            stbtt_uint16 valueFormat1 = ttUSHORT(table + 4);
                            stbtt_uint16 valueFormat2 = ttUSHORT(table + 6);

                            stbtt_uint16 classDef1Offset = ttUSHORT(table + 8);
                            stbtt_uint16 classDef2Offset = ttUSHORT(table + 10);
                            int glyph1class = stbtt__GetGlyphClass(table + classDef1Offset, glyph1);
                            int glyph2class = stbtt__GetGlyphClass(table + classDef2Offset, glyph2);

                            stbtt_uint16 class1Count = ttUSHORT(table + 12);
                            stbtt_uint16 class2Count = ttUSHORT(table + 14);
                            STBTT_assert(glyph1class < class1Count);
                            STBTT_assert(glyph2class < class2Count);

                            // TODO: Support more formats.
                            STBTT_GPOS_TODO_assert(valueFormat1 == 4);
                            if (valueFormat1 != 4) return 0;
                            STBTT_GPOS_TODO_assert(valueFormat2 == 0);
                            if (valueFormat2 != 0) return 0;

                            if (glyph1class >= 0 && glyph1class < class1Count && glyph2class >= 0 && glyph2class < class2Count) {
                                stbtt_uint8 *class1Records = table + 16;
                                stbtt_uint8 *class2Records = class1Records + 2 * (glyph1class * class2Count);
                                stbtt_int16 xAdvance = ttSHORT(class2Records + 2 * glyph2class);
                                return xAdvance;
                            }
                        } break;

                        default: {
                            // There are no other cases.
                            STBTT_assert(0);
                            break;
                        };
                    }
                }
                break;
            };

            default:
                // TODO: Implement other stuff.
                break;
        }
    }

    return 0;
}

STBTT_DEF int  stbtt_GetGlyphKernAdvance(const stbtt_fontinfo *info, int g1, int g2)
{
   int xAdvance = 0;

   if (info->gpos)
      xAdvance += stbtt__GetGlyphGPOSInfoAdvance(info, g1, g2);

   if (info->kern)
      xAdvance += stbtt__GetGlyphKernInfoAdvance(info, g1, g2);

   return xAdvance;
}

STBTT_DEF int  stbtt_GetCodepointKernAdvance(const stbtt_fontinfo *info, int ch1, int ch2)
{
   if (!info->kern && !info->gpos) // if no kerning table, don't waste time looking up both codepoint->glyphs
      return 0;
   return stbtt_GetGlyphKernAdvance(info, stbtt_FindGlyphIndex(info,ch1), stbtt_FindGlyphIndex(info,ch2));
}

STBTT_DEF void stbtt_GetCodepointHMetrics(const stbtt_fontinfo *info, int codepoint, int *advanceWidth, int *leftSideBearing)
{
   stbtt_GetGlyphHMetrics(info, stbtt_FindGlyphIndex(info,codepoint), advanceWidth, leftSideBearing);
}

STBTT_DEF void stbtt_GetFontVMetrics(const stbtt_fontinfo *info, int *ascent, int *descent, int *lineGap)
{
   if (ascent ) *ascent  = ttSHORT(info->data+info->hhea + 4);
   if (descent) *descent = ttSHORT(info->data+info->hhea + 6);
   if (lineGap) *lineGap = ttSHORT(info->data+info->hhea + 8);
}

STBTT_DEF int  stbtt_GetFontVMetricsOS2(const stbtt_fontinfo *info, int *typoAscent, int *typoDescent, int *typoLineGap)
{
   int tab = stbtt__find_table(info->data, info->fontstart, "OS/2");
   if (!tab)
      return 0;
   if (typoAscent ) *typoAscent  = ttSHORT(info->data+tab + 68);
   if (typoDescent) *typoDescent = ttSHORT(info->data+tab + 70);
   if (typoLineGap) *typoLineGap = ttSHORT(info->data+tab + 72);
   return 1;
}

STBTT_DEF void stbtt_GetFontBoundingBox(const stbtt_fontinfo *info, int *x0, int *y0, int *x1, int *y1)
{
   *x0 = ttSHORT(info->data + info->head + 36);
   *y0 = ttSHORT(info->data + info->head + 38);
   *x1 = ttSHORT(info->data + info->head + 40);
   *y1 = ttSHORT(info->data + info->head + 42);
}

STBTT_DEF float stbtt_ScaleForPixelHeight(const stbtt_fontinfo *info, float height)
{
   int fheight = ttSHORT(info->data + info->hhea + 4) - ttSHORT(info->data + info->hhea + 6);
   return (float) height / fheight;
}

STBTT_DEF float stbtt_ScaleForMappingEmToPixels(const stbtt_fontinfo *info, float pixels)
{
   int unitsPerEm = ttUSHORT(info->data + info->head + 18);
   return pixels / unitsPerEm;
}

STBTT_DEF void stbtt_FreeShape(const stbtt_fontinfo *info, stbtt_vertex *v)
{
   STBTT_free(v, info->userdata);
}

//////////////////////////////////////////////////////////////////////////////
//
// antialiasing software rasterizer
//

STBTT_DEF void stbtt_GetGlyphBitmapBoxSubpixel(const stbtt_fontinfo *font, int glyph, float scale_x, float scale_y,float shift_x, float shift_y, int *ix0, int *iy0, int *ix1, int *iy1)
{
   int x0=0,y0=0,x1,y1; // =0 suppresses compiler warning
   if (!stbtt_GetGlyphBox(font, glyph, &x0,&y0,&x1,&y1)) {
      // e.g. space character
      if (ix0) *ix0 = 0;
      if (iy0) *iy0 = 0;
      if (ix1) *ix1 = 0;
      if (iy1) *iy1 = 0;
   } else {
      // move to integral bboxes (treating pixels as little squares, what pixels get touched)?
      if (ix0) *ix0 = STBTT_ifloor( x0 * scale_x + shift_x);
      if (iy0) *iy0 = STBTT_ifloor(-y1 * scale_y + shift_y);
      if (ix1) *ix1 = STBTT_iceil ( x1 * scale_x + shift_x);
      if (iy1) *iy1 = STBTT_iceil (-y0 * scale_y + shift_y);
   }
}

STBTT_DEF void stbtt_GetGlyphBitmapBox(const stbtt_fontinfo *font, int glyph, float scale_x, float scale_y, int *ix0, int *iy0, int *ix1, int *iy1)
{
   stbtt_GetGlyphBitmapBoxSubpixel(font, glyph, scale_x, scale_y,0.0f,0.0f, ix0, iy0, ix1, iy1);
}

STBTT_DEF void stbtt_GetCodepointBitmapBoxSubpixel(const stbtt_fontinfo *font, int codepoint, float scale_x, float scale_y, float shift_x, float shift_y, int *ix0, int *iy0, int *ix1, int *iy1)
{
   stbtt_GetGlyphBitmapBoxSubpixel(font, stbtt_FindGlyphIndex(font,codepoint), scale_x, scale_y,shift_x,shift_y, ix0,iy0,ix1,iy1);
}

STBTT_DEF void stbtt_GetCodepointBitmapBox(const stbtt_fontinfo *font, int codepoint, float scale_x, float scale_y, int *ix0, int *iy0, int *ix1, int *iy1)
{
   stbtt_GetCodepointBitmapBoxSubpixel(font, codepoint, scale_x, scale_y,0.0f,0.0f, ix0,iy0,ix1,iy1);
}

//////////////////////////////////////////////////////////////////////////////
//
//  Rasterizer

typedef struct stbtt__hheap_chunk
{
   struct stbtt__hheap_chunk *next;
} stbtt__hheap_chunk;

typedef struct stbtt__hheap
{
   struct stbtt__hheap_chunk *head;
   void   *first_free;
   int    num_remaining_in_head_chunk;
} stbtt__hheap;

static void *stbtt__hheap_alloc(stbtt__hheap *hh, size_t size, void *userdata)
{
   if (hh->first_free) {
      void *p = hh->first_free;
      hh->first_free = * (void **) p;
      return p;
   } else {
      if (hh->num_remaining_in_head_chunk == 0) {
         int count = (size < 32 ? 2000 : size < 128 ? 800 : 100);
         stbtt__hheap_chunk *c = (stbtt__hheap_chunk *) STBTT_malloc(sizeof(stbtt__hheap_chunk) + size * count, userdata);
         if (c == NULL)
            return NULL;
         c->next = hh->head;
         hh->head = c;
         hh->num_remaining_in_head_chunk = count;
      }
      --hh->num_remaining_in_head_chunk;
      return (char *) (hh->head) + sizeof(stbtt__hheap_chunk) + size * hh->num_remaining_in_head_chunk;
   }
}

static void stbtt__hheap_free(stbtt__hheap *hh, void *p)
{
   *(void **) p = hh->first_free;
   hh->first_free = p;
}

static void stbtt__hheap_cleanup(stbtt__hheap *hh, void *userdata)
{
   stbtt__hheap_chunk *c = hh->head;
   while (c) {
      stbtt__hheap_chunk *n = c->next;
      STBTT_free(c, userdata);
      c = n;
   }
}

typedef struct stbtt__edge {
   float x0,y0, x1,y1;
   int invert;
} stbtt__edge;


typedef struct stbtt__active_edge
{
   struct stbtt__active_edge *next;
   #if STBTT_RASTERIZER_VERSION==1
   int x,dx;
   float ey;
   int direction;
   #elif STBTT_RASTERIZER_VERSION==2
   float fx,fdx,fdy;
   float direction;
   float sy;
   float ey;
   #else
   #error "Unrecognized value of STBTT_RASTERIZER_VERSION"
   #endif
} stbtt__active_edge;

#if STBTT_RASTERIZER_VERSION == 1
#define STBTT_FIXSHIFT   10
#define STBTT_FIX        (1 << STBTT_FIXSHIFT)
#define STBTT_FIXMASK    (STBTT_FIX-1)

static stbtt__active_edge *stbtt__new_active(stbtt__hheap *hh, stbtt__edge *e, int off_x, float start_point, void *userdata)
{
   stbtt__active_edge *z = (stbtt__active_edge *) stbtt__hheap_alloc(hh, sizeof(*z), userdata);
   float dxdy = (e->x1 - e->x0) / (e->y1 - e->y0);
   STBTT_assert(z != NULL);
   if (!z) return z;
   
   // round dx down to avoid overshooting
   if (dxdy < 0)
      z->dx = -STBTT_ifloor(STBTT_FIX * -dxdy);
   else
      z->dx = STBTT_ifloor(STBTT_FIX * dxdy);

   z->x = STBTT_ifloor(STBTT_FIX * e->x0 + z->dx * (start_point - e->y0)); // use z->dx so when we offset later it's by the same amount
   z->x -= off_x * STBTT_FIX;

   z->ey = e->y1;
   z->next = 0;
   z->direction = e->invert ? 1 : -1;
   return z;
}
#elif STBTT_RASTERIZER_VERSION == 2
static stbtt__active_edge *stbtt__new_active(stbtt__hheap *hh, stbtt__edge *e, int off_x, float start_point, void *userdata)
{
   stbtt__active_edge *z = (stbtt__active_edge *) stbtt__hheap_alloc(hh, sizeof(*z), userdata);
   float dxdy = (e->x1 - e->x0) / (e->y1 - e->y0);
   STBTT_assert(z != NULL);
   //STBTT_assert(e->y0 <= start_point);
   if (!z) return z;
   z->fdx = dxdy;
   z->fdy = dxdy != 0.0f ? (1.0f/dxdy) : 0.0f;
   z->fx = e->x0 + dxdy * (start_point - e->y0);
   z->fx -= off_x;
   z->direction = e->invert ? 1.0f : -1.0f;
   z->sy = e->y0;
   z->ey = e->y1;
   z->next = 0;
   return z;
}
#else
#error "Unrecognized value of STBTT_RASTERIZER_VERSION"
#endif

#if STBTT_RASTERIZER_VERSION == 1
// note: this routine clips fills that extend off the edges... ideally this
// wouldn't happen, but it could happen if the truetype glyph bounding boxes
// are wrong, or if the user supplies a too-small bitmap
static void stbtt__fill_active_edges(unsigned char *scanline, int len, stbtt__active_edge *e, int max_weight)
{
   // non-zero winding fill
   int x0=0, w=0;

   while (e) {
      if (w == 0) {
         // if we're currently at zero, we need to record the edge start point
         x0 = e->x; w += e->direction;
      } else {
         int x1 = e->x; w += e->direction;
         // if we went to zero, we need to draw
         if (w == 0) {
            int i = x0 >> STBTT_FIXSHIFT;
            int j = x1 >> STBTT_FIXSHIFT;

            if (i < len && j >= 0) {
               if (i == j) {
                  // x0,x1 are the same pixel, so compute combined coverage
                  scanline[i] = scanline[i] + (stbtt_uint8) ((x1 - x0) * max_weight >> STBTT_FIXSHIFT);
               } else {
                  if (i >= 0) // add antialiasing for x0
                     scanline[i] = scanline[i] + (stbtt_uint8) (((STBTT_FIX - (x0 & STBTT_FIXMASK)) * max_weight) >> STBTT_FIXSHIFT);
                  else
                     i = -1; // clip

                  if (j < len) // add antialiasing for x1
                     scanline[j] = scanline[j] + (stbtt_uint8) (((x1 & STBTT_FIXMASK) * max_weight) >> STBTT_FIXSHIFT);
                  else
                     j = len; // clip

                  for (++i; i < j; ++i) // fill pixels between x0 and x1
                     scanline[i] = scanline[i] + (stbtt_uint8) max_weight;
               }
            }
         }
      }
      
      e = e->next;
   }
}

static void stbtt__rasterize_sorted_edges(stbtt__bitmap *result, stbtt__edge *e, int n, int vsubsample, int off_x, int off_y, void *userdata)
{
   stbtt__hheap hh = { 0, 0, 0 };
   stbtt__active_edge *active = NULL;
   int y,j=0;
   int max_weight = (255 / vsubsample);  // weight per vertical scanline
   int s; // vertical subsample index
   unsigned char scanline_data[512], *scanline;

   if (result->w > 512)
      scanline = (unsigned char *) STBTT_malloc(result->w, userdata);
   else
      scanline = scanline_data;

   y = off_y * vsubsample;
   e[n].y0 = (off_y + result->h) * (float) vsubsample + 1;

   while (j < result->h) {
      STBTT_memset(scanline, 0, result->w);
      for (s=0; s < vsubsample; ++s) {
         // find center of pixel for this scanline
         float scan_y = y + 0.5f;
         stbtt__active_edge **step = &active;

         // update all active edges;
         // remove all active edges that terminate before the center of this scanline
         while (*step) {
            stbtt__active_edge * z = *step;
            if (z->ey <= scan_y) {
               *step = z->next; // delete from list
               STBTT_assert(z->direction);
               z->direction = 0;
               stbtt__hheap_free(&hh, z);
            } else {
               z->x += z->dx; // advance to position for current scanline
               step = &((*step)->next); // advance through list
            }
         }

         // resort the list if needed
         for(;;) {
            int changed=0;
            step = &active;
            while (*step && (*step)->next) {
               if ((*step)->x > (*step)->next->x) {
                  stbtt__active_edge *t = *step;
                  stbtt__active_edge *q = t->next;

                  t->next = q->next;
                  q->next = t;
                  *step = q;
                  changed = 1;
               }
               step = &(*step)->next;
            }
            if (!changed) break;
         }

         // insert all edges that start before the center of this scanline -- omit ones that also end on this scanline
         while (e->y0 <= scan_y) {
            if (e->y1 > scan_y) {
               stbtt__active_edge *z = stbtt__new_active(&hh, e, off_x, scan_y, userdata);
               if (z != NULL) {
                  // find insertion point
                  if (active == NULL)
                     active = z;
                  else if (z->x < active->x) {
                     // insert at front
                     z->next = active;
                     active = z;
                  } else {
                     // find thing to insert AFTER
                     stbtt__active_edge *p = active;
                     while (p->next && p->next->x < z->x)
                        p = p->next;
                     // at this point, p->next->x is NOT < z->x
                     z->next = p->next;
                     p->next = z;
                  }
               }
            }
            ++e;
         }

         // now process all active edges in XOR fashion
         if (active)
            stbtt__fill_active_edges(scanline, result->w, active, max_weight);

         ++y;
      }
      STBTT_memcpy(result->pixels + j * result->stride, scanline, result->w);
      ++j;
   }

   stbtt__hheap_cleanup(&hh, userdata);

   if (scanline != scanline_data)
      STBTT_free(scanline, userdata);
}

#elif STBTT_RASTERIZER_VERSION == 2

// the edge passed in here does not cross the vertical line at x or the vertical line at x+1
// (i.e. it has already been clipped to those)
static void stbtt__handle_clipped_edge(float *scanline, int x, stbtt__active_edge *e, float x0, float y0, float x1, float y1)
{
   if (y0 == y1) return;
   STBTT_assert(y0 < y1);
   STBTT_assert(e->sy <= e->ey);
   if (y0 > e->ey) return;
   if (y1 < e->sy) return;
   if (y0 < e->sy) {
      x0 += (x1-x0) * (e->sy - y0) / (y1-y0);
      y0 = e->sy;
   }
   if (y1 > e->ey) {
      x1 += (x1-x0) * (e->ey - y1) / (y1-y0);
      y1 = e->ey;
   }

   if (x0 == x)
      STBTT_assert(x1 <= x+1);
   else if (x0 == x+1)
      STBTT_assert(x1 >= x);
   else if (x0 <= x)
      STBTT_assert(x1 <= x);
   else if (x0 >= x+1)
      STBTT_assert(x1 >= x+1);
   else
      STBTT_assert(x1 >= x && x1 <= x+1);

   if (x0 <= x && x1 <= x)
      scanline[x] += e->direction * (y1-y0);
   else if (x0 >= x+1 && x1 >= x+1)
      ;
   else {
      STBTT_assert(x0 >= x && x0 <= x+1 && x1 >= x && x1 <= x+1);
      scanline[x] += e->direction * (y1-y0) * (1-((x0-x)+(x1-x))/2); // coverage = 1 - average x position
   }
}

static void stbtt__fill_active_edges_new(float *scanline, float *scanline_fill, int len, stbtt__active_edge *e, float y_top)
{
   float y_bottom = y_top+1;

   while (e) {
      // brute force every pixel

      // compute intersection points with top & bottom
      STBTT_assert(e->ey >= y_top);

      if (e->fdx == 0) {
         float x0 = e->fx;
         if (x0 < len) {
            if (x0 >= 0) {
               stbtt__handle_clipped_edge(scanline,(int) x0,e, x0,y_top, x0,y_bottom);
               stbtt__handle_clipped_edge(scanline_fill-1,(int) x0+1,e, x0,y_top, x0,y_bottom);
            } else {
               stbtt__handle_clipped_edge(scanline_fill-1,0,e, x0,y_top, x0,y_bottom);
            }
         }
      } else {
         float x0 = e->fx;
         float dx = e->fdx;
         float xb = x0 + dx;
         float x_top, x_bottom;
         float sy0,sy1;
         float dy = e->fdy;
         STBTT_assert(e->sy <= y_bottom && e->ey >= y_top);

         // compute endpoints of line segment clipped to this scanline (if the
         // line segment starts on this scanline. x0 is the intersection of the
         // line with y_top, but that may be off the line segment.
         if (e->sy > y_top) {
            x_top = x0 + dx * (e->sy - y_top);
            sy0 = e->sy;
         } else {
            x_top = x0;
            sy0 = y_top;
         }
         if (e->ey < y_bottom) {
            x_bottom = x0 + dx * (e->ey - y_top);
            sy1 = e->ey;
         } else {
            x_bottom = xb;
            sy1 = y_bottom;
         }

         if (x_top >= 0 && x_bottom >= 0 && x_top < len && x_bottom < len) {
            // from here on, we don't have to range check x values

            if ((int) x_top == (int) x_bottom) {
               float height;
               // simple case, only spans one pixel
               int x = (int) x_top;
               height = sy1 - sy0;
               STBTT_assert(x >= 0 && x < len);
               scanline[x] += e->direction * (1-((x_top - x) + (x_bottom-x))/2)  * height;
               scanline_fill[x] += e->direction * height; // everything right of this pixel is filled
            } else {
               int x,x1,x2;
               float y_crossing, step, sign, area;
               // covers 2+ pixels
               if (x_top > x_bottom) {
                  // flip scanline vertically; signed area is the same
                  float t;
                  sy0 = y_bottom - (sy0 - y_top);
                  sy1 = y_bottom - (sy1 - y_top);
                  t = sy0, sy0 = sy1, sy1 = t;
                  t = x_bottom, x_bottom = x_top, x_top = t;
                  dx = -dx;
                  dy = -dy;
                  t = x0, x0 = xb, xb = t;
               }

               x1 = (int) x_top;
               x2 = (int) x_bottom;
               // compute intersection with y axis at x1+1
               y_crossing = (x1+1 - x0) * dy + y_top;

               sign = e->direction;
               // area of the rectangle covered from y0..y_crossing
               area = sign * (y_crossing-sy0);
               // area of the triangle (x_top,y0), (x+1,y0), (x+1,y_crossing)
               scanline[x1] += area * (1-((x_top - x1)+(x1+1-x1))/2);

               step = sign * dy;
               for (x = x1+1; x < x2; ++x) {
                  scanline[x] += area + step/2;
                  area += step;
               }
               y_crossing += dy * (x2 - (x1+1));

               STBTT_assert(STBTT_fabs(area) <= 1.01f);

               scanline[x2] += area + sign * (1-((x2-x2)+(x_bottom-x2))/2) * (sy1-y_crossing);

               scanline_fill[x2] += sign * (sy1-sy0);
            }
         } else {
            // if edge goes outside of box we're drawing, we require
            // clipping logic. since this does not match the intended use
            // of this library, we use a different, very slow brute
            // force implementation
            int x;
            for (x=0; x < len; ++x) {
               // cases:
               //
               // there can be up to two intersections with the pixel. any intersection
               // with left or right edges can be handled by splitting into two (or three)
               // regions. intersections with top & bottom do not necessitate case-wise logic.
               //
               // the old way of doing this found the intersections with the left & right edges,
               // then used some simple logic to produce up to three segments in sorted order
               // from top-to-bottom. however, this had a problem: if an x edge was epsilon
               // across the x border, then the corresponding y position might not be distinct
               // from the other y segment, and it might ignored as an empty segment. to avoid
               // that, we need to explicitly produce segments based on x positions.

               // rename variables to clearly-defined pairs
               float y0 = y_top;
               float x1 = (float) (x);
               float x2 = (float) (x+1);
               float x3 = xb;
               float y3 = y_bottom;

               // x = e->x + e->dx * (y-y_top)
               // (y-y_top) = (x - e->x) / e->dx
               // y = (x - e->x) / e->dx + y_top
               float y1 = (x - x0) / dx + y_top;
               float y2 = (x+1 - x0) / dx + y_top;

               if (x0 < x1 && x3 > x2) {         // three segments descending down-right
                  stbtt__handle_clipped_edge(scanline,x,e, x0,y0, x1,y1);
                  stbtt__handle_clipped_edge(scanline,x,e, x1,y1, x2,y2);
                  stbtt__handle_clipped_edge(scanline,x,e, x2,y2, x3,y3);
               } else if (x3 < x1 && x0 > x2) {  // three segments descending down-left
                  stbtt__handle_clipped_edge(scanline,x,e, x0,y0, x2,y2);
                  stbtt__handle_clipped_edge(scanline,x,e, x2,y2, x1,y1);
                  stbtt__handle_clipped_edge(scanline,x,e, x1,y1, x3,y3);
               } else if (x0 < x1 && x3 > x1) {  // two segments across x, down-right
                  stbtt__handle_clipped_edge(scanline,x,e, x0,y0, x1,y1);
                  stbtt__handle_clipped_edge(scanline,x,e, x1,y1, x3,y3);
               } else if (x3 < x1 && x0 > x1) {  // two segments across x, down-left
                  stbtt__handle_clipped_edge(scanline,x,e, x0,y0, x1,y1);
                  stbtt__handle_clipped_edge(scanline,x,e, x1,y1, x3,y3);
               } else if (x0 < x2 && x3 > x2) {  // two segments across x+1, down-right
                  stbtt__handle_clipped_edge(scanline,x,e, x0,y0, x2,y2);
                  stbtt__handle_clipped_edge(scanline,x,e, x2,y2, x3,y3);
               } else if (x3 < x2 && x0 > x2) {  // two segments across x+1, down-left
                  stbtt__handle_clipped_edge(scanline,x,e, x0,y0, x2,y2);
                  stbtt__handle_clipped_edge(scanline,x,e, x2,y2, x3,y3);
               } else {  // one segment
                  stbtt__handle_clipped_edge(scanline,x,e, x0,y0, x3,y3);
               }
            }
         }
      }
      e = e->next;
   }
}

// directly AA rasterize edges w/o supersampling
static void stbtt__rasterize_sorted_edges(stbtt__bitmap *result, stbtt__edge *e, int n, int vsubsample, int off_x, int off_y, void *userdata)
{
   stbtt__hheap hh = { 0, 0, 0 };
   stbtt__active_edge *active = NULL;
   int y,j=0, i;
   float scanline_data[129], *scanline, *scanline2;

   STBTT__NOTUSED(vsubsample);

   if (result->w > 64)
      scanline = (float *) STBTT_malloc((result->w*2+1) * sizeof(float), userdata);
   else
      scanline = scanline_data;

   scanline2 = scanline + result->w;

   y = off_y;
   e[n].y0 = (float) (off_y + result->h) + 1;

   while (j < result->h) {
      // find center of pixel for this scanline
      float scan_y_top    = y + 0.0f;
      float scan_y_bottom = y + 1.0f;
      stbtt__active_edge **step = &active;

      STBTT_memset(scanline , 0, result->w*sizeof(scanline[0]));
      STBTT_memset(scanline2, 0, (result->w+1)*sizeof(scanline[0]));

      // update all active edges;
      // remove all active edges that terminate before the top of this scanline
      while (*step) {
         stbtt__active_edge * z = *step;
         if (z->ey <= scan_y_top) {
            *step = z->next; // delete from list
            STBTT_assert(z->direction);
            z->direction = 0;
            stbtt__hheap_free(&hh, z);
         } else {
            step = &((*step)->next); // advance through list
         }
      }

      // insert all edges that start before the bottom of this scanline
      while (e->y0 <= scan_y_bottom) {
         if (e->y0 != e->y1) {
            stbtt__active_edge *z = stbtt__new_active(&hh, e, off_x, scan_y_top, userdata);
            if (z != NULL) {
               if (j == 0 && off_y != 0) {
                  if (z->ey < scan_y_top) {
                     // this can happen due to subpixel positioning and some kind of fp rounding error i think
                     z->ey = scan_y_top;
                  }
               }
               STBTT_assert(z->ey >= scan_y_top); // if we get really unlucky a tiny bit of an edge can be out of bounds
               // insert at front
               z->next = active;
               active = z;
            }
         }
         ++e;
      }

      // now process all active edges
      if (active)
         stbtt__fill_active_edges_new(scanline, scanline2+1, result->w, active, scan_y_top);

      {
         float sum = 0;
         for (i=0; i < result->w; ++i) {
            float k;
            int m;
            sum += scanline2[i];
            k = scanline[i] + sum;
            k = (float) STBTT_fabs(k)*255 + 0.5f;
            m = (int) k;
            if (m > 255) m = 255;
            result->pixels[j*result->stride + i] = (unsigned char) m;
         }
      }
      // advance all the edges
      step = &active;
      while (*step) {
         stbtt__active_edge *z = *step;
         z->fx += z->fdx; // advance to position for current scanline
         step = &((*step)->next); // advance through list
      }

      ++y;
      ++j;
   }

   stbtt__hheap_cleanup(&hh, userdata);

   if (scanline != scanline_data)
      STBTT_free(scanline, userdata);
}
#else
#error "Unrecognized value of STBTT_RASTERIZER_VERSION"
#endif

#define STBTT__COMPARE(a,b)  ((a)->y0 < (b)->y0)

static void stbtt__sort_edges_ins_sort(stbtt__edge *p, int n)
{
   int i,j;
   for (i=1; i < n; ++i) {
      stbtt__edge t = p[i], *a = &t;
      j = i;
      while (j > 0) {
         stbtt__edge *b = &p[j-1];
         int c = STBTT__COMPARE(a,b);
         if (!c) break;
         p[j] = p[j-1];
         --j;
      }
      if (i != j)
         p[j] = t;
   }
}

static void stbtt__sort_edges_quicksort(stbtt__edge *p, int n)
{
   /* threshold for transitioning to insertion sort */
   while (n > 12) {
      stbtt__edge t;
      int c01,c12,c,m,i,j;

      /* compute median of three */
      m = n >> 1;
      c01 = STBTT__COMPARE(&p[0],&p[m]);
      c12 = STBTT__COMPARE(&p[m],&p[n-1]);
      /* if 0 >= mid >= end, or 0 < mid < end, then use mid */
      if (c01 != c12) {
         /* otherwise, we'll need to swap something else to middle */
         int z;
         c = STBTT__COMPARE(&p[0],&p[n-1]);
         /* 0>mid && mid<n:  0>n => n; 0<n => 0 */
         /* 0<mid && mid>n:  0>n => 0; 0<n => n */
         z = (c == c12) ? 0 : n-1;
         t = p[z];
         p[z] = p[m];
         p[m] = t;
      }
      /* now p[m] is the median-of-three */
      /* swap it to the beginning so it won't move around */
      t = p[0];
      p[0] = p[m];
      p[m] = t;

      /* partition loop */
      i=1;
      j=n-1;
      for(;;) {
         /* handling of equality is crucial here */
         /* for sentinels & efficiency with duplicates */
         for (;;++i) {
            if (!STBTT__COMPARE(&p[i], &p[0])) break;
         }
         for (;;--j) {
            if (!STBTT__COMPARE(&p[0], &p[j])) break;
         }
         /* make sure we haven't crossed */
         if (i >= j) break;
         t = p[i];
         p[i] = p[j];
         p[j] = t;

         ++i;
         --j;
      }
      /* recurse on smaller side, iterate on larger */
      if (j < (n-i)) {
         stbtt__sort_edges_quicksort(p,j);
         p = p+i;
         n = n-i;
      } else {
         stbtt__sort_edges_quicksort(p+i, n-i);
         n = j;
      }
   }
}

static void stbtt__sort_edges(stbtt__edge *p, int n)
{
   stbtt__sort_edges_quicksort(p, n);
   stbtt__sort_edges_ins_sort(p, n);
}

typedef struct
{
   float x,y;
} stbtt__point;

static void stbtt__rasterize(stbtt__bitmap *result, stbtt__point *pts, int *wcount, int windings, float scale_x, float scale_y, float shift_x, float shift_y, int off_x, int off_y, int invert, void *userdata)
{
   float y_scale_inv = invert ? -scale_y : scale_y;
   stbtt__edge *e;
   int n,i,j,k,m;
#if STBTT_RASTERIZER_VERSION == 1
   int vsubsample = result->h < 8 ? 15 : 5;
#elif STBTT_RASTERIZER_VERSION == 2
   int vsubsample = 1;
#else
   #error "Unrecognized value of STBTT_RASTERIZER_VERSION"
#endif
   // vsubsample should divide 255 evenly; otherwise we won't reach full opacity

   // now we have to blow out the windings into explicit edge lists
   n = 0;
   for (i=0; i < windings; ++i)
      n += wcount[i];

   e = (stbtt__edge *) STBTT_malloc(sizeof(*e) * (n+1), userdata); // add an extra one as a sentinel
   if (e == 0) return;
   n = 0;

   m=0;
   for (i=0; i < windings; ++i) {
      stbtt__point *p = pts + m;
      m += wcount[i];
      j = wcount[i]-1;
      for (k=0; k < wcount[i]; j=k++) {
         int a=k,b=j;
         // skip the edge if horizontal
         if (p[j].y == p[k].y)
            continue;
         // add edge from j to k to the list
         e[n].invert = 0;
         if (invert ? p[j].y > p[k].y : p[j].y < p[k].y) {
            e[n].invert = 1;
            a=j,b=k;
         }
         e[n].x0 = p[a].x * scale_x + shift_x;
         e[n].y0 = (p[a].y * y_scale_inv + shift_y) * vsubsample;
         e[n].x1 = p[b].x * scale_x + shift_x;
         e[n].y1 = (p[b].y * y_scale_inv + shift_y) * vsubsample;
         ++n;
      }
   }

   // now sort the edges by their highest point (should snap to integer, and then by x)
   //STBTT_sort(e, n, sizeof(e[0]), stbtt__edge_compare);
   stbtt__sort_edges(e, n);

   // now, traverse the scanlines and find the intersections on each scanline, use xor winding rule
   stbtt__rasterize_sorted_edges(result, e, n, vsubsample, off_x, off_y, userdata);

   STBTT_free(e, userdata);
}

static void stbtt__add_point(stbtt__point *points, int n, float x, float y)
{
   if (!points) return; // during first pass, it's unallocated
   points[n].x = x;
   points[n].y = y;
}

// tessellate until threshold p is happy... @TODO warped to compensate for non-linear stretching
static int stbtt__tesselate_curve(stbtt__point *points, int *num_points, float x0, float y0, float x1, float y1, float x2, float y2, float objspace_flatness_squared, int n)
{
   // midpoint
   float mx = (x0 + 2*x1 + x2)/4;
   float my = (y0 + 2*y1 + y2)/4;
   // versus directly drawn line
   float dx = (x0+x2)/2 - mx;
   float dy = (y0+y2)/2 - my;
   if (n > 16) // 65536 segments on one curve better be enough!
      return 1;
   if (dx*dx+dy*dy > objspace_flatness_squared) { // half-pixel error allowed... need to be smaller if AA
      stbtt__tesselate_curve(points, num_points, x0,y0, (x0+x1)/2.0f,(y0+y1)/2.0f, mx,my, objspace_flatness_squared,n+1);
      stbtt__tesselate_curve(points, num_points, mx,my, (x1+x2)/2.0f,(y1+y2)/2.0f, x2,y2, objspace_flatness_squared,n+1);
   } else {
      stbtt__add_point(points, *num_points,x2,y2);
      *num_points = *num_points+1;
   }
   return 1;
}

static void stbtt__tesselate_cubic(stbtt__point *points, int *num_points, float x0, float y0, float x1, float y1, float x2, float y2, float x3, float y3, float objspace_flatness_squared, int n)
{
   // @TODO this "flatness" calculation is just made-up nonsense that seems to work well enough
   float dx0 = x1-x0;
   float dy0 = y1-y0;
   float dx1 = x2-x1;
   float dy1 = y2-y1;
   float dx2 = x3-x2;
   float dy2 = y3-y2;
   float dx = x3-x0;
   float dy = y3-y0;
   float longlen = (float) (STBTT_sqrt(dx0*dx0+dy0*dy0)+STBTT_sqrt(dx1*dx1+dy1*dy1)+STBTT_sqrt(dx2*dx2+dy2*dy2));
   float shortlen = (float) STBTT_sqrt(dx*dx+dy*dy);
   float flatness_squared = longlen*longlen-shortlen*shortlen;

   if (n > 16) // 65536 segments on one curve better be enough!
      return;

   if (flatness_squared > objspace_flatness_squared) {
      float x01 = (x0+x1)/2;
      float y01 = (y0+y1)/2;
      float x12 = (x1+x2)/2;
      float y12 = (y1+y2)/2;
      float x23 = (x2+x3)/2;
      float y23 = (y2+y3)/2;

      float xa = (x01+x12)/2;
      float ya = (y01+y12)/2;
      float xb = (x12+x23)/2;
      float yb = (y12+y23)/2;

      float mx = (xa+xb)/2;
      float my = (ya+yb)/2;

      stbtt__tesselate_cubic(points, num_points, x0,y0, x01,y01, xa,ya, mx,my, objspace_flatness_squared,n+1);
      stbtt__tesselate_cubic(points, num_points, mx,my, xb,yb, x23,y23, x3,y3, objspace_flatness_squared,n+1);
   } else {
      stbtt__add_point(points, *num_points,x3,y3);
      *num_points = *num_points+1;
   }
}

// returns number of contours
static stbtt__point *stbtt_FlattenCurves(stbtt_vertex *vertices, int num_verts, float objspace_flatness, int **contour_lengths, int *num_contours, void *userdata)
{
   stbtt__point *points=0;
   int num_points=0;

   float objspace_flatness_squared = objspace_flatness * objspace_flatness;
   int i,n=0,start=0, pass;

   // count how many "moves" there are to get the contour count
   for (i=0; i < num_verts; ++i)
      if (vertices[i].type == STBTT_vmove)
         ++n;

   *num_contours = n;
   if (n == 0) return 0;

   *contour_lengths = (int *) STBTT_malloc(sizeof(**contour_lengths) * n, userdata);

   if (*contour_lengths == 0) {
      *num_contours = 0;
      return 0;
   }

   // make two passes through the points so we don't need to realloc
   for (pass=0; pass < 2; ++pass) {
      float x=0,y=0;
      if (pass == 1) {
         points = (stbtt__point *) STBTT_malloc(num_points * sizeof(points[0]), userdata);
         if (points == NULL) goto error;
      }
      num_points = 0;
      n= -1;
      for (i=0; i < num_verts; ++i) {
         switch (vertices[i].type) {
            case STBTT_vmove:
               // start the next contour
               if (n >= 0)
                  (*contour_lengths)[n] = num_points - start;
               ++n;
               start = num_points;

               x = vertices[i].x, y = vertices[i].y;
               stbtt__add_point(points, num_points++, x,y);
               break;
            case STBTT_vline:
               x = vertices[i].x, y = vertices[i].y;
               stbtt__add_point(points, num_points++, x, y);
               break;
            case STBTT_vcurve:
               stbtt__tesselate_curve(points, &num_points, x,y,
                                        vertices[i].cx, vertices[i].cy,
                                        vertices[i].x,  vertices[i].y,
                                        objspace_flatness_squared, 0);
               x = vertices[i].x, y = vertices[i].y;
               break;
            case STBTT_vcubic:
               stbtt__tesselate_cubic(points, &num_points, x,y,
                                        vertices[i].cx, vertices[i].cy,
                                        vertices[i].cx1, vertices[i].cy1,
                                        vertices[i].x,  vertices[i].y,
                                        objspace_flatness_squared, 0);
               x = vertices[i].x, y = vertices[i].y;
               break;
         }
      }
      (*contour_lengths)[n] = num_points - start;
   }

   return points;
error:
   STBTT_free(points, userdata);
   STBTT_free(*contour_lengths, userdata);
   *contour_lengths = 0;
   *num_contours = 0;
   return NULL;
}

STBTT_DEF void stbtt_Rasterize(stbtt__bitmap *result, float flatness_in_pixels, stbtt_vertex *vertices, int num_verts, float scale_x, float scale_y, float shift_x, float shift_y, int x_off, int y_off, int invert, void *userdata)
{
   float scale            = scale_x > scale_y ? scale_y : scale_x;
   int winding_count      = 0;
   int *winding_lengths   = NULL;
   stbtt__point *windings = stbtt_FlattenCurves(vertices, num_verts, flatness_in_pixels / scale, &winding_lengths, &winding_count, userdata);
   if (windings) {
      stbtt__rasterize(result, windings, winding_lengths, winding_count, scale_x, scale_y, shift_x, shift_y, x_off, y_off, invert, userdata);
      STBTT_free(winding_lengths, userdata);
      STBTT_free(windings, userdata);
   }
}

STBTT_DEF void stbtt_FreeBitmap(unsigned char *bitmap, void *userdata)
{
   STBTT_free(bitmap, userdata);
}

STBTT_DEF unsigned char *stbtt_GetGlyphBitmapSubpixel(const stbtt_fontinfo *info, float scale_x, float scale_y, float shift_x, float shift_y, int glyph, int *width, int *height, int *xoff, int *yoff)
{
   int ix0,iy0,ix1,iy1;
   stbtt__bitmap gbm;
   stbtt_vertex *vertices;   
   int num_verts = stbtt_GetGlyphShape(info, glyph, &vertices);

   if (scale_x == 0) scale_x = scale_y;
   if (scale_y == 0) {
      if (scale_x == 0) {
         STBTT_free(vertices, info->userdata);
         return NULL;
      }
      scale_y = scale_x;
   }

   stbtt_GetGlyphBitmapBoxSubpixel(info, glyph, scale_x, scale_y, shift_x, shift_y, &ix0,&iy0,&ix1,&iy1);

   // now we get the size
   gbm.w = (ix1 - ix0);
   gbm.h = (iy1 - iy0);
   gbm.pixels = NULL; // in case we error

   if (width ) *width  = gbm.w;
   if (height) *height = gbm.h;
   if (xoff  ) *xoff   = ix0;
   if (yoff  ) *yoff   = iy0;
   
   if (gbm.w && gbm.h) {
      gbm.pixels = (unsigned char *) STBTT_malloc(gbm.w * gbm.h, info->userdata);
      if (gbm.pixels) {
         gbm.stride = gbm.w;

         stbtt_Rasterize(&gbm, 0.35f, vertices, num_verts, scale_x, scale_y, shift_x, shift_y, ix0, iy0, 1, info->userdata);
      }
   }
   STBTT_free(vertices, info->userdata);
   return gbm.pixels;
}   

STBTT_DEF unsigned char *stbtt_GetGlyphBitmap(const stbtt_fontinfo *info, float scale_x, float scale_y, int glyph, int *width, int *height, int *xoff, int *yoff)
{
   return stbtt_GetGlyphBitmapSubpixel(info, scale_x, scale_y, 0.0f, 0.0f, glyph, width, height, xoff, yoff);
}

STBTT_DEF void stbtt_MakeGlyphBitmapSubpixel(const stbtt_fontinfo *info, unsigned char *output, int out_w, int out_h, int out_stride, float scale_x, float scale_y, float shift_x, float shift_y, int glyph)
{
   int ix0,iy0;
   stbtt_vertex *vertices;
   int num_verts = stbtt_GetGlyphShape(info, glyph, &vertices);
   stbtt__bitmap gbm;   

   stbtt_GetGlyphBitmapBoxSubpixel(info, glyph, scale_x, scale_y, shift_x, shift_y, &ix0,&iy0,0,0);
   gbm.pixels = output;
   gbm.w = out_w;
   gbm.h = out_h;
   gbm.stride = out_stride;

   if (gbm.w && gbm.h)
      stbtt_Rasterize(&gbm, 0.35f, vertices, num_verts, scale_x, scale_y, shift_x, shift_y, ix0,iy0, 1, info->userdata);

   STBTT_free(vertices, info->userdata);
}

STBTT_DEF void stbtt_MakeGlyphBitmap(const stbtt_fontinfo *info, unsigned char *output, int out_w, int out_h, int out_stride, float scale_x, float scale_y, int glyph)
{
   stbtt_MakeGlyphBitmapSubpixel(info, output, out_w, out_h, out_stride, scale_x, scale_y, 0.0f,0.0f, glyph);
}

STBTT_DEF unsigned char *stbtt_GetCodepointBitmapSubpixel(const stbtt_fontinfo *info, float scale_x, float scale_y, float shift_x, float shift_y, int codepoint, int *width, int *height, int *xoff, int *yoff)
{
   return stbtt_GetGlyphBitmapSubpixel(info, scale_x, scale_y,shift_x,shift_y, stbtt_FindGlyphIndex(info,codepoint), width,height,xoff,yoff);
}   

STBTT_DEF void stbtt_MakeCodepointBitmapSubpixelPrefilter(const stbtt_fontinfo *info, unsigned char *output, int out_w, int out_h, int out_stride, float scale_x, float scale_y, float shift_x, float shift_y, int oversample_x, int oversample_y, float *sub_x, float *sub_y, int codepoint)
{
   stbtt_MakeGlyphBitmapSubpixelPrefilter(info, output, out_w, out_h, out_stride, scale_x, scale_y, shift_x, shift_y, oversample_x, oversample_y, sub_x, sub_y, stbtt_FindGlyphIndex(info,codepoint));
}

STBTT_DEF void stbtt_MakeCodepointBitmapSubpixel(const stbtt_fontinfo *info, unsigned char *output, int out_w, int out_h, int out_stride, float scale_x, float scale_y, float shift_x, float shift_y, int codepoint)
{
   stbtt_MakeGlyphBitmapSubpixel(info, output, out_w, out_h, out_stride, scale_x, scale_y, shift_x, shift_y, stbtt_FindGlyphIndex(info,codepoint));
}

STBTT_DEF unsigned char *stbtt_GetCodepointBitmap(const stbtt_fontinfo *info, float scale_x, float scale_y, int codepoint, int *width, int *height, int *xoff, int *yoff)
{
   return stbtt_GetCodepointBitmapSubpixel(info, scale_x, scale_y, 0.0f,0.0f, codepoint, width,height,xoff,yoff);
}   

STBTT_DEF void stbtt_MakeCodepointBitmap(const stbtt_fontinfo *info, unsigned char *output, int out_w, int out_h, int out_stride, float scale_x, float scale_y, int codepoint)
{
   stbtt_MakeCodepointBitmapSubpixel(info, output, out_w, out_h, out_stride, scale_x, scale_y, 0.0f,0.0f, codepoint);
}

//////////////////////////////////////////////////////////////////////////////
//
// bitmap baking
//
// This is SUPER-CRAPPY packing to keep source code small

static int stbtt_BakeFontBitmap_internal(unsigned char *data, int offset,  // font location (use offset=0 for plain .ttf)
                                float pixel_height,                     // height of font in pixels
                                unsigned char *pixels, int pw, int ph,  // bitmap to be filled in
                                int first_char, int num_chars,          // characters to bake
                                stbtt_bakedchar *chardata)
{
   float scale;
   int x,y,bottom_y, i;
   stbtt_fontinfo f;
   f.userdata = NULL;
   if (!stbtt_InitFont(&f, data, offset))
      return -1;
   STBTT_memset(pixels, 0, pw*ph); // background of 0 around pixels
   x=y=1;
   bottom_y = 1;

   scale = stbtt_ScaleForPixelHeight(&f, pixel_height);

   for (i=0; i < num_chars; ++i) {
      int advance, lsb, x0,y0,x1,y1,gw,gh;
      int g = stbtt_FindGlyphIndex(&f, first_char + i);
      stbtt_GetGlyphHMetrics(&f, g, &advance, &lsb);
      stbtt_GetGlyphBitmapBox(&f, g, scale,scale, &x0,&y0,&x1,&y1);
      gw = x1-x0;
      gh = y1-y0;
      if (x + gw + 1 >= pw)
         y = bottom_y, x = 1; // advance to next row
      if (y + gh + 1 >= ph) // check if it fits vertically AFTER potentially moving to next row
         return -i;
      STBTT_assert(x+gw < pw);
      STBTT_assert(y+gh < ph);
      stbtt_MakeGlyphBitmap(&f, pixels+x+y*pw, gw,gh,pw, scale,scale, g);
      chardata[i].x0 = (stbtt_int16) x;
      chardata[i].y0 = (stbtt_int16) y;
      chardata[i].x1 = (stbtt_int16) (x + gw);
      chardata[i].y1 = (stbtt_int16) (y + gh);
      chardata[i].xadvance = scale * advance;
      chardata[i].xoff     = (float) x0;
      chardata[i].yoff     = (float) y0;
      x = x + gw + 1;
      if (y+gh+1 > bottom_y)
         bottom_y = y+gh+1;
   }
   return bottom_y;
}

STBTT_DEF void stbtt_GetBakedQuad(const stbtt_bakedchar *chardata, int pw, int ph, int char_index, float *xpos, float *ypos, stbtt_aligned_quad *q, int opengl_fillrule)
{
   float d3d_bias = opengl_fillrule ? 0 : -0.5f;
   float ipw = 1.0f / pw, iph = 1.0f / ph;
   const stbtt_bakedchar *b = chardata + char_index;
   int round_x = STBTT_ifloor((*xpos + b->xoff) + 0.5f);
   int round_y = STBTT_ifloor((*ypos + b->yoff) + 0.5f);

   q->x0 = round_x + d3d_bias;
   q->y0 = round_y + d3d_bias;
   q->x1 = round_x + b->x1 - b->x0 + d3d_bias;
   q->y1 = round_y + b->y1 - b->y0 + d3d_bias;

   q->s0 = b->x0 * ipw;
   q->t0 = b->y0 * iph;
   q->s1 = b->x1 * ipw;
   q->t1 = b->y1 * iph;

   *xpos += b->xadvance;
}

//////////////////////////////////////////////////////////////////////////////
//
// rectangle packing replacement routines if you don't have stb_rect_pack.h
//

#ifndef STB_RECT_PACK_VERSION

typedef int stbrp_coord;

////////////////////////////////////////////////////////////////////////////////////
//                                                                                //
//                                                                                //
// COMPILER WARNING ?!?!?                                                         //
//                                                                                //
//                                                                                //
// if you get a compile warning due to these symbols being defined more than      //
// once, move #include "stb_rect_pack.h" before #include "stb_truetype.h"         //
//                                                                                //
////////////////////////////////////////////////////////////////////////////////////

typedef struct
{
   int width,height;
   int x,y,bottom_y;
} stbrp_context;

typedef struct
{
   unsigned char x;
} stbrp_node;

struct stbrp_rect
{
   stbrp_coord x,y;
   int id,w,h,was_packed;
};

static void stbrp_init_target(stbrp_context *con, int pw, int ph, stbrp_node *nodes, int num_nodes)
{
   con->width  = pw;
   con->height = ph;
   con->x = 0;
   con->y = 0;
   con->bottom_y = 0;
   STBTT__NOTUSED(nodes);
   STBTT__NOTUSED(num_nodes);   
}

static void stbrp_pack_rects(stbrp_context *con, stbrp_rect *rects, int num_rects)
{
   int i;
   for (i=0; i < num_rects; ++i) {
      if (con->x + rects[i].w > con->width) {
         con->x = 0;
         con->y = con->bottom_y;
      }
      if (con->y + rects[i].h > con->height)
         break;
      rects[i].x = con->x;
      rects[i].y = con->y;
      rects[i].was_packed = 1;
      con->x += rects[i].w;
      if (con->y + rects[i].h > con->bottom_y)
         con->bottom_y = con->y + rects[i].h;
   }
   for (   ; i < num_rects; ++i)
      rects[i].was_packed = 0;
}
#endif

//////////////////////////////////////////////////////////////////////////////
//
// bitmap baking
//
// This is SUPER-AWESOME (tm Ryan Gordon) packing using stb_rect_pack.h. If
// stb_rect_pack.h isn't available, it uses the BakeFontBitmap strategy.

STBTT_DEF int stbtt_PackBegin(stbtt_pack_context *spc, unsigned char *pixels, int pw, int ph, int stride_in_bytes, int padding, void *alloc_context)
{
   stbrp_context *context = (stbrp_context *) STBTT_malloc(sizeof(*context)            ,alloc_context);
   int            num_nodes = pw - padding;
   stbrp_node    *nodes   = (stbrp_node    *) STBTT_malloc(sizeof(*nodes  ) * num_nodes,alloc_context);

   if (context == NULL || nodes == NULL) {
      if (context != NULL) STBTT_free(context, alloc_context);
      if (nodes   != NULL) STBTT_free(nodes  , alloc_context);
      return 0;
   }

   spc->user_allocator_context = alloc_context;
   spc->width = pw;
   spc->height = ph;
   spc->pixels = pixels;
   spc->pack_info = context;
   spc->nodes = nodes;
   spc->padding = padding;
   spc->stride_in_bytes = stride_in_bytes != 0 ? stride_in_bytes : pw;
   spc->h_oversample = 1;
   spc->v_oversample = 1;
   spc->skip_missing = 0;

   stbrp_init_target(context, pw-padding, ph-padding, nodes, num_nodes);

   if (pixels)
      STBTT_memset(pixels, 0, pw*ph); // background of 0 around pixels

   return 1;
}

STBTT_DEF void stbtt_PackEnd  (stbtt_pack_context *spc)
{
   STBTT_free(spc->nodes    , spc->user_allocator_context);
   STBTT_free(spc->pack_info, spc->user_allocator_context);
}

STBTT_DEF void stbtt_PackSetOversampling(stbtt_pack_context *spc, unsigned int h_oversample, unsigned int v_oversample)
{
   STBTT_assert(h_oversample <= STBTT_MAX_OVERSAMPLE);
   STBTT_assert(v_oversample <= STBTT_MAX_OVERSAMPLE);
   if (h_oversample <= STBTT_MAX_OVERSAMPLE)
      spc->h_oversample = h_oversample;
   if (v_oversample <= STBTT_MAX_OVERSAMPLE)
      spc->v_oversample = v_oversample;
}

STBTT_DEF void stbtt_PackSetSkipMissingCodepoints(stbtt_pack_context *spc, int skip)
{
   spc->skip_missing = skip;
}

#define STBTT__OVER_MASK  (STBTT_MAX_OVERSAMPLE-1)

static void stbtt__h_prefilter(unsigned char *pixels, int w, int h, int stride_in_bytes, unsigned int kernel_width)
{
   unsigned char buffer[STBTT_MAX_OVERSAMPLE];
   int safe_w = w - kernel_width;
   int j;
   STBTT_memset(buffer, 0, STBTT_MAX_OVERSAMPLE); // suppress bogus warning from VS2013 -analyze
   for (j=0; j < h; ++j) {
      int i;
      unsigned int total;
      STBTT_memset(buffer, 0, kernel_width);

      total = 0;

      // make kernel_width a constant in common cases so compiler can optimize out the divide
      switch (kernel_width) {
         case 2:
            for (i=0; i <= safe_w; ++i) {
               total += pixels[i] - buffer[i & STBTT__OVER_MASK];
               buffer[(i+kernel_width) & STBTT__OVER_MASK] = pixels[i];
               pixels[i] = (unsigned char) (total / 2);
            }
            break;
         case 3:
            for (i=0; i <= safe_w; ++i) {
               total += pixels[i] - buffer[i & STBTT__OVER_MASK];
               buffer[(i+kernel_width) & STBTT__OVER_MASK] = pixels[i];
               pixels[i] = (unsigned char) (total / 3);
            }
            break;
         case 4:
            for (i=0; i <= safe_w; ++i) {
               total += pixels[i] - buffer[i & STBTT__OVER_MASK];
               buffer[(i+kernel_width) & STBTT__OVER_MASK] = pixels[i];
               pixels[i] = (unsigned char) (total / 4);
            }
            break;
         case 5:
            for (i=0; i <= safe_w; ++i) {
               total += pixels[i] - buffer[i & STBTT__OVER_MASK];
               buffer[(i+kernel_width) & STBTT__OVER_MASK] = pixels[i];
               pixels[i] = (unsigned char) (total / 5);
            }
            break;
         default:
            for (i=0; i <= safe_w; ++i) {
               total += pixels[i] - buffer[i & STBTT__OVER_MASK];
               buffer[(i+kernel_width) & STBTT__OVER_MASK] = pixels[i];
               pixels[i] = (unsigned char) (total / kernel_width);
            }
            break;
      }

      for (; i < w; ++i) {
         STBTT_assert(pixels[i] == 0);
         total -= buffer[i & STBTT__OVER_MASK];
         pixels[i] = (unsigned char) (total / kernel_width);
      }

      pixels += stride_in_bytes;
   }
}

static void stbtt__v_prefilter(unsigned char *pixels, int w, int h, int stride_in_bytes, unsigned int kernel_width)
{
   unsigned char buffer[STBTT_MAX_OVERSAMPLE];
   int safe_h = h - kernel_width;
   int j;
   STBTT_memset(buffer, 0, STBTT_MAX_OVERSAMPLE); // suppress bogus warning from VS2013 -analyze
   for (j=0; j < w; ++j) {
      int i;
      unsigned int total;
      STBTT_memset(buffer, 0, kernel_width);

      total = 0;

      // make kernel_width a constant in common cases so compiler can optimize out the divide
      switch (kernel_width) {
         case 2:
            for (i=0; i <= safe_h; ++i) {
               total += pixels[i*stride_in_bytes] - buffer[i & STBTT__OVER_MASK];
               buffer[(i+kernel_width) & STBTT__OVER_MASK] = pixels[i*stride_in_bytes];
               pixels[i*stride_in_bytes] = (unsigned char) (total / 2);
            }
            break;
         case 3:
            for (i=0; i <= safe_h; ++i) {
               total += pixels[i*stride_in_bytes] - buffer[i & STBTT__OVER_MASK];
               buffer[(i+kernel_width) & STBTT__OVER_MASK] = pixels[i*stride_in_bytes];
               pixels[i*stride_in_bytes] = (unsigned char) (total / 3);
            }
            break;
         case 4:
            for (i=0; i <= safe_h; ++i) {
               total += pixels[i*stride_in_bytes] - buffer[i & STBTT__OVER_MASK];
               buffer[(i+kernel_width) & STBTT__OVER_MASK] = pixels[i*stride_in_bytes];
               pixels[i*stride_in_bytes] = (unsigned char) (total / 4);
            }
            break;
         case 5:
            for (i=0; i <= safe_h; ++i) {
               total += pixels[i*stride_in_bytes] - buffer[i & STBTT__OVER_MASK];
               buffer[(i+kernel_width) & STBTT__OVER_MASK] = pixels[i*stride_in_bytes];
               pixels[i*stride_in_bytes] = (unsigned char) (total / 5);
            }
            break;
         default:
            for (i=0; i <= safe_h; ++i) {
               total += pixels[i*stride_in_bytes] - buffer[i & STBTT__OVER_MASK];
               buffer[(i+kernel_width) & STBTT__OVER_MASK] = pixels[i*stride_in_bytes];
               pixels[i*stride_in_bytes] = (unsigned char) (total / kernel_width);
            }
            break;
      }

      for (; i < h; ++i) {
         STBTT_assert(pixels[i*stride_in_bytes] == 0);
         total -= buffer[i & STBTT__OVER_MASK];
         pixels[i*stride_in_bytes] = (unsigned char) (total / kernel_width);
      }

      pixels += 1;
   }
}

static float stbtt__oversample_shift(int oversample)
{
   if (!oversample)
      return 0.0f;

   // The prefilter is a box filter of width "oversample",
   // which shifts phase by (oversample - 1)/2 pixels in
   // oversampled space. We want to shift in the opposite
   // direction to counter this.
   return (float)-(oversample - 1) / (2.0f * (float)oversample);
}

// rects array must be big enough to accommodate all characters in the given ranges
STBTT_DEF int stbtt_PackFontRangesGatherRects(stbtt_pack_context *spc, const stbtt_fontinfo *info, stbtt_pack_range *ranges, int num_ranges, stbrp_rect *rects)
{
   int i,j,k;

   k=0;
   for (i=0; i < num_ranges; ++i) {
      float fh = ranges[i].font_size;
      float scale = fh > 0 ? stbtt_ScaleForPixelHeight(info, fh) : stbtt_ScaleForMappingEmToPixels(info, -fh);
      ranges[i].h_oversample = (unsigned char) spc->h_oversample;
      ranges[i].v_oversample = (unsigned char) spc->v_oversample;
      for (j=0; j < ranges[i].num_chars; ++j) {
         int x0,y0,x1,y1;
         int codepoint = ranges[i].array_of_unicode_codepoints == NULL ? ranges[i].first_unicode_codepoint_in_range + j : ranges[i].array_of_unicode_codepoints[j];
         int glyph = stbtt_FindGlyphIndex(info, codepoint);
         if (glyph == 0 && spc->skip_missing) {
            rects[k].w = rects[k].h = 0;
         } else {
            stbtt_GetGlyphBitmapBoxSubpixel(info,glyph,
                                            scale * spc->h_oversample,
                                            scale * spc->v_oversample,
                                            0,0,
                                            &x0,&y0,&x1,&y1);
            rects[k].w = (stbrp_coord) (x1-x0 + spc->padding + spc->h_oversample-1);
            rects[k].h = (stbrp_coord) (y1-y0 + spc->padding + spc->v_oversample-1);
         }
         ++k;
      }
   }

   return k;
}

STBTT_DEF void stbtt_MakeGlyphBitmapSubpixelPrefilter(const stbtt_fontinfo *info, unsigned char *output, int out_w, int out_h, int out_stride, float scale_x, float scale_y, float shift_x, float shift_y, int prefilter_x, int prefilter_y, float *sub_x, float *sub_y, int glyph)
{
   stbtt_MakeGlyphBitmapSubpixel(info,
                                 output,
                                 out_w - (prefilter_x - 1),
                                 out_h - (prefilter_y - 1),
                                 out_stride,
                                 scale_x,
                                 scale_y,
                                 shift_x,
                                 shift_y,
                                 glyph);

   if (prefilter_x > 1)
      stbtt__h_prefilter(output, out_w, out_h, out_stride, prefilter_x);

   if (prefilter_y > 1)
      stbtt__v_prefilter(output, out_w, out_h, out_stride, prefilter_y);

   *sub_x = stbtt__oversample_shift(prefilter_x);
   *sub_y = stbtt__oversample_shift(prefilter_y);
}

// rects array must be big enough to accommodate all characters in the given ranges
STBTT_DEF int stbtt_PackFontRangesRenderIntoRects(stbtt_pack_context *spc, const stbtt_fontinfo *info, stbtt_pack_range *ranges, int num_ranges, stbrp_rect *rects)
{
   int i,j,k, return_value = 1;

   // save current values
   int old_h_over = spc->h_oversample;
   int old_v_over = spc->v_oversample;

   k = 0;
   for (i=0; i < num_ranges; ++i) {
      float fh = ranges[i].font_size;
      float scale = fh > 0 ? stbtt_ScaleForPixelHeight(info, fh) : stbtt_ScaleForMappingEmToPixels(info, -fh);
      float recip_h,recip_v,sub_x,sub_y;
      spc->h_oversample = ranges[i].h_oversample;
      spc->v_oversample = ranges[i].v_oversample;
      recip_h = 1.0f / spc->h_oversample;
      recip_v = 1.0f / spc->v_oversample;
      sub_x = stbtt__oversample_shift(spc->h_oversample);
      sub_y = stbtt__oversample_shift(spc->v_oversample);
      for (j=0; j < ranges[i].num_chars; ++j) {
         stbrp_rect *r = &rects[k];
         if (r->was_packed && r->w != 0 && r->h != 0) {
            stbtt_packedchar *bc = &ranges[i].chardata_for_range[j];
            int advance, lsb, x0,y0,x1,y1;
            int codepoint = ranges[i].array_of_unicode_codepoints == NULL ? ranges[i].first_unicode_codepoint_in_range + j : ranges[i].array_of_unicode_codepoints[j];
            int glyph = stbtt_FindGlyphIndex(info, codepoint);
            stbrp_coord pad = (stbrp_coord) spc->padding;

            // pad on left and top
            r->x += pad;
            r->y += pad;
            r->w -= pad;
            r->h -= pad;
            stbtt_GetGlyphHMetrics(info, glyph, &advance, &lsb);
            stbtt_GetGlyphBitmapBox(info, glyph,
                                    scale * spc->h_oversample,
                                    scale * spc->v_oversample,
                                    &x0,&y0,&x1,&y1);
            stbtt_MakeGlyphBitmapSubpixel(info,
                                          spc->pixels + r->x + r->y*spc->stride_in_bytes,
                                          r->w - spc->h_oversample+1,
                                          r->h - spc->v_oversample+1,
                                          spc->stride_in_bytes,
                                          scale * spc->h_oversample,
                                          scale * spc->v_oversample,
                                          0,0,
                                          glyph);

            if (spc->h_oversample > 1)
               stbtt__h_prefilter(spc->pixels + r->x + r->y*spc->stride_in_bytes,
                                  r->w, r->h, spc->stride_in_bytes,
                                  spc->h_oversample);

            if (spc->v_oversample > 1)
               stbtt__v_prefilter(spc->pixels + r->x + r->y*spc->stride_in_bytes,
                                  r->w, r->h, spc->stride_in_bytes,
                                  spc->v_oversample);

            bc->x0       = (stbtt_int16)  r->x;
            bc->y0       = (stbtt_int16)  r->y;
            bc->x1       = (stbtt_int16) (r->x + r->w);
            bc->y1       = (stbtt_int16) (r->y + r->h);
            bc->xadvance =                scale * advance;
            bc->xoff     =       (float)  x0 * recip_h + sub_x;
            bc->yoff     =       (float)  y0 * recip_v + sub_y;
            bc->xoff2    =                (x0 + r->w) * recip_h + sub_x;
            bc->yoff2    =                (y0 + r->h) * recip_v + sub_y;
         } else {
            return_value = 0; // if any fail, report failure
         }

         ++k;
      }
   }

   // restore original values
   spc->h_oversample = old_h_over;
   spc->v_oversample = old_v_over;

   return return_value;
}

STBTT_DEF void stbtt_PackFontRangesPackRects(stbtt_pack_context *spc, stbrp_rect *rects, int num_rects)
{
   stbrp_pack_rects((stbrp_context *) spc->pack_info, rects, num_rects);
}

STBTT_DEF int stbtt_PackFontRanges(stbtt_pack_context *spc, const unsigned char *fontdata, int font_index, stbtt_pack_range *ranges, int num_ranges)
{
   stbtt_fontinfo info;
   int i,j,n, return_value = 1;
   //stbrp_context *context = (stbrp_context *) spc->pack_info;
   stbrp_rect    *rects;

   // flag all characters as NOT packed
   for (i=0; i < num_ranges; ++i)
      for (j=0; j < ranges[i].num_chars; ++j)
         ranges[i].chardata_for_range[j].x0 =
         ranges[i].chardata_for_range[j].y0 =
         ranges[i].chardata_for_range[j].x1 =
         ranges[i].chardata_for_range[j].y1 = 0;

   n = 0;
   for (i=0; i < num_ranges; ++i)
      n += ranges[i].num_chars;
         
   rects = (stbrp_rect *) STBTT_malloc(sizeof(*rects) * n, spc->user_allocator_context);
   if (rects == NULL)
      return 0;

   info.userdata = spc->user_allocator_context;
   stbtt_InitFont(&info, fontdata, stbtt_GetFontOffsetForIndex(fontdata,font_index));

   n = stbtt_PackFontRangesGatherRects(spc, &info, ranges, num_ranges, rects);

   stbtt_PackFontRangesPackRects(spc, rects, n);
  
   return_value = stbtt_PackFontRangesRenderIntoRects(spc, &info, ranges, num_ranges, rects);

   STBTT_free(rects, spc->user_allocator_context);
   return return_value;
}

STBTT_DEF int stbtt_PackFontRange(stbtt_pack_context *spc, const unsigned char *fontdata, int font_index, float font_size,
            int first_unicode_codepoint_in_range, int num_chars_in_range, stbtt_packedchar *chardata_for_range)
{
   stbtt_pack_range range;
   range.first_unicode_codepoint_in_range = first_unicode_codepoint_in_range;
   range.array_of_unicode_codepoints = NULL;
   range.num_chars                   = num_chars_in_range;
   range.chardata_for_range          = chardata_for_range;
   range.font_size                   = font_size;
   return stbtt_PackFontRanges(spc, fontdata, font_index, &range, 1);
}

STBTT_DEF void stbtt_GetScaledFontVMetrics(const unsigned char *fontdata, int index, float size, float *ascent, float *descent, float *lineGap)
{
   int i_ascent, i_descent, i_lineGap;
   float scale;
   stbtt_fontinfo info;
   stbtt_InitFont(&info, fontdata, stbtt_GetFontOffsetForIndex(fontdata, index));
   scale = size > 0 ? stbtt_ScaleForPixelHeight(&info, size) : stbtt_ScaleForMappingEmToPixels(&info, -size);
   stbtt_GetFontVMetrics(&info, &i_ascent, &i_descent, &i_lineGap);
   *ascent  = (float) i_ascent  * scale;
   *descent = (float) i_descent * scale;
   *lineGap = (float) i_lineGap * scale;
}

STBTT_DEF void stbtt_GetPackedQuad(const stbtt_packedchar *chardata, int pw, int ph, int char_index, float *xpos, float *ypos, stbtt_aligned_quad *q, int align_to_integer)
{
   float ipw = 1.0f / pw, iph = 1.0f / ph;
   const stbtt_packedchar *b = chardata + char_index;

   if (align_to_integer) {
      float x = (float) STBTT_ifloor((*xpos + b->xoff) + 0.5f);
      float y = (float) STBTT_ifloor((*ypos + b->yoff) + 0.5f);
      q->x0 = x;
      q->y0 = y;
      q->x1 = x + b->xoff2 - b->xoff;
      q->y1 = y + b->yoff2 - b->yoff;
   } else {
      q->x0 = *xpos + b->xoff;
      q->y0 = *ypos + b->yoff;
      q->x1 = *xpos + b->xoff2;
      q->y1 = *ypos + b->yoff2;
   }

   q->s0 = b->x0 * ipw;
   q->t0 = b->y0 * iph;
   q->s1 = b->x1 * ipw;
   q->t1 = b->y1 * iph;

   *xpos += b->xadvance;
}

//////////////////////////////////////////////////////////////////////////////
//
// sdf computation
//

#define STBTT_min(a,b)  ((a) < (b) ? (a) : (b))
#define STBTT_max(a,b)  ((a) < (b) ? (b) : (a))

static int stbtt__ray_intersect_bezier(float orig[2], float ray[2], float q0[2], float q1[2], float q2[2], float hits[2][2])
{
   float q0perp = q0[1]*ray[0] - q0[0]*ray[1];
   float q1perp = q1[1]*ray[0] - q1[0]*ray[1];
   float q2perp = q2[1]*ray[0] - q2[0]*ray[1];
   float roperp = orig[1]*ray[0] - orig[0]*ray[1];

   float a = q0perp - 2*q1perp + q2perp;
   float b = q1perp - q0perp;
   float c = q0perp - roperp;

   float s0 = 0., s1 = 0.;
   int num_s = 0;

   if (a != 0.0) {
      float discr = b*b - a*c;
      if (discr > 0.0) {
         float rcpna = -1 / a;
         float d = (float) STBTT_sqrt(discr);
         s0 = (b+d) * rcpna;
         s1 = (b-d) * rcpna;
         if (s0 >= 0.0 && s0 <= 1.0)
            num_s = 1;
         if (d > 0.0 && s1 >= 0.0 && s1 <= 1.0) {
            if (num_s == 0) s0 = s1;
            ++num_s;
         }
      }
   } else {
      // 2*b*s + c = 0
      // s = -c / (2*b)
      s0 = c / (-2 * b);
      if (s0 >= 0.0 && s0 <= 1.0)
         num_s = 1;
   }

   if (num_s == 0)
      return 0;
   else {
      float rcp_len2 = 1 / (ray[0]*ray[0] + ray[1]*ray[1]);
      float rayn_x = ray[0] * rcp_len2, rayn_y = ray[1] * rcp_len2;

      float q0d =   q0[0]*rayn_x +   q0[1]*rayn_y;
      float q1d =   q1[0]*rayn_x +   q1[1]*rayn_y;
      float q2d =   q2[0]*rayn_x +   q2[1]*rayn_y;
      float rod = orig[0]*rayn_x + orig[1]*rayn_y;

      float q10d = q1d - q0d;
      float q20d = q2d - q0d;
      float q0rd = q0d - rod;

      hits[0][0] = q0rd + s0*(2.0f - 2.0f*s0)*q10d + s0*s0*q20d;
      hits[0][1] = a*s0+b;

      if (num_s > 1) {
         hits[1][0] = q0rd + s1*(2.0f - 2.0f*s1)*q10d + s1*s1*q20d;
         hits[1][1] = a*s1+b;
         return 2;
      } else {
         return 1;
      }
   }
}

static int equal(float *a, float *b)
{
   return (a[0] == b[0] && a[1] == b[1]);
}

static int stbtt__compute_crossings_x(float x, float y, int nverts, stbtt_vertex *verts)
{
   int i;
   float orig[2], ray[2] = { 1, 0 };
   float y_frac;
   int winding = 0;

   orig[0] = x;
   orig[1] = y;

   // make sure y never passes through a vertex of the shape
   y_frac = (float) STBTT_fmod(y, 1.0f);
   if (y_frac < 0.01f)
      y += 0.01f;
   else if (y_frac > 0.99f)
      y -= 0.01f;
   orig[1] = y;

   // test a ray from (-infinity,y) to (x,y)
   for (i=0; i < nverts; ++i) {
      if (verts[i].type == STBTT_vline) {
         int x0 = (int) verts[i-1].x, y0 = (int) verts[i-1].y;
         int x1 = (int) verts[i  ].x, y1 = (int) verts[i  ].y;
         if (y > STBTT_min(y0,y1) && y < STBTT_max(y0,y1) && x > STBTT_min(x0,x1)) {
            float x_inter = (y - y0) / (y1 - y0) * (x1-x0) + x0;
            if (x_inter < x)  
               winding += (y0 < y1) ? 1 : -1;
         }
      }
      if (verts[i].type == STBTT_vcurve) {
         int x0 = (int) verts[i-1].x , y0 = (int) verts[i-1].y ;
         int x1 = (int) verts[i  ].cx, y1 = (int) verts[i  ].cy;
         int x2 = (int) verts[i  ].x , y2 = (int) verts[i  ].y ;
         int ax = STBTT_min(x0,STBTT_min(x1,x2)), ay = STBTT_min(y0,STBTT_min(y1,y2));
         int by = STBTT_max(y0,STBTT_max(y1,y2));
         if (y > ay && y < by && x > ax) {
            float q0[2],q1[2],q2[2];
            float hits[2][2];
            q0[0] = (float)x0;
            q0[1] = (float)y0;
            q1[0] = (float)x1;
            q1[1] = (float)y1;
            q2[0] = (float)x2;
            q2[1] = (float)y2;
            if (equal(q0,q1) || equal(q1,q2)) {
               x0 = (int)verts[i-1].x;
               y0 = (int)verts[i-1].y;
               x1 = (int)verts[i  ].x;
               y1 = (int)verts[i  ].y;
               if (y > STBTT_min(y0,y1) && y < STBTT_max(y0,y1) && x > STBTT_min(x0,x1)) {
                  float x_inter = (y - y0) / (y1 - y0) * (x1-x0) + x0;
                  if (x_inter < x)  
                     winding += (y0 < y1) ? 1 : -1;
               }
            } else {
               int num_hits = stbtt__ray_intersect_bezier(orig, ray, q0, q1, q2, hits);
               if (num_hits >= 1)
                  if (hits[0][0] < 0)
                     winding += (hits[0][1] < 0 ? -1 : 1);
               if (num_hits >= 2)
                  if (hits[1][0] < 0)
                     winding += (hits[1][1] < 0 ? -1 : 1);
            }
         } 
      }
   }
   return winding;
}

static float stbtt__cuberoot( float x )
{
   if (x<0)
      return -(float) STBTT_pow(-x,1.0f/3.0f);
   else
      return  (float) STBTT_pow( x,1.0f/3.0f);
}

// x^3 + c*x^2 + b*x + a = 0
static int stbtt__solve_cubic(float a, float b, float c, float* r)
{
	float s = -a / 3;
	float p = b - a*a / 3;
	float q = a * (2*a*a - 9*b) / 27 + c;
   float p3 = p*p*p;
	float d = q*q + 4*p3 / 27;
	if (d >= 0) {
		float z = (float) STBTT_sqrt(d);
		float u = (-q + z) / 2;
		float v = (-q - z) / 2;
		u = stbtt__cuberoot(u);
		v = stbtt__cuberoot(v);
		r[0] = s + u + v;
		return 1;
	} else {
	   float u = (float) STBTT_sqrt(-p/3);
	   float v = (float) STBTT_acos(-STBTT_sqrt(-27/p3) * q / 2) / 3; // p3 must be negative, since d is negative
	   float m = (float) STBTT_cos(v);
      float n = (float) STBTT_cos(v-3.141592/2)*1.732050808f;
	   r[0] = s + u * 2 * m;
	   r[1] = s - u * (m + n);
	   r[2] = s - u * (m - n);

      //STBTT_assert( STBTT_fabs(((r[0]+a)*r[0]+b)*r[0]+c) < 0.05f);  // these asserts may not be safe at all scales, though they're in bezier t parameter units so maybe?
      //STBTT_assert( STBTT_fabs(((r[1]+a)*r[1]+b)*r[1]+c) < 0.05f);
      //STBTT_assert( STBTT_fabs(((r[2]+a)*r[2]+b)*r[2]+c) < 0.05f);
   	return 3;
   }
}

STBTT_DEF unsigned char * stbtt_GetGlyphSDF(const stbtt_fontinfo *info, float scale, int glyph, int padding, unsigned char onedge_value, float pixel_dist_scale, int *width, int *height, int *xoff, int *yoff)
{
   float scale_x = scale, scale_y = scale;
   int ix0,iy0,ix1,iy1;
   int w,h;
   unsigned char *data;

   // if one scale is 0, use same scale for both
   if (scale_x == 0) scale_x = scale_y;
   if (scale_y == 0) {
      if (scale_x == 0) return NULL;  // if both scales are 0, return NULL
      scale_y = scale_x;
   }

   stbtt_GetGlyphBitmapBoxSubpixel(info, glyph, scale, scale, 0.0f,0.0f, &ix0,&iy0,&ix1,&iy1);

   // if empty, return NULL
   if (ix0 == ix1 || iy0 == iy1)
      return NULL;

   ix0 -= padding;
   iy0 -= padding;
   ix1 += padding;
   iy1 += padding;

   w = (ix1 - ix0);
   h = (iy1 - iy0);

   if (width ) *width  = w;
   if (height) *height = h;
   if (xoff  ) *xoff   = ix0;
   if (yoff  ) *yoff   = iy0;

   // invert for y-downwards bitmaps
   scale_y = -scale_y;
      
   {
      int x,y,i,j;
      float *precompute;
      stbtt_vertex *verts;
      int num_verts = stbtt_GetGlyphShape(info, glyph, &verts);
      data = (unsigned char *) STBTT_malloc(w * h, info->userdata);
      precompute = (float *) STBTT_malloc(num_verts * sizeof(float), info->userdata);

      for (i=0,j=num_verts-1; i < num_verts; j=i++) {
         if (verts[i].type == STBTT_vline) {
            float x0 = verts[i].x*scale_x, y0 = verts[i].y*scale_y;
            float x1 = verts[j].x*scale_x, y1 = verts[j].y*scale_y;
            float dist = (float) STBTT_sqrt((x1-x0)*(x1-x0) + (y1-y0)*(y1-y0));
            precompute[i] = (dist == 0) ? 0.0f : 1.0f / dist;
         } else if (verts[i].type == STBTT_vcurve) {
            float x2 = verts[j].x *scale_x, y2 = verts[j].y *scale_y;
            float x1 = verts[i].cx*scale_x, y1 = verts[i].cy*scale_y;
            float x0 = verts[i].x *scale_x, y0 = verts[i].y *scale_y;
            float bx = x0 - 2*x1 + x2, by = y0 - 2*y1 + y2;
            float len2 = bx*bx + by*by;
            if (len2 != 0.0f)
               precompute[i] = 1.0f / (bx*bx + by*by);
            else
               precompute[i] = 0.0f;
         } else
            precompute[i] = 0.0f;
      }

      for (y=iy0; y < iy1; ++y) {
         for (x=ix0; x < ix1; ++x) {
            float val;
            float min_dist = 999999.0f;
            float sx = (float) x + 0.5f;
            float sy = (float) y + 0.5f;
            float x_gspace = (sx / scale_x);
            float y_gspace = (sy / scale_y);

            int winding = stbtt__compute_crossings_x(x_gspace, y_gspace, num_verts, verts); // @OPTIMIZE: this could just be a rasterization, but needs to be line vs. non-tesselated curves so a new path

            for (i=0; i < num_verts; ++i) {
               float x0 = verts[i].x*scale_x, y0 = verts[i].y*scale_y;

               // check against every point here rather than inside line/curve primitives -- @TODO: wrong if multiple 'moves' in a row produce a garbage point, and given culling, probably more efficient to do within line/curve
               float dist2 = (x0-sx)*(x0-sx) + (y0-sy)*(y0-sy);
               if (dist2 < min_dist*min_dist)
                  min_dist = (float) STBTT_sqrt(dist2);

               if (verts[i].type == STBTT_vline) {
                  float x1 = verts[i-1].x*scale_x, y1 = verts[i-1].y*scale_y;

                  // coarse culling against bbox
                  //if (sx > STBTT_min(x0,x1)-min_dist && sx < STBTT_max(x0,x1)+min_dist &&
                  //    sy > STBTT_min(y0,y1)-min_dist && sy < STBTT_max(y0,y1)+min_dist)
                  float dist = (float) STBTT_fabs((x1-x0)*(y0-sy) - (y1-y0)*(x0-sx)) * precompute[i];
                  STBTT_assert(i != 0);
                  if (dist < min_dist) {
                     // check position along line
                     // x' = x0 + t*(x1-x0), y' = y0 + t*(y1-y0)
                     // minimize (x'-sx)*(x'-sx)+(y'-sy)*(y'-sy)
                     float dx = x1-x0, dy = y1-y0;
                     float px = x0-sx, py = y0-sy;
                     // minimize (px+t*dx)^2 + (py+t*dy)^2 = px*px + 2*px*dx*t + t^2*dx*dx + py*py + 2*py*dy*t + t^2*dy*dy
                     // derivative: 2*px*dx + 2*py*dy + (2*dx*dx+2*dy*dy)*t, set to 0 and solve
                     float t = -(px*dx + py*dy) / (dx*dx + dy*dy);
                     if (t >= 0.0f && t <= 1.0f)
                        min_dist = dist;
                  }
               } else if (verts[i].type == STBTT_vcurve) {
                  float x2 = verts[i-1].x *scale_x, y2 = verts[i-1].y *scale_y;
                  float x1 = verts[i  ].cx*scale_x, y1 = verts[i  ].cy*scale_y;
                  float box_x0 = STBTT_min(STBTT_min(x0,x1),x2);
                  float box_y0 = STBTT_min(STBTT_min(y0,y1),y2);
                  float box_x1 = STBTT_max(STBTT_max(x0,x1),x2);
                  float box_y1 = STBTT_max(STBTT_max(y0,y1),y2);
                  // coarse culling against bbox to avoid computing cubic unnecessarily
                  if (sx > box_x0-min_dist && sx < box_x1+min_dist && sy > box_y0-min_dist && sy < box_y1+min_dist) {
                     int num=0;
                     float ax = x1-x0, ay = y1-y0;
                     float bx = x0 - 2*x1 + x2, by = y0 - 2*y1 + y2;
                     float mx = x0 - sx, my = y0 - sy;
                     float res[3],px,py,t,it;
                     float a_inv = precompute[i];
                     if (a_inv == 0.0) { // if a_inv is 0, it's 2nd degree so use quadratic formula
                        float a = 3*(ax*bx + ay*by);
                        float b = 2*(ax*ax + ay*ay) + (mx*bx+my*by);
                        float c = mx*ax+my*ay;
                        if (a == 0.0) { // if a is 0, it's linear
                           if (b != 0.0) {
                              res[num++] = -c/b;
                           }
                        } else {
                           float discriminant = b*b - 4*a*c;
                           if (discriminant < 0)
                              num = 0;
                           else {
                              float root = (float) STBTT_sqrt(discriminant);
                              res[0] = (-b - root)/(2*a);
                              res[1] = (-b + root)/(2*a);
                              num = 2; // don't bother distinguishing 1-solution case, as code below will still work
                           }
                        }
                     } else {
                        float b = 3*(ax*bx + ay*by) * a_inv; // could precompute this as it doesn't depend on sample point
                        float c = (2*(ax*ax + ay*ay) + (mx*bx+my*by)) * a_inv;
                        float d = (mx*ax+my*ay) * a_inv;
                        num = stbtt__solve_cubic(b, c, d, res);
                     }
                     if (num >= 1 && res[0] >= 0.0f && res[0] <= 1.0f) {
                        t = res[0], it = 1.0f - t;
                        px = it*it*x0 + 2*t*it*x1 + t*t*x2;
                        py = it*it*y0 + 2*t*it*y1 + t*t*y2;
                        dist2 = (px-sx)*(px-sx) + (py-sy)*(py-sy);
                        if (dist2 < min_dist * min_dist)
                           min_dist = (float) STBTT_sqrt(dist2);
                     }
                     if (num >= 2 && res[1] >= 0.0f && res[1] <= 1.0f) {
                        t = res[1], it = 1.0f - t;
                        px = it*it*x0 + 2*t*it*x1 + t*t*x2;
                        py = it*it*y0 + 2*t*it*y1 + t*t*y2;
                        dist2 = (px-sx)*(px-sx) + (py-sy)*(py-sy);
                        if (dist2 < min_dist * min_dist)
                           min_dist = (float) STBTT_sqrt(dist2);
                     }
                     if (num >= 3 && res[2] >= 0.0f && res[2] <= 1.0f) {
                        t = res[2], it = 1.0f - t;
                        px = it*it*x0 + 2*t*it*x1 + t*t*x2;
                        py = it*it*y0 + 2*t*it*y1 + t*t*y2;
                        dist2 = (px-sx)*(px-sx) + (py-sy)*(py-sy);
                        if (dist2 < min_dist * min_dist)
                           min_dist = (float) STBTT_sqrt(dist2);
                     }
                  }
               }
            }
            if (winding == 0)
               min_dist = -min_dist;  // if outside the shape, value is negative
            val = onedge_value + pixel_dist_scale * min_dist;
            if (val < 0)
               val = 0;
            else if (val > 255)
               val = 255;
            data[(y-iy0)*w+(x-ix0)] = (unsigned char) val;
         }
      }
      STBTT_free(precompute, info->userdata);
      STBTT_free(verts, info->userdata);
   }
   return data;
}   

STBTT_DEF unsigned char * stbtt_GetCodepointSDF(const stbtt_fontinfo *info, float scale, int codepoint, int padding, unsigned char onedge_value, float pixel_dist_scale, int *width, int *height, int *xoff, int *yoff)
{
   return stbtt_GetGlyphSDF(info, scale, stbtt_FindGlyphIndex(info, codepoint), padding, onedge_value, pixel_dist_scale, width, height, xoff, yoff);
}

STBTT_DEF void stbtt_FreeSDF(unsigned char *bitmap, void *userdata)
{
   STBTT_free(bitmap, userdata);
}

//////////////////////////////////////////////////////////////////////////////
//
// font name matching -- recommended not to use this
//

// check if a utf8 string contains a prefix which is the utf16 string; if so return length of matching utf8 string
static stbtt_int32 stbtt__CompareUTF8toUTF16_bigendian_prefix(stbtt_uint8 *s1, stbtt_int32 len1, stbtt_uint8 *s2, stbtt_int32 len2) 
{
   stbtt_int32 i=0;

   // convert utf16 to utf8 and compare the results while converting
   while (len2) {
      stbtt_uint16 ch = s2[0]*256 + s2[1];
      if (ch < 0x80) {
         if (i >= len1) return -1;
         if (s1[i++] != ch) return -1;
      } else if (ch < 0x800) {
         if (i+1 >= len1) return -1;
         if (s1[i++] != 0xc0 + (ch >> 6)) return -1;
         if (s1[i++] != 0x80 + (ch & 0x3f)) return -1;
      } else if (ch >= 0xd800 && ch < 0xdc00) {
         stbtt_uint32 c;
         stbtt_uint16 ch2 = s2[2]*256 + s2[3];
         if (i+3 >= len1) return -1;
         c = ((ch - 0xd800) << 10) + (ch2 - 0xdc00) + 0x10000;
         if (s1[i++] != 0xf0 + (c >> 18)) return -1;
         if (s1[i++] != 0x80 + ((c >> 12) & 0x3f)) return -1;
         if (s1[i++] != 0x80 + ((c >>  6) & 0x3f)) return -1;
         if (s1[i++] != 0x80 + ((c      ) & 0x3f)) return -1;
         s2 += 2; // plus another 2 below
         len2 -= 2;
      } else if (ch >= 0xdc00 && ch < 0xe000) {
         return -1;
      } else {
         if (i+2 >= len1) return -1;
         if (s1[i++] != 0xe0 + (ch >> 12)) return -1;
         if (s1[i++] != 0x80 + ((ch >> 6) & 0x3f)) return -1;
         if (s1[i++] != 0x80 + ((ch     ) & 0x3f)) return -1;
      }
      s2 += 2;
      len2 -= 2;
   }
   return i;
}

static int stbtt_CompareUTF8toUTF16_bigendian_internal(char *s1, int len1, char *s2, int len2) 
{
   return len1 == stbtt__CompareUTF8toUTF16_bigendian_prefix((stbtt_uint8*) s1, len1, (stbtt_uint8*) s2, len2);
}

// returns results in whatever encoding you request... but note that 2-byte encodings
// will be BIG-ENDIAN... use stbtt_CompareUTF8toUTF16_bigendian() to compare
STBTT_DEF const char *stbtt_GetFontNameString(const stbtt_fontinfo *font, int *length, int platformID, int encodingID, int languageID, int nameID)
{
   stbtt_int32 i,count,stringOffset;
   stbtt_uint8 *fc = font->data;
   stbtt_uint32 offset = font->fontstart;
   stbtt_uint32 nm = stbtt__find_table(fc, offset, "name");
   if (!nm) return NULL;

   count = ttUSHORT(fc+nm+2);
   stringOffset = nm + ttUSHORT(fc+nm+4);
   for (i=0; i < count; ++i) {
      stbtt_uint32 loc = nm + 6 + 12 * i;
      if (platformID == ttUSHORT(fc+loc+0) && encodingID == ttUSHORT(fc+loc+2)
          && languageID == ttUSHORT(fc+loc+4) && nameID == ttUSHORT(fc+loc+6)) {
         *length = ttUSHORT(fc+loc+8);
         return (const char *) (fc+stringOffset+ttUSHORT(fc+loc+10));
      }
   }
   return NULL;
}

static int stbtt__matchpair(stbtt_uint8 *fc, stbtt_uint32 nm, stbtt_uint8 *name, stbtt_int32 nlen, stbtt_int32 target_id, stbtt_int32 next_id)
{
   stbtt_int32 i;
   stbtt_int32 count = ttUSHORT(fc+nm+2);
   stbtt_int32 stringOffset = nm + ttUSHORT(fc+nm+4);

   for (i=0; i < count; ++i) {
      stbtt_uint32 loc = nm + 6 + 12 * i;
      stbtt_int32 id = ttUSHORT(fc+loc+6);
      if (id == target_id) {
         // find the encoding
         stbtt_int32 platform = ttUSHORT(fc+loc+0), encoding = ttUSHORT(fc+loc+2), language = ttUSHORT(fc+loc+4);

         // is this a Unicode encoding?
         if (platform == 0 || (platform == 3 && encoding == 1) || (platform == 3 && encoding == 10)) {
            stbtt_int32 slen = ttUSHORT(fc+loc+8);
            stbtt_int32 off = ttUSHORT(fc+loc+10);

            // check if there's a prefix match
            stbtt_int32 matchlen = stbtt__CompareUTF8toUTF16_bigendian_prefix(name, nlen, fc+stringOffset+off,slen);
            if (matchlen >= 0) {
               // check for target_id+1 immediately following, with same encoding & language
               if (i+1 < count && ttUSHORT(fc+loc+12+6) == next_id && ttUSHORT(fc+loc+12) == platform && ttUSHORT(fc+loc+12+2) == encoding && ttUSHORT(fc+loc+12+4) == language) {
                  slen = ttUSHORT(fc+loc+12+8);
                  off = ttUSHORT(fc+loc+12+10);
                  if (slen == 0) {
                     if (matchlen == nlen)
                        return 1;
                  } else if (matchlen < nlen && name[matchlen] == ' ') {
                     ++matchlen;
                     if (stbtt_CompareUTF8toUTF16_bigendian_internal((char*) (name+matchlen), nlen-matchlen, (char*)(fc+stringOffset+off),slen))
                        return 1;
                  }
               } else {
                  // if nothing immediately following
                  if (matchlen == nlen)
                     return 1;
               }
            }
         }

         // @TODO handle other encodings
      }
   }
   return 0;
}

static int stbtt__matches(stbtt_uint8 *fc, stbtt_uint32 offset, stbtt_uint8 *name, stbtt_int32 flags)
{
   stbtt_int32 nlen = (stbtt_int32) STBTT_strlen((char *) name);
   stbtt_uint32 nm,hd;
   if (!stbtt__isfont(fc+offset)) return 0;

   // check italics/bold/underline flags in macStyle...
   if (flags) {
      hd = stbtt__find_table(fc, offset, "head");
      if ((ttUSHORT(fc+hd+44) & 7) != (flags & 7)) return 0;
   }

   nm = stbtt__find_table(fc, offset, "name");
   if (!nm) return 0;

   if (flags) {
      // if we checked the macStyle flags, then just check the family and ignore the subfamily
      if (stbtt__matchpair(fc, nm, name, nlen, 16, -1))  return 1;
      if (stbtt__matchpair(fc, nm, name, nlen,  1, -1))  return 1;
      if (stbtt__matchpair(fc, nm, name, nlen,  3, -1))  return 1;
   } else {
      if (stbtt__matchpair(fc, nm, name, nlen, 16, 17))  return 1;
      if (stbtt__matchpair(fc, nm, name, nlen,  1,  2))  return 1;
      if (stbtt__matchpair(fc, nm, name, nlen,  3, -1))  return 1;
   }

   return 0;
}

static int stbtt_FindMatchingFont_internal(unsigned char *font_collection, char *name_utf8, stbtt_int32 flags)
{
   stbtt_int32 i;
   for (i=0;;++i) {
      stbtt_int32 off = stbtt_GetFontOffsetForIndex(font_collection, i);
      if (off < 0) return off;
      if (stbtt__matches((stbtt_uint8 *) font_collection, off, (stbtt_uint8*) name_utf8, flags))
         return off;
   }
}

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wcast-qual"
#endif

STBTT_DEF int stbtt_BakeFontBitmap(const unsigned char *data, int offset,
                                float pixel_height, unsigned char *pixels, int pw, int ph,
                                int first_char, int num_chars, stbtt_bakedchar *chardata)
{
   return stbtt_BakeFontBitmap_internal((unsigned char *) data, offset, pixel_height, pixels, pw, ph, first_char, num_chars, chardata);
}

STBTT_DEF int stbtt_GetFontOffsetForIndex(const unsigned char *data, int index)
{
   return stbtt_GetFontOffsetForIndex_internal((unsigned char *) data, index);   
}

STBTT_DEF int stbtt_GetNumberOfFonts(const unsigned char *data)
{
   return stbtt_GetNumberOfFonts_internal((unsigned char *) data);
}

STBTT_DEF int stbtt_InitFont(stbtt_fontinfo *info, const unsigned char *data, int offset)
{
   return stbtt_InitFont_internal(info, (unsigned char *) data, offset);
}

STBTT_DEF int stbtt_FindMatchingFont(const unsigned char *fontdata, const char *name, int flags)
{
   return stbtt_FindMatchingFont_internal((unsigned char *) fontdata, (char *) name, flags);
}

STBTT_DEF int stbtt_CompareUTF8toUTF16_bigendian(const char *s1, int len1, const char *s2, int len2)
{
   return stbtt_CompareUTF8toUTF16_bigendian_internal((char *) s1, len1, (char *) s2, len2);
}

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC diagnostic pop
#endif

#endif // STB_TRUETYPE_IMPLEMENTATION


// FULL VERSION HISTORY
//
//   1.19 (2018-02-11) OpenType GPOS kerning (horizontal only), STBTT_fmod
//   1.18 (2018-01-29) add missing function
//   1.17 (2017-07-23) make more arguments const; doc fix
//   1.16 (2017-07-12) SDF support
//   1.15 (2017-03-03) make more arguments const
//   1.14 (2017-01-16) num-fonts-in-TTC function
//   1.13 (2017-01-02) support OpenType fonts, certain Apple fonts
//   1.12 (2016-10-25) suppress warnings about casting away const with -Wcast-qual
//   1.11 (2016-04-02) fix unused-variable warning
//   1.10 (2016-04-02) allow user-defined fabs() replacement
//                     fix memory leak if fontsize=0.0
//                     fix warning from duplicate typedef
//   1.09 (2016-01-16) warning fix; avoid crash on outofmem; use alloc userdata for PackFontRanges
//   1.08 (2015-09-13) document stbtt_Rasterize(); fixes for vertical & horizontal edges
//   1.07 (2015-08-01) allow PackFontRanges to accept arrays of sparse codepoints;
//                     allow PackFontRanges to pack and render in separate phases;
//                     fix stbtt_GetFontOFfsetForIndex (never worked for non-0 input?);
//                     fixed an assert() bug in the new rasterizer
//                     replace assert() with STBTT_assert() in new rasterizer
//   1.06 (2015-07-14) performance improvements (~35% faster on x86 and x64 on test machine)
//                     also more precise AA rasterizer, except if shapes overlap
//                     remove need for STBTT_sort
//   1.05 (2015-04-15) fix misplaced definitions for STBTT_STATIC
//   1.04 (2015-04-15) typo in example
//   1.03 (2015-04-12) STBTT_STATIC, fix memory leak in new packing, various fixes
//   1.02 (2014-12-10) fix various warnings & compile issues w/ stb_rect_pack, C++
//   1.01 (2014-12-08) fix subpixel position when oversampling to exactly match
//                        non-oversampled; STBTT_POINT_SIZE for packed case only
//   1.00 (2014-12-06) add new PackBegin etc. API, w/ support for oversampling
//   0.99 (2014-09-18) fix multiple bugs with subpixel rendering (ryg)
//   0.9  (2014-08-07) support certain mac/iOS fonts without an MS platformID
//   0.8b (2014-07-07) fix a warning
//   0.8  (2014-05-25) fix a few more warnings
//   0.7  (2013-09-25) bugfix: subpixel glyph bug fixed in 0.5 had come back
//   0.6c (2012-07-24) improve documentation
//   0.6b (2012-07-20) fix a few more warnings
//   0.6  (2012-07-17) fix warnings; added stbtt_ScaleForMappingEmToPixels,
//                        stbtt_GetFontBoundingBox, stbtt_IsGlyphEmpty
//   0.5  (2011-12-09) bugfixes:
//                        subpixel glyph renderer computed wrong bounding box
//                        first vertex of shape can be off-curve (FreeSans)
//   0.4b (2011-12-03) fixed an error in the font baking example
//   0.4  (2011-12-01) kerning, subpixel rendering (tor)
//                    bugfixes for:
//                        codepoint-to-glyph conversion using table fmt=12
//                        codepoint-to-glyph conversion using table fmt=4
//                        stbtt_GetBakedQuad with non-square texture (Zer)
//                    updated Hello World! sample to use kerning and subpixel
//                    fixed some warnings
//   0.3  (2009-06-24) cmap fmt=12, compound shapes (MM)
//                    userdata, malloc-from-userdata, non-zero fill (stb)
//   0.2  (2009-03-11) Fix unsigned/signed char warnings
//   0.1  (2009-03-09) First public release
//

/*
------------------------------------------------------------------------------
This software is available under 2 licenses -- choose whichever you prefer.
------------------------------------------------------------------------------
ALTERNATIVE A - MIT License
Copyright (c) 2017 Sean Barrett
Permission is hereby granted, free of charge, to any person obtaining a copy of 
this software and associated documentation files (the "Software"), to deal in 
the Software without restriction, including without limitation the rights to 
use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies 
of the Software, and to permit persons to whom the Software is furnished to do 
so, subject to the following conditions:
The above copyright notice and this permission notice shall be included in all 
copies or substantial portions of the Software.
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, 
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE 
SOFTWARE.
------------------------------------------------------------------------------
ALTERNATIVE B - Public Domain (www.unlicense.org)
This is free and unencumbered software released into the public domain.
Anyone is free to copy, modify, publish, use, compile, sell, or distribute this 
software, either in source code form or as a compiled binary, for any purpose, 
commercial or non-commercial, and by any means.
In jurisdictions that recognize copyright laws, the author or authors of this 
software dedicate any and all copyright interest in the software to the public 
domain. We make this dedication for the benefit of the public at large and to 
the detriment of our heirs and successors. We intend this dedication to be an 
overt act of relinquishment in perpetuity of all present and future rights to 
this software under copyright law.
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN 
ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION 
WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
------------------------------------------------------------------------------
*/

typedef struct
{ int ascent, descent, height, width;
  unsigned char *data;
  unsigned int chr; } fchr_t;

typedef struct 
{ womap_t *cache; stbtt_fontinfo finfo; 
  float scale; int height; } font_t;

typedef struct { const unsigned char *data; int size; } fontdef_t;

static int font1height, font2height, font3height, font4height, font5height;
static const unsigned char fontdata0[]={
0,1,0,0,0,17,1,0,0,4,0,16,70,70,84,77,87,54,
16,91,0,2,161,8,0,0,0,28,79,83,47,50,149,39,194,13,
0,0,1,152,0,0,0,96,99,109,97,112,37,32,40,209,0,0,
25,108,0,0,12,74,99,118,116,32,0,101,7,138,0,0,37,184,
0,0,0,8,102,101,97,116,192,20,7,181,0,2,157,24,0,0,
0,64,103,97,115,112,255,255,0,3,0,2,154,248,0,0,0,8,
103,108,121,102,141,11,97,80,0,0,61,60,0,2,16,248,104,101,
97,100,255,151,191,23,0,0,1,28,0,0,0,54,104,104,101,97,
14,29,13,9,0,0,1,84,0,0,0,36,104,109,116,120,160,43,
203,145,0,0,1,248,0,0,23,114,107,101,114,110,50,81,48,135,
0,2,78,52,0,0,2,136,108,111,99,97,5,220,183,8,0,0,
37,192,0,0,23,124,109,97,120,112,6,50,1,149,0,0,1,120,
0,0,0,32,109,111,114,120,59,103,231,1,0,2,157,88,0,0,
3,176,110,97,109,101,12,174,93,6,0,2,80,188,0,0,10,59,
112,111,115,116,212,110,94,137,0,2,90,248,0,0,63,255,112,114,
111,112,230,235,74,39,0,2,155,0,0,0,2,24,0,1,0,0,
0,1,71,174,71,74,179,118,95,15,60,245,2,11,8,0,0,0,
0,0,203,255,22,134,0,0,0,0,203,255,22,134,252,56,253,120,
10,68,7,231,0,0,0,8,0,0,0,1,0,0,0,0,0,1,
0,0,7,158,254,7,0,0,10,193,252,56,254,101,10,68,0,1,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,219,0,1,
0,0,5,222,0,181,0,9,0,172,0,5,0,2,0,0,0,1,
0,1,0,0,0,64,0,46,0,4,0,3,0,4,4,65,1,244,
0,5,0,0,5,51,5,153,0,0,1,30,5,51,5,153,0,0,
3,215,0,102,2,18,0,0,2,11,6,3,6,1,0,0,0,0,
224,0,2,255,82,0,32,251,0,0,0,0,0,0,0,0,80,102,
69,100,0,192,0,32,255,255,6,61,254,7,0,0,7,158,1,195,
32,0,1,159,0,0,0,0,4,45,5,170,0,0,0,32,0,1,
2,236,0,68,0,0,0,0,2,170,0,0,2,104,0,0,1,165,
0,103,2,178,0,129,6,53,0,129,3,249,0,25,5,122,0,104,
4,217,0,100,1,126,0,129,2,36,0,41,2,24,0,90,3,145,
0,33,3,126,0,78,1,143,0,103,3,98,0,109,1,149,0,103,
3,40,255,233,4,112,0,100,4,112,1,168,4,112,0,109,4,102,
0,113,4,112,0,88,4,112,0,135,4,112,0,129,4,112,0,111,
4,112,0,104,4,112,0,143,1,167,0,113,1,167,0,113,3,75,
0,84,3,139,0,66,3,88,0,92,3,217,0,57,6,88,0,41,
5,22,0,72,4,155,0,121,4,196,0,100,4,196,0,121,4,118,
0,121,4,122,0,121,5,83,0,100,4,174,0,121,1,188,0,154,
4,116,0,113,4,215,0,121,4,81,0,121,6,26,0,121,4,247,
0,121,5,53,0,92,4,75,0,121,5,90,0,92,4,77,0,121,
4,55,0,45,4,219,0,88,4,241,0,121,4,221,0,80,6,40,
0,84,4,190,0,74,4,155,0,76,5,45,0,100,2,114,0,131,
3,43,255,227,2,126,0,129,3,159,0,133,4,217,0,88,2,38,
0,60,3,225,0,84,4,20,0,129,3,153,0,76,4,20,0,73,
3,245,0,98,2,204,0,125,3,253,0,73,4,40,0,129,1,174,
0,131,1,212,255,137,3,176,0,129,1,174,0,150,5,253,0,129,
4,40,0,129,4,30,0,102,4,20,0,129,4,24,0,73,2,174,
0,129,3,153,0,96,2,184,0,102,4,40,0,120,4,0,0,82,
5,94,0,68,3,133,0,53,4,40,0,120,3,194,0,90,2,235,
0,90,1,112,0,125,2,235,0,133,2,223,0,63,5,53,0,92,
1,53,0,28,3,40,0,80,4,96,0,84,3,88,0,63,4,86,
0,74,1,49,0,90,2,174,0,43,3,26,0,76,3,174,0,41,
2,250,0,109,3,104,0,59,4,2,0,154,3,182,0,109,4,165,
0,94,3,182,0,188,2,86,0,49,3,215,0,150,2,152,0,68,
2,158,0,51,2,38,0,60,3,235,0,154,4,126,0,121,1,182,
0,142,1,217,0,117,1,198,0,49,2,160,0,46,3,165,0,98,
5,27,0,48,5,27,0,48,5,27,0,47,3,186,0,18,5,22,
0,64,5,22,0,64,5,12,0,82,5,12,0,82,5,12,0,82,
5,12,0,82,5,108,0,83,4,196,0,120,4,118,0,121,4,118,
0,121,4,122,0,131,4,122,0,131,1,188,255,144,1,184,0,164,
1,184,255,153,1,184,255,166,5,98,0,144,5,12,0,131,5,53,
0,92,5,53,0,92,5,49,0,102,5,49,0,102,5,49,0,102,
3,65,0,108,5,5,0,96,4,241,0,121,4,241,0,121,5,18,
0,131,5,18,0,131,4,155,0,76,5,49,0,145,4,188,0,92,
3,228,0,84,3,228,0,84,4,12,0,94,4,12,0,94,4,12,
0,94,4,12,0,94,5,206,0,84,3,243,0,86,3,228,0,98,
4,22,0,108,4,22,0,108,4,22,0,108,1,174,255,139,1,165,
0,150,3,120,0,115,2,155,0,8,4,6,0,82,4,20,0,139,
3,228,0,102,3,228,0,102,4,38,0,112,4,38,0,112,4,36,
0,112,3,143,0,119,4,0,0,86,3,228,0,120,3,228,0,162,
4,40,0,130,4,40,0,130,3,228,0,120,3,235,0,129,4,40,
0,130,5,22,0,64,3,228,0,84,5,22,0,64,3,228,0,84,
5,22,0,64,3,228,0,84,4,196,0,100,3,153,0,76,4,196,
0,100,3,153,0,69,4,196,0,100,3,153,0,76,4,196,0,100,
3,153,0,70,4,196,0,121,4,184,0,73,5,98,0,106,4,20,
0,128,4,118,0,121,3,228,0,98,4,118,0,121,3,228,0,98,
4,118,0,121,3,228,0,98,4,118,0,121,3,228,0,98,4,118,
0,121,3,228,0,98,5,83,0,100,4,20,0,73,5,83,0,100,
4,20,0,73,5,83,0,100,4,20,0,73,5,83,0,100,4,20,
0,73,4,174,0,121,3,225,0,129,4,174,0,42,3,225,0,30,
1,188,255,214,1,174,255,172,1,188,255,138,1,174,255,158,1,188,
255,181,1,174,255,168,1,188,0,117,1,174,0,117,1,188,0,135,
1,174,0,140,5,73,0,154,2,198,0,123,4,116,0,113,1,212,
255,137,4,215,0,121,3,122,0,129,4,36,0,121,4,81,0,119,
1,216,0,128,4,81,0,121,1,216,0,150,4,81,0,121,2,24,
0,150,4,81,0,121,2,113,0,150,4,81,0,17,1,216,0,17,
4,247,0,121,3,228,0,139,4,247,0,121,3,228,0,129,4,247,
0,121,3,228,0,129,5,36,0,103,4,247,0,110,4,20,0,108,
5,53,0,92,3,228,0,102,5,53,0,92,3,228,0,102,5,53,
0,92,3,228,0,102,6,26,0,92,5,206,0,102,4,77,0,121,
2,174,0,129,4,77,0,121,2,174,0,114,4,77,0,121,2,174,
0,32,4,55,0,45,3,153,0,96,4,55,0,45,3,153,0,96,
4,55,0,45,3,153,0,88,4,55,0,45,3,153,0,96,4,219,
0,88,2,184,0,102,4,219,0,88,2,240,0,102,4,219,0,88,
2,184,0,52,4,241,0,121,3,228,0,120,4,241,0,121,3,228,
0,120,4,241,0,121,3,228,0,120,4,241,0,121,3,228,0,120,
4,241,0,121,3,228,0,162,4,241,0,121,3,228,0,102,6,40,
0,84,5,94,0,68,4,155,0,76,3,228,0,120,4,155,0,76,
5,45,0,100,3,194,0,90,5,45,0,100,3,194,0,90,5,45,
0,100,3,194,0,90,2,204,1,7,3,252,255,250,5,216,0,92,
5,249,0,94,4,55,0,45,3,153,0,96,4,219,0,88,2,184,
0,102,3,168,0,48,3,168,0,48,3,225,0,106,3,225,0,90,
3,225,0,90,4,20,0,131,3,153,0,101,3,153,255,181,5,28,
0,128,5,16,0,128,3,245,0,98,3,245,0,98,4,122,0,98,
3,245,0,138,3,245,0,138,4,56,0,138,3,214,0,101,2,14,
255,137,5,22,0,115,3,253,0,115,3,216,0,73,3,232,0,82,
2,146,0,32,4,40,0,129,4,40,0,126,4,40,0,126,1,174,
0,0,2,112,0,52,1,188,0,61,2,184,0,7,2,228,255,88,
3,8,1,7,4,112,0,110,5,253,0,129,5,253,0,129,5,253,
0,129,4,112,0,18,4,190,0,108,3,254,0,105,3,245,0,98,
5,206,0,102,4,184,0,55,5,48,0,100,2,174,0,129,3,18,
0,129,4,58,0,129,3,18,0,129,3,18,0,129,2,112,0,15,
2,112,0,15,3,152,0,98,3,152,0,98,3,153,0,96,3,8,
255,214,2,14,255,137,3,8,255,214,3,8,255,86,2,184,0,102,
2,184,0,102,4,40,0,50,4,30,0,50,3,246,0,31,4,0,
0,82,5,94,0,68,4,0,0,82,4,15,0,89,4,202,0,90,
4,90,0,90,6,172,2,189,3,228,0,36,3,217,0,57,3,217,
0,57,3,217,0,57,3,178,0,101,5,53,0,92,3,152,0,92,
3,214,0,101,4,214,0,98,3,150,0,102,2,186,255,41,3,176,
0,55,3,201,0,121,5,0,0,96,3,217,0,57,3,217,0,57,
7,14,0,128,6,172,0,128,7,250,0,128,4,190,0,102,4,116,
0,102,5,162,0,102,5,200,0,125,4,34,0,154,4,24,0,154,
4,76,0,66,4,174,0,121,4,192,0,37,5,230,0,37,4,22,
0,186,4,38,0,184,3,182,0,188,5,22,1,98,1,164,0,76,
4,12,1,26,1,217,0,117,2,223,0,63,5,49,1,186,0,0,
252,65,0,0,252,56,0,0,252,151,0,0,252,161,0,0,252,147,
0,0,252,161,0,0,252,161,0,0,252,169,0,0,252,161,0,0,
252,160,0,0,252,143,0,0,252,161,0,0,252,165,0,0,252,169,
0,0,252,161,0,0,252,161,0,0,252,161,5,22,1,98,0,0,
252,161,3,172,0,121,3,172,0,121,4,247,0,121,1,149,0,103,
3,153,0,101,3,153,0,101,3,153,0,101,1,167,0,113,3,33,
0,248,3,26,0,76,5,22,0,72,1,149,0,95,4,218,0,28,
5,16,0,27,1,188,0,31,5,53,0,58,5,93,0,41,5,78,
0,25,2,112,255,221,5,22,0,72,4,155,0,121,4,75,0,121,
6,26,0,120,4,118,0,121,5,45,0,100,4,174,0,121,5,53,
0,92,1,188,0,154,4,215,0,121,4,221,0,123,6,26,0,121,
4,247,0,121,4,174,0,110,5,53,0,92,4,174,0,110,4,75,
0,121,4,174,0,110,4,219,0,88,4,155,0,66,6,26,0,95,
4,190,0,74,5,114,0,112,5,78,0,25,1,188,255,157,4,155,
0,66,4,188,0,90,3,245,0,138,4,40,0,118,2,112,0,135,
3,246,0,118,4,188,0,90,3,246,0,111,4,0,0,82,4,6,
0,90,3,245,0,138,4,30,0,105,4,40,0,118,4,112,0,100,
2,112,0,135,3,226,0,90,4,40,0,74,4,40,0,118,4,0,
0,82,4,30,0,51,4,30,0,90,4,40,0,22,4,30,0,90,
4,30,0,90,4,30,0,90,4,40,0,120,3,246,0,118,4,184,
0,55,4,0,0,74,4,30,0,90,4,184,0,55,2,95,255,137,
3,246,0,118,4,30,0,90,3,246,0,118,4,184,0,55,4,215,
0,121,3,246,0,111,4,112,0,100,5,192,0,25,6,84,0,54,
6,12,0,25,5,16,0,126,4,184,0,0,4,50,0,81,5,53,
0,92,4,30,0,90,4,196,0,100,4,50,0,101,4,122,0,121,
4,72,0,0,4,40,0,91,4,40,0,118,5,126,0,131,4,174,
0,78,3,220,0,42,3,220,0,42,4,75,0,121,4,20,0,129,
4,40,0,129,4,40,0,115,4,55,0,45,4,55,0,45,3,232,
0,16,3,232,0,16,4,30,0,90,4,30,0,109,3,52,0,17,
2,130,0,10,4,50,0,81,4,30,0,90,3,153,0,101,1,212,
255,137,4,112,0,100,3,153,0,101,3,153,0,101,3,235,0,129,
5,49,0,145,4,196,0,100,6,26,0,121,4,0,0,121,4,30,
0,12,4,196,0,100,4,196,0,100,4,196,0,100,4,74,0,88,
4,74,0,56,4,172,0,18,4,74,0,63,4,154,0,56,4,55,
0,45,1,188,0,154,1,188,255,160,4,116,0,113,6,62,0,69,
5,18,0,73,4,214,0,18,4,215,0,121,4,247,0,121,4,247,
0,26,4,69,0,58,5,22,0,72,4,74,0,94,4,74,0,67,
4,74,0,92,5,30,0,79,4,74,0,88,5,186,0,76,4,102,
0,113,4,247,0,121,4,247,0,121,4,215,0,121,4,120,0,84,
6,26,0,121,4,174,0,121,5,53,0,92,4,174,0,121,4,75,
0,121,4,196,0,100,4,219,0,88,4,247,0,26,6,26,0,95,
4,190,0,74,5,170,0,121,4,0,0,98,6,24,0,121,7,10,
0,121,4,247,0,40,4,175,0,121,4,75,0,121,4,196,0,100,
5,249,0,125,4,180,0,121,3,225,0,106,4,30,0,90,3,152,
0,92,3,60,0,94,4,207,0,128,3,245,0,98,5,220,0,94,
3,162,0,97,4,40,0,122,4,40,0,122,3,194,0,121,3,194,
0,69,4,150,0,98,3,150,0,102,4,30,0,90,4,40,0,121,
4,20,0,129,3,153,0,101,3,221,0,82,4,40,0,74,5,48,
0,100,3,133,0,53,5,8,0,121,4,40,0,129,5,253,0,125,
6,237,0,125,4,122,0,12,4,206,0,51,4,20,0,129,3,153,
0,101,5,218,0,97,3,153,0,117,3,245,0,98,3,245,0,98,
4,40,0,0,3,60,0,94,3,153,0,101,3,153,0,96,1,174,
0,131,1,174,255,144,1,212,255,137,6,118,0,72,5,124,0,88,
4,40,0,0,3,194,0,121,4,40,0,122,4,40,0,74,4,40,
0,121,4,247,0,121,4,40,0,122,4,75,0,121,4,20,0,129,
4,75,0,121,4,20,0,129,4,74,0,92,3,60,0,94,4,74,
255,127,3,60,255,111,4,74,0,92,3,60,0,94,5,186,0,76,
5,220,0,94,4,102,0,113,3,162,0,97,4,215,0,121,3,194,
0,121,4,215,0,121,3,194,0,121,4,215,0,121,3,194,0,121,
4,215,0,121,3,194,0,121,4,174,0,121,3,150,0,102,5,249,
0,121,5,123,0,102,4,174,0,121,4,40,0,121,4,196,0,100,
3,153,0,101,4,196,0,100,3,153,0,101,4,219,0,88,3,221,
0,82,4,155,0,66,4,40,0,120,4,155,0,66,4,40,0,120,
4,190,0,74,3,133,0,53,5,170,0,121,5,8,0,121,4,0,
0,98,4,40,0,129,4,0,0,98,4,40,0,129,4,40,0,129,
4,40,0,129,4,196,0,100,3,153,0,101,4,196,0,100,3,153,
0,101,1,174,0,131,5,186,0,76,5,220,0,94,4,215,0,121,
3,194,0,121,4,120,0,84,3,194,0,69,4,174,0,121,3,150,
0,102,4,174,0,121,3,150,0,102,4,0,0,98,4,40,0,129,
6,26,0,121,4,150,0,98,1,188,0,154,5,22,0,72,3,225,
0,106,5,22,0,72,3,225,0,106,5,108,0,83,5,206,0,84,
4,74,0,88,3,245,0,98,4,196,0,23,3,245,0,98,4,196,
0,23,3,245,0,98,5,186,0,76,5,220,0,94,4,102,0,113,
3,162,0,97,4,102,0,113,3,162,0,97,4,247,0,121,4,40,
0,122,4,247,0,121,4,40,0,122,5,53,0,92,3,228,0,102,
5,53,0,92,3,245,0,98,5,53,0,92,3,245,0,98,4,196,
0,100,3,153,0,101,4,247,0,26,4,40,0,74,4,247,0,26,
4,40,0,74,4,247,0,26,4,40,0,74,4,0,0,98,4,40,
0,129,4,74,0,92,3,60,0,94,4,175,0,121,4,206,0,51,
4,155,0,121,4,20,0,129,4,196,0,121,4,20,0,73,4,238,
0,131,4,21,0,129,4,196,0,121,4,20,0,73,4,122,0,121,
2,168,0,125,4,216,0,131,4,42,0,139,4,174,0,121,4,40,
0,129,5,1,0,131,3,218,0,139,4,124,0,131,1,215,0,160,
4,124,255,154,1,215,255,190,4,124,0,131,1,215,0,113,6,26,
0,121,5,253,0,129,6,69,0,131,6,40,0,139,5,34,0,131,
4,42,0,139,5,34,0,131,4,42,0,139,5,34,0,131,4,42,
0,139,4,75,0,121,4,20,0,129,4,119,0,131,3,0,0,113,
4,119,0,131,3,0,0,82,4,119,0,131,3,0,0,29,4,55,
0,45,3,153,0,96,4,179,0,76,3,195,0,107,4,219,0,88,
2,184,0,102,5,5,0,98,2,225,0,113,5,5,0,98,2,225,
0,113,6,40,0,84,5,94,0,68,6,40,0,84,5,94,0,68,
6,40,0,84,5,94,0,68,4,197,0,86,4,1,0,129,4,42,
0,139,5,27,0,131,4,155,0,76,3,228,0,120,5,88,0,126,
3,64,0,0,4,188,0,90,4,188,0,90,4,188,0,90,4,188,
0,90,4,188,0,90,4,188,0,90,4,188,0,90,4,188,0,90,
5,22,0,72,5,22,0,72,5,110,0,20,5,110,0,196,5,110,
0,19,5,110,0,196,5,110,0,19,5,110,0,19,3,245,0,138,
3,245,0,138,3,245,0,138,3,245,0,138,3,245,0,138,3,245,
0,138,4,250,0,19,4,197,0,19,6,222,0,19,6,174,0,19,
5,234,0,19,6,10,0,19,4,40,0,118,4,40,0,118,4,40,
0,118,4,40,0,118,4,40,0,118,4,40,0,118,4,40,0,118,
4,40,0,118,5,50,0,19,5,0,0,19,7,26,0,19,6,242,
0,19,6,67,0,19,6,76,0,19,6,67,0,19,6,18,0,19,
2,112,0,76,2,112,0,135,2,236,0,56,2,112,0,8,2,168,
0,19,2,112,0,12,2,112,0,27,2,112,0,27,1,230,0,16,
1,223,0,19,2,228,0,19,3,187,0,19,2,228,0,19,3,11,
0,19,3,171,0,19,3,201,0,19,4,30,0,90,4,30,0,90,
4,30,0,90,4,30,0,90,4,30,0,90,4,30,0,90,5,53,
0,92,5,53,0,19,6,242,0,100,6,198,0,19,6,87,0,100,
6,30,0,19,3,246,0,118,3,246,0,118,3,246,0,118,3,246,
0,118,3,246,0,118,3,246,0,118,3,246,0,118,3,246,0,118,
5,102,0,19,7,86,0,19,6,194,0,19,6,173,0,19,4,184,
0,55,4,184,0,55,4,184,0,55,4,184,0,55,4,184,0,55,
4,184,0,55,4,184,0,55,4,184,0,55,5,78,0,19,5,78,
0,19,6,200,0,19,6,208,0,19,6,36,0,19,5,217,0,19,
6,240,0,19,7,5,0,19,4,188,0,90,4,188,0,90,3,245,
0,138,3,245,0,138,4,40,0,118,4,40,0,118,2,112,255,127,
2,112,0,134,4,30,0,90,4,30,0,90,3,246,0,87,3,246,
0,118,4,184,0,55,4,184,0,55,4,188,0,90,4,188,0,90,
4,188,0,90,4,188,0,90,4,188,0,90,4,188,0,90,4,188,
0,90,4,188,0,90,5,22,0,72,5,22,0,72,5,230,0,19,
5,230,0,19,5,230,0,19,5,22,0,32,5,22,0,19,5,22,
0,28,4,40,0,118,4,40,0,118,4,40,0,118,4,40,0,118,
4,40,0,118,4,40,0,118,4,40,0,118,4,40,0,118,5,50,
0,19,4,216,0,19,7,26,0,19,7,22,0,19,7,22,0,19,
5,232,0,20,5,170,0,19,5,170,0,19,4,184,0,55,4,184,
0,55,4,184,0,55,4,184,0,55,4,184,0,55,4,184,0,55,
4,184,0,55,4,184,0,55,5,78,0,19,5,78,0,19,7,37,
0,19,5,78,0,25,6,16,0,19,6,14,0,19,7,21,0,19,
7,21,1,53,4,188,0,90,4,188,0,90,4,188,0,90,4,188,
0,90,4,188,0,90,4,188,0,90,4,188,0,90,5,22,0,72,
5,22,0,72,5,22,0,59,5,22,0,72,5,22,0,72,1,143,
0,100,3,33,2,72,1,143,0,100,2,223,0,49,3,26,0,57,
4,40,0,118,4,40,0,117,4,40,0,116,4,40,0,118,4,40,
0,113,5,222,0,19,4,118,0,121,6,26,0,19,6,26,0,22,
4,174,0,121,3,79,0,100,3,66,0,100,2,223,0,49,2,112,
255,175,2,112,255,125,2,112,255,134,2,112,0,135,2,112,255,177,
2,112,255,140,1,188,255,190,1,188,255,139,3,12,0,19,2,218,
0,19,3,110,0,100,3,90,0,100,2,223,0,49,3,246,0,118,
3,246,0,118,3,246,0,118,3,246,0,118,4,30,0,90,4,30,
0,90,3,246,0,118,3,246,0,118,4,155,0,66,4,155,0,66,
6,70,0,19,5,106,0,19,4,210,0,19,3,26,0,60,4,12,
0,188,2,38,0,60,4,184,0,55,4,184,0,55,4,184,0,55,
4,184,0,55,4,184,0,55,5,158,0,19,5,53,0,19,5,210,
0,19,5,78,0,19,5,78,0,25,2,38,0,60,1,143,0,100,
8,0,0,0,1,85,0,0,1,0,0,0,0,205,0,0,0,170,
0,0,4,40,0,118,4,40,0,118,4,63,0,170,3,233,0,170,
5,10,0,150,6,26,0,0,2,54,0,69,1,129,0,83,1,129,
0,95,1,129,0,99,1,129,0,106,2,165,0,81,2,165,0,97,
2,176,0,113,2,176,0,91,3,176,0,134,3,176,0,134,2,127,
0,59,2,127,0,199,1,126,0,92,3,207,0,92,6,231,0,92,
4,12,0,253,8,51,0,115,10,193,0,115,1,126,0,129,2,147,
0,129,2,0,0,70,2,62,0,109,2,230,0,103,3,217,0,55,
6,99,0,1,6,38,0,32,2,200,0,47,1,64,254,34,5,200,
0,57,4,84,0,57,4,84,0,103,4,126,0,121,4,169,0,131,
4,169,0,131,3,18,0,32,1,167,0,113,3,228,0,62,2,223,
0,63,3,90,0,26,5,168,0,26,5,167,0,26,1,160,0,100,
5,184,0,37,1,160,0,100,1,160,0,100,2,162,0,48,1,198,
0,49,2,152,0,68,2,158,0,51,2,238,0,65,2,164,0,48,
2,114,0,48,2,198,0,50,2,200,0,58,2,168,0,45,2,78,
0,70,2,124,0,80,2,106,0,64,1,144,0,60,1,161,0,51,
2,106,0,66,2,162,0,48,1,198,0,49,2,152,0,68,2,158,
0,51,2,238,0,65,2,164,0,48,2,114,0,48,2,198,0,50,
2,200,0,58,2,168,0,45,2,78,0,70,2,124,0,80,2,106,
0,64,1,144,0,60,1,161,0,51,2,84,0,63,2,84,0,39,
2,90,0,42,2,144,0,52,2,66,0,26,4,12,0,253,4,12,
0,253,4,154,0,178,4,154,0,117,4,154,0,64,4,154,0,68,
4,154,0,100,5,52,0,16,5,42,0,16,7,126,0,16,6,110,
0,16,6,79,0,16,5,36,0,16,4,154,1,74,4,65,0,135,
4,242,0,16,4,154,0,43,4,154,1,2,4,154,0,166,4,154,
0,41,4,154,0,156,4,154,0,0,4,154,0,43,4,154,0,195,
4,154,0,144,4,154,0,76,4,154,0,43,4,154,0,131,4,196,
0,57,3,164,0,34,5,222,0,121,4,75,0,121,4,77,0,121,
4,176,0,23,5,78,0,25,4,247,0,49,4,24,0,141,3,246,
0,29,4,82,0,72,3,246,0,29,4,94,0,76,4,94,0,51,
4,94,0,65,3,246,0,29,4,34,0,50,3,246,0,29,4,26,
0,53,4,26,0,48,4,26,0,50,3,246,0,29,1,188,0,154,
2,164,0,154,3,200,0,154,6,88,0,154,4,221,0,123,6,68,
0,123,7,92,0,123,7,90,0,123,6,44,0,154,4,190,0,74,
6,6,0,74,7,34,0,74,4,81,0,121,4,196,0,100,4,196,
0,121,6,26,0,121,1,174,0,121,2,174,0,121,3,198,0,121,
1,174,0,121,4,0,0,82,5,72,0,82,7,134,0,82,6,108,
0,82,5,14,0,121,3,133,0,53,4,236,0,53,6,4,0,53,
1,174,0,126,3,153,0,101,4,20,0,128,5,253,0,129,8,8,
0,62,4,196,0,121,8,252,0,38,4,196,0,100,3,153,0,101,
4,196,0,100,4,214,0,66,4,196,0,121,8,252,0,38,5,122,
0,48,6,138,0,120,3,244,0,250,6,138,0,120,3,244,0,250,
6,138,0,120,3,244,0,250,6,138,1,52,6,138,1,52,6,138,
1,52,6,138,1,52,6,138,0,120,6,138,0,120,6,138,0,206,
6,138,0,206,6,138,0,120,3,244,0,250,6,138,0,120,3,244,
0,250,6,138,0,120,6,138,0,120,6,138,0,120,3,244,0,248,
6,138,0,120,3,244,0,250,3,244,0,120,3,244,0,120,3,244,
0,150,3,244,0,120,3,244,0,150,3,244,0,120,6,138,0,120,
6,138,0,72,6,138,0,72,6,138,1,52,6,138,0,120,6,138,
0,90,6,138,0,111,6,138,0,120,6,138,0,120,4,0,1,192,
4,0,1,0,6,138,0,120,6,138,0,120,4,0,1,192,4,0,
1,0,6,138,0,120,6,138,1,74,6,138,0,120,6,138,0,120,
6,138,1,160,6,138,0,120,6,138,1,160,6,138,0,120,6,138,
0,120,3,138,0,10,3,138,0,85,3,138,0,10,3,138,0,85,
4,230,0,10,5,22,0,72,4,6,0,82,4,118,0,121,4,165,
0,94,6,26,0,120,6,26,0,120,4,118,0,137,4,118,0,109,
5,124,0,58,4,174,0,110,4,174,0,110,4,122,0,64,2,204,
0,68,3,145,0,73,4,221,0,0,4,221,0,0,4,221,0,0,
3,198,0,22,5,144,0,6,3,98,0,54,3,220,0,79,3,220,
0,79,4,241,0,121,4,241,0,121,2,248,0,23,3,207,0,92,
3,132,0,63,3,139,0,66,2,223,0,63,3,139,0,15,3,139,
0,66,3,104,0,109,3,104,0,109,5,124,0,58,5,124,0,58,
4,112,0,95,4,112,0,100,4,112,0,100,4,165,0,94,4,165,
0,94,3,128,0,34,1,149,0,82,1,149,0,82,3,57,1,102,
2,100,0,145,1,240,0,57,1,240,0,57,3,193,0,131,5,136,
0,126,2,190,0,129,4,122,0,121,5,22,1,216,8,22,0,115,
6,58,0,102,5,220,0,101,4,148,0,125,3,230,0,125,3,226,
0,125,3,197,0,100,7,10,0,125,5,172,0,125,5,168,0,125,
5,160,0,125,4,112,0,225,4,112,1,76,4,112,0,226,4,112,
0,106,4,112,0,86,4,112,0,111,4,112,0,118,4,112,0,84,
4,112,0,84,4,112,0,118,3,225,0,90,3,225,0,90,3,225,
0,90,3,225,0,90,3,225,0,90,3,225,0,90,3,225,0,90,
3,225,0,90,3,225,0,90,3,225,0,90,4,76,0,38,6,69,
0,131,6,40,0,139,6,69,0,131,6,40,0,139,5,34,0,131,
4,42,0,139,4,119,0,131,3,0,0,4,5,5,0,98,2,225,
0,62,4,179,0,76,3,195,0,107,4,216,0,131,4,42,0,139,
4,216,0,131,4,124,0,131,1,215,0,23,4,124,255,154,1,215,
255,190,4,119,0,131,3,0,255,215,4,119,0,131,3,0,255,215,
1,212,255,137,5,128,0,27,3,188,0,119,4,165,0,94,3,154,
0,170,6,138,0,158,6,138,0,212,5,78,0,25,6,138,0,34,
6,138,0,120,6,138,0,132,6,138,0,104,6,138,0,250,6,250,
0,116,4,184,0,72,4,165,0,94,1,188,1,61,1,188,1,61,
1,188,0,0,1,149,0,82,1,188,0,0,1,188,0,0,1,188,
1,61,1,188,0,0,2,100,0,145,2,162,0,50,2,162,0,50,
4,20,0,99,4,108,0,125,5,82,0,96,5,248,0,24,4,220,
0,170,4,111,0,11,5,228,0,20,4,118,0,121,4,155,0,66,
3,128,0,34,4,52,0,66,5,116,0,20,5,45,0,100,5,78,
0,26,3,110,0,52,4,113,0,44,3,200,0,34,4,79,0,41,
5,132,0,34,4,129,0,38,4,165,0,35,4,165,0,22,4,148,
0,22,6,40,0,84,4,190,0,74,1,188,0,154,3,233,0,120,
2,238,0,27,4,244,0,19,2,221,0,154,3,253,0,154,1,149,
0,95,0,95,0,95,0,95,0,0,0,0,0,5,0,0,0,3,
0,0,0,44,0,0,0,4,0,0,4,36,0,1,0,0,0,0,
10,64,0,3,0,1,0,0,0,44,0,3,0,10,0,0,4,36,
0,4,3,248,0,0,0,250,0,128,0,6,0,122,0,127,1,127,
1,146,1,227,2,29,2,175,2,199,2,205,2,221,3,4,3,8,
3,12,3,16,3,37,3,40,3,46,3,49,3,113,3,118,3,126,
3,138,3,140,3,161,4,95,4,249,30,3,30,15,30,31,30,37,
30,43,30,59,30,73,30,87,30,99,30,111,30,133,30,143,30,150,
30,158,30,243,30,251,31,21,31,29,31,69,31,77,31,87,31,89,
31,91,31,93,31,125,31,180,31,196,31,211,31,219,31,239,31,244,
31,254,32,5,32,10,32,22,32,39,32,51,32,58,32,61,32,63,
32,68,32,73,32,79,32,83,32,86,32,91,32,94,32,142,32,148,
32,153,32,185,33,3,33,17,33,22,33,24,33,28,33,34,33,38,
33,46,33,53,33,137,33,168,33,204,33,212,34,0,34,3,34,9,
34,13,34,18,34,23,34,30,34,32,34,43,34,52,34,60,34,69,
34,72,34,97,34,101,34,132,34,135,34,149,34,151,34,165,34,197,
35,33,35,42,37,202,167,71,224,150,225,14,225,33,226,89,226,104,
239,173,239,184,246,190,248,255,251,6,255,255,0,0,0,32,0,161,
1,146,1,226,2,24,2,80,2,198,2,205,2,216,3,0,3,6,
3,10,3,16,3,35,3,39,3,46,3,49,3,112,3,118,3,122,
3,132,3,140,3,142,3,163,4,138,30,2,30,10,30,30,30,36,
30,42,30,52,30,64,30,86,30,90,30,106,30,128,30,142,30,150,
30,158,30,242,30,250,31,0,31,24,31,32,31,72,31,80,31,89,
31,91,31,93,31,95,31,128,31,182,31,198,31,214,31,221,31,242,
31,246,32,3,32,9,32,16,32,24,32,48,32,57,32,60,32,63,
32,66,32,71,32,75,32,82,32,86,32,88,32,93,32,112,32,144,
32,152,32,160,33,3,33,17,33,22,33,24,33,28,33,34,33,38,
33,46,33,53,33,83,33,144,33,176,33,208,34,0,34,2,34,5,
34,13,34,15,34,23,34,26,34,32,34,39,34,52,34,60,34,69,
34,72,34,96,34,100,34,130,34,134,34,149,34,151,34,165,34,196,
35,32,35,41,37,202,167,70,224,149,225,4,225,24,226,80,226,104,
239,160,239,176,246,190,248,229,251,5,255,255,255,227,255,194,255,176,
255,97,255,45,254,251,254,229,254,224,254,214,254,180,254,179,254,178,
254,175,254,157,254,156,254,151,254,149,254,87,254,83,254,80,254,75,
254,74,254,73,254,72,254,30,229,22,229,16,229,2,228,254,228,250,
228,242,228,238,228,226,228,224,228,218,228,202,228,194,228,188,228,181,
228,98,228,92,228,88,228,86,228,84,228,82,228,80,228,79,228,78,
228,77,228,76,228,74,228,73,228,72,228,70,228,69,228,67,228,66,
228,62,228,59,228,54,228,53,228,45,228,40,228,39,228,38,228,36,
228,34,228,33,228,31,228,29,228,28,228,27,228,10,228,9,228,6,
228,0,227,183,227,170,227,166,227,165,227,162,227,157,227,154,227,147,
227,141,227,112,227,106,227,99,227,96,227,53,227,52,227,51,227,48,
227,47,227,43,227,41,227,40,227,34,227,26,227,19,227,11,227,9,
226,242,226,240,226,212,226,211,226,198,226,197,226,184,226,154,226,64,
226,57,223,154,94,31,36,210,36,101,36,92,35,46,35,32,21,233,
21,231,14,226,12,188,10,183,0,1,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,12,0,0,0,0,6,28,0,0,
0,0,0,0,0,129,0,0,0,32,0,0,0,127,0,0,0,3,
0,0,0,161,0,0,1,127,0,0,0,99,0,0,1,146,0,0,
1,146,0,0,1,66,0,0,1,226,0,0,1,227,0,0,1,67,
0,0,2,24,0,0,2,29,0,0,1,69,0,0,2,80,0,0,
2,175,0,0,1,75,0,0,2,198,0,0,2,199,0,0,1,171,
0,0,2,205,0,0,2,205,0,0,1,173,0,0,2,216,0,0,
2,221,0,0,1,174,0,0,3,0,0,0,3,4,0,0,1,180,
0,0,3,6,0,0,3,8,0,0,1,185,0,0,3,10,0,0,
3,12,0,0,1,188,0,0,3,16,0,0,3,16,0,0,1,191,
0,0,3,35,0,0,3,37,0,0,1,192,0,0,3,39,0,0,
3,40,0,0,1,195,0,0,3,46,0,0,3,46,0,0,1,197,
0,0,3,49,0,0,3,49,0,0,1,198,0,0,3,112,0,0,
3,113,0,0,1,199,0,0,3,118,0,0,3,118,0,0,1,201,
0,0,3,122,0,0,3,126,0,0,1,202,0,0,3,132,0,0,
3,138,0,0,1,207,0,0,3,140,0,0,3,140,0,0,1,214,
0,0,3,142,0,0,3,161,0,0,1,215,0,0,3,163,0,0,
4,95,0,0,1,235,0,0,4,138,0,0,4,249,0,0,2,168,
0,0,30,2,0,0,30,3,0,0,3,24,0,0,30,10,0,0,
30,15,0,0,3,26,0,0,30,30,0,0,30,31,0,0,3,32,
0,0,30,36,0,0,30,37,0,0,3,34,0,0,30,42,0,0,
30,43,0,0,3,36,0,0,30,52,0,0,30,59,0,0,3,38,
0,0,30,64,0,0,30,73,0,0,3,46,0,0,30,86,0,0,
30,87,0,0,3,56,0,0,30,90,0,0,30,99,0,0,3,58,
0,0,30,106,0,0,30,111,0,0,3,68,0,0,30,128,0,0,
30,133,0,0,3,74,0,0,30,142,0,0,30,143,0,0,3,80,
0,0,30,150,0,0,30,150,0,0,3,82,0,0,30,158,0,0,
30,158,0,0,3,83,0,0,30,242,0,0,30,243,0,0,3,84,
0,0,30,250,0,0,30,251,0,0,3,86,0,0,31,0,0,0,
31,21,0,0,3,88,0,0,31,24,0,0,31,29,0,0,3,110,
0,0,31,32,0,0,31,69,0,0,3,116,0,0,31,72,0,0,
31,77,0,0,3,154,0,0,31,80,0,0,31,87,0,0,3,160,
0,0,31,89,0,0,31,89,0,0,3,168,0,0,31,91,0,0,
31,91,0,0,3,169,0,0,31,93,0,0,31,93,0,0,3,170,
0,0,31,95,0,0,31,125,0,0,3,171,0,0,31,128,0,0,
31,180,0,0,3,202,0,0,31,182,0,0,31,196,0,0,3,255,
0,0,31,198,0,0,31,211,0,0,4,14,0,0,31,214,0,0,
31,219,0,0,4,28,0,0,31,221,0,0,31,239,0,0,4,34,
0,0,31,242,0,0,31,244,0,0,4,53,0,0,31,246,0,0,
31,254,0,0,4,56,0,0,32,3,0,0,32,5,0,0,4,65,
0,0,32,9,0,0,32,10,0,0,4,68,0,0,32,16,0,0,
32,22,0,0,4,70,0,0,32,24,0,0,32,39,0,0,4,77,
0,0,32,48,0,0,32,51,0,0,4,93,0,0,32,57,0,0,
32,58,0,0,4,97,0,0,32,60,0,0,32,61,0,0,4,99,
0,0,32,63,0,0,32,63,0,0,4,101,0,0,32,66,0,0,
32,68,0,0,4,102,0,0,32,71,0,0,32,73,0,0,4,105,
0,0,32,75,0,0,32,79,0,0,4,108,0,0,32,82,0,0,
32,83,0,0,4,113,0,0,32,86,0,0,32,86,0,0,4,115,
0,0,32,88,0,0,32,91,0,0,4,116,0,0,32,93,0,0,
32,94,0,0,4,120,0,0,32,112,0,0,32,142,0,0,4,122,
0,0,32,144,0,0,32,148,0,0,4,153,0,0,32,152,0,0,
32,153,0,0,4,158,0,0,32,160,0,0,32,185,0,0,4,160,
0,0,33,3,0,0,33,3,0,0,4,186,0,0,33,17,0,0,
33,17,0,0,4,187,0,0,33,22,0,0,33,22,0,0,4,188,
0,0,33,24,0,0,33,24,0,0,4,189,0,0,33,28,0,0,
33,28,0,0,4,190,0,0,33,34,0,0,33,34,0,0,4,191,
0,0,33,38,0,0,33,38,0,0,4,192,0,0,33,46,0,0,
33,46,0,0,4,193,0,0,33,53,0,0,33,53,0,0,4,194,
0,0,33,83,0,0,33,137,0,0,4,195,0,0,33,144,0,0,
33,168,0,0,4,250,0,0,33,176,0,0,33,204,0,0,5,19,
0,0,33,208,0,0,33,212,0,0,5,48,0,0,34,0,0,0,
34,0,0,0,5,53,0,0,34,2,0,0,34,3,0,0,5,54,
0,0,34,5,0,0,34,9,0,0,5,56,0,0,34,13,0,0,
34,13,0,0,5,61,0,0,34,15,0,0,34,18,0,0,5,62,
0,0,34,23,0,0,34,23,0,0,5,66,0,0,34,26,0,0,
34,30,0,0,5,67,0,0,34,32,0,0,34,32,0,0,5,72,
0,0,34,39,0,0,34,43,0,0,5,73,0,0,34,52,0,0,
34,52,0,0,5,78,0,0,34,60,0,0,34,60,0,0,5,79,
0,0,34,69,0,0,34,69,0,0,5,80,0,0,34,72,0,0,
34,72,0,0,5,81,0,0,34,96,0,0,34,97,0,0,5,82,
0,0,34,100,0,0,34,101,0,0,5,84,0,0,34,130,0,0,
34,132,0,0,5,86,0,0,34,134,0,0,34,135,0,0,5,89,
0,0,34,149,0,0,34,149,0,0,5,91,0,0,34,151,0,0,
34,151,0,0,5,92,0,0,34,165,0,0,34,165,0,0,5,93,
0,0,34,196,0,0,34,197,0,0,5,94,0,0,35,32,0,0,
35,33,0,0,5,96,0,0,35,41,0,0,35,42,0,0,5,98,
0,0,37,202,0,0,37,202,0,0,5,100,0,0,167,70,0,0,
167,71,0,0,5,101,0,0,224,149,0,0,224,150,0,0,5,103,
0,0,225,4,0,0,225,14,0,0,5,105,0,0,225,24,0,0,
225,33,0,0,5,116,0,0,226,80,0,0,226,89,0,0,5,126,
0,0,226,104,0,0,226,104,0,0,5,136,0,0,239,160,0,0,
239,173,0,0,5,137,0,0,239,176,0,0,239,184,0,0,5,151,
0,0,246,190,0,0,246,190,0,0,5,160,0,0,248,229,0,0,
248,255,0,0,5,161,0,0,251,5,0,0,251,6,0,0,5,188,
0,1,9,0,0,1,9,27,0,0,5,190,0,1,9,28,0,1,
9,28,0,0,5,221,0,1,9,29,0,1,9,29,0,0,5,220,
0,1,9,30,0,1,9,30,0,0,5,219,0,1,9,31,0,1,
9,31,0,0,5,218,0,6,2,10,0,0,0,0,1,0,0,1,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,
0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,1,0,0,0,0,0,3,0,4,0,5,0,6,0,7,
0,8,0,9,0,10,0,11,0,12,0,13,0,14,0,15,0,16,
0,17,0,18,0,19,0,20,0,21,0,22,0,23,0,24,0,25,
0,26,0,27,0,28,0,29,0,30,0,31,0,32,0,33,0,34,
0,35,0,36,0,37,0,38,0,39,0,40,0,41,0,42,0,43,
0,44,0,45,0,46,0,47,0,48,0,49,0,50,0,51,0,52,
0,53,0,54,0,55,0,56,0,57,0,58,0,59,0,60,0,61,
0,62,0,63,0,64,0,65,0,66,0,67,0,68,0,69,0,70,
0,71,0,72,0,73,0,74,0,75,0,76,0,77,0,78,0,79,
0,80,0,81,0,82,0,83,0,84,0,85,0,86,0,87,0,88,
0,89,0,90,0,91,0,92,0,93,0,94,0,95,0,96,0,97,
0,98,0,134,0,135,0,137,0,139,0,147,0,152,0,158,0,163,
0,162,0,164,0,166,0,165,0,167,0,169,0,171,0,170,0,172,
0,173,0,175,0,174,0,176,0,177,0,179,0,181,0,180,0,182,
0,184,0,183,0,188,0,187,0,189,0,190,4,85,0,114,0,100,
0,101,0,105,4,87,0,120,0,161,0,112,0,107,4,191,0,118,
0,106,5,82,0,136,0,154,5,71,0,115,5,84,5,85,0,103,
0,119,5,54,5,64,5,62,2,8,5,77,0,108,0,124,1,241,
0,168,0,186,0,129,0,99,0,110,5,67,1,66,5,81,5,57,
0,109,0,125,4,91,0,0,0,130,0,133,0,151,1,20,1,21,
4,73,4,74,4,81,4,82,4,77,4,78,0,185,5,100,0,193,
1,58,4,104,4,172,4,97,4,98,0,0,0,0,4,86,0,121,
4,79,4,83,4,93,0,132,0,140,0,131,0,141,0,138,0,143,
0,144,0,145,0,142,0,149,0,150,5,187,0,148,0,156,0,157,
0,155,0,243,1,171,1,178,0,113,1,174,1,175,1,176,0,122,
1,179,1,177,1,172,0,0,0,33,2,121,0,68,5,17,0,0,
0,0,0,0,0,88,0,0,0,88,0,0,0,88,0,0,0,88,
0,0,0,184,0,0,1,56,0,0,1,164,0,0,2,92,0,0,
3,40,0,0,3,184,0,0,3,252,0,0,4,52,0,0,4,108,
0,0,5,12,0,0,5,60,0,0,5,136,0,0,5,164,0,0,
5,220,0,0,5,248,0,0,6,116,0,0,6,148,0,0,7,28,
0,0,7,164,0,0,7,228,0,0,8,92,0,0,8,224,0,0,
9,4,0,0,9,196,0,0,10,72,0,0,10,96,0,0,10,120,
0,0,10,160,0,0,10,200,0,0,10,240,0,0,11,140,0,0,
12,136,0,0,12,192,0,0,13,108,0,0,13,228,0,0,14,64,
0,0,14,112,0,0,14,156,0,0,15,32,0,0,15,80,0,0,
15,104,0,0,15,176,0,0,15,232,0,0,16,8,0,0,16,64,
0,0,16,108,0,0,17,0,0,0,17,88,0,0,18,4,0,0,
18,96,0,0,18,252,0,0,19,36,0,0,19,120,0,0,19,160,
0,0,19,220,0,0,20,28,0,0,20,76,0,0,20,120,0,0,
20,156,0,0,20,188,0,0,20,224,0,0,21,4,0,0,21,28,
0,0,21,116,0,0,21,240,0,0,22,92,0,0,22,192,0,0,
23,40,0,0,23,152,0,0,23,236,0,0,24,132,0,0,24,208,
0,0,25,20,0,0,25,136,0,0,25,192,0,0,25,240,0,0,
26,104,0,0,26,180,0,0,27,32,0,0,27,140,0,0,28,8,
0,0,28,68,0,0,28,228,0,0,29,28,0,0,29,104,0,0,
29,148,0,0,29,208,0,0,30,8,0,0,30,120,0,0,30,160,
0,0,31,80,0,0,31,104,0,0,32,24,0,0,32,132,0,0,
34,124,0,0,34,152,0,0,35,0,0,0,35,124,0,0,36,12,
0,0,36,96,0,0,36,136,0,0,37,52,0,0,37,160,0,0,
38,76,0,0,38,232,0,0,39,36,0,0,39,68,0,0,39,88,
0,0,40,52,0,0,40,80,0,0,40,180,0,0,40,208,0,0,
41,152,0,0,42,80,0,0,42,168,0,0,43,4,0,0,43,144,
0,0,43,164,0,0,43,240,0,0,44,16,0,0,44,136,0,0,
44,196,0,0,45,24,0,0,46,4,0,0,46,240,0,0,47,4,
0,0,47,28,0,0,47,52,0,0,47,76,0,0,47,100,0,0,
47,124,0,0,47,148,0,0,47,228,0,0,47,252,0,0,48,20,
0,0,48,44,0,0,48,68,0,0,48,92,0,0,48,116,0,0,
48,140,0,0,48,164,0,0,48,188,0,0,49,36,0,0,49,60,
0,0,49,84,0,0,49,108,0,0,49,132,0,0,49,156,0,0,
49,180,0,0,49,208,0,0,50,124,0,0,50,148,0,0,50,172,
0,0,50,196,0,0,50,220,0,0,50,244,0,0,51,76,0,0,
52,24,0,0,52,48,0,0,52,72,0,0,52,96,0,0,52,120,
0,0,52,144,0,0,52,168,0,0,53,208,0,0,53,232,0,0,
54,0,0,0,54,24,0,0,54,48,0,0,54,72,0,0,54,172,
0,0,55,16,0,0,55,68,0,0,55,188,0,0,56,120,0,0,
56,144,0,0,56,168,0,0,56,192,0,0,56,216,0,0,56,240,
0,0,57,8,0,0,57,124,0,0,58,24,0,0,58,48,0,0,
58,72,0,0,58,96,0,0,58,120,0,0,58,144,0,0,59,20,
0,0,59,44,0,0,59,68,0,0,59,92,0,0,59,116,0,0,
59,140,0,0,59,164,0,0,59,188,0,0,59,212,0,0,59,236,
0,0,60,4,0,0,60,28,0,0,60,52,0,0,60,76,0,0,
60,100,0,0,60,124,0,0,60,148,0,0,61,68,0,0,61,180,
0,0,62,100,0,0,62,124,0,0,62,148,0,0,62,172,0,0,
62,196,0,0,62,220,0,0,62,244,0,0,63,12,0,0,63,36,
0,0,63,60,0,0,63,84,0,0,63,108,0,0,63,132,0,0,
63,156,0,0,63,180,0,0,63,204,0,0,63,228,0,0,63,252,
0,0,64,20,0,0,64,44,0,0,64,68,0,0,64,148,0,0,
65,20,0,0,65,44,0,0,65,196,0,0,65,220,0,0,66,4,
0,0,66,28,0,0,66,52,0,0,66,76,0,0,66,100,0,0,
66,124,0,0,66,152,0,0,67,20,0,0,67,228,0,0,67,252,
0,0,68,128,0,0,68,152,0,0,68,176,0,0,68,232,0,0,
69,0,0,0,69,24,0,0,69,48,0,0,69,72,0,0,69,180,
0,0,70,48,0,0,70,72,0,0,70,96,0,0,70,152,0,0,
70,224,0,0,70,248,0,0,71,16,0,0,71,40,0,0,71,64,
0,0,71,88,0,0,71,112,0,0,71,140,0,0,72,48,0,0,
72,204,0,0,72,228,0,0,72,252,0,0,73,20,0,0,73,44,
0,0,73,68,0,0,73,92,0,0,74,28,0,0,75,20,0,0,
75,44,0,0,75,68,0,0,75,92,0,0,75,116,0,0,75,140,
0,0,75,164,0,0,75,188,0,0,75,212,0,0,75,236,0,0,
76,4,0,0,77,108,0,0,78,196,0,0,78,220,0,0,78,244,
0,0,79,88,0,0,79,208,0,0,79,232,0,0,80,108,0,0,
80,168,0,0,80,244,0,0,81,12,0,0,81,36,0,0,81,60,
0,0,81,84,0,0,81,108,0,0,81,132,0,0,81,156,0,0,
81,180,0,0,81,204,0,0,81,228,0,0,81,252,0,0,82,20,
0,0,82,44,0,0,82,68,0,0,82,92,0,0,82,116,0,0,
82,140,0,0,82,164,0,0,82,188,0,0,82,212,0,0,82,236,
0,0,83,4,0,0,83,28,0,0,83,120,0,0,83,228,0,0,
84,64,0,0,85,96,0,0,86,60,0,0,87,24,0,0,87,40,
0,0,87,56,0,0,88,16,0,0,88,224,0,0,89,128,0,0,
90,12,0,0,90,152,0,0,91,108,0,0,92,0,0,0,92,224,
0,0,93,188,0,0,94,152,0,0,95,40,0,0,95,192,0,0,
96,120,0,0,97,44,0,0,97,224,0,0,98,160,0,0,99,120,
0,0,99,224,0,0,101,0,0,0,101,224,0,0,102,176,0,0,
103,148,0,0,104,16,0,0,104,124,0,0,105,44,0,0,106,32,
0,0,106,128,0,0,106,224,0,0,107,16,0,0,107,156,0,0,
108,52,0,0,108,140,0,0,109,48,0,0,109,208,0,0,110,116,
0,0,111,88,0,0,111,248,0,0,112,152,0,0,112,196,0,0,
113,92,0,0,114,84,0,0,115,48,0,0,115,216,0,0,116,28,
0,0,116,96,0,0,116,228,0,0,117,40,0,0,117,180,0,0,
118,24,0,0,118,120,0,0,118,224,0,0,119,76,0,0,120,108,
0,0,120,248,0,0,121,160,0,0,122,44,0,0,123,8,0,0,
123,68,0,0,123,128,0,0,124,16,0,0,124,168,0,0,125,64,
0,0,125,104,0,0,125,164,0,0,125,212,0,0,126,4,0,0,
126,116,0,0,127,4,0,0,127,132,0,0,128,96,0,0,128,244,
0,0,129,148,0,0,130,48,0,0,130,240,0,0,132,20,0,0,
132,172,0,0,133,132,0,0,134,104,0,0,134,120,0,0,135,92,
0,0,135,148,0,0,135,180,0,0,136,156,0,0,137,68,0,0,
137,248,0,0,138,180,0,0,139,196,0,0,140,228,0,0,141,216,
0,0,142,144,0,0,143,148,0,0,144,128,0,0,145,100,0,0,
145,152,0,0,145,252,0,0,146,60,0,0,146,244,0,0,147,232,
0,0,148,12,0,0,148,52,0,0,148,80,0,0,148,160,0,0,
148,220,0,0,149,88,0,0,149,188,0,0,150,72,0,0,150,212,
0,0,151,24,0,0,151,88,0,0,151,108,0,0,152,8,0,0,
152,28,0,0,152,108,0,0,152,172,0,0,153,32,0,0,153,160,
0,0,153,184,0,0,153,204,0,0,153,228,0,0,154,36,0,0,
154,152,0,0,155,24,0,0,155,84,0,0,155,148,0,0,155,228,
0,0,156,0,0,0,156,40,0,0,156,80,0,0,156,124,0,0,
156,188,0,0,157,80,0,0,158,28,0,0,158,52,0,0,158,184,
0,0,159,20,0,0,159,44,0,0,159,180,0,0,159,248,0,0,
160,120,0,0,160,248,0,0,161,96,0,0,162,160,0,0,162,188,
0,0,162,212,0,0,162,236,0,0,163,36,0,0,164,32,0,0,
164,64,0,0,164,108,0,0,164,156,0,0,164,200,0,0,164,248,
0,0,165,248,0,0,166,16,0,0,166,72,0,0,166,116,0,0,
166,172,0,0,166,216,0,0,167,12,0,0,167,252,0,0,168,36,
0,0,168,148,0,0,168,204,0,0,168,244,0,0,169,36,0,0,
170,36,0,0,170,100,0,0,171,0,0,0,171,228,0,0,172,96,
0,0,172,236,0,0,173,4,0,0,173,28,0,0,173,52,0,0,
173,76,0,0,173,100,0,0,174,40,0,0,175,40,0,0,175,88,
0,0,176,4,0,0,176,184,0,0,177,48,0,0,177,156,0,0,
178,76,0,0,178,164,0,0,178,216,0,0,179,72,0,0,179,184,
0,0,180,12,0,0,180,204,0,0,181,100,0,0,181,148,0,0,
182,56,0,0,182,220,0,0,183,120,0,0,183,224,0,0,184,108,
0,0,185,64,0,0,185,128,0,0,186,8,0,0,186,224,0,0,
186,248,0,0,187,16,0,0,187,248,0,0,188,16,0,0,188,40,
0,0,188,56,0,0,189,76,0,0,189,252,0,0,190,156,0,0,
190,180,0,0,190,204,0,0,191,88,0,0,192,52,0,0,192,208,
0,0,193,200,0,0,194,112,0,0,195,64,0,0,195,212,0,0,
196,0,0,0,196,196,0,0,197,136,0,0,197,188,0,0,198,184,
0,0,199,72,0,0,199,244,0,0,200,160,0,0,201,8,0,0,
201,148,0,0,202,116,0,0,203,164,0,0,204,164,0,0,205,188,
0,0,206,140,0,0,207,92,0,0,208,108,0,0,209,80,0,0,
209,252,0,0,210,44,0,0,210,168,0,0,211,112,0,0,212,4,
0,0,212,20,0,0,212,196,0,0,213,104,0,0,214,12,0,0,
214,192,0,0,215,56,0,0,216,0,0,0,216,56,0,0,216,112,
0,0,217,36,0,0,217,224,0,0,218,220,0,0,219,204,0,0,
219,228,0,0,219,252,0,0,220,180,0,0,220,204,0,0,221,152,
0,0,221,168,0,0,221,184,0,0,221,208,0,0,222,40,0,0,
222,224,0,0,223,100,0,0,223,220,0,0,223,244,0,0,224,12,
0,0,224,36,0,0,224,84,0,0,224,140,0,0,225,0,0,0,
225,252,0,0,226,28,0,0,226,112,0,0,226,160,0,0,226,240,
0,0,227,168,0,0,227,216,0,0,228,72,0,0,228,128,0,0,
228,232,0,0,229,32,0,0,229,80,0,0,230,64,0,0,230,104,
0,0,230,216,0,0,231,160,0,0,231,200,0,0,232,56,0,0,
233,56,0,0,233,120,0,0,233,168,0,0,234,24,0,0,234,80,
0,0,234,144,0,0,235,4,0,0,235,132,0,0,235,248,0,0,
236,188,0,0,237,184,0,0,238,32,0,0,238,192,0,0,239,136,
0,0,240,32,0,0,240,68,0,0,240,148,0,0,241,48,0,0,
241,128,0,0,242,56,0,0,242,104,0,0,242,216,0,0,243,16,
0,0,243,120,0,0,243,176,0,0,243,228,0,0,244,124,0,0,
244,164,0,0,245,68,0,0,245,216,0,0,246,0,0,0,246,112,
0,0,247,8,0,0,247,64,0,0,247,112,0,0,247,220,0,0,
248,16,0,0,248,80,0,0,248,204,0,0,249,84,0,0,249,204,
0,0,250,112,0,0,251,116,0,0,251,196,0,0,251,220,0,0,
251,244,0,0,252,184,0,0,252,208,0,0,253,116,0,0,254,76,
0,0,254,92,0,0,254,116,0,0,254,132,0,0,255,72,0,0,
255,216,0,1,0,96,0,1,0,120,0,1,0,144,0,1,1,64,
0,1,1,112,0,1,1,128,0,1,1,144,0,1,2,4,0,1,
2,124,0,1,2,236,0,1,3,140,0,1,3,252,0,1,4,108,
0,1,4,160,0,1,4,216,0,1,5,124,0,1,5,140,0,1,
5,156,0,1,5,172,0,1,5,188,0,1,5,204,0,1,5,220,
0,1,5,236,0,1,5,252,0,1,6,12,0,1,6,28,0,1,
6,44,0,1,6,60,0,1,6,76,0,1,6,92,0,1,6,108,
0,1,6,164,0,1,6,220,0,1,6,236,0,1,6,252,0,1,
7,12,0,1,7,28,0,1,7,44,0,1,7,60,0,1,7,76,
0,1,7,92,0,1,7,140,0,1,8,48,0,1,8,96,0,1,
9,4,0,1,9,20,0,1,9,36,0,1,9,52,0,1,9,68,
0,1,9,84,0,1,9,100,0,1,9,116,0,1,9,132,0,1,
9,244,0,1,10,100,0,1,10,116,0,1,10,132,0,1,11,84,
0,1,11,240,0,1,12,0,0,1,12,24,0,1,12,48,0,1,
12,152,0,1,12,248,0,1,13,100,0,1,13,208,0,1,14,52,
0,1,14,152,0,1,14,208,0,1,15,8,0,1,15,128,0,1,
15,244,0,1,16,48,0,1,16,112,0,1,16,128,0,1,16,152,
0,1,16,176,0,1,17,72,0,1,18,72,0,1,18,152,0,1,
20,36,0,1,20,60,0,1,20,84,0,1,21,24,0,1,21,176,
0,1,21,200,0,1,21,224,0,1,21,248,0,1,22,16,0,1,
22,40,0,1,22,64,0,1,22,80,0,1,22,96,0,1,22,156,
0,1,22,216,0,1,22,240,0,1,23,128,0,1,23,152,0,1,
23,176,0,1,24,176,0,1,25,76,0,1,26,172,0,1,27,172,
0,1,28,212,0,1,29,220,0,1,30,92,0,1,30,216,0,1,
30,240,0,1,31,8,0,1,31,32,0,1,31,56,0,1,31,80,
0,1,31,104,0,1,31,120,0,1,31,136,0,1,31,160,0,1,
32,140,0,1,32,164,0,1,32,188,0,1,32,212,0,1,32,236,
0,1,33,160,0,1,34,140,0,1,34,164,0,1,34,188,0,1,
34,212,0,1,34,236,0,1,35,88,0,1,35,240,0,1,36,8,
0,1,36,32,0,1,36,104,0,1,36,172,0,1,37,12,0,1,
37,116,0,1,37,224,0,1,38,88,0,1,38,132,0,1,38,188,
0,1,38,212,0,1,38,236,0,1,39,100,0,1,40,36,0,1,
40,140,0,1,41,36,0,1,41,144,0,1,42,40,0,1,42,100,
0,1,42,208,0,1,42,232,0,1,43,0,0,1,43,164,0,1,
44,60,0,1,44,236,0,1,45,144,0,1,46,4,0,1,46,108,
0,1,46,132,0,1,46,156,0,1,47,164,0,1,48,180,0,1,
48,204,0,1,48,228,0,1,49,72,0,1,49,192,0,1,49,244,
0,1,50,60,0,1,50,84,0,1,50,108,0,1,50,132,0,1,
50,156,0,1,50,180,0,1,50,204,0,1,51,44,0,1,51,248,
0,1,52,96,0,1,52,240,0,1,53,8,0,1,53,32,0,1,
53,108,0,1,53,208,0,1,53,232,0,1,54,0,0,1,54,32,
0,1,54,64,0,1,54,96,0,1,54,128,0,1,54,160,0,1,
54,192,0,1,54,216,0,1,54,240,0,1,55,16,0,1,55,40,
0,1,55,72,0,1,55,96,0,1,55,128,0,1,55,160,0,1,
55,184,0,1,55,208,0,1,55,240,0,1,56,16,0,1,56,48,
0,1,56,80,0,1,56,104,0,1,56,128,0,1,56,160,0,1,
56,192,0,1,56,224,0,1,57,0,0,1,57,24,0,1,57,48,
0,1,57,80,0,1,57,112,0,1,57,144,0,1,57,176,0,1,
57,208,0,1,57,240,0,1,58,8,0,1,58,32,0,1,58,64,
0,1,58,96,0,1,58,128,0,1,58,160,0,1,58,192,0,1,
58,224,0,1,58,248,0,1,59,16,0,1,59,48,0,1,59,80,
0,1,59,112,0,1,59,144,0,1,59,176,0,1,59,208,0,1,
59,232,0,1,60,0,0,1,60,32,0,1,60,64,0,1,60,96,
0,1,60,128,0,1,60,160,0,1,60,192,0,1,60,216,0,1,
60,240,0,1,61,16,0,1,61,40,0,1,61,72,0,1,61,104,
0,1,61,128,0,1,61,152,0,1,61,184,0,1,61,216,0,1,
61,248,0,1,62,24,0,1,62,48,0,1,62,72,0,1,62,104,
0,1,62,136,0,1,62,168,0,1,62,200,0,1,62,232,0,1,
63,8,0,1,63,32,0,1,63,64,0,1,63,96,0,1,63,128,
0,1,63,152,0,1,63,176,0,1,63,208,0,1,63,240,0,1,
64,16,0,1,64,48,0,1,64,80,0,1,64,112,0,1,64,136,
0,1,64,160,0,1,64,192,0,1,64,224,0,1,65,0,0,1,
65,32,0,1,65,64,0,1,65,96,0,1,65,120,0,1,65,144,
0,1,65,168,0,1,65,192,0,1,65,216,0,1,65,240,0,1,
66,8,0,1,66,32,0,1,66,56,0,1,66,80,0,1,66,104,
0,1,66,128,0,1,66,152,0,1,66,176,0,1,66,200,0,1,
66,224,0,1,67,0,0,1,67,32,0,1,67,64,0,1,67,96,
0,1,67,128,0,1,67,160,0,1,67,184,0,1,67,208,0,1,
67,240,0,1,68,16,0,1,68,48,0,1,68,80,0,1,68,112,
0,1,68,144,0,1,68,176,0,1,68,208,0,1,68,248,0,1,
69,32,0,1,69,72,0,1,69,112,0,1,69,152,0,1,69,192,
0,1,69,216,0,1,69,240,0,1,70,16,0,1,70,48,0,1,
70,80,0,1,70,112,0,1,70,144,0,1,70,176,0,1,70,200,
0,1,70,224,0,1,71,0,0,1,71,32,0,1,71,64,0,1,
71,88,0,1,71,120,0,1,71,152,0,1,71,180,0,1,71,208,
0,1,71,248,0,1,72,24,0,1,72,64,0,1,72,104,0,1,
72,144,0,1,72,180,0,1,72,204,0,1,72,228,0,1,72,252,
0,1,73,20,0,1,73,44,0,1,73,68,0,1,73,92,0,1,
73,116,0,1,73,140,0,1,73,164,0,1,73,188,0,1,73,212,
0,1,74,48,0,1,74,128,0,1,74,220,0,1,75,104,0,1,
76,92,0,1,76,124,0,1,76,148,0,1,76,180,0,1,76,204,
0,1,76,236,0,1,77,8,0,1,77,24,0,1,77,52,0,1,
77,80,0,1,77,104,0,1,77,128,0,1,77,152,0,1,77,180,
0,1,77,204,0,1,77,228,0,1,77,252,0,1,78,20,0,1,
78,44,0,1,78,76,0,1,78,100,0,1,78,124,0,1,78,152,
0,1,78,180,0,1,79,88,0,1,79,252,0,1,80,212,0,1,
80,236,0,1,81,4,0,1,81,36,0,1,81,68,0,1,81,92,
0,1,81,116,0,1,81,140,0,1,81,172,0,1,81,196,0,1,
81,220,0,1,81,248,0,1,82,20,0,1,82,44,0,1,82,224,
0,1,83,152,0,1,83,240,0,1,84,8,0,1,84,32,0,1,
84,56,0,1,84,80,0,1,84,104,0,1,84,132,0,1,84,156,
0,1,84,180,0,1,84,204,0,1,84,228,0,1,85,60,0,1,
85,152,0,1,85,152,0,1,85,152,0,1,85,152,0,1,85,152,
0,1,85,152,0,1,85,180,0,1,85,208,0,1,85,236,0,1,
86,8,0,1,86,36,0,1,86,64,0,1,86,104,0,1,86,124,
0,1,86,144,0,1,86,164,0,1,86,180,0,1,86,204,0,1,
86,228,0,1,86,248,0,1,87,8,0,1,87,56,0,1,87,128,
0,1,87,196,0,1,87,224,0,1,88,28,0,1,88,140,0,1,
89,44,0,1,89,112,0,1,91,8,0,1,93,28,0,1,93,108,
0,1,93,248,0,1,94,28,0,1,94,64,0,1,95,20,0,1,
95,216,0,1,96,24,0,1,96,148,0,1,96,212,0,1,96,240,
0,1,98,108,0,1,99,148,0,1,100,192,0,1,101,132,0,1,
101,212,0,1,102,36,0,1,102,88,0,1,102,228,0,1,103,108,
0,1,103,248,0,1,104,160,0,1,105,128,0,1,106,148,0,1,
107,8,0,1,107,244,0,1,108,160,0,1,109,120,0,1,110,16,
0,1,110,48,0,1,110,248,0,1,111,176,0,1,111,228,0,1,
112,132,0,1,113,32,0,1,113,68,0,1,114,32,0,1,114,212,
0,1,114,252,0,1,115,24,0,1,115,64,0,1,115,136,0,1,
115,212,0,1,116,64,0,1,116,216,0,1,116,248,0,1,117,192,
0,1,118,120,0,1,118,172,0,1,119,76,0,1,119,232,0,1,
120,12,0,1,120,232,0,1,121,156,0,1,121,196,0,1,121,224,
0,1,122,8,0,1,122,76,0,1,122,152,0,1,123,32,0,1,
123,188,0,1,124,80,0,1,124,132,0,1,125,36,0,1,125,104,
0,1,125,172,0,1,126,44,0,1,126,252,0,1,127,220,0,1,
128,32,0,1,128,180,0,1,129,68,0,1,129,204,0,1,131,4,
0,1,132,116,0,1,133,40,0,1,133,160,0,1,134,60,0,1,
134,200,0,1,135,16,0,1,135,104,0,1,135,216,0,1,137,8,
0,1,137,176,0,1,138,100,0,1,138,212,0,1,139,228,0,1,
140,164,0,1,140,244,0,1,142,164,0,1,142,216,0,1,143,144,
0,1,144,196,0,1,145,80,0,1,146,0,0,1,146,112,0,1,
146,220,0,1,147,44,0,1,148,16,0,1,148,220,0,1,149,140,
0,1,150,104,0,1,151,232,0,1,152,172,0,1,154,24,0,1,
155,116,0,1,156,76,0,1,157,12,0,1,158,76,0,1,159,76,
0,1,160,228,0,1,162,96,0,1,163,100,0,1,163,148,0,1,
163,172,0,1,163,212,0,1,164,8,0,1,164,64,0,1,164,104,
0,1,164,160,0,1,164,228,0,1,165,40,0,1,165,120,0,1,
165,184,0,1,166,4,0,1,166,92,0,1,166,124,0,1,167,68,
0,1,167,204,0,1,168,4,0,1,168,80,0,1,168,220,0,1,
169,168,0,1,169,244,0,1,170,32,0,1,170,140,0,1,171,112,
0,1,172,24,0,1,172,144,0,1,172,200,0,1,173,64,0,1,
173,244,0,1,174,36,0,1,174,184,0,1,175,88,0,1,175,248,
0,1,177,28,0,1,177,164,0,1,178,156,0,1,179,88,0,1,
179,236,0,1,180,180,0,1,180,232,0,1,181,112,0,1,182,104,
0,1,183,188,0,1,183,228,0,1,184,12,0,1,184,52,0,1,
184,92,0,1,184,148,0,1,184,204,0,1,184,248,0,1,185,36,
0,1,185,80,0,1,185,124,0,1,185,192,0,1,186,4,0,1,
186,88,0,1,186,172,0,1,186,228,0,1,187,28,0,1,187,84,
0,1,187,140,0,1,187,196,0,1,187,252,0,1,188,48,0,1,
188,96,0,1,188,148,0,1,188,200,0,1,189,12,0,1,189,60,
0,1,189,108,0,1,189,156,0,1,189,204,0,1,189,252,0,1,
190,44,0,1,190,152,0,1,191,4,0,1,191,60,0,1,191,156,
0,1,192,52,0,1,192,204,0,1,192,236,0,1,193,12,0,1,
193,44,0,1,193,76,0,1,193,108,0,1,193,140,0,1,193,172,
0,1,193,204,0,1,194,16,0,1,194,84,0,1,194,148,0,1,
194,212,0,1,195,20,0,1,195,84,0,1,195,148,0,1,195,200,
0,1,195,252,0,1,196,64,0,1,196,132,0,1,196,196,0,1,
197,8,0,1,197,100,0,1,197,156,0,1,198,128,0,1,198,176,
0,1,199,148,0,1,199,192,0,1,199,236,0,1,200,88,0,1,
200,240,0,1,201,92,0,1,201,132,0,1,201,168,0,1,201,228,
0,1,202,0,0,1,202,176,0,1,202,220,0,1,202,244,0,1,
203,12,0,1,203,216,0,1,204,152,0,1,204,188,0,1,204,232,
0,1,205,16,0,1,205,112,0,1,205,212,0,1,206,88,0,1,
207,24,0,1,207,148,0,1,208,40,0,1,209,56,0,1,209,124,
0,1,209,176,0,1,209,232,0,1,210,28,0,1,210,124,0,1,
210,220,0,1,211,88,0,1,211,196,0,1,212,40,0,1,213,24,
0,1,213,248,0,1,214,28,0,1,214,92,0,1,214,160,0,1,
214,244,0,1,215,76,0,1,215,116,0,1,215,152,0,1,215,204,
0,1,215,252,0,1,216,84,0,1,216,164,0,1,216,212,0,1,
218,76,0,1,219,28,0,1,220,36,0,1,220,176,0,1,221,128,
0,1,222,24,0,1,222,212,0,1,223,184,0,1,224,188,0,1,
225,100,0,1,226,100,0,1,227,4,0,1,227,48,0,1,228,8,
0,1,228,192,0,1,229,0,0,1,229,164,0,1,230,76,0,1,
230,112,0,1,231,84,0,1,231,252,0,1,232,136,0,1,232,160,
0,1,232,184,0,1,232,208,0,1,232,232,0,1,233,0,0,1,
233,24,0,1,233,48,0,1,233,72,0,1,233,96,0,1,234,28,
0,1,234,212,0,1,235,212,0,1,236,80,0,1,237,20,0,1,
237,132,0,1,238,36,0,1,238,212,0,1,239,112,0,1,239,252,
0,1,240,156,0,1,241,200,0,1,242,252,0,1,243,144,0,1,
244,80,0,1,244,140,0,1,245,28,0,1,245,180,0,1,246,80,
0,1,246,248,0,1,247,208,0,1,248,152,0,1,249,124,0,1,
250,80,0,1,250,188,0,1,251,68,0,1,251,112,0,1,252,72,
0,1,252,112,0,1,253,108,0,1,254,104,0,1,255,108,0,2,
0,28,0,2,0,100,0,2,1,24,0,2,2,8,0,2,2,132,
0,2,2,176,0,2,3,172,0,2,4,216,0,2,4,244,0,2,
5,16,0,2,5,72,0,2,5,136,0,2,5,192,0,2,5,224,
0,2,5,252,0,2,6,28,0,2,6,112,0,2,6,140,0,2,
6,168,0,2,7,112,0,2,8,4,0,2,9,64,0,2,9,140,
0,2,9,196,0,2,9,232,0,2,10,28,0,2,10,88,0,2,
10,136,0,2,10,184,0,2,10,252,0,2,11,128,0,2,11,184,
0,2,11,240,0,2,12,20,0,2,12,116,0,2,12,164,0,2,
12,252,0,2,13,76,0,2,13,164,0,2,13,224,0,2,14,76,
0,2,14,120,0,2,14,180,0,2,14,244,0,2,15,12,0,2,
15,44,0,2,15,104,0,2,15,156,0,2,15,196,0,2,15,248,
0,2,16,56,0,2,16,120,0,2,16,184,0,2,16,248,0,2,
0,68,0,0,2,100,5,85,0,3,0,7,0,46,177,1,0,47,
60,178,7,4,2,237,50,177,6,5,220,60,178,3,2,2,237,50,
0,177,3,0,47,60,178,5,4,2,237,50,178,7,6,3,252,60,
178,1,2,2,237,50,51,17,33,17,37,33,17,33,68,2,32,254,
36,1,152,254,104,5,85,250,171,68,4,205,0,0,0,2,0,103,
255,243,1,66,5,203,0,13,0,29,0,0,1,20,6,35,46,1,
53,3,52,54,51,50,22,21,3,52,54,51,50,22,23,22,21,20,
6,35,34,38,39,38,1,25,35,23,25,34,41,59,39,40,61,219,
64,44,39,58,8,2,63,44,39,58,8,3,1,184,25,34,1,33,
25,3,181,39,55,55,37,250,239,45,63,49,36,8,15,44,63,48,
37,10,0,2,0,129,4,20,2,59,6,6,0,19,0,38,0,0,
1,3,52,54,59,1,50,22,23,22,21,3,14,1,35,34,38,39,
52,38,37,3,52,54,59,1,50,22,23,22,21,3,14,1,35,34,
38,39,38,1,186,20,43,29,4,26,39,6,2,20,1,34,20,19,
29,4,2,254,220,21,43,29,4,25,41,6,2,21,1,34,20,19,
29,4,1,4,68,1,118,36,40,29,27,6,14,254,138,22,26,20,
19,1,6,2,1,118,36,40,29,27,12,8,254,138,22,26,20,19,
3,0,0,0,0,2,0,129,0,53,5,199,5,123,0,3,0,31,
0,0,1,17,33,17,5,17,35,17,33,17,35,17,33,53,33,17,
33,53,33,17,51,17,33,17,51,17,33,21,33,17,33,21,3,201,
254,170,1,235,149,254,170,150,254,164,1,92,254,164,1,92,150,1,
86,149,1,105,254,151,1,105,2,35,1,82,254,174,141,254,159,1,
97,254,159,1,97,141,1,82,139,1,123,254,133,1,123,254,133,139,
254,174,141,0,0,3,0,25,255,101,3,205,6,1,0,47,0,56,
0,63,0,0,1,51,21,22,23,7,46,1,39,17,30,9,21,20,
6,7,21,35,53,46,3,39,55,30,4,23,17,46,3,53,52,54,
55,19,17,14,1,21,20,30,2,23,17,62,1,53,52,38,1,197,
129,208,146,125,35,119,75,18,76,39,68,37,55,31,36,18,13,211,
180,127,81,126,102,76,45,135,27,32,59,53,79,45,83,124,107,57,
212,157,2,93,116,30,60,69,177,108,121,114,6,1,126,16,227,80,
65,101,10,254,23,7,28,14,30,22,37,36,51,55,71,41,164,226,
19,129,129,7,42,80,92,71,80,42,46,68,36,32,5,2,43,20,
54,87,132,86,155,194,9,253,176,1,197,12,117,90,57,81,52,31,
200,254,1,18,140,106,84,128,0,5,0,104,0,104,5,29,5,68,
0,15,0,31,0,47,0,63,0,67,0,0,1,20,23,30,1,51,
50,54,53,52,39,46,1,35,34,6,7,52,54,51,50,22,23,22,
21,20,6,35,34,38,39,38,1,20,23,30,1,51,50,54,53,52,
39,46,1,35,34,6,7,52,54,51,50,22,23,22,21,20,6,35,
34,38,39,38,1,35,1,51,3,123,4,11,73,53,61,87,4,11,
79,54,58,83,129,159,113,98,151,20,6,161,114,98,148,20,6,253,
237,4,12,74,54,61,86,3,11,80,53,58,86,127,159,114,98,150,
20,6,161,113,98,149,20,6,1,64,150,2,209,144,1,117,23,16,
51,64,88,66,18,13,51,67,89,60,112,158,122,92,27,29,112,157,
120,92,28,2,221,14,24,51,64,87,66,15,17,50,68,90,60,113,
158,122,93,27,29,112,156,120,92,27,252,113,4,158,0,1,0,100,
255,227,4,135,5,213,0,52,0,0,1,46,1,35,34,6,21,20,
22,59,1,21,35,34,6,21,20,22,51,50,54,53,35,53,33,21,
35,20,14,3,35,34,46,2,53,52,62,2,55,46,1,53,52,62,
1,51,50,22,23,3,43,39,110,95,99,138,146,91,101,97,143,170,
184,119,124,167,195,1,246,141,33,74,103,156,91,90,168,127,76,54,
82,89,40,82,111,95,184,116,131,197,51,4,176,76,76,129,103,105,
138,142,158,147,144,173,177,118,139,141,52,115,117,93,58,72,121,172,
94,80,142,93,59,9,35,155,117,96,169,108,128,99,0,1,0,129,
4,20,1,23,6,6,0,18,0,0,19,3,52,54,59,1,50,22,
23,22,21,3,14,1,35,34,38,39,38,150,21,43,29,4,25,41,
6,2,21,1,34,20,19,29,4,1,4,68,1,118,36,40,29,27,
12,8,254,138,22,26,20,19,3,0,0,1,0,41,255,172,1,201,
6,14,0,12,0,0,5,38,2,53,52,18,55,51,0,17,20,18,
23,1,23,110,128,123,115,178,254,248,147,117,84,169,1,168,230,200,
1,175,180,254,130,254,73,216,254,85,170,0,0,1,0,90,255,172,
1,250,6,14,0,13,0,0,5,35,54,18,53,52,2,39,51,22,
18,21,20,2,1,10,176,127,137,148,116,176,106,134,121,84,187,1,
169,199,208,1,189,170,166,254,74,219,210,254,93,0,0,1,0,33,
0,254,3,121,3,253,0,55,0,0,1,7,6,35,34,39,38,53,
52,63,1,7,34,38,53,52,54,51,23,39,38,53,52,55,54,51,
50,31,1,55,54,51,50,23,22,21,20,15,1,55,50,22,21,20,
6,35,39,23,22,21,20,7,6,35,34,39,1,206,113,19,43,22,
20,38,12,135,245,28,48,42,34,248,136,12,40,20,20,42,20,111,
109,20,42,21,19,40,12,135,247,34,42,48,28,244,134,12,38,20,
22,43,19,2,6,224,40,12,22,40,20,21,207,14,35,41,33,41,
14,208,22,20,38,23,12,40,219,217,40,12,23,38,20,22,206,14,
41,33,41,35,14,205,21,20,40,22,12,40,0,1,0,78,1,2,
3,66,3,254,0,11,0,0,19,33,17,51,17,33,21,33,17,35,
17,33,78,1,51,141,1,52,254,204,141,254,205,2,199,1,55,254,
201,142,254,201,1,55,0,1,0,103,255,35,1,62,0,202,0,22,
0,0,37,20,14,4,7,39,54,53,34,38,39,38,53,52,54,51,
50,22,23,22,1,62,16,21,33,22,29,2,56,72,39,58,8,3,
64,44,39,58,8,2,94,37,77,58,63,35,42,3,31,103,75,47,
37,10,12,45,63,49,36,8,0,0,0,1,0,109,2,51,3,18,
2,193,0,3,0,0,19,33,21,33,109,2,165,253,91,2,193,142,
0,0,0,1,0,103,255,243,1,62,0,202,0,15,0,0,55,52,
54,51,50,22,23,22,21,20,6,35,34,38,39,38,103,64,44,39,
58,8,2,63,44,39,58,8,3,94,45,63,49,36,8,15,44,63,
48,37,10,0,0,1,255,233,0,0,3,84,6,8,0,3,0,0,
51,35,1,51,135,158,2,205,158,6,8,0,0,0,0,2,0,100,
255,227,4,25,5,213,0,18,0,38,0,0,19,52,18,62,1,51,
50,18,23,22,21,20,2,6,35,34,2,39,38,55,20,23,30,1,
51,50,62,2,53,52,39,46,1,35,34,14,2,100,66,121,184,111,
165,227,46,29,109,220,147,168,231,46,28,158,26,34,146,109,80,127,
73,38,28,33,141,107,80,128,76,40,2,215,154,1,21,211,124,254,
248,218,136,148,207,254,173,210,1,9,218,132,141,135,120,160,199,112,
183,210,109,142,130,157,196,115,186,215,0,0,0,1,1,168,0,0,
2,227,5,176,0,5,0,0,1,35,55,51,17,35,2,70,158,223,
92,157,4,182,250,250,80,0,0,1,0,109,0,0,3,248,5,215,
0,47,0,0,1,39,54,36,51,50,30,3,21,20,14,6,7,14,
3,21,33,21,33,52,62,3,55,62,7,53,52,38,35,34,6,1,
6,139,39,1,0,151,65,120,108,80,47,27,42,64,58,77,51,67,
11,42,98,96,63,2,211,252,117,52,80,121,112,71,11,63,34,61,
35,45,24,18,160,107,100,170,4,86,55,138,192,32,71,101,149,89,
51,98,79,79,56,62,35,44,8,30,92,110,121,47,141,94,175,134,
131,92,50,8,42,24,48,37,57,54,70,37,139,162,127,0,0,0,
0,1,0,113,255,227,4,12,5,217,0,47,0,0,63,1,30,1,
51,50,54,53,52,46,2,43,1,53,51,50,54,53,52,38,43,1,
34,6,7,39,62,1,51,50,30,1,21,20,14,1,7,30,3,21,
20,0,35,34,38,113,155,38,158,83,139,193,57,95,115,61,78,98,
97,143,147,95,6,80,121,32,137,53,200,123,101,182,117,66,78,39,
38,84,77,51,254,230,207,125,254,252,47,82,104,170,141,73,119,75,
40,125,148,112,100,142,85,73,64,105,128,94,178,109,82,142,77,20,
11,64,93,132,71,196,254,255,153,0,0,2,0,88,0,0,4,29,
5,176,0,11,0,14,0,0,1,17,51,21,35,17,35,17,33,1,
59,1,7,1,33,3,96,189,189,157,253,149,2,94,13,157,153,254,
125,1,131,5,165,252,116,140,254,115,1,141,4,35,235,253,86,0,
0,0,0,1,0,135,255,227,4,25,5,176,0,38,0,0,1,34,
14,5,7,39,19,33,21,33,3,54,51,50,22,23,22,21,20,14,
1,35,34,38,39,55,22,51,50,54,53,52,39,46,1,2,92,33,
59,49,37,36,17,27,2,145,94,2,160,253,227,66,91,155,163,234,
35,13,107,209,135,170,247,46,156,84,223,132,163,9,24,159,3,39,
7,16,14,23,12,23,1,75,2,158,141,254,84,55,194,164,63,62,
130,221,137,197,162,28,245,193,155,44,39,114,149,0,0,2,0,129,
255,227,4,4,5,174,0,15,0,41,0,0,1,52,39,46,1,35,
34,6,21,20,23,30,1,51,50,54,1,54,51,50,22,23,22,21,
20,14,2,35,34,38,39,38,53,52,62,3,55,1,51,3,111,7,
22,164,113,128,166,6,22,163,105,133,171,254,69,73,64,162,250,33,
10,66,115,175,101,166,235,32,9,23,47,34,59,5,1,78,155,1,
152,26,37,103,135,180,117,33,30,102,126,175,2,19,31,201,155,43,
51,78,155,126,78,205,147,42,45,58,115,110,68,100,9,2,72,0,
0,0,0,1,0,111,0,0,4,55,5,176,0,5,0,0,9,1,
35,1,33,53,4,55,253,213,182,2,4,253,21,5,176,250,80,5,
27,149,0,3,0,104,255,227,4,47,5,217,0,15,0,31,0,64,
0,0,37,50,54,53,52,39,46,1,35,34,6,21,20,23,30,1,
3,20,23,30,1,51,50,54,53,52,39,46,1,35,34,6,19,50,
22,23,22,21,20,7,30,1,23,22,21,20,14,1,35,34,36,39,
38,53,52,62,2,55,38,39,38,53,52,54,2,70,137,194,6,23,
183,115,140,184,7,24,176,137,6,18,134,96,111,141,6,17,130,101,
119,133,252,153,222,28,8,188,85,148,23,8,135,224,130,171,254,250,
35,10,51,83,81,41,147,30,9,234,113,187,132,34,32,110,131,165,
142,30,38,111,140,3,243,30,29,86,98,130,113,28,26,81,97,132,
1,17,165,131,32,45,207,110,39,148,108,40,40,129,213,119,205,160,
52,44,78,134,89,57,17,86,144,39,48,159,214,0,0,2,0,143,
0,0,4,18,5,211,0,15,0,42,0,0,1,20,23,30,1,51,
50,54,53,52,39,46,1,35,34,6,1,6,35,34,38,39,38,53,
52,62,3,51,50,22,23,22,21,20,14,3,7,1,35,1,37,7,
22,163,113,129,166,7,22,163,105,132,171,1,186,73,64,162,250,33,
10,41,80,109,146,81,166,236,31,9,22,49,30,65,2,254,188,168,
4,29,35,29,102,135,179,118,34,28,102,128,176,253,236,31,201,155,
50,45,62,126,112,87,51,206,147,44,43,58,114,114,62,109,4,253,
178,0,255,255,0,113,255,243,1,72,3,163,16,39,0,17,0,10,
2,217,16,6,0,17,10,0,255,255,0,113,255,35,1,72,3,163,
16,38,0,15,10,0,16,7,0,17,0,10,2,217,0,1,0,84,
0,23,3,23,4,211,0,5,0,0,37,9,1,51,9,1,2,80,
254,4,1,252,199,254,2,1,254,23,2,100,2,88,253,166,253,158,
0,2,0,66,1,102,3,98,3,98,0,3,0,7,0,0,19,33,
21,33,17,33,21,33,66,3,32,252,224,3,32,252,224,1,244,142,
1,252,141,0,0,1,0,92,0,20,3,29,4,211,0,5,0,0,
37,35,9,1,51,1,1,35,199,1,252,254,4,199,1,250,20,2,
101,2,90,253,168,0,0,0,0,2,0,57,255,243,3,164,5,217,
0,38,0,54,0,0,1,21,35,53,52,62,4,55,62,4,53,52,
38,35,34,14,1,21,39,62,1,51,50,30,2,21,20,7,14,3,
3,52,54,51,50,22,23,22,21,20,6,35,34,38,39,38,2,61,
157,22,29,54,40,69,18,31,20,44,16,15,154,124,82,139,72,146,
19,244,169,86,156,126,75,136,29,96,54,44,177,64,44,39,58,8,
2,63,44,39,58,8,3,1,245,141,145,45,79,55,60,35,57,16,
28,19,51,40,65,39,124,138,90,124,57,25,164,223,50,96,156,97,
171,136,29,71,44,87,254,46,45,63,49,36,8,15,44,63,48,37,
10,0,0,2,0,41,255,221,6,29,5,215,0,70,0,86,0,0,
37,23,6,35,32,0,3,38,53,52,18,36,51,50,4,30,1,23,
22,21,20,14,2,35,34,38,39,14,1,35,34,38,39,38,53,52,
54,51,50,22,23,22,21,20,23,30,1,51,50,54,53,52,39,46,
3,35,34,14,2,21,20,23,22,0,51,50,54,1,20,23,30,1,
51,50,54,53,52,39,46,1,35,34,6,4,152,77,199,249,254,238,
254,94,55,17,204,1,96,208,136,0,255,193,137,25,14,54,84,98,
45,55,120,40,44,141,79,122,188,25,7,200,142,118,174,24,7,5,
12,82,51,56,102,11,20,111,160,214,115,132,237,169,99,14,46,1,
91,230,93,203,254,3,5,16,117,75,90,109,5,15,113,66,84,129,
213,102,146,1,87,1,5,82,80,208,1,95,205,93,158,212,119,67,
64,75,139,94,56,57,43,60,69,154,117,32,39,140,200,153,113,34,
40,16,22,58,88,143,92,49,53,95,175,134,80,104,174,236,127,65,
65,216,254,223,68,2,59,22,25,75,93,124,91,19,22,71,103,127,
0,0,0,2,0,72,0,0,4,223,5,176,0,2,0,11,0,0,
1,3,33,23,33,3,35,1,48,51,1,35,2,147,204,1,159,37,
254,15,162,176,2,12,127,2,12,180,4,190,253,175,136,254,27,5,
176,250,80,0,0,3,0,121,0,0,4,61,5,176,0,13,0,31,
0,59,0,0,1,17,33,50,62,3,53,52,39,46,1,35,1,17,
51,50,62,3,53,52,39,46,3,35,34,38,39,33,50,30,2,23,
22,21,20,6,35,50,30,2,23,22,21,20,14,5,35,33,1,23,
1,63,70,113,75,52,22,7,19,162,144,254,193,237,83,125,70,43,
13,5,8,37,72,127,85,15,203,177,1,139,118,182,111,63,12,8,
167,87,72,118,75,45,11,8,8,25,42,75,99,148,90,254,35,2,
193,253,204,33,55,75,82,44,35,29,94,117,2,100,254,39,33,48,
67,57,30,29,22,35,60,57,33,2,139,52,89,101,58,42,35,117,
180,53,88,94,51,36,36,34,66,87,75,76,53,33,0,1,0,100,
255,227,4,143,5,215,0,41,0,0,1,14,3,35,34,46,3,53,
52,62,3,51,50,30,3,23,7,46,1,43,1,34,14,2,21,20,
30,2,51,50,54,55,4,143,24,76,112,160,95,119,200,139,97,45,
46,97,140,200,119,76,135,98,78,49,15,149,29,169,104,2,104,169,
105,56,60,109,166,99,106,182,32,1,37,64,109,95,54,82,143,192,
219,118,119,221,198,146,86,37,60,81,81,42,41,91,110,108,180,222,
119,121,221,171,101,131,92,0,0,2,0,121,0,0,4,129,5,176,
0,14,0,27,0,0,1,52,46,4,43,1,17,51,50,62,2,55,
20,2,14,1,35,33,17,33,50,30,1,18,3,219,20,42,74,99,
143,85,245,245,127,183,105,48,166,79,146,225,138,254,68,1,188,137,
226,146,79,2,215,65,130,135,115,91,52,251,106,84,160,207,135,154,
254,248,197,112,5,176,122,204,254,251,0,1,0,121,0,0,4,18,
5,176,0,11,0,0,19,33,21,33,17,33,21,33,17,33,21,33,
121,3,153,253,5,2,208,253,48,2,251,252,103,5,176,141,254,14,
141,253,233,141,0,1,0,121,0,0,4,18,5,176,0,9,0,0,
19,33,21,33,17,33,21,33,17,35,121,3,153,253,5,2,208,253,
48,158,5,176,141,254,14,141,253,92,0,0,0,1,0,100,255,227,
4,209,5,215,0,45,0,0,5,34,46,1,2,53,52,62,3,51,
50,22,23,7,46,1,35,34,14,2,21,20,30,2,51,50,62,4,
53,33,53,33,21,20,14,3,35,2,188,141,231,148,80,45,98,138,
202,119,159,203,73,138,58,133,106,103,171,105,57,57,105,169,103,70,
118,80,60,33,16,254,119,2,37,37,83,120,179,108,29,127,213,1,
15,149,105,211,200,154,94,120,115,68,81,81,117,185,216,105,112,217,
180,111,42,73,89,103,93,44,141,86,90,177,167,128,77,0,0,0,
0,1,0,121,0,0,4,74,5,176,0,11,0,0,19,51,17,33,
17,51,17,35,17,33,17,35,121,158,2,149,158,158,253,107,158,5,
176,253,127,2,129,250,80,2,162,253,94,0,0,1,0,154,0,0,
1,55,5,176,0,3,0,0,51,17,51,17,154,157,5,176,250,80,
0,1,0,113,255,227,4,4,5,176,0,20,0,0,19,51,20,23,
30,1,51,50,62,1,53,17,51,17,20,0,35,34,38,39,38,113,
141,11,27,162,111,92,143,70,158,254,254,205,165,233,38,16,2,23,
52,53,129,180,125,186,103,3,153,252,103,246,254,194,227,180,71,0,
0,1,0,121,0,0,4,211,5,176,0,11,0,0,19,51,17,1,
51,9,1,35,1,7,17,35,121,158,2,235,193,253,120,2,152,207,
253,207,188,158,5,176,253,14,2,242,253,115,252,221,2,190,186,253,
252,0,0,1,0,121,0,0,4,20,5,176,0,5,0,0,19,51,
17,33,21,33,121,158,2,253,252,101,5,176,250,221,141,0,0,1,
0,121,0,0,5,182,5,176,0,12,0,0,51,17,51,9,1,51,
17,35,17,1,35,1,17,121,215,1,203,1,204,207,153,254,84,179,
254,84,5,176,251,33,4,223,250,80,4,180,251,92,4,164,251,76,
0,1,0,121,0,0,4,147,5,176,0,9,0,0,51,17,51,1,
17,51,17,35,1,17,121,153,2,228,157,145,253,21,5,176,251,119,
4,137,250,80,4,166,251,90,0,2,0,92,255,227,4,238,5,215,
0,25,0,51,0,0,1,52,39,46,3,35,34,14,3,21,20,23,
30,3,51,50,62,3,37,52,62,3,51,50,30,2,23,22,21,20,
14,3,35,34,46,2,39,38,4,72,23,18,61,94,138,86,93,148,
92,61,24,22,17,61,94,139,85,93,148,92,62,25,252,20,38,90,
130,203,123,121,198,134,86,23,24,39,90,131,203,123,120,198,134,86,
23,23,2,213,118,109,83,138,116,65,80,127,169,167,86,111,107,82,
135,113,64,77,122,164,164,85,101,206,206,158,99,92,159,186,108,116,
109,100,202,202,154,96,90,156,184,107,106,0,0,2,0,121,0,0,
4,8,5,176,0,11,0,27,0,0,1,51,32,17,52,39,46,3,
43,1,39,59,1,50,4,23,22,21,20,14,2,43,1,17,35,1,
23,206,1,129,6,9,44,83,145,98,206,158,158,206,230,1,21,32,
8,66,130,213,138,206,158,3,6,1,17,35,25,41,69,63,35,141,
176,148,45,40,87,148,115,66,253,137,0,2,0,92,255,225,5,8,
5,215,0,26,0,57,0,0,1,52,39,46,3,35,34,14,2,21,
20,23,30,3,51,50,54,55,39,55,23,54,1,52,62,3,51,50,
30,3,23,22,21,20,2,7,23,7,39,14,1,35,34,46,3,39,
38,4,80,22,18,65,97,142,86,100,162,101,53,22,17,61,97,146,
91,54,123,34,188,88,198,103,252,12,40,91,131,201,121,98,171,124,
98,61,18,24,85,63,166,90,172,76,152,110,100,171,125,98,61,18,
23,2,213,114,106,86,141,117,65,105,178,223,123,109,100,82,136,118,
67,41,34,142,116,149,144,1,28,101,206,206,158,99,63,104,144,155,
86,111,107,156,254,232,82,121,117,127,60,65,60,101,141,151,85,105,
0,0,0,2,0,121,0,0,4,80,5,176,0,11,0,26,0,0,
1,51,50,62,3,53,52,38,43,1,9,1,35,17,35,17,59,1,
50,4,21,20,6,7,1,1,23,206,94,142,82,50,17,186,199,206,
2,132,254,83,215,158,158,206,242,1,51,198,166,1,178,3,6,34,
53,76,70,40,124,144,250,221,2,119,253,137,5,176,217,192,149,220,
30,253,120,0,0,1,0,45,255,227,4,10,5,215,0,57,0,0,
19,55,30,1,51,50,54,53,52,46,6,39,46,5,53,52,54,51,
50,22,23,7,46,1,35,34,6,21,20,30,5,23,30,5,21,20,
14,1,35,34,38,45,170,21,188,115,141,201,29,44,71,62,89,55,
83,14,44,61,83,55,51,26,244,181,172,242,41,152,23,168,112,115,
148,20,46,46,79,56,98,27,48,74,97,70,64,33,137,219,139,191,
245,1,71,31,87,158,144,114,41,76,58,58,38,43,22,32,6,18,
30,49,58,76,100,60,164,195,170,131,25,72,113,124,94,41,67,53,
39,39,24,38,11,20,38,59,70,89,114,66,130,183,84,196,0,1,
0,88,0,0,4,156,5,176,0,7,0,0,19,33,21,33,17,35,
17,33,88,4,68,254,55,158,254,35,5,176,141,250,221,5,35,0,
0,0,0,1,0,121,255,227,4,141,5,176,0,23,0,0,1,51,
17,16,0,35,34,36,39,38,53,17,51,17,20,23,30,1,51,50,
62,2,53,3,236,161,254,236,246,196,254,253,45,22,162,19,35,184,
122,75,128,101,57,5,176,252,213,254,195,254,155,231,212,103,128,3,
43,252,213,114,86,166,166,63,126,208,135,0,0,0,0,1,0,80,
0,0,4,162,5,176,0,6,0,0,1,51,1,35,1,51,1,3,
254,164,254,71,219,254,66,170,1,129,5,176,250,80,5,176,250,248,
0,1,0,84,0,0,5,236,5,176,0,12,0,0,19,51,19,1,
51,1,19,51,3,35,9,1,35,84,160,184,1,18,195,1,18,185,
160,230,219,254,246,254,246,224,5,176,251,6,4,213,251,43,4,250,
250,80,4,205,251,51,0,1,0,74,0,0,4,137,5,176,0,11,
0,0,19,51,9,1,51,9,1,35,9,1,35,1,74,182,1,106,
1,99,182,254,59,1,203,190,254,159,254,152,178,1,199,5,176,253,
162,2,94,253,41,253,39,2,74,253,182,2,217,0,0,0,0,1,
0,76,0,0,4,100,5,176,0,8,0,0,19,51,9,1,51,1,
17,35,17,76,168,1,100,1,100,168,254,66,158,5,176,253,168,2,
88,253,60,253,20,2,236,0,0,0,0,1,0,100,0,0,4,221,
5,176,0,7,0,0,19,33,1,33,21,33,1,33,129,4,80,252,
160,3,108,251,135,3,105,252,180,5,176,250,221,141,5,35,0,0,
0,1,0,131,255,160,2,14,5,250,0,7,0,0,5,33,17,33,
21,35,17,51,2,14,254,117,1,139,245,245,96,6,90,141,250,190,
0,1,255,227,0,0,3,92,6,8,0,3,0,0,33,1,51,1,
2,178,253,49,172,2,205,6,8,249,248,0,0,0,0,1,0,129,
255,160,2,12,5,250,0,7,0,0,23,53,51,17,35,53,33,17,
129,246,246,1,139,96,141,5,64,141,249,166,0,0,0,1,0,133,
4,125,3,53,5,213,0,6,0,0,1,35,39,7,35,1,51,3,
53,188,156,158,186,1,21,131,4,125,213,211,1,86,0,1,0,88,
255,25,4,154,255,166,0,3,0,0,23,53,33,21,88,4,66,231,
141,141,0,1,0,60,6,46,1,224,7,152,0,25,0,0,1,22,
23,22,21,20,7,6,7,6,35,34,39,37,38,39,38,53,52,55,
54,55,54,51,50,23,1,208,11,3,2,13,12,20,10,4,14,12,
254,207,21,6,3,17,16,24,6,12,26,22,6,140,11,12,8,6,
17,18,15,5,2,9,219,18,23,15,2,26,20,22,6,2,18,0,
0,2,0,84,255,227,3,98,4,66,0,11,0,41,0,0,1,34,
6,21,20,22,51,50,54,53,52,38,39,50,22,23,53,52,38,35,
34,6,7,39,54,51,50,22,29,1,17,35,61,1,14,1,35,34,
38,53,52,54,1,233,111,140,143,108,96,142,147,123,104,152,12,127,
117,69,122,34,78,134,169,166,219,139,6,162,103,162,210,217,2,70,
139,99,103,135,139,99,102,136,135,109,49,96,142,157,43,34,104,109,
230,205,123,253,236,156,2,49,138,206,167,160,213,0,0,0,0,2,
0,129,255,227,3,207,5,174,0,24,0,34,0,0,1,17,62,3,
51,50,30,2,21,20,14,2,35,34,46,2,39,21,35,17,0,16,
38,34,6,21,20,22,51,50,1,25,19,48,70,100,62,101,156,92,
46,46,92,157,102,62,100,70,45,20,152,2,180,153,232,160,160,116,
115,5,174,253,200,45,71,65,35,93,161,197,112,111,197,164,96,35,
64,69,45,184,5,174,251,165,1,144,227,230,199,198,233,0,0,1,
0,76,255,227,3,108,4,70,0,31,0,0,1,46,1,35,34,6,
21,20,22,51,50,62,2,55,23,14,1,35,34,38,2,53,52,62,
3,51,50,22,23,2,233,18,120,70,127,181,176,130,43,79,54,33,
10,122,54,174,113,131,211,117,40,80,109,148,84,114,171,54,3,41,
50,99,239,182,194,237,35,54,48,21,77,90,126,152,1,3,155,86,
163,141,106,61,122,97,0,0,0,2,0,73,255,227,3,151,5,174,
0,22,0,32,0,0,1,51,17,35,53,14,1,35,34,46,2,53,
52,62,2,51,50,30,2,23,4,16,22,51,50,54,53,52,38,34,
2,255,152,152,42,137,119,101,157,92,46,46,92,156,101,62,100,70,
48,19,253,228,154,115,116,160,160,232,5,174,250,82,184,97,116,96,
164,198,110,112,197,161,93,35,65,71,45,147,254,112,233,233,198,199,
230,0,0,0,0,2,0,98,255,227,3,157,4,70,0,7,0,34,
0,0,1,33,46,1,35,34,14,1,7,30,2,51,50,54,55,23,
14,1,35,34,46,1,16,62,1,51,50,30,2,21,20,22,21,1,
1,2,10,9,140,112,76,119,60,6,8,60,117,76,72,141,32,133,
51,209,118,130,193,97,98,192,130,97,158,99,52,1,2,92,145,209,
108,157,224,96,160,107,77,60,55,99,118,153,254,1,62,250,148,91,
151,186,101,11,73,12,0,0,0,1,0,125,0,0,2,211,5,201,
0,26,0,0,1,17,35,17,35,53,51,53,52,62,2,51,50,22,
23,7,46,2,35,34,6,29,1,51,21,1,160,152,139,138,59,88,
96,39,58,77,43,109,14,18,40,28,40,57,195,3,170,252,86,3,
170,135,135,60,106,68,39,41,41,105,18,18,16,52,45,176,135,0,
0,0,0,2,0,73,254,63,3,151,4,78,0,43,0,53,0,0,
5,20,14,2,35,34,46,2,39,51,30,1,51,50,54,61,2,14,
3,35,34,46,3,53,52,62,2,51,50,30,2,23,53,51,17,0,
16,22,51,50,54,53,52,38,34,3,151,70,115,144,77,91,157,101,
60,7,143,14,158,92,104,159,20,45,70,100,62,82,135,90,62,28,
46,92,156,101,62,100,70,48,19,152,253,76,154,115,116,160,160,232,
18,99,166,107,59,65,103,116,56,87,117,146,134,33,184,45,69,64,
35,64,108,147,161,88,112,197,161,93,35,65,71,45,187,251,207,2,
227,254,112,233,233,198,199,230,0,0,0,1,0,129,0,0,3,188,
5,176,0,22,0,0,33,35,17,51,17,62,1,51,50,18,25,1,
35,17,52,46,2,35,34,14,1,21,1,25,152,152,28,164,113,169,
201,151,29,60,102,68,89,123,53,5,176,253,204,89,121,254,233,254,
230,253,227,2,29,90,150,118,66,120,186,119,0,0,0,2,0,131,
0,0,1,63,5,147,0,15,0,19,0,0,19,52,54,51,50,22,
23,22,21,20,6,35,34,38,39,38,23,51,17,35,131,56,38,34,
51,7,2,56,38,33,52,7,2,19,151,151,5,53,38,56,43,32,
6,13,38,56,43,32,12,253,251,207,0,2,255,137,254,84,1,102,
5,147,0,11,0,39,0,0,19,52,54,51,50,22,21,20,6,35,
34,38,1,55,23,30,7,51,50,61,1,17,51,17,21,20,14,3,
35,34,46,1,170,56,38,37,57,56,38,37,57,254,223,107,8,7,
3,14,6,13,10,14,15,8,102,152,46,68,81,66,24,42,72,32,
5,53,38,56,55,39,38,56,55,249,152,102,7,7,2,12,3,9,
3,4,2,123,170,4,49,251,207,139,63,103,63,43,17,30,25,0,
0,1,0,129,0,0,3,172,5,174,0,11,0,0,9,1,35,1,
7,17,35,17,51,17,1,51,1,223,1,205,174,254,133,106,152,152,
1,153,174,2,104,253,152,2,0,133,254,133,5,174,252,152,1,235,
0,0,0,1,0,150,255,227,1,164,5,174,0,12,0,0,37,20,
23,22,51,21,34,38,39,38,53,17,51,1,45,3,16,100,113,131,
19,7,151,207,17,13,75,131,74,89,37,32,4,227,0,1,0,129,
0,0,5,147,4,78,0,42,0,0,33,35,17,52,46,3,35,34,
25,1,35,17,51,21,62,4,51,50,22,23,62,1,51,50,22,21,
17,35,17,52,46,4,35,34,17,3,86,152,8,26,43,75,51,218,
152,152,18,25,47,49,76,46,116,149,27,26,150,109,159,149,151,6,
14,29,43,65,43,222,2,35,72,110,114,75,47,254,97,253,218,4,
49,182,38,47,64,36,26,137,105,104,138,239,210,253,115,2,31,59,
94,100,72,60,30,254,103,0,0,1,0,129,0,0,3,188,4,78,
0,22,0,0,33,35,17,51,21,62,1,51,50,18,25,1,35,17,
52,46,2,35,34,14,1,21,1,25,152,152,28,164,113,169,201,151,
29,60,102,68,89,123,53,4,49,181,89,121,254,233,254,230,253,227,
2,29,90,150,118,66,120,186,119,0,0,0,0,2,0,102,255,227,
3,207,4,70,0,16,0,34,0,0,19,52,62,2,51,50,30,1,
21,20,14,1,35,34,46,1,55,20,30,2,51,50,62,2,53,52,
46,1,35,34,14,1,102,57,107,168,105,138,201,97,95,201,140,139,
201,97,154,32,66,111,74,73,111,66,32,55,130,97,98,130,55,2,
25,119,202,151,85,150,248,159,161,252,153,154,252,160,90,152,121,68,
68,121,152,90,121,183,117,117,183,0,0,0,0,2,0,129,254,84,
3,207,4,78,0,24,0,34,0,0,1,21,62,3,51,50,30,2,
21,20,14,2,35,34,46,2,39,17,35,17,0,16,38,34,6,21,
20,22,51,50,1,25,19,48,70,100,62,101,156,92,46,46,92,157,
102,62,100,70,45,20,152,2,180,153,232,160,160,116,115,4,49,187,
45,71,65,35,93,161,197,112,111,197,164,96,35,64,69,45,253,156,
5,221,253,34,1,144,227,230,199,198,233,0,0,2,0,73,254,63,
4,13,4,78,0,32,0,42,0,0,5,20,22,51,21,34,38,61,
2,14,3,35,34,46,2,53,52,62,2,51,50,30,2,23,53,51,
17,0,16,22,51,50,54,53,52,38,34,3,151,52,66,132,138,27,
69,79,78,48,100,156,91,46,46,92,156,101,62,100,70,48,19,152,
253,76,154,115,116,160,160,232,199,61,53,136,117,127,205,184,63,86,
45,19,97,163,198,110,112,197,161,93,35,65,71,45,187,251,207,2,
227,254,112,233,233,198,199,230,0,0,0,1,0,129,0,0,2,225,
4,78,0,16,0,0,1,7,38,35,34,14,1,21,17,35,17,51,
21,62,1,51,50,2,225,80,49,62,89,123,53,152,152,28,164,113,
82,4,42,131,30,120,186,119,253,228,4,49,181,89,121,0,0,1,
0,96,255,227,3,72,4,74,0,58,0,0,1,46,4,53,52,54,
55,50,30,2,23,7,38,35,34,6,21,20,30,7,23,30,9,21,
20,6,35,34,38,39,55,30,1,51,50,54,53,52,46,2,1,213,
60,82,101,62,43,200,148,81,131,82,48,12,146,54,152,80,117,8,
20,17,34,19,41,15,40,3,12,63,34,63,37,54,33,38,21,14,
216,151,152,187,38,147,30,104,92,101,116,38,71,63,1,221,20,32,
58,65,98,59,137,150,2,45,74,71,37,30,122,79,71,21,36,30,
24,23,13,17,7,14,1,4,23,12,26,20,34,32,46,48,61,34,
137,179,134,112,28,67,72,96,85,40,64,45,27,0,0,1,0,102,
255,227,2,80,5,43,0,18,0,0,19,35,53,51,53,51,21,51,
21,35,17,20,59,1,21,35,34,38,53,244,142,142,151,197,197,117,
70,70,148,120,3,170,135,250,250,135,253,45,117,127,111,129,0,1,
0,120,255,227,3,179,4,49,0,22,0,0,1,51,17,35,53,14,
1,35,34,2,25,1,51,17,20,30,2,51,50,62,1,53,3,27,
152,152,28,164,113,169,201,151,29,60,102,68,89,123,53,4,49,251,
207,181,89,121,1,23,1,26,2,29,253,227,90,150,118,66,120,186,
119,0,0,1,0,82,0,0,3,199,4,49,0,6,0,0,33,1,
51,9,1,51,1,1,190,254,148,160,1,24,1,31,158,254,143,4,
49,252,146,3,110,251,207,0,0,0,0,1,0,68,0,0,5,49,
4,49,0,13,0,0,1,3,35,1,51,27,1,48,51,27,1,51,
1,35,2,186,227,117,254,226,153,193,209,151,209,193,153,254,225,122,
3,94,252,162,4,49,252,201,3,47,252,209,3,55,251,207,0,1,
0,53,0,0,3,102,4,49,0,11,0,0,33,35,11,1,35,9,
1,51,27,1,51,1,3,102,170,241,230,176,1,58,254,200,170,234,
233,170,254,201,1,184,254,72,2,27,2,22,254,78,1,178,253,238,
0,1,0,120,254,63,3,179,4,49,0,36,0,0,5,20,14,2,
35,34,39,55,22,51,50,62,2,61,1,14,1,35,34,2,25,1,
51,17,20,30,2,51,50,62,1,53,17,51,3,179,76,123,151,77,
213,150,106,103,154,49,94,82,50,28,164,113,169,201,151,29,60,102,
68,89,123,53,152,18,98,167,107,59,174,85,123,35,65,111,69,214,
89,121,1,23,1,26,2,29,253,227,90,150,118,66,120,186,119,2,
28,0,0,0,0,1,0,90,0,0,3,139,4,49,0,7,0,0,
37,33,21,33,1,33,53,33,1,86,2,23,252,237,2,53,253,244,
3,8,141,141,3,164,141,0,0,1,0,90,255,154,2,123,5,250,
0,61,0,0,19,62,3,38,54,55,62,8,55,21,38,35,34,6,
7,6,29,1,20,14,1,7,22,23,22,29,1,20,23,22,23,30,
1,51,50,55,21,46,8,39,38,39,38,2,39,38,90,64,84,33,
16,2,8,12,10,28,24,44,22,58,20,70,15,39,28,15,43,90,
19,12,19,60,46,60,34,31,6,2,4,19,89,44,15,28,39,15,
70,20,58,22,44,24,28,10,5,3,8,6,19,40,2,217,20,102,
125,150,129,119,27,20,34,24,20,12,9,5,3,1,1,135,4,32,
28,22,80,45,77,179,188,19,23,159,142,167,43,62,25,13,7,27,
32,4,135,1,1,3,5,9,12,20,24,34,20,12,14,39,1,64,
87,190,0,0,0,1,0,125,0,0,1,12,5,174,0,3,0,0,
51,17,51,17,125,143,5,174,250,82,0,1,0,133,255,160,2,166,
5,250,0,61,0,0,1,14,3,22,6,7,14,8,7,53,22,51,
50,54,55,54,61,1,52,62,1,55,38,39,38,61,1,52,39,38,
39,46,1,35,34,7,53,30,8,23,22,23,22,18,23,22,2,166,
64,84,33,16,2,8,12,10,28,24,44,22,58,20,70,15,39,28,
15,44,89,19,12,19,60,46,63,34,28,5,4,3,19,90,43,15,
28,39,15,70,20,58,22,44,24,28,10,6,2,8,6,18,39,2,
217,19,105,130,156,135,124,27,20,34,24,20,12,9,5,3,1,1,
135,4,32,27,23,84,43,81,190,197,17,25,161,133,144,45,57,25,
14,6,28,32,4,135,1,1,3,5,9,12,20,24,34,20,15,13,
37,254,216,82,185,0,0,1,0,63,2,51,2,188,3,92,0,38,
0,0,19,62,5,51,50,30,3,51,50,62,3,55,21,14,5,35,
34,46,3,34,14,3,7,63,5,37,18,38,28,38,19,27,56,48,
48,58,29,20,38,45,22,57,6,4,50,13,42,24,37,18,32,63,
52,48,51,44,39,45,16,56,3,2,252,4,31,14,25,12,10,31,
45,44,31,9,27,14,44,4,145,3,40,10,27,9,10,31,45,45,
31,8,28,11,48,2,0,4,0,92,255,227,4,238,5,215,0,73,
0,92,0,130,0,170,0,0,1,21,35,53,52,55,54,55,54,55,
54,55,54,55,54,55,62,1,55,62,2,63,1,62,1,55,54,55,
62,1,55,54,55,62,1,55,54,55,54,53,52,38,35,34,7,14,
1,21,39,54,55,54,51,50,23,22,23,22,21,20,7,6,7,6,
7,14,1,7,6,7,6,7,6,3,52,55,54,51,50,23,22,23,
21,20,7,6,35,34,39,38,39,38,1,52,39,38,39,38,39,38,
39,38,35,34,6,7,6,7,14,1,21,20,23,22,23,22,23,22,
23,22,51,50,55,54,55,54,55,54,55,54,37,52,55,54,55,54,
55,54,55,54,51,50,23,22,23,22,23,22,23,22,21,20,7,6,
7,6,7,6,7,6,35,34,39,38,39,38,39,38,39,38,2,202,
110,8,7,11,11,18,25,8,2,36,22,15,3,7,4,2,5,5,
1,13,2,8,2,4,6,1,6,2,4,3,1,3,1,2,2,1,
108,87,59,47,49,50,102,13,86,86,118,81,69,70,44,46,26,25,
45,18,25,6,30,7,18,17,18,8,9,124,23,22,31,26,22,20,
6,21,22,31,26,22,20,6,2,1,250,23,17,32,29,48,46,70,
67,88,94,146,47,47,30,30,24,22,15,33,29,48,46,71,70,84,
94,73,75,45,45,32,33,11,12,252,20,19,20,44,43,67,64,103,
101,123,122,98,100,66,65,45,44,22,24,20,20,44,47,63,67,101,
102,122,120,99,98,68,65,45,43,23,23,2,37,99,102,29,30,27,
20,21,19,27,7,1,30,18,13,3,7,3,2,4,6,1,13,2,
9,2,4,10,2,12,2,6,12,4,12,4,7,16,8,19,87,96,
31,32,86,40,17,115,78,78,30,30,64,66,89,68,52,50,45,18,
19,5,23,5,14,18,19,24,25,254,194,30,23,22,17,16,26,16,
32,21,22,17,16,26,10,1,211,115,112,79,73,67,60,57,34,32,
80,64,63,85,84,168,85,114,104,75,74,65,59,57,32,32,39,40,
59,60,83,85,79,82,85,103,101,104,102,100,82,79,50,49,46,47,
78,76,97,93,108,116,109,98,103,104,98,105,73,77,48,48,45,45,
78,75,95,91,108,109,255,255,0,28,255,227,0,247,5,187,16,135,
0,4,1,94,5,174,192,0,255,255,0,0,192,0,0,0,0,1,
0,80,0,78,2,227,4,184,0,33,0,0,1,46,1,39,38,53,
52,62,2,55,53,51,21,22,23,7,38,35,34,6,21,20,23,30,
1,51,50,55,23,6,7,21,35,1,125,107,158,26,10,56,93,96,
52,135,99,100,90,80,107,85,126,7,18,112,80,127,82,90,60,163,
135,1,23,13,145,119,44,57,76,124,77,46,13,215,215,25,87,95,
80,122,91,33,38,83,93,106,90,96,52,196,0,1,0,84,0,0,
4,39,5,186,0,39,0,0,1,35,53,51,16,18,51,50,19,7,
46,1,35,34,14,1,29,2,33,21,33,6,3,33,62,2,55,23,
14,2,7,6,7,33,62,2,1,55,227,238,130,144,222,106,144,17,
94,73,31,58,32,1,103,254,147,13,94,1,248,22,26,46,23,80,
21,70,54,50,9,5,253,59,10,84,66,2,84,135,1,107,1,116,
254,215,6,70,100,134,184,81,125,78,135,185,254,236,1,6,33,32,
115,32,39,12,7,1,1,42,226,233,0,2,0,63,1,119,3,45,
4,119,0,15,0,49,0,0,1,20,23,30,1,51,50,54,53,52,
39,46,1,35,34,6,1,6,34,39,21,35,53,51,38,39,38,53,
52,55,35,53,51,21,54,50,23,53,51,21,35,22,23,22,21,20,
7,51,21,35,1,4,4,13,99,65,75,105,4,13,98,65,76,105,
1,100,80,196,80,197,127,43,15,7,59,121,197,80,196,80,197,121,
38,15,7,66,127,197,2,252,22,16,62,81,106,75,22,16,62,81,
106,254,177,55,55,129,196,57,70,28,36,103,81,197,123,55,55,123,
197,52,66,37,29,104,87,196,0,0,0,1,0,74,0,0,4,29,
5,117,0,22,0,0,1,33,53,33,1,51,9,1,51,1,51,21,
33,21,33,21,33,17,35,17,33,53,33,1,215,254,201,1,2,254,
168,155,1,68,1,88,156,254,139,248,254,207,1,49,254,207,152,254,
201,1,55,2,170,135,2,68,253,202,2,54,253,188,135,215,135,254,
180,1,76,135,0,2,0,90,0,0,0,233,5,154,0,3,0,7,
0,0,19,17,35,17,53,17,51,17,233,143,143,2,133,253,123,2,
133,143,2,134,253,122,0,0,0,2,0,43,0,104,2,156,5,14,
0,44,0,59,0,0,19,54,51,50,22,23,22,21,20,2,35,34,
38,39,55,30,1,59,1,50,54,55,53,52,34,6,35,34,38,39,
38,53,52,62,1,51,50,22,23,7,46,1,43,1,34,1,52,39,
46,1,35,34,7,20,23,30,1,59,1,50,186,28,38,138,236,32,
10,188,130,93,147,59,150,18,83,32,4,71,97,16,10,45,10,140,
229,34,11,78,146,91,97,118,70,154,17,70,27,4,140,1,19,5,
18,139,94,33,22,3,17,155,81,18,37,3,190,9,195,150,48,44,
169,254,255,87,100,10,26,35,112,88,2,3,13,171,156,55,58,110,
192,120,72,92,16,19,26,253,191,20,23,83,123,14,18,18,81,133,
0,2,0,76,6,52,2,223,6,243,0,16,0,33,0,0,1,52,
54,51,50,22,23,22,21,20,6,35,34,39,38,39,38,37,52,54,
51,50,22,23,22,21,20,6,35,34,39,38,39,38,2,35,56,38,
34,50,8,2,56,38,32,27,26,7,2,254,41,56,38,34,50,8,
2,56,38,32,27,25,8,2,6,149,38,56,42,33,10,9,39,56,
22,21,33,16,1,38,56,42,33,10,9,39,56,22,21,33,8,0,
0,3,0,41,1,55,3,150,4,164,0,24,0,40,0,56,0,0,
1,6,35,34,38,39,38,53,52,54,51,50,23,7,38,34,6,21,
20,23,30,1,51,50,55,37,20,23,30,1,51,50,54,53,52,39,
46,1,35,34,6,7,52,0,51,50,22,23,22,21,20,0,35,34,
38,39,38,2,117,67,83,74,113,15,5,121,86,91,59,78,34,76,
56,2,7,52,33,46,30,254,115,7,24,175,115,133,189,7,24,176,
115,133,188,117,1,1,181,157,240,32,10,254,254,181,156,240,32,10,
2,98,67,92,71,23,21,85,121,59,82,29,56,38,7,12,32,44,
27,68,37,31,111,145,190,134,29,39,110,145,189,134,181,1,1,197,
150,50,41,182,254,255,197,150,43,0,0,2,0,109,4,22,2,28,
6,109,0,12,0,50,0,0,1,34,6,21,20,23,22,51,50,54,
52,39,38,19,7,6,7,6,35,34,39,38,53,52,55,54,51,50,
23,30,1,23,38,39,38,35,34,7,6,15,1,39,55,54,51,50,
23,22,21,17,35,1,76,48,58,30,28,48,40,58,30,29,59,6,
20,28,30,31,89,59,58,60,61,86,58,43,2,8,2,1,26,26,
48,29,30,26,14,16,65,15,73,92,91,61,60,110,5,71,58,41,
42,29,27,56,84,29,28,254,255,6,18,12,12,57,57,92,90,58,
59,31,1,8,1,56,31,32,10,9,14,16,86,12,59,64,63,110,
254,164,0,0,0,2,0,59,2,25,3,20,4,94,0,5,0,11,
0,0,1,51,3,19,35,11,1,51,3,19,35,3,2,141,135,192,
192,135,192,209,135,192,192,135,193,4,94,254,221,254,222,1,34,1,
35,254,221,254,222,1,34,0,0,0,0,1,0,154,2,33,3,152,
3,125,0,5,0,0,1,35,53,33,53,33,3,152,136,253,138,2,
254,2,33,205,143,0,255,255,0,109,2,223,3,18,3,109,16,7,
0,16,0,0,0,172,0,0,0,4,0,94,0,242,4,88,4,236,
0,23,0,44,0,58,0,77,0,0,19,20,23,30,3,51,50,62,
2,53,52,39,46,3,35,34,14,2,7,52,62,3,51,50,4,23,
22,21,20,14,1,35,34,46,1,39,38,37,51,50,62,2,53,52,
38,53,46,1,43,1,39,51,50,22,23,22,21,20,14,3,7,23,
35,39,7,21,35,211,9,16,81,108,118,59,68,137,116,72,9,16,
86,112,117,53,69,135,116,71,117,63,103,134,139,69,181,1,24,38,
11,149,232,129,107,202,161,26,12,1,158,51,34,47,48,25,1,7,
93,75,29,82,82,113,156,13,3,18,23,45,27,27,162,100,142,65,
82,2,238,50,44,74,117,71,36,53,97,152,90,46,40,75,122,72,
38,49,94,155,95,102,172,116,82,38,223,176,57,54,146,237,125,85,
182,123,56,113,4,12,28,21,2,8,1,34,21,78,58,62,10,14,
29,44,24,20,8,6,239,227,2,225,0,0,0,1,0,188,4,191,
3,97,5,41,0,3,0,0,19,33,21,33,188,2,165,253,91,5,
41,106,0,0,0,2,0,49,3,147,2,61,5,152,0,15,0,31,
0,0,19,20,23,30,1,51,50,54,53,52,39,46,1,35,34,6,
7,52,54,51,50,22,23,22,21,20,6,35,34,38,39,38,167,3,
11,78,52,61,83,3,11,78,52,61,83,118,153,109,94,144,19,5,
153,109,94,143,19,6,4,154,18,16,51,65,87,63,16,17,51,66,
88,66,107,151,116,89,21,32,108,151,116,89,26,0,255,255,0,150,
1,18,3,138,5,29,16,39,0,14,0,72,1,31,16,7,0,16,
0,80,254,223,0,0,0,1,0,68,3,173,2,80,6,222,0,66,
0,0,19,39,55,54,55,54,51,50,22,23,30,1,23,22,21,20,
7,6,7,6,7,6,7,6,7,6,15,2,6,7,14,1,15,1,
33,21,33,53,52,55,54,55,54,55,54,55,54,63,1,62,2,63,
6,52,38,35,34,7,6,7,202,134,9,22,74,73,88,38,68,32,
33,46,14,14,8,8,12,12,18,18,16,24,13,28,6,29,22,13,
28,26,40,9,8,1,95,253,244,15,17,19,23,32,33,28,20,46,
22,6,11,6,1,22,21,16,14,8,4,60,38,40,32,35,14,5,
205,53,30,79,56,55,18,21,22,58,44,45,48,28,30,29,23,22,
23,22,15,22,10,22,4,20,14,8,27,25,44,17,16,140,35,52,
48,54,32,39,33,34,24,17,33,16,4,7,3,1,17,19,19,23,
23,31,53,60,25,27,46,0,0,1,0,51,3,173,2,83,6,238,
0,62,0,0,19,55,23,30,1,51,50,55,54,53,52,39,38,39,
38,39,38,43,1,53,51,50,55,54,53,52,38,43,1,34,7,6,
15,1,39,55,54,55,54,51,50,23,22,23,22,21,20,7,6,7,
22,23,22,23,22,21,20,7,6,35,34,38,39,51,144,13,16,60,
32,56,38,37,11,9,20,19,22,24,24,74,84,34,25,26,52,34,
3,30,21,20,13,15,134,17,32,57,58,72,56,56,53,35,35,19,
18,26,23,21,23,15,14,81,82,116,72,146,31,4,115,43,27,33,
40,33,33,54,28,24,19,17,16,7,8,132,27,28,40,36,50,15,
15,28,32,62,32,62,37,37,28,26,54,53,65,49,41,39,26,18,
26,28,38,36,45,114,73,74,88,74,0,0,0,1,0,60,6,46,
1,224,7,152,0,25,0,0,19,37,54,51,50,23,22,23,22,21,
20,7,6,7,5,6,35,34,39,38,39,38,53,52,55,54,76,1,
25,22,26,12,6,24,16,17,3,6,21,254,207,12,14,4,10,20,
12,13,2,3,6,140,250,18,2,6,22,20,26,2,15,23,18,219,
9,2,5,15,18,17,6,8,12,0,0,1,0,154,254,117,3,102,
3,104,0,30,0,0,37,17,35,17,51,17,20,23,22,51,50,62,
3,53,17,51,17,35,53,14,1,35,34,46,5,1,41,143,145,12,
36,149,46,78,53,37,17,143,143,46,117,58,26,43,39,22,34,9,
35,74,254,43,4,243,254,54,76,56,171,39,64,81,81,38,1,202,
252,152,98,57,68,5,16,8,28,7,36,0,0,4,0,121,0,0,
3,246,5,117,0,7,0,21,0,27,0,44,0,0,1,17,50,22,
51,17,34,6,7,14,3,21,20,23,30,4,23,19,51,17,34,38,
35,3,17,46,4,39,38,53,52,62,2,59,1,17,2,133,17,181,
19,17,181,162,48,71,77,42,5,7,36,41,65,47,37,143,217,18,
181,18,143,61,94,94,65,48,11,8,115,197,246,138,197,4,236,254,
0,9,2,21,12,33,16,33,54,79,50,24,25,33,53,33,29,15,
9,253,129,1,221,11,253,145,2,131,13,29,44,55,79,49,42,41,
98,157,96,51,250,139,0,0,255,255,0,142,2,110,1,101,3,69,
16,7,0,17,0,39,2,123,0,0,0,1,0,117,254,197,1,113,
0,74,0,23,0,0,23,62,3,53,52,39,46,3,39,55,22,23,
22,21,20,14,3,7,117,20,17,39,18,2,2,11,9,26,5,129,
64,16,4,27,56,42,74,10,190,15,13,34,29,13,5,10,9,23,
14,35,8,56,62,72,24,14,32,56,49,30,44,6,0,1,0,49,
3,173,1,64,6,203,0,5,0,0,19,35,55,51,17,35,172,123,
174,97,148,6,8,195,252,226,0,0,0,2,0,46,5,40,2,58,
7,45,0,19,0,38,0,0,19,20,23,22,23,22,51,50,55,54,
53,52,39,38,39,38,35,34,7,6,7,52,55,54,51,50,22,23,
22,21,20,7,6,35,34,39,38,39,38,164,3,10,40,39,52,60,
42,42,3,10,40,39,52,60,42,42,118,76,76,110,95,142,20,5,
76,78,108,95,71,70,20,6,6,47,17,17,49,34,33,43,44,63,
17,16,50,34,33,44,43,67,108,75,75,116,89,23,30,108,75,76,
58,57,90,25,0,2,0,98,2,25,3,59,4,94,0,5,0,11,
0,0,27,1,3,35,19,3,33,19,3,35,19,3,233,193,193,135,
193,193,2,25,192,192,135,192,192,4,94,254,221,254,222,1,34,1,
35,254,221,254,222,1,34,1,35,0,0,4,0,48,254,185,4,233,
6,203,0,9,0,12,0,18,0,22,0,0,37,51,21,35,21,35,
53,33,1,51,3,51,53,1,35,55,51,17,35,19,35,1,51,4,
118,94,94,148,254,177,1,87,140,245,99,252,220,123,174,97,148,6,
150,4,41,144,12,140,199,199,2,87,254,54,173,5,78,195,252,226,
251,192,6,210,0,3,0,48,254,185,4,233,6,203,0,66,0,72,
0,76,0,0,37,39,55,54,55,54,51,50,22,23,30,1,23,22,
21,20,7,6,7,6,7,6,7,6,7,6,15,2,6,7,14,1,
15,1,33,21,33,53,52,55,54,55,54,55,54,55,54,63,1,62,
2,63,6,52,38,35,34,7,6,7,1,35,55,51,17,35,19,35,
1,51,3,78,134,9,22,74,73,88,38,68,32,33,46,14,14,8,
8,12,12,18,18,16,24,13,28,6,29,22,13,28,26,40,9,8,
1,95,253,244,15,17,19,23,32,33,28,20,46,22,6,11,6,1,
22,21,16,14,8,4,60,38,40,32,35,14,253,103,123,174,97,148,
6,150,4,41,144,217,53,30,79,56,55,18,21,22,58,44,45,48,
28,30,29,23,22,23,22,15,22,10,22,4,20,14,8,27,25,44,
17,16,140,35,52,48,54,32,39,33,34,24,17,33,16,4,7,3,
1,17,19,19,23,23,31,53,60,25,27,46,5,12,195,252,226,251,
192,6,210,0,0,0,0,4,0,47,254,185,4,233,6,238,0,61,
0,71,0,74,0,78,0,0,19,55,23,30,1,51,50,54,53,52,
39,38,39,38,39,38,43,1,53,51,50,55,54,53,52,38,43,1,
34,7,6,15,1,39,55,54,55,54,51,50,23,22,23,22,21,20,
7,6,7,22,23,22,23,22,21,20,7,6,35,34,38,39,1,51,
21,35,21,35,53,33,1,51,3,51,53,1,35,1,51,47,144,13,
16,60,32,57,74,11,9,20,19,22,24,24,74,84,34,25,26,52,
34,3,30,21,20,13,15,134,17,32,57,58,72,56,56,53,35,35,
19,18,26,23,21,23,15,14,81,82,116,72,146,31,4,55,94,94,
148,254,177,1,87,140,245,99,252,226,150,4,41,144,4,115,43,27,
33,40,66,54,28,24,19,17,16,7,8,132,27,28,40,36,50,15,
15,28,32,62,32,62,37,37,28,26,54,53,65,49,41,39,26,18,
26,28,38,36,45,114,73,74,88,74,251,189,140,199,199,2,87,254,
54,173,254,179,6,210,0,0,255,255,0,18,255,162,3,125,5,136,
16,15,0,34,3,182,5,123,192,0,255,255,0,64,0,0,4,215,
7,152,16,38,0,36,248,0,16,7,0,67,0,248,0,0,255,255,
0,64,0,0,4,215,7,152,16,38,0,36,248,0,16,7,0,118,
1,247,0,0,255,255,0,82,0,0,4,233,7,113,16,39,0,65,
0,188,1,156,16,6,0,36,10,0,255,255,0,82,0,0,4,233,
7,74,16,39,0,97,1,27,3,238,16,6,0,36,10,0,255,255,
0,82,0,0,4,233,6,242,16,39,0,106,1,2,255,255,16,6,
0,36,10,0,255,255,0,82,0,0,4,233,7,201,16,39,0,114,
1,102,2,49,16,6,0,36,10,0,0,2,0,83,0,0,5,103,
5,176,0,15,0,19,0,0,1,33,1,35,1,33,21,33,17,33,
21,33,17,33,21,33,3,53,3,51,3,17,254,248,254,253,179,2,
79,2,197,254,70,1,186,254,70,1,186,253,170,2,202,204,2,133,
253,123,5,176,149,253,249,147,254,18,147,4,213,74,253,245,0,0,
255,255,0,120,254,88,4,163,5,215,16,39,0,122,1,201,255,147,
16,6,0,38,20,0,255,255,0,121,0,0,4,18,7,152,16,38,
0,40,0,0,16,7,0,67,1,24,0,0,255,255,0,121,0,0,
4,18,7,152,16,38,0,40,0,0,16,7,0,118,1,128,0,0,
255,255,0,131,0,0,4,28,7,90,16,39,0,65,0,129,1,133,
16,6,0,40,10,0,255,255,0,131,0,0,4,28,7,4,16,39,
0,106,0,190,0,17,16,6,0,40,10,0,255,255,255,144,0,0,
1,55,7,152,16,38,0,44,0,0,16,7,0,67,255,84,0,0,
255,255,0,164,0,0,2,72,7,152,16,38,0,44,10,0,16,6,
0,118,104,0,0,0,255,255,255,153,0,0,2,73,7,102,16,39,
0,65,255,20,1,145,16,6,0,44,10,0,255,255,255,166,0,0,
2,57,6,244,16,39,0,106,255,90,0,1,16,6,0,44,10,0,
0,2,0,144,0,0,5,31,5,176,0,16,0,31,0,0,1,35,
53,51,17,33,50,0,23,22,21,20,2,4,43,2,19,17,51,50,
18,17,52,39,46,1,43,1,17,33,21,1,70,182,182,1,125,222,
1,56,50,20,150,254,234,176,226,155,157,224,194,253,18,40,231,158,
224,1,44,2,150,141,2,141,254,220,236,98,104,203,254,182,193,2,
150,253,249,1,69,1,2,94,83,187,222,254,3,141,255,255,0,131,
0,0,4,157,7,53,16,39,0,97,1,43,3,217,16,6,0,49,
10,0,255,255,0,92,255,227,4,238,7,152,16,38,0,50,0,0,
16,7,0,67,0,236,0,0,255,255,0,92,255,227,4,238,7,152,
16,38,0,50,0,0,16,7,0,118,2,4,0,0,255,255,0,102,
255,227,4,248,7,115,16,39,0,65,0,209,1,158,16,6,0,50,
10,0,255,255,0,102,255,227,4,248,7,74,16,39,0,97,1,51,
3,238,16,6,0,50,10,0,255,255,0,102,255,227,4,248,6,247,
16,39,0,106,1,8,0,4,16,6,0,50,10,0,255,255,0,108,
1,74,2,241,3,202,16,135,0,14,2,55,255,132,44,229,45,156,
210,99,44,229,0,0,0,3,0,96,255,227,4,190,5,216,0,31,
0,44,0,57,0,0,37,7,35,55,38,39,38,53,52,62,4,51,
50,23,55,51,7,22,19,22,21,20,14,4,35,34,39,22,51,50,
62,3,53,52,39,38,39,9,1,38,35,34,14,3,21,20,23,22,
1,144,31,152,74,124,47,24,26,54,91,120,169,99,122,97,31,152,
69,149,53,24,27,53,92,119,169,99,144,53,86,111,89,143,90,61,
25,23,35,79,253,198,1,204,73,88,89,143,90,60,25,22,29,41,
70,163,139,227,111,107,82,168,173,150,118,68,50,69,151,145,254,255,
109,116,82,167,170,147,115,66,199,59,76,122,162,163,84,116,111,162,
100,252,96,3,253,38,79,125,167,165,84,120,100,133,0,0,255,255,
0,121,255,227,4,141,7,152,16,38,0,56,0,0,16,7,0,67,
0,244,0,0,255,255,0,121,255,227,4,141,7,152,16,38,0,56,
0,0,16,7,0,118,1,220,0,0,255,255,0,131,255,227,4,151,
7,119,16,39,0,65,0,164,1,162,16,6,0,56,10,0,255,255,
0,131,255,227,4,151,6,247,16,39,0,106,0,242,0,4,16,6,
0,56,10,0,255,255,0,76,0,0,4,100,7,152,16,38,0,60,
0,0,16,7,0,118,1,159,0,0,0,2,0,145,0,0,4,3,
5,176,0,10,0,26,0,0,1,50,62,3,53,52,39,38,33,3,
51,17,32,19,22,21,20,14,4,35,17,35,1,47,87,152,153,108,
67,5,46,253,252,158,158,2,135,69,8,55,103,130,170,167,99,158,
1,221,14,38,59,98,64,21,23,216,1,190,254,206,254,190,38,40,
83,133,88,62,33,14,254,175,0,1,0,92,255,226,4,93,5,199,
0,70,0,0,19,62,1,51,50,22,23,22,29,1,20,14,3,7,
30,3,23,22,21,16,33,34,39,55,30,2,51,50,62,3,53,52,
39,46,1,43,1,34,7,53,22,59,1,50,62,1,53,52,39,38,
35,34,14,2,7,6,10,1,7,35,54,26,1,174,55,245,181,165,
242,30,8,44,68,88,81,39,43,94,101,78,14,7,254,6,80,106,
91,11,40,31,13,63,100,95,63,38,5,24,248,141,36,25,17,15,
21,42,89,180,130,8,41,247,74,115,79,51,20,33,28,10,5,148,
12,12,25,4,128,146,181,163,142,43,44,13,56,99,70,58,34,10,
11,44,71,110,65,29,39,254,104,53,123,4,20,12,13,36,59,96,
64,20,25,111,145,6,152,4,59,120,74,39,37,192,35,67,80,55,
98,254,122,253,240,89,130,2,10,1,145,0,0,0,255,255,0,84,
255,227,3,98,6,61,16,38,0,68,0,0,16,7,0,67,0,142,
254,165,255,255,0,84,255,227,3,98,6,61,16,38,0,68,0,0,
16,7,0,118,1,79,254,165,255,255,0,94,255,227,3,108,5,203,
16,38,0,65,14,246,16,6,0,68,10,0,0,0,255,255,0,94,
255,227,3,108,5,168,16,39,0,97,0,121,2,76,16,6,0,68,
10,0,255,255,0,94,255,227,3,108,5,131,16,39,0,106,0,94,
254,144,16,6,0,68,10,0,255,255,0,94,255,227,3,108,6,86,
16,39,0,114,0,197,0,190,16,6,0,68,10,0,0,3,0,84,
255,227,5,96,4,70,0,14,0,96,0,106,0,0,1,34,6,21,
20,23,22,51,50,54,53,52,39,46,1,19,62,1,51,50,22,23,
22,21,20,6,21,33,20,23,30,1,51,50,62,2,55,62,2,55,
23,14,1,35,34,46,4,39,14,9,35,34,38,39,38,53,52,54,
51,50,22,23,54,38,55,52,39,38,35,34,6,7,39,62,7,51,
50,22,19,33,38,39,38,35,34,14,2,1,180,105,95,8,34,158,
92,109,7,17,102,210,58,122,100,144,177,33,21,3,253,178,15,20,
97,86,33,46,39,19,20,1,2,2,1,133,56,131,109,39,64,53,
36,44,22,24,4,23,9,24,15,28,25,37,39,51,28,136,179,27,
10,200,152,87,82,36,1,4,2,10,34,156,65,80,39,78,6,38,
13,37,21,39,34,48,26,94,133,116,1,182,6,13,47,154,58,88,
47,24,2,90,140,108,49,36,163,144,104,31,40,79,98,1,52,95,
89,180,158,94,125,11,45,12,73,71,93,126,15,43,30,38,2,3,
4,2,55,110,107,12,30,25,57,32,37,7,42,15,37,16,29,13,
19,8,7,153,127,55,48,163,220,51,53,7,44,8,54,43,165,38,
39,102,5,32,10,26,9,17,6,6,89,254,115,71,57,226,66,109,
117,0,0,0,255,255,0,86,254,93,3,118,4,70,16,39,0,122,
1,12,255,152,16,6,0,70,10,0,255,255,0,98,255,227,3,157,
6,61,16,38,0,72,0,0,16,7,0,67,0,122,254,165,255,255,
0,108,255,227,3,167,6,61,16,38,0,72,10,0,16,7,0,118,
1,99,254,165,255,255,0,108,255,227,3,167,5,217,16,38,0,65,
53,4,16,6,0,72,10,0,0,0,255,255,0,108,255,227,3,167,
5,133,16,39,0,106,0,127,254,146,16,6,0,72,10,0,0,2,
255,139,0,0,1,47,6,61,0,3,0,29,0,0,19,51,17,35,
19,22,23,22,21,20,7,6,7,6,35,34,39,37,38,39,38,53,
52,55,54,55,54,51,50,23,150,151,151,137,11,3,2,13,12,20,
10,4,14,12,254,207,21,6,3,17,16,24,6,12,26,22,4,49,
251,207,5,49,11,12,8,6,17,18,15,5,2,9,219,18,23,15,
2,26,20,22,6,2,18,0,0,2,0,150,0,0,2,59,6,61,
0,3,0,29,0,0,19,51,17,35,19,37,54,51,50,23,22,23,
22,21,20,7,6,7,5,6,35,34,39,38,39,38,53,52,55,54,
150,151,151,17,1,25,22,26,12,6,24,16,17,3,6,21,254,207,
12,14,4,10,20,12,13,2,3,4,49,251,207,5,49,250,18,2,
6,22,20,26,2,15,23,18,219,9,2,5,15,18,17,6,8,12,
0,2,0,115,0,0,3,35,5,182,0,3,0,10,0,0,1,51,
17,35,1,35,39,7,35,1,51,1,135,152,152,1,156,188,156,158,
186,1,21,131,4,49,251,207,4,94,213,211,1,86,0,0,0,3,
0,8,0,0,2,155,5,98,0,3,0,20,0,37,0,0,1,51,
17,35,19,52,54,51,50,22,23,22,21,20,6,35,34,39,38,39,
38,37,52,54,51,50,22,23,22,21,20,6,35,34,39,38,39,38,
1,16,152,152,207,56,38,34,50,8,2,56,38,32,27,26,7,2,
254,41,56,38,34,50,8,2,56,38,32,27,25,8,2,4,49,251,
207,5,4,38,56,42,33,10,9,39,56,22,21,33,16,1,38,56,
42,33,10,9,39,56,22,21,33,8,0,2,0,82,255,227,3,160,
5,246,0,16,0,62,0,0,19,20,23,30,1,51,50,54,53,52,
39,46,1,35,34,14,1,1,30,1,23,22,23,22,29,1,20,2,
35,34,38,39,38,53,52,18,51,50,30,4,23,52,39,46,1,39,
7,39,55,38,35,34,7,39,54,51,50,23,55,23,233,10,25,151,
73,113,171,7,24,189,103,59,104,57,1,195,67,131,24,8,1,13,
247,179,172,201,32,15,221,160,41,71,47,51,27,48,12,9,20,104,
56,153,99,136,71,89,41,74,14,27,55,192,135,156,96,1,199,46,
50,117,136,215,134,37,29,115,155,106,155,2,248,77,232,111,36,33,
195,66,38,229,254,210,184,152,72,80,194,1,17,14,17,36,24,46,
11,33,40,94,210,49,143,100,129,25,8,147,2,70,140,109,0,0,
255,255,0,139,0,0,3,198,5,180,16,39,0,97,0,139,2,88,
16,6,0,81,10,0,255,255,0,102,255,227,3,207,6,60,16,38,
0,82,0,0,16,7,0,67,0,82,254,164,255,255,0,102,255,227,
3,207,6,61,16,38,0,82,0,0,16,7,0,118,1,162,254,165,
255,255,0,112,255,227,3,217,5,186,16,38,0,65,51,229,16,6,
0,82,10,0,0,0,255,255,0,112,255,227,3,217,5,139,16,39,
0,97,0,164,2,47,16,6,0,82,10,0,255,255,0,112,255,227,
3,217,5,127,16,39,0,106,0,141,254,140,16,6,0,82,10,0,
0,3,0,119,0,171,3,28,4,91,0,15,0,31,0,35,0,0,
1,52,54,51,50,22,23,22,21,20,6,35,34,38,39,38,17,52,
54,51,50,22,23,22,21,20,6,35,34,38,39,38,3,33,21,33,
1,88,64,44,39,58,8,2,63,44,39,58,8,3,64,44,39,58,
8,2,63,44,39,58,8,3,225,2,165,253,91,3,239,45,63,49,
36,8,15,44,63,48,37,10,253,51,45,63,49,36,8,15,44,63,
48,37,10,1,183,142,0,0,0,3,0,86,255,227,3,180,4,74,
0,11,0,23,0,49,0,0,9,1,22,51,50,62,2,53,52,39,
38,39,38,35,34,14,2,21,20,23,22,23,3,55,38,39,38,53,
52,62,1,51,50,23,55,51,7,22,23,22,21,20,14,1,35,34,
39,7,2,231,254,138,65,84,69,106,60,29,15,11,90,65,83,65,
104,62,33,15,9,15,207,115,55,26,18,95,191,130,131,95,49,155,
113,57,24,18,95,192,129,128,99,48,3,3,253,171,68,78,129,146,
78,86,68,50,154,63,76,123,146,76,87,71,43,37,254,184,182,89,
119,90,86,159,250,148,75,79,181,90,117,81,92,160,254,152,78,78,
0,0,255,255,0,120,255,227,3,179,6,61,16,38,0,88,0,0,
16,7,0,67,0,101,254,165,255,255,0,162,255,227,3,221,6,61,
16,38,0,88,42,0,16,7,0,118,1,140,254,165,255,255,0,130,
255,227,3,189,6,4,16,38,0,65,49,47,16,6,0,88,10,0,
0,0,255,255,0,130,255,227,3,189,5,135,16,39,0,106,0,127,
254,148,16,6,0,88,10,0,255,255,0,120,254,63,3,179,6,61,
16,38,0,92,0,0,16,7,0,118,1,92,254,165,0,2,0,129,
0,0,3,166,5,174,0,26,0,44,0,0,33,35,17,51,17,62,
3,51,50,22,23,22,21,20,14,3,35,34,46,2,47,1,1,52,
39,46,1,35,34,14,2,21,20,23,30,1,51,50,54,1,25,152,
152,28,47,68,85,52,139,181,34,19,23,58,91,146,94,46,83,54,
40,9,9,1,245,17,24,102,68,53,104,85,53,16,28,138,74,114,
136,5,174,254,170,41,53,52,26,200,162,88,101,90,156,151,107,65,
30,44,43,15,15,1,162,93,82,112,133,60,105,162,93,81,72,132,
145,227,255,255,0,130,254,63,3,189,5,124,16,39,0,106,0,147,
254,137,16,6,0,92,10,0,255,255,0,64,0,0,4,215,6,203,
16,38,0,36,248,0,16,7,0,113,0,118,1,162,255,255,0,84,
255,227,3,98,5,41,16,38,0,68,0,0,16,6,0,113,245,0,
0,0,255,255,0,64,0,0,4,215,7,46,16,38,1,174,254,0,
16,6,0,36,248,0,0,0,255,255,0,84,255,227,3,98,5,211,
16,39,1,174,255,106,254,165,16,6,0,68,0,0,255,255,0,64,
254,197,4,239,5,176,16,39,1,177,3,126,0,0,16,6,0,36,
248,0,255,255,0,84,254,197,3,140,4,66,16,39,1,177,2,27,
0,0,16,6,0,68,0,0,255,255,0,100,255,227,4,143,7,152,
16,39,0,118,1,244,0,0,16,6,0,38,0,0,255,255,0,76,
255,227,3,108,6,61,16,39,0,118,1,117,254,165,16,6,0,70,
0,0,255,255,0,100,255,227,4,143,7,66,16,39,1,171,0,172,
0,0,16,6,0,38,0,0,255,255,0,69,255,227,3,109,5,236,
16,39,1,171,0,3,254,170,16,6,0,70,249,0,255,255,0,100,
255,227,4,143,6,241,16,39,1,175,1,212,0,0,16,6,0,38,
0,0,255,255,0,76,255,227,3,108,5,170,16,39,1,175,1,116,
254,185,16,6,0,70,0,0,255,255,0,100,255,227,4,143,7,66,
16,39,1,172,0,176,0,0,16,6,0,38,0,0,255,255,0,70,
255,227,3,132,5,234,16,39,1,172,0,28,254,168,16,6,0,70,
250,0,255,255,0,121,0,0,4,129,7,66,16,38,1,172,0,0,
16,6,0,39,0,0,0,0,0,3,0,73,255,227,4,154,5,234,
0,25,0,48,0,58,0,0,1,20,7,6,7,6,7,6,15,1,
39,54,53,34,38,39,38,53,52,55,54,51,50,23,22,21,37,51,
17,35,53,14,1,35,34,46,2,53,52,62,2,51,50,30,2,23,
4,16,22,51,50,54,53,52,38,34,4,154,6,6,13,8,14,5,
18,15,39,50,28,40,6,2,23,22,31,26,22,26,254,101,152,152,
42,137,119,101,157,92,46,46,92,156,101,62,100,70,48,19,253,228,
154,115,116,160,160,232,5,148,36,35,36,30,19,30,12,31,23,24,
81,62,38,29,10,8,35,26,25,20,24,29,13,250,82,184,97,116,
96,164,198,110,112,197,161,93,35,65,71,45,147,254,112,233,233,198,
199,230,0,0,0,2,0,106,0,0,4,249,5,176,0,19,0,35,
0,0,1,35,53,51,17,33,50,23,22,23,22,21,20,7,6,7,
6,43,2,19,17,51,50,18,17,52,39,38,39,38,43,1,17,33,
21,1,32,182,182,1,124,221,157,156,50,21,75,76,138,140,176,226,
154,157,223,194,254,18,40,116,115,159,223,1,43,2,150,141,2,141,
146,146,236,105,97,203,165,167,95,96,2,150,253,249,1,70,1,1,
94,83,187,111,111,254,3,141,0,2,0,128,255,227,4,82,5,174,
0,14,0,58,0,0,1,20,23,22,51,50,55,54,53,52,39,38,
34,7,6,1,51,21,51,21,35,17,35,53,6,7,6,7,6,7,
6,35,34,39,38,39,46,1,39,38,53,52,55,62,2,51,50,23,
22,23,22,23,22,23,17,35,53,51,1,26,77,76,116,117,79,80,
80,79,234,76,76,2,28,152,132,132,152,18,25,23,34,35,50,47,
66,80,69,66,46,44,64,13,14,23,22,94,154,102,63,49,53,32,
38,21,24,19,247,247,2,27,199,118,116,116,118,197,198,116,115,114,
113,2,203,133,142,251,101,184,42,38,34,32,32,18,17,32,31,55,
53,148,80,84,85,110,101,96,164,92,18,19,31,36,32,36,44,1,
37,142,0,0,255,255,0,121,0,0,4,18,6,235,16,39,0,113,
0,91,1,194,16,6,0,40,0,0,255,255,0,98,255,227,3,157,
5,41,16,38,0,113,247,0,16,6,0,72,0,0,0,0,255,255,
0,121,0,0,4,18,7,46,16,38,1,174,216,0,16,6,0,40,
0,0,0,0,255,255,0,98,255,227,3,157,5,211,16,39,1,174,
255,124,254,165,16,6,0,72,0,0,255,255,0,121,0,0,4,18,
6,241,16,39,1,175,1,172,0,0,16,6,0,40,0,0,255,255,
0,98,255,227,3,157,5,170,16,39,1,175,1,68,254,185,16,6,
0,72,0,0,255,255,0,121,254,197,4,18,5,176,16,39,1,177,
2,142,0,0,16,6,0,40,0,0,255,255,0,98,254,197,3,157,
4,70,16,39,1,177,0,252,0,0,16,6,0,72,0,0,255,255,
0,121,0,0,4,18,7,66,16,38,1,172,98,0,16,6,0,40,
0,0,0,0,255,255,0,98,255,227,3,157,5,231,16,39,1,172,
255,253,254,165,16,6,0,72,0,0,255,255,0,100,255,227,4,209,
7,66,16,39,1,171,0,172,0,0,16,6,0,42,0,0,255,255,
0,73,254,63,3,151,5,230,16,39,1,171,255,251,254,164,16,6,
0,74,0,0,255,255,0,100,255,227,4,209,7,46,16,38,1,174,
0,0,16,6,0,42,0,0,0,0,255,255,0,73,254,63,3,151,
5,213,16,39,1,174,255,120,254,167,16,6,0,74,0,0,255,255,
0,100,255,227,4,209,6,241,16,39,1,175,2,19,0,0,16,6,
0,42,0,0,255,255,0,73,254,63,3,151,5,170,16,39,1,175,
1,100,254,185,16,6,0,74,0,0,255,255,0,100,254,63,4,209,
5,215,16,39,0,15,1,212,255,28,16,6,0,42,0,0,255,255,
0,73,254,63,3,151,6,49,16,39,0,15,1,108,5,103,16,6,
0,74,0,0,255,255,0,121,0,0,4,74,7,66,16,38,1,171,
79,0,16,6,0,43,0,0,0,0,255,255,0,129,0,0,3,188,
7,66,16,38,1,171,0,0,16,6,0,75,0,0,0,0,0,2,
0,42,0,0,4,130,5,176,0,19,0,23,0,0,19,51,17,33,
17,51,17,51,21,35,17,35,17,33,17,35,17,35,53,51,5,33,
21,33,121,158,2,149,158,56,56,158,253,107,158,79,79,3,51,253,
107,2,149,5,176,254,127,1,129,254,127,102,252,55,2,162,253,94,
3,201,102,102,154,0,0,1,0,30,0,0,3,188,5,176,0,42,
0,0,33,35,17,35,53,51,53,51,21,33,21,33,17,54,55,54,
51,50,23,22,23,22,23,22,21,17,35,17,52,39,38,39,46,1,
35,34,7,6,7,6,7,6,21,1,25,152,99,99,152,1,25,254,
231,29,80,81,115,82,66,69,48,50,27,28,151,15,16,28,30,102,
68,70,50,51,31,34,14,15,4,155,142,135,135,142,254,225,91,59,
60,33,34,66,69,106,112,141,253,227,2,29,90,75,79,55,59,66,
34,35,58,65,70,75,88,0,255,255,255,214,0,0,2,83,7,115,
16,39,1,178,255,151,4,23,16,6,0,44,0,0,0,2,255,172,
0,0,2,41,5,183,0,3,0,47,0,0,19,51,17,35,3,54,
55,62,1,51,50,23,22,23,30,1,23,22,23,22,51,50,55,54,
55,54,55,21,6,7,6,7,6,34,39,38,39,38,39,38,39,38,
35,34,6,7,6,7,150,151,151,234,24,27,25,70,37,25,30,26,
26,8,32,8,25,28,29,29,31,35,30,32,27,33,49,11,27,33,
35,66,31,30,27,16,34,26,23,25,23,36,66,24,27,28,4,49,
251,207,5,87,18,24,22,32,16,14,24,8,29,7,23,15,15,15,
13,25,21,24,145,38,9,23,14,15,15,14,24,14,32,25,13,15,
30,21,23,23,255,255,255,138,0,0,2,47,6,202,16,39,0,113,
254,206,1,161,16,6,0,44,0,0,0,2,255,158,0,0,2,67,
5,40,0,3,0,7,0,0,19,51,17,35,3,33,21,33,150,151,
151,248,2,165,253,91,4,49,251,207,5,40,106,0,255,255,255,181,
0,0,2,19,7,46,16,39,1,174,254,83,0,0,16,6,0,44,
0,0,255,255,255,168,0,0,2,6,5,170,16,38,0,243,0,0,
16,7,1,174,254,70,254,124,255,255,0,117,254,197,1,113,5,176,
16,38,1,177,0,0,16,6,0,44,0,0,0,0,255,255,0,117,
254,197,1,113,5,147,16,38,1,177,0,0,16,6,0,76,0,0,
0,0,255,255,0,135,0,0,1,67,6,241,16,38,1,175,59,0,
16,6,0,44,0,0,0,0,0,1,0,140,0,0,1,35,4,49,
0,3,0,0,19,51,17,35,140,151,151,4,49,251,207,0,0,0,
0,2,0,154,255,227,4,217,5,184,0,33,0,37,0,0,1,17,
20,7,14,1,35,34,39,38,39,38,39,38,61,1,51,21,20,23,
22,23,30,1,51,50,55,54,55,54,55,54,53,17,1,17,51,17,
4,217,152,51,140,114,82,66,69,48,47,30,28,151,15,16,28,30,
102,68,70,50,51,31,34,14,15,252,89,157,5,184,252,103,247,179,
60,86,33,34,66,64,112,106,146,11,11,90,75,79,55,59,66,34,
34,60,65,69,75,88,3,163,250,72,5,176,250,80,0,0,0,4,
0,123,254,84,2,88,5,147,0,13,0,46,0,64,0,68,0,0,
1,52,54,51,50,23,22,21,20,6,35,34,39,38,1,55,22,23,
22,23,22,23,30,1,51,50,61,1,17,51,17,21,20,7,6,7,
6,7,6,7,6,35,34,39,38,39,38,3,52,54,51,50,23,22,
23,22,21,20,6,35,34,39,38,39,38,19,51,17,35,1,156,56,
38,38,28,28,56,38,38,28,28,254,223,107,10,5,10,6,15,4,
10,24,14,102,152,23,22,35,40,34,40,34,29,28,42,36,35,17,
8,28,56,38,33,26,25,8,2,56,38,33,26,25,8,2,19,151,
151,5,53,38,56,27,27,40,38,56,27,27,249,153,102,10,4,8,
4,10,2,5,6,123,170,4,49,251,207,139,63,52,50,32,36,18,
21,9,8,15,15,12,6,6,177,38,56,21,21,33,8,11,38,56,
21,21,33,16,254,255,251,207,255,255,0,113,255,227,5,11,7,66,
16,39,1,171,1,161,0,0,16,6,0,45,0,0,0,2,255,137,
254,84,2,91,5,235,0,32,0,39,0,0,3,55,22,23,22,23,
22,23,30,1,51,50,61,1,17,51,17,21,20,7,6,7,6,7,
6,7,6,35,34,39,38,39,38,1,35,39,7,35,1,51,119,107,
10,5,10,6,15,4,10,24,14,102,152,23,22,35,40,34,40,34,
29,28,42,36,35,17,8,2,174,188,156,158,186,1,21,131,254,166,
102,10,4,8,4,10,2,5,6,123,170,4,49,251,207,139,63,52,
50,32,36,18,21,9,8,15,15,12,6,6,15,213,211,1,86,0,
0,0,255,255,0,121,254,66,4,211,5,176,16,39,0,15,1,70,
255,31,16,6,0,46,0,0,255,255,0,129,254,66,3,172,5,174,
16,39,0,15,1,19,255,31,16,6,0,78,0,0,0,1,0,121,
0,0,3,168,4,53,0,10,0,0,19,51,17,1,51,9,1,35,
1,3,35,121,158,1,161,186,254,6,2,48,216,254,72,1,158,4,
48,254,80,1,181,253,231,253,228,1,149,254,107,0,0,0,255,255,
0,119,0,0,4,20,7,152,16,38,0,118,59,0,16,6,0,47,
0,0,0,0,255,255,0,128,255,227,2,36,7,152,16,38,0,118,
68,0,16,6,0,79,0,0,0,0,255,255,0,121,254,66,4,20,
5,176,16,39,0,15,1,74,255,31,16,6,0,47,0,0,255,255,
0,150,254,62,1,164,5,174,16,39,0,15,0,90,255,27,16,6,
0,79,0,0,0,2,0,121,0,0,4,20,5,234,0,25,0,31,
0,0,1,20,7,6,7,6,7,6,15,1,39,54,53,34,38,39,
38,53,52,55,54,51,50,23,22,21,37,51,17,33,21,33,1,232,
6,6,13,8,14,5,18,15,39,50,28,40,6,2,23,22,31,26,
22,26,254,145,158,2,253,252,101,5,148,36,35,36,30,19,30,12,
31,23,24,81,62,38,29,10,8,35,26,25,20,24,29,15,250,221,
141,0,0,0,0,2,0,150,255,227,1,232,5,234,0,25,0,38,
0,0,1,20,7,6,7,6,7,6,15,1,39,54,53,34,38,39,
38,53,52,55,54,51,50,23,22,21,3,20,23,22,51,21,34,38,
39,38,53,17,51,1,232,6,6,13,8,14,5,18,15,39,50,28,
40,6,2,23,22,31,26,22,26,187,3,16,100,113,131,19,7,151,
5,148,36,35,36,30,19,30,12,31,23,24,81,62,38,29,10,8,
35,26,25,20,24,29,251,46,17,13,75,131,74,89,37,32,4,227,
0,0,255,255,0,121,0,0,4,20,5,176,16,39,0,121,1,154,
0,0,16,6,0,47,0,0,255,255,0,150,255,227,2,157,5,174,
16,39,0,121,1,56,0,0,16,6,0,79,0,0,0,1,0,17,
0,0,4,20,5,176,0,13,0,0,19,63,1,17,51,17,55,23,
7,17,33,21,33,17,17,1,103,158,125,1,126,2,253,252,101,1,
254,202,104,2,128,254,32,126,208,125,253,140,141,2,101,0,0,1,
0,17,255,227,1,149,5,174,0,20,0,0,19,63,1,17,51,17,
55,23,7,17,20,23,22,51,21,34,38,39,38,53,17,17,1,108,
151,127,1,128,3,16,100,113,130,20,7,1,254,202,109,2,121,254,
32,128,208,127,253,208,17,13,75,131,74,89,35,34,1,159,255,255,
0,121,0,0,4,147,7,152,16,39,0,118,1,196,0,0,16,6,
0,49,0,0,255,255,0,139,0,0,3,198,6,58,16,39,0,118,
1,68,254,162,16,6,0,81,10,0,255,255,0,121,254,63,4,147,
5,176,16,39,0,15,1,118,255,28,16,6,0,49,0,0,255,255,
0,129,254,63,3,188,4,78,16,39,0,15,1,66,255,28,16,6,
0,81,0,0,255,255,0,121,0,0,4,147,7,66,16,38,1,172,
116,0,16,6,0,49,0,0,0,0,255,255,0,129,0,0,3,188,
5,234,16,39,1,172,0,8,254,168,16,6,0,81,0,0,255,255,
0,103,0,0,4,184,6,49,16,39,0,15,0,0,5,103,16,7,
0,81,0,252,0,0,0,0,0,1,0,110,255,169,4,137,5,184,
0,54,0,0,37,50,55,54,61,1,17,52,39,38,39,46,1,35,
34,7,6,7,6,7,6,21,17,35,3,51,23,54,55,54,51,50,
23,22,23,22,23,22,21,17,23,20,22,21,20,7,6,7,6,7,
6,35,48,35,54,2,246,103,74,73,14,15,30,30,102,68,42,98,
60,96,119,49,16,152,7,152,7,121,165,113,121,83,66,67,49,52,
26,27,1,1,36,20,72,65,65,80,65,4,1,47,74,73,135,33,
2,29,95,70,76,58,59,66,34,24,57,72,75,26,137,252,122,5,
176,202,92,70,48,33,34,66,71,104,108,145,253,228,1,2,6,1,
58,133,68,68,60,24,29,10,0,0,0,1,0,108,254,63,3,168,
4,78,0,51,0,0,1,50,55,54,61,1,17,52,39,38,39,46,
1,35,34,7,6,7,6,7,6,21,17,35,17,51,21,54,55,54,
51,50,23,22,23,22,23,22,21,17,23,21,20,7,6,7,6,7,
6,43,1,54,2,22,103,74,73,15,16,28,30,102,68,70,50,53,
30,32,15,15,152,152,29,80,81,115,82,66,69,48,50,27,28,1,
35,19,74,65,64,80,65,4,1,254,197,74,73,135,33,2,29,90,
75,79,55,59,66,34,36,57,62,73,75,88,253,228,4,49,181,91,
59,60,33,34,66,69,106,112,141,253,228,1,9,62,129,67,69,61,
23,29,10,0,255,255,0,92,255,227,4,238,6,202,16,39,0,113,
0,153,1,161,16,6,0,50,0,0,255,255,0,102,255,227,3,207,
5,44,16,38,0,113,254,3,16,6,0,82,0,0,0,0,255,255,
0,92,255,227,4,238,7,46,16,38,1,174,0,0,16,6,0,50,
0,0,0,0,255,255,0,102,255,227,3,207,5,211,16,39,1,174,
255,133,254,165,16,6,0,82,0,0,255,255,0,92,255,227,4,238,
7,150,16,38,1,179,0,0,16,6,0,50,0,0,0,0,255,255,
0,102,255,227,3,218,6,61,16,39,1,179,255,106,254,167,16,6,
0,82,0,0,0,2,0,92,255,227,5,182,5,215,0,34,0,61,
0,0,19,52,55,54,55,54,55,54,55,54,51,50,23,33,21,33,
17,33,21,33,17,33,21,33,6,35,34,39,38,39,38,39,38,39,
38,1,17,46,1,39,38,35,34,6,7,6,7,14,1,21,20,23,
22,23,22,23,22,23,22,51,50,55,92,19,20,44,43,67,64,103,
101,123,175,39,2,60,254,52,1,161,254,95,1,204,253,160,84,94,
120,99,98,68,65,45,43,23,23,2,240,1,9,3,67,88,94,146,
47,47,30,30,24,22,15,33,29,48,46,71,70,84,102,65,2,213,
103,101,104,102,100,82,79,50,49,39,141,254,14,141,253,233,141,29,
45,45,78,75,95,91,108,109,254,47,4,139,1,5,1,32,80,64,
63,85,84,168,85,114,104,75,74,65,59,57,32,32,39,0,0,3,
0,102,255,227,5,118,4,70,0,25,0,74,0,82,0,0,1,20,
23,22,23,22,23,22,50,63,1,38,39,38,53,52,55,54,55,38,
35,34,7,6,7,6,7,52,55,54,55,54,55,54,51,50,23,54,
51,50,23,22,23,30,1,21,20,22,29,1,33,22,23,22,23,22,
51,50,55,54,55,23,6,7,6,35,34,39,6,35,34,39,38,39,
38,37,33,46,1,35,34,14,1,1,0,16,17,32,32,57,55,148,
55,7,31,24,49,49,25,28,53,81,99,64,65,27,28,154,28,30,
52,55,83,84,105,133,98,94,127,95,81,79,50,49,52,1,253,100,
7,31,30,58,58,77,74,69,70,32,133,52,103,106,117,124,95,98,
135,138,101,102,48,48,2,116,2,10,9,140,112,75,120,60,2,25,
92,74,79,58,59,35,34,34,4,46,61,130,156,161,123,62,40,35,
58,59,91,95,118,121,99,104,73,77,41,42,70,70,46,45,75,74,
190,99,1,32,14,49,95,81,79,54,54,38,39,60,55,100,58,59,
71,71,77,78,125,126,227,146,208,108,156,0,255,255,0,121,0,0,
4,80,7,152,16,39,0,118,1,30,0,0,16,6,0,53,0,0,
255,255,0,129,0,0,2,225,6,61,16,39,0,118,0,164,254,165,
16,6,0,85,0,0,255,255,0,121,254,63,4,80,5,176,16,39,
0,15,1,54,255,28,16,6,0,53,0,0,255,255,0,114,254,63,
2,244,4,78,16,39,0,15,0,11,255,28,16,6,0,85,19,0,
255,255,0,121,0,0,4,80,7,66,16,38,1,172,0,0,16,6,
0,53,0,0,0,0,255,255,0,32,0,0,2,235,5,234,16,39,
1,172,255,104,254,168,16,6,0,85,10,0,255,255,0,45,255,227,
4,10,7,152,16,39,0,118,1,108,0,0,16,6,0,54,0,0,
255,255,0,96,255,227,3,72,6,61,16,39,0,118,1,35,254,165,
16,6,0,86,0,0,255,255,0,45,255,227,4,10,7,66,16,38,
1,171,0,0,16,6,0,54,0,0,0,0,255,255,0,96,255,227,
3,74,5,235,16,39,1,171,255,224,254,169,16,6,0,86,0,0,
0,2,0,45,254,93,4,10,5,215,0,90,0,119,0,0,19,55,
30,1,51,50,54,53,52,39,38,39,38,39,38,39,38,39,38,39,
38,47,1,38,39,38,39,38,39,38,39,38,39,38,39,38,53,52,
55,54,51,50,23,22,23,7,38,39,38,35,34,6,21,20,23,22,
23,22,23,22,23,22,23,22,23,22,23,22,23,22,23,22,23,22,
23,22,23,22,23,30,1,21,20,7,6,7,6,35,34,39,38,1,
54,55,54,55,62,1,53,52,39,38,39,38,39,55,22,23,22,21,
20,7,6,7,6,7,6,7,6,7,45,170,21,188,115,140,202,15,
17,19,23,35,36,30,33,42,25,48,6,62,56,33,31,16,46,43,
18,20,32,25,18,18,10,10,122,121,182,172,121,122,40,152,22,85,
83,113,115,148,9,9,14,15,24,30,17,16,42,32,30,15,53,62,
4,33,39,24,50,42,32,28,36,33,21,20,28,68,69,109,110,139,
189,124,122,1,25,26,3,4,24,19,18,2,3,15,17,18,129,63,
17,4,13,13,29,39,10,19,39,40,7,1,71,31,87,158,144,114,
41,38,43,24,30,27,28,20,21,20,12,21,2,25,22,13,14,7,
27,25,15,17,35,28,36,37,41,43,53,164,98,97,85,86,130,25,
72,57,56,124,94,36,31,30,24,25,20,24,12,11,19,14,13,6,
21,24,2,14,18,11,29,24,26,22,40,36,39,37,106,54,132,90,
91,42,42,98,97,254,52,20,2,3,20,16,30,13,1,14,18,22,
25,24,56,60,74,21,17,33,27,28,24,33,7,14,23,24,4,0,
0,2,0,88,254,93,3,64,4,74,0,82,0,113,0,0,1,38,
39,38,39,38,39,38,39,38,53,52,55,54,55,50,22,23,22,23,
22,23,7,38,35,34,7,6,21,20,23,22,23,22,23,22,23,22,
23,30,1,23,22,23,22,23,22,23,22,23,22,23,22,23,22,23,
22,23,22,21,20,7,6,35,34,39,38,39,55,22,23,22,51,50,
54,53,52,39,38,39,38,39,38,3,62,1,55,54,55,54,55,54,
53,52,39,38,39,38,39,55,22,23,22,21,20,7,6,7,6,7,
6,7,6,7,1,206,67,35,39,52,47,34,34,19,21,100,101,147,
81,130,41,47,19,24,12,146,54,152,80,59,58,14,15,22,24,25,
31,20,31,15,2,29,12,10,39,24,24,40,10,40,6,26,17,9,
26,19,11,10,8,6,108,107,151,154,92,95,37,148,30,52,52,92,
100,116,18,21,34,37,30,33,173,6,19,3,4,24,19,9,10,2,
3,15,10,26,130,63,17,4,14,13,29,45,3,19,39,20,28,1,
221,22,14,16,29,26,36,35,46,49,59,137,75,76,1,44,38,44,
28,36,37,30,122,39,39,72,38,28,31,17,19,14,17,6,9,7,
1,9,5,4,14,9,10,17,6,23,4,16,17,9,30,22,25,24,
30,24,41,137,90,89,67,69,110,28,67,36,36,96,85,43,29,34,
21,23,13,14,253,10,4,16,2,3,20,16,15,17,11,1,14,18,
22,15,34,56,60,74,21,17,30,30,28,24,38,2,14,23,12,16,
0,0,255,255,0,45,255,227,4,10,7,66,16,38,1,172,0,0,
16,6,0,54,0,0,0,0,255,255,0,96,255,227,3,72,5,234,
16,39,1,172,255,188,254,168,16,6,0,86,0,0,0,2,0,88,
254,44,4,156,5,176,0,22,0,30,0,0,5,20,14,4,7,39,
54,53,34,38,39,38,53,52,54,51,50,22,23,22,1,33,21,33,
17,35,17,33,2,239,16,21,33,22,29,2,56,72,39,58,8,3,
64,44,39,58,8,2,253,105,4,68,254,55,158,254,35,153,37,77,
58,63,35,42,3,31,103,75,47,37,11,11,45,63,49,36,8,6,
58,141,250,221,5,35,0,2,0,102,254,30,2,80,5,43,0,22,
0,41,0,0,5,20,14,4,7,39,54,53,34,38,39,38,53,52,
54,51,50,22,23,22,3,35,53,51,53,51,21,51,21,35,17,20,
59,1,21,35,34,38,53,1,204,16,21,33,22,29,2,56,72,39,
58,8,3,64,44,39,58,8,2,216,142,142,151,197,197,117,70,70,
148,120,167,37,77,58,63,35,42,3,31,103,75,47,37,11,11,45,
63,49,36,8,4,66,135,250,250,135,253,45,117,127,111,129,0,0,
255,255,0,88,0,0,4,156,7,66,16,38,1,172,120,0,16,6,
0,55,0,0,0,0,0,2,0,102,255,227,2,192,5,234,0,25,
0,44,0,0,1,20,7,6,7,6,7,6,15,1,39,54,53,34,
38,39,38,53,52,55,54,51,50,23,22,21,1,35,53,51,53,51,
21,51,21,35,17,20,59,1,21,35,34,38,53,2,192,6,6,13,
8,14,5,18,15,39,50,28,40,6,2,23,22,31,26,22,26,254,
52,142,142,151,197,197,117,70,70,148,120,5,148,36,35,36,30,19,
30,12,31,23,24,81,62,38,29,10,8,35,26,25,20,24,29,254,
9,135,250,250,135,253,45,117,127,111,129,0,0,1,0,88,0,0,
4,156,5,176,0,15,0,0,19,33,21,33,17,33,21,33,17,35,
17,33,53,33,17,33,88,4,68,254,55,1,89,254,167,158,254,188,
1,68,254,35,5,176,141,253,165,142,253,198,2,58,142,2,91,0,
0,1,0,52,255,227,2,132,5,43,0,27,0,0,19,35,53,51,
53,51,21,51,21,35,21,51,21,35,17,20,59,1,21,35,34,39,
38,53,17,35,53,51,244,142,142,151,197,197,249,249,117,70,70,149,
59,60,192,192,3,170,135,250,250,135,226,142,254,157,117,127,55,56,
129,1,103,142,255,255,0,121,255,227,4,141,7,70,16,39,1,178,
1,5,3,234,16,6,0,56,0,0,255,255,0,120,255,227,3,179,
5,184,16,39,1,178,0,154,2,92,16,6,0,88,0,0,255,255,
0,121,255,227,4,141,6,194,16,39,0,113,0,116,1,153,16,6,
0,56,0,0,255,255,0,120,255,227,3,179,5,39,16,38,0,113,
9,254,16,6,0,88,0,0,0,0,255,255,0,121,255,227,4,141,
7,46,16,38,1,174,0,0,16,6,0,56,0,0,0,0,255,255,
0,120,255,227,3,179,5,211,16,39,1,174,255,118,254,165,16,6,
0,88,0,0,255,255,0,121,255,227,4,141,7,155,16,39,1,176,
0,132,255,253,16,6,0,56,0,0,255,255,0,120,255,227,3,179,
6,48,16,39,1,176,0,36,254,146,16,6,0,88,0,0,255,255,
0,121,255,227,4,141,7,150,16,38,1,179,0,0,16,6,0,56,
0,0,0,0,255,255,0,162,255,227,4,0,6,60,16,39,1,179,
255,144,254,166,16,6,0,88,42,0,255,255,0,121,254,197,4,141,
5,176,16,39,1,177,1,248,0,0,16,6,0,56,0,0,255,255,
0,102,254,197,3,194,4,49,16,39,1,177,2,81,0,0,16,6,
0,88,238,0,255,255,0,84,0,0,5,236,7,66,16,39,1,171,
1,6,0,0,16,6,0,58,0,0,255,255,0,68,0,0,5,49,
5,235,16,39,1,171,0,168,254,169,16,6,0,90,0,0,255,255,
0,76,0,0,4,100,7,66,16,38,1,171,61,0,16,6,0,60,
0,0,0,0,255,255,0,120,254,63,3,179,5,230,16,39,1,171,
0,3,254,164,16,6,0,92,0,0,255,255,0,76,0,0,4,100,
6,243,16,38,0,60,0,0,16,7,0,106,0,185,0,0,255,255,
0,100,0,0,4,221,7,152,16,39,0,118,1,217,0,0,16,6,
0,61,0,0,255,255,0,90,0,0,3,139,6,61,16,39,0,118,
1,93,254,165,16,6,0,93,0,0,255,255,0,100,0,0,4,221,
6,241,16,39,1,175,2,1,0,0,16,6,0,61,0,0,255,255,
0,90,0,0,3,139,5,170,16,39,1,175,1,98,254,185,16,6,
0,93,0,0,255,255,0,100,0,0,4,221,7,66,16,39,1,172,
0,175,0,0,16,6,0,61,0,0,255,255,0,90,0,0,3,139,
5,230,16,39,1,172,255,244,254,164,16,6,0,93,0,0,0,1,
1,7,0,0,2,211,5,201,0,26,0,0,1,53,52,55,54,55,
54,55,54,51,50,23,22,23,7,38,39,38,39,38,35,34,6,29,
1,3,35,1,7,29,30,44,43,49,47,40,58,39,37,44,109,12,
11,10,19,21,27,39,58,1,152,4,49,135,62,51,52,35,34,20,
19,21,20,41,105,16,11,9,8,8,52,45,176,251,207,0,0,0,
0,1,255,250,0,0,3,160,5,240,0,30,0,0,9,1,35,1,
35,55,51,55,54,55,54,55,54,55,54,51,50,23,22,23,7,38,
47,1,34,7,6,15,1,51,7,1,232,254,170,152,1,86,139,49,
138,49,25,41,45,56,51,65,25,29,46,40,41,31,4,26,46,92,
40,51,50,17,64,195,49,3,170,252,86,3,170,135,135,65,64,69,
53,48,9,4,12,12,40,152,24,24,20,39,38,46,176,135,0,0,
0,3,0,92,0,0,5,114,6,182,0,3,0,19,0,23,0,0,
1,33,21,33,19,33,1,35,1,33,21,33,17,33,21,33,17,33,
21,33,3,53,3,51,2,214,2,92,253,164,69,254,248,254,254,181,
2,81,2,197,254,71,1,185,254,71,1,185,253,169,2,201,203,6,
182,135,252,87,253,122,5,178,150,253,249,147,254,18,148,4,214,74,
253,245,0,4,0,94,255,227,5,108,5,55,0,3,0,21,0,86,
0,95,0,0,1,33,21,33,19,34,7,6,21,20,23,22,51,50,
55,54,53,52,39,38,39,38,1,54,55,54,51,32,19,30,1,23,
22,21,7,33,20,23,22,51,50,55,54,55,23,6,7,6,35,34,
39,38,39,6,7,6,35,34,39,38,39,38,53,52,55,54,50,23,
30,1,23,39,52,39,38,35,34,15,1,39,54,55,54,51,50,23,
22,19,33,38,39,38,35,34,7,6,1,174,2,93,253,163,17,173,
24,4,8,34,159,124,54,23,8,27,109,32,1,4,80,88,52,61,
1,10,80,2,5,1,21,4,253,177,17,45,158,82,45,11,24,133,
80,96,51,68,137,85,18,43,55,27,68,133,208,95,27,12,11,136,
93,248,60,3,11,7,2,8,34,157,106,72,7,77,85,38,59,80,
166,101,8,67,1,183,6,12,46,155,150,51,18,5,55,136,253,172,
189,25,34,44,42,162,125,57,66,34,35,135,35,9,1,51,132,34,
19,254,208,6,24,5,99,120,68,72,71,219,73,16,46,53,156,41,
21,103,23,67,98,27,68,173,50,58,52,51,193,112,78,74,5,16,
10,60,50,46,166,71,7,103,70,16,25,158,12,254,196,73,54,227,
211,72,0,2,0,45,254,13,4,10,5,215,0,22,0,80,0,0,
5,20,14,4,7,39,54,53,34,38,39,38,53,52,54,51,50,22,
23,22,1,55,30,1,51,50,54,53,52,46,6,39,46,5,53,52,
54,51,50,22,23,7,46,1,35,34,6,21,20,30,5,23,30,5,
21,20,14,1,35,34,38,2,126,16,21,33,22,29,2,56,72,39,
58,8,3,64,44,39,58,8,2,253,175,170,21,188,115,141,201,29,
44,71,62,89,55,83,14,44,61,83,55,51,26,244,181,172,242,41,
152,23,168,112,115,148,20,46,46,79,56,98,27,48,74,97,70,64,
33,137,219,139,191,245,184,37,77,58,63,35,42,3,31,103,75,47,
37,11,11,45,63,49,36,8,1,240,31,87,158,144,114,41,76,58,
58,38,43,22,32,6,18,30,49,58,76,100,60,164,195,170,131,25,
72,113,124,94,41,67,53,39,39,24,38,11,20,38,59,70,89,114,
66,130,183,84,196,0,0,2,0,96,254,14,3,72,4,74,0,22,
0,81,0,0,5,20,14,4,7,39,54,53,34,38,39,38,53,52,
54,51,50,22,23,22,3,46,4,53,52,54,55,50,30,2,23,7,
38,35,34,6,21,20,30,7,23,30,9,21,20,6,35,34,38,39,
55,30,1,51,50,54,53,52,46,2,2,65,16,21,33,22,29,2,
56,72,39,58,8,3,64,44,39,58,8,2,108,60,82,101,62,43,
200,148,81,131,82,48,12,146,54,152,80,117,8,20,17,34,19,41,
15,40,3,12,63,34,63,37,54,33,38,21,14,216,151,152,187,38,
147,30,104,92,101,116,38,71,63,183,37,77,58,63,35,42,3,31,
103,75,47,37,11,11,45,63,49,36,8,2,133,20,32,58,65,98,
59,137,150,2,45,74,71,37,30,122,79,71,21,36,30,24,23,13,
17,7,14,1,4,23,12,26,20,34,32,46,48,61,34,137,179,134,
112,28,67,72,96,85,40,64,45,27,255,255,0,88,254,44,4,156,
5,176,16,6,1,36,0,0,255,255,0,102,254,30,2,80,5,43,
16,6,1,37,0,0,0,1,0,48,255,32,3,113,5,236,0,70,
0,0,23,54,55,54,55,54,55,54,53,52,39,38,39,38,39,38,
35,34,15,1,53,55,62,1,53,52,39,38,35,34,15,1,6,7,
6,7,39,54,55,54,55,54,51,50,23,22,23,22,21,20,7,6,
7,6,7,22,23,22,23,22,23,22,21,20,7,2,7,6,7,6,
7,117,99,210,109,94,80,15,1,29,28,47,45,59,38,18,30,30,
77,96,95,142,73,58,68,12,28,6,77,61,60,31,135,53,98,100,
119,36,34,63,56,90,58,58,33,34,37,46,31,63,16,25,54,38,
25,28,2,60,80,95,191,175,131,80,20,125,64,99,86,160,7,13,
52,58,55,30,29,11,6,6,13,127,17,16,176,113,100,61,47,4,
1,13,55,54,79,41,116,82,83,21,6,20,32,80,81,110,83,78,
79,45,54,19,24,6,9,57,41,62,70,41,16,7,254,244,86,106,
128,117,21,0,0,0,0,1,0,48,254,67,3,114,4,56,0,67,
0,0,19,36,55,54,55,52,54,53,52,39,38,39,38,39,38,35,
34,15,1,53,55,54,55,54,53,52,39,38,35,34,15,1,6,7,
6,7,39,54,55,54,55,54,51,50,23,22,23,22,21,20,7,6,
7,6,7,22,23,22,23,22,23,22,29,1,6,7,6,5,153,1,
159,119,38,2,1,32,28,47,45,59,32,24,35,25,77,96,94,72,
71,73,56,70,19,21,6,77,61,60,31,135,53,98,100,119,36,34,
63,56,89,59,58,33,33,38,46,31,31,48,25,54,26,37,29,8,
76,203,254,62,254,233,54,185,59,38,1,5,1,40,64,55,30,29,
11,5,5,13,126,17,16,89,88,113,100,61,46,3,1,13,55,54,
79,41,116,82,83,21,6,20,31,82,81,109,84,78,77,46,54,19,
14,16,9,57,28,75,57,48,11,112,92,236,89,0,0,0,0,2,
0,106,255,227,3,120,4,66,0,14,0,53,0,0,1,50,54,53,
52,39,38,35,34,7,6,21,20,23,22,23,34,39,38,39,21,20,
22,51,50,55,54,55,23,6,35,34,38,61,1,17,51,29,1,54,
55,54,55,54,55,54,51,50,23,22,21,20,7,6,1,226,112,140,
72,71,109,96,70,71,73,74,122,104,76,76,12,128,116,68,62,61,
35,78,133,171,166,218,139,2,21,19,37,33,53,51,55,162,104,106,
109,107,1,223,138,100,103,68,67,69,69,100,103,67,68,135,54,53,
51,96,141,158,21,21,35,104,109,230,205,123,2,20,156,2,20,31,
27,34,30,23,22,103,104,166,160,107,106,0,0,0,0,2,0,90,
255,227,3,120,4,66,0,25,0,45,0,0,55,38,47,1,48,53,
52,55,54,51,50,23,53,51,17,35,53,6,7,6,7,6,7,6,
35,34,3,23,20,23,22,51,50,55,54,53,3,38,39,38,35,34,
7,6,7,6,200,107,2,1,110,133,169,144,102,140,140,3,20,23,
32,33,53,51,55,159,88,1,64,66,148,96,72,70,2,2,61,63,
118,70,51,54,33,61,89,113,207,252,3,201,116,109,87,70,251,207,
156,19,29,33,29,30,23,22,2,178,252,142,79,82,70,69,96,1,
58,145,76,78,19,20,33,76,0,0,0,2,0,90,255,227,3,120,
4,66,0,25,0,45,0,0,37,6,35,34,39,38,39,38,39,38,
39,21,35,17,51,21,54,51,50,23,22,21,48,21,7,6,3,38,
39,38,39,38,35,34,7,6,7,3,20,23,22,51,50,55,54,53,
3,10,119,158,55,51,53,33,35,21,20,3,140,140,102,144,170,133,
109,1,2,138,2,61,33,54,51,70,118,63,61,2,2,71,72,95,
149,66,63,89,118,22,23,30,32,30,29,19,156,4,49,70,87,109,
115,202,3,252,207,1,203,145,76,33,20,19,78,76,145,254,198,96,
69,70,82,78,143,0,0,2,0,131,255,227,3,209,5,242,0,55,
0,71,0,0,5,34,39,38,53,17,53,52,55,54,55,54,55,54,
51,50,23,22,23,22,23,22,23,35,46,1,35,34,6,29,2,54,
55,62,1,55,54,51,50,23,22,23,22,23,22,23,22,21,20,7,
6,7,14,1,35,19,52,39,38,35,34,7,6,21,20,23,22,51,
50,55,54,2,6,159,119,109,35,35,57,52,78,72,77,93,76,80,
50,48,32,29,8,143,14,158,92,105,158,17,26,24,66,52,50,62,
81,69,66,46,44,32,32,13,14,23,22,47,45,158,100,239,77,76,
116,117,79,80,80,79,117,116,76,77,29,118,113,207,2,152,18,98,
84,83,54,50,32,30,32,34,50,48,62,57,57,88,116,146,134,33,
184,39,40,37,60,19,18,32,31,55,52,76,74,80,84,84,109,101,
99,81,79,94,2,56,198,115,114,115,116,198,197,118,116,116,118,0,
0,0,0,1,0,101,255,227,3,133,4,70,0,47,0,0,19,39,
54,55,54,51,50,23,22,23,22,23,22,23,22,21,20,7,6,7,
6,35,34,39,38,39,38,39,38,39,55,22,23,22,23,22,23,22,
51,50,54,53,52,38,35,34,7,6,232,131,53,86,85,115,84,74,
72,56,54,41,40,20,20,59,58,106,104,132,61,53,55,41,50,25,
32,24,122,11,16,18,25,24,43,39,43,130,176,180,128,69,61,60,
3,41,66,96,62,61,30,29,55,52,72,70,82,83,84,155,130,128,
77,76,19,20,32,39,29,37,40,77,21,24,26,25,24,20,18,236,
195,181,240,50,50,0,0,2,255,181,255,90,3,133,4,70,0,60,
0,74,0,0,1,38,39,38,35,34,6,21,20,23,54,55,54,55,
50,62,1,51,50,23,22,23,22,21,20,6,21,6,7,6,7,6,
7,35,34,39,38,39,6,7,39,54,55,38,39,38,53,52,55,54,
55,54,55,54,55,54,51,50,23,22,23,1,22,51,50,55,54,61,
1,38,39,38,35,7,6,3,2,18,60,61,69,128,180,53,83,46,
57,77,4,15,12,5,43,32,55,30,34,1,2,14,60,81,16,66,
10,122,104,39,33,103,153,71,177,87,14,15,59,20,20,40,41,54,
56,72,74,84,115,85,86,53,253,231,83,113,43,39,25,3,36,40,
31,61,68,3,41,49,50,50,240,181,150,106,57,24,31,9,2,1,
16,29,50,56,78,1,4,1,51,20,84,33,8,3,76,29,34,94,
182,97,193,72,24,32,130,155,84,83,82,70,72,52,55,29,30,61,
62,96,253,91,92,18,55,17,2,50,14,15,11,26,0,2,0,128,
254,84,5,1,5,234,0,14,0,73,0,0,1,20,23,22,51,50,
55,54,53,52,39,38,34,7,6,1,51,17,20,51,63,4,23,6,
7,6,7,6,35,34,39,38,39,38,39,38,39,38,53,17,6,7,
6,7,6,7,6,35,34,39,38,39,46,1,39,38,53,52,55,62,
2,51,50,23,22,23,22,23,22,23,1,26,77,76,116,117,79,80,
80,79,234,76,76,2,28,152,102,26,22,19,16,15,107,36,8,17,
35,36,42,28,29,34,40,34,40,35,22,23,18,25,23,34,35,50,
47,66,80,69,66,46,44,64,13,14,23,22,94,154,102,63,49,53,
32,38,21,24,19,2,27,199,118,116,116,118,197,198,116,115,114,113,
3,7,249,108,123,3,8,12,12,14,102,34,6,12,15,15,8,9,
21,18,36,32,50,52,63,1,67,42,38,34,32,32,18,17,32,31,
55,53,148,80,84,85,110,101,96,164,92,18,19,31,36,32,36,44,
0,2,0,128,255,227,5,1,5,234,0,14,0,73,0,0,1,20,
23,22,51,50,55,54,53,52,39,38,34,7,6,1,7,47,4,34,
21,17,35,53,6,7,6,7,6,7,6,35,34,39,38,39,46,1,
39,38,53,52,55,62,2,51,50,23,22,23,22,23,22,23,17,52,
55,54,55,54,55,54,55,54,51,50,23,22,23,22,1,26,77,76,
116,117,79,80,80,79,234,76,76,3,231,107,15,16,19,22,26,102,
152,18,25,23,34,35,50,47,66,80,69,66,46,44,64,13,14,23,
22,94,154,102,63,49,53,32,38,21,24,19,23,22,35,40,34,40,
34,29,28,42,36,35,17,8,2,27,199,118,116,116,118,197,198,116,
115,114,113,2,181,102,14,12,12,8,3,123,251,24,184,42,38,34,
32,32,18,17,32,31,55,53,148,80,84,85,110,101,96,164,92,18,
19,31,36,32,36,44,1,83,63,52,50,32,36,18,21,9,8,15,
15,12,6,0,0,2,0,98,255,227,3,157,4,70,0,7,0,45,
0,0,1,46,2,35,34,6,7,5,33,53,52,54,53,52,54,55,
54,55,54,51,50,23,22,23,22,21,20,7,14,1,35,34,39,38,
39,55,22,23,22,51,50,55,54,55,54,2,254,6,60,120,75,112,
140,9,2,10,253,100,1,52,49,50,79,81,95,129,97,95,50,49,
49,47,194,130,117,106,103,52,133,32,70,69,74,77,58,58,30,31,
2,92,90,156,108,208,146,135,49,14,32,1,99,190,74,75,45,46,
74,73,126,123,161,156,130,126,154,59,58,100,55,60,39,38,54,54,
79,81,0,0,0,2,0,98,255,227,3,157,4,70,0,10,0,48,
0,0,1,33,22,23,22,51,50,55,54,55,54,55,46,2,35,34,
7,6,7,39,54,55,54,51,50,23,22,23,22,21,20,7,6,7,
6,35,34,39,38,39,38,39,38,53,52,38,61,1,2,254,253,246,
9,70,71,111,75,60,59,31,30,6,7,62,114,78,73,70,71,31,
133,52,103,106,117,132,95,96,48,49,49,50,95,97,129,97,79,77,
52,50,25,26,1,1,205,145,104,105,54,53,80,78,224,95,162,106,
39,39,59,55,100,58,59,76,76,128,130,156,161,123,126,73,74,45,
44,78,75,93,95,99,1,33,14,48,0,0,0,2,0,98,255,227,
4,96,4,70,0,39,0,57,0,0,1,54,51,50,23,22,23,55,
19,7,3,7,22,23,22,21,20,7,6,7,6,35,34,39,38,39,
38,39,38,53,52,38,61,1,1,39,38,35,34,7,5,1,23,22,
23,22,51,50,55,54,55,54,55,54,53,52,39,38,1,26,106,117,
132,95,20,27,181,160,114,108,35,10,4,48,49,50,95,97,129,97,
79,77,52,50,25,26,1,2,36,6,57,78,73,70,1,110,254,27,
1,9,70,71,111,75,60,59,31,33,3,2,2,7,4,11,59,76,
16,28,100,254,70,54,1,30,19,20,11,127,159,161,123,126,73,74,
45,44,78,75,93,95,99,1,33,14,48,1,48,6,53,39,148,254,
250,49,145,104,105,54,53,80,85,82,62,18,27,28,95,0,0,1,
0,138,255,227,3,107,4,74,0,61,0,0,37,6,7,6,35,34,
38,53,52,55,54,55,54,63,1,38,39,38,39,38,53,52,55,54,
55,54,51,50,23,22,23,7,46,1,43,1,34,7,6,21,20,23,
22,59,1,21,35,34,7,6,7,6,7,6,21,20,23,22,51,50,
54,55,3,107,43,102,101,101,164,226,25,25,37,59,20,84,40,42,
45,23,32,45,51,67,73,78,99,77,79,41,100,24,96,58,17,65,
38,72,61,59,73,72,57,47,40,34,43,40,26,29,73,75,103,63,
120,29,195,102,61,61,190,145,130,47,49,34,55,3,42,13,20,22,
23,38,70,51,60,67,33,35,52,53,84,52,47,66,26,49,51,73,
30,29,125,13,10,27,25,37,41,121,91,54,55,66,54,0,0,1,
0,138,255,227,3,107,4,74,0,61,0,0,63,1,30,1,51,50,
55,54,53,52,39,38,39,38,39,38,43,1,53,51,50,55,54,53,
52,39,38,43,1,34,6,7,39,54,55,54,51,50,23,22,23,22,
21,20,7,6,7,6,7,23,22,23,22,23,22,21,20,6,35,34,
39,38,138,117,29,120,63,103,75,73,29,26,40,43,34,40,47,57,
72,73,59,61,72,38,65,17,58,96,24,100,41,79,77,99,78,73,
67,51,45,32,23,45,42,40,84,20,59,37,25,25,226,164,101,101,
102,195,38,54,66,55,54,91,121,41,37,25,27,10,13,125,29,30,
73,51,49,26,66,47,52,84,53,52,35,33,67,60,51,70,38,23,
22,20,13,42,3,55,34,49,47,130,145,190,61,61,0,0,0,1,
0,138,255,227,4,30,4,74,0,64,0,0,63,1,30,1,51,50,
55,54,53,52,39,38,39,38,39,38,43,1,53,51,50,55,54,53,
52,39,38,43,1,34,6,7,39,54,55,54,51,50,23,22,23,55,
19,7,3,7,20,7,6,7,6,7,23,22,23,22,23,22,21,20,
6,35,34,39,38,138,117,29,120,63,103,75,73,29,26,40,43,34,
40,47,57,72,73,59,61,72,38,65,17,58,96,24,100,41,79,77,
99,78,73,52,46,152,160,114,108,25,32,23,45,42,40,84,20,59,
37,25,25,226,164,101,101,102,195,38,54,66,55,54,91,121,41,37,
25,27,10,13,125,29,30,73,51,49,26,66,47,52,84,53,52,35,
24,53,88,254,70,54,1,30,14,68,38,23,22,20,13,42,3,55,
34,49,47,130,145,190,61,61,0,0,0,2,0,101,255,227,3,178,
4,74,0,39,0,73,0,0,37,38,39,38,53,52,55,54,55,54,
55,54,55,54,51,50,23,22,23,22,21,20,7,6,7,6,7,23,
22,23,22,23,22,21,20,6,43,2,34,1,38,39,38,35,34,6,
21,20,23,22,23,22,51,50,55,54,53,52,39,38,39,38,39,38,
43,1,53,51,50,55,54,53,52,1,68,106,58,59,20,20,40,41,
54,56,72,83,77,78,73,67,51,45,32,23,45,42,40,84,20,59,
37,25,25,226,160,4,1,127,1,50,17,25,61,69,128,180,88,52,
65,38,41,84,64,103,29,26,40,43,34,40,47,57,72,73,59,61,
47,77,128,130,155,84,83,82,70,72,52,55,29,34,35,33,67,60,
51,74,34,23,22,20,13,42,3,55,34,49,47,130,145,190,3,129,
19,21,50,240,181,195,118,70,28,13,36,76,88,121,41,37,25,27,
10,13,125,29,30,73,13,0,0,0,0,1,255,137,254,84,1,252,
4,49,0,34,0,0,3,55,31,4,50,61,1,35,53,51,17,51,
17,51,21,35,21,20,7,6,7,6,7,6,7,6,35,34,39,38,
39,38,119,107,15,16,19,22,26,102,170,170,152,168,168,23,22,35,
40,34,40,34,29,28,42,36,35,17,8,254,166,102,14,12,12,8,
3,123,170,142,3,163,252,93,142,139,63,52,50,32,36,18,21,9,
8,15,15,12,6,0,0,2,0,115,254,63,4,244,5,234,0,15,
0,98,0,0,1,20,23,22,51,50,55,54,53,52,39,38,35,34,
7,6,1,20,7,6,7,6,7,6,35,34,39,38,39,38,39,38,
39,51,30,1,51,50,54,61,2,6,7,6,7,6,7,6,35,34,
39,38,39,46,1,39,38,53,52,55,62,2,51,50,23,22,23,22,
23,22,23,17,52,55,54,55,54,55,54,55,54,51,50,23,22,23,
22,23,7,47,4,34,21,17,1,13,77,76,116,117,79,80,80,79,
117,116,76,77,2,180,35,34,58,56,74,70,79,91,78,80,50,49,
31,29,8,143,13,160,91,105,158,18,25,22,35,35,50,47,65,81,
69,66,46,44,64,13,14,23,22,94,154,102,62,50,53,32,38,21,
24,19,23,22,35,38,37,41,32,29,28,42,36,35,17,8,36,107,
15,16,18,22,27,102,2,27,199,118,116,116,118,197,198,116,115,114,
115,253,13,98,84,81,55,53,31,29,33,34,50,49,60,57,57,86,
118,146,134,33,184,42,38,34,32,32,18,17,32,31,55,53,148,80,
84,85,110,101,96,164,92,18,19,31,36,32,36,44,1,83,63,52,
50,32,35,19,21,9,8,15,15,12,6,34,102,14,12,12,8,3,
123,251,24,0,0,0,0,2,0,115,254,63,3,193,4,78,0,59,
0,75,0,0,5,20,7,6,7,6,7,6,35,34,39,38,39,38,
39,38,39,51,30,1,51,50,54,61,2,6,7,6,7,6,7,6,
35,34,39,38,39,46,1,39,38,53,52,55,62,2,51,50,23,22,
23,22,23,22,23,53,51,17,1,20,23,22,51,50,55,54,53,52,
39,38,35,34,7,6,3,193,35,34,58,56,74,70,79,91,78,80,
50,49,31,29,8,143,13,160,91,105,158,18,25,22,35,35,50,47,
65,81,69,66,46,44,64,13,14,23,22,94,154,102,62,50,53,32,
38,21,24,19,152,253,76,77,76,116,117,79,80,80,79,117,116,76,
77,18,98,84,81,55,53,31,29,33,34,50,49,60,57,57,86,118,
146,134,33,184,42,38,34,32,32,18,17,32,31,55,53,148,80,84,
85,110,101,96,164,92,18,19,31,36,32,36,44,187,251,207,2,27,
199,118,116,116,118,197,198,116,115,114,115,0,0,0,0,1,0,73,
255,235,3,132,4,67,0,69,0,0,5,34,39,38,39,38,39,38,
53,52,55,54,55,54,55,54,55,54,51,50,23,22,23,7,38,39,
38,35,34,7,6,7,6,7,6,21,20,23,22,23,22,23,22,51,
50,55,54,55,54,55,54,55,54,53,33,53,33,21,20,7,6,7,
6,7,6,7,14,1,43,1,1,255,104,83,86,53,55,28,29,16,
16,37,38,48,51,73,72,88,118,73,72,55,101,42,49,46,80,74,
63,60,41,38,21,21,21,22,37,38,57,55,76,46,54,49,14,43,
22,14,6,8,254,255,1,145,10,12,17,20,31,28,46,40,116,65,
2,21,46,48,76,79,98,101,107,79,74,75,75,78,52,56,34,34,
43,43,85,87,58,31,29,42,40,71,65,81,80,38,82,79,82,63,
65,32,31,13,12,25,41,75,46,27,37,29,151,111,57,51,61,46,
54,44,40,39,34,40,0,3,0,82,253,255,3,199,4,49,0,48,
0,50,0,73,0,0,1,48,21,6,7,6,7,6,43,1,38,35,
34,38,34,39,38,39,46,1,39,38,39,38,39,38,39,38,39,38,
39,38,53,52,55,54,61,1,54,55,1,51,9,1,51,1,22,23,
22,7,21,39,38,39,7,20,6,21,20,23,22,23,22,23,22,23,
51,50,54,55,54,55,53,48,2,205,3,18,21,41,40,53,5,3,
5,3,8,2,14,11,6,2,13,4,11,8,12,7,14,5,12,4,
9,5,19,1,3,1,82,254,148,160,1,24,1,31,158,254,145,98,
15,4,119,1,8,54,55,1,11,6,8,9,5,6,14,3,15,20,
8,11,2,255,0,11,89,48,55,27,27,1,1,2,2,2,1,4,
2,5,5,8,6,12,7,17,7,16,14,51,67,18,12,12,2,1,
33,205,4,49,252,146,3,110,251,214,198,44,16,16,1,4,34,88,
127,2,9,3,46,30,15,7,8,1,1,2,12,21,27,66,1,0,
0,2,0,32,255,255,2,84,4,69,0,11,0,37,0,0,1,6,
21,20,23,22,23,50,55,54,53,52,55,22,23,22,21,6,7,6,
7,6,35,34,38,35,38,39,38,53,55,54,55,3,51,27,1,51,
1,67,56,10,13,36,33,12,14,9,95,11,5,3,19,22,39,42,
50,2,10,3,111,39,18,3,2,79,199,113,168,172,111,1,114,129,
11,49,27,32,3,33,36,51,15,252,191,37,17,16,85,51,56,26,
28,1,7,105,48,70,44,35,198,2,74,253,242,2,14,0,0,1,
0,129,254,158,3,188,4,78,0,33,0,0,1,51,17,35,17,14,
1,35,34,39,38,39,38,39,38,53,17,51,17,20,23,22,23,30,
1,51,50,55,54,55,54,55,54,53,3,36,152,152,29,162,114,83,
66,67,49,52,26,27,151,14,15,30,30,102,68,69,50,55,29,31,
15,16,4,78,250,80,2,52,90,120,33,34,66,71,104,108,145,2,
29,253,227,95,70,76,58,59,66,34,37,56,58,77,80,83,0,1,
0,126,0,0,3,188,5,242,0,57,0,0,33,35,3,53,52,55,
54,55,54,55,54,51,50,22,23,22,23,22,23,35,46,1,35,34,
7,6,7,17,54,55,54,51,50,23,22,23,22,23,22,21,17,35,
17,52,39,38,39,46,1,35,34,7,6,7,6,7,6,21,1,25,
152,3,35,34,59,53,76,72,77,94,152,52,50,31,29,8,143,14,
158,92,104,79,65,12,29,80,81,115,82,66,69,48,50,27,28,151,
15,16,28,30,102,68,70,50,51,31,34,14,15,4,49,18,98,84,
81,56,50,32,30,64,52,50,60,57,57,88,116,73,59,98,254,248,
91,59,60,33,34,66,69,106,112,141,253,227,2,29,90,75,79,55,
59,66,34,35,58,65,70,75,88,0,0,0,0,1,0,126,254,85,
3,188,5,242,0,84,0,0,33,35,3,53,52,55,54,55,54,55,
54,51,50,22,23,22,23,22,23,35,46,1,35,34,7,6,7,17,
54,55,54,51,50,23,22,23,22,23,22,21,17,29,1,20,7,6,
7,6,7,6,7,6,35,34,39,38,39,38,39,55,31,4,50,61,
1,17,51,52,39,38,39,46,1,35,34,7,6,7,6,7,6,21,
1,25,152,3,35,34,59,53,76,72,77,94,152,52,50,31,29,8,
143,14,158,92,104,79,65,12,29,80,81,115,82,66,69,48,50,27,
28,23,24,33,35,39,40,34,33,24,42,36,32,20,12,32,107,15,
16,19,22,26,102,1,15,16,28,30,102,68,70,50,51,31,34,14,
15,4,49,18,98,84,81,56,50,32,30,64,52,50,60,57,57,88,
116,73,59,98,254,248,91,59,60,33,34,66,69,106,112,141,253,228,
1,138,62,52,54,30,32,20,21,9,9,15,13,15,9,30,102,13,
14,11,8,3,123,170,2,28,90,75,79,55,59,66,34,35,58,65,
70,75,88,0,0,2,0,0,0,0,1,174,5,147,0,17,0,29,
0,0,19,52,54,51,50,23,22,23,22,21,20,6,35,34,39,38,
39,38,19,51,17,51,21,35,17,35,17,35,53,51,121,56,38,33,
26,25,8,2,56,38,33,26,25,8,2,19,151,139,139,151,140,140,
5,53,38,56,21,21,33,8,11,38,56,21,21,33,16,254,255,254,
151,142,253,198,2,58,142,0,0,0,0,1,0,52,0,0,2,86,
4,143,0,29,0,0,19,35,53,51,21,17,20,51,63,4,23,6,
7,6,7,6,35,34,39,38,39,38,39,38,39,38,53,135,83,239,
102,27,22,18,16,15,107,36,8,17,35,36,42,28,29,32,41,37,
38,36,23,24,4,1,142,142,253,1,123,3,8,12,12,14,102,34,
6,12,15,15,8,9,21,19,35,33,49,51,64,0,0,0,0,1,
0,61,0,0,1,144,4,50,0,11,0,0,1,17,51,21,33,53,
51,17,35,53,33,21,1,55,89,254,173,93,93,1,83,3,164,252,
234,142,142,3,22,142,142,0,0,0,0,1,0,7,255,227,2,132,
5,43,0,46,0,0,19,51,17,31,1,50,55,54,63,1,21,6,
7,6,7,6,35,34,39,17,20,59,1,21,35,34,39,38,53,17,
47,1,34,7,6,7,6,7,53,54,55,54,55,54,51,50,23,244,
151,3,58,29,37,36,26,60,50,10,27,33,34,34,33,28,117,70,
70,149,59,60,8,48,36,33,31,26,13,42,33,18,25,35,37,35,
27,27,5,43,253,179,2,16,16,15,21,46,145,38,9,23,14,15,
14,254,143,117,127,55,56,129,1,233,6,16,15,14,23,12,33,146,
25,16,22,16,17,15,0,2,255,88,255,227,2,195,5,174,0,38,
0,49,0,0,37,20,23,22,51,21,34,38,39,38,53,17,6,7,
6,35,34,39,38,39,38,61,1,52,55,54,55,17,51,17,54,55,
54,55,23,6,7,6,7,39,17,6,7,20,6,21,20,23,22,51,
1,21,3,16,100,113,130,20,7,29,36,24,11,45,30,56,30,33,
16,60,218,151,41,45,109,163,72,205,83,55,87,151,142,19,1,39,
37,35,207,17,13,75,131,74,89,35,34,1,3,8,5,2,15,29,
50,54,80,7,15,55,212,47,1,187,252,230,29,38,95,195,96,225,
59,40,58,43,1,40,42,182,2,6,2,40,15,14,0,1,1,7,
254,104,2,211,5,176,0,24,0,0,1,51,19,20,22,51,50,55,
54,55,54,55,23,6,7,6,35,34,39,38,39,38,39,38,53,1,
8,152,1,58,39,27,21,19,10,11,12,109,47,34,37,60,38,49,
52,40,44,30,29,5,176,249,160,45,52,8,7,10,11,16,105,44,
18,20,20,21,32,35,52,51,62,0,0,0,0,2,0,110,254,116,
4,76,5,174,0,12,0,51,0,0,37,20,23,22,51,21,34,38,
39,38,53,17,51,19,1,33,53,33,1,22,23,22,23,22,23,22,
23,22,21,20,7,6,35,34,39,38,39,55,22,23,22,51,50,55,
54,53,52,39,38,39,38,39,1,21,3,16,100,113,130,20,7,151,
231,1,84,253,244,3,8,254,142,36,17,33,47,26,55,38,26,25,
141,140,208,125,127,126,56,155,37,80,79,83,141,95,96,28,28,48,
49,57,207,17,13,75,131,74,89,35,34,4,227,251,190,2,57,141,
253,145,12,11,21,22,12,67,46,66,65,72,196,129,128,76,75,130,
47,81,53,52,85,86,140,74,59,58,38,39,19,0,0,1,0,129,
0,0,5,147,4,78,0,53,0,0,1,51,17,20,23,22,23,30,
2,51,50,25,1,51,17,35,53,14,1,7,6,7,6,7,6,7,
6,35,34,39,38,39,14,1,35,34,38,53,17,51,17,20,23,22,
23,22,23,30,2,51,50,17,2,190,152,4,5,12,13,44,72,53,
218,152,152,7,22,2,13,23,25,23,22,40,36,48,116,74,75,27,
26,150,109,158,150,151,3,3,7,8,13,15,42,66,43,222,4,78,
253,221,78,49,61,51,55,78,46,1,159,2,38,251,207,182,15,43,
3,25,31,33,17,17,14,13,68,69,105,104,138,240,209,2,141,253,
225,59,47,54,43,56,30,36,60,30,1,153,0,1,0,129,254,131,
5,147,4,78,0,54,0,0,1,51,17,20,23,22,23,30,2,51,
50,25,1,51,17,35,17,53,14,1,7,6,7,6,7,6,7,6,
35,34,39,38,39,14,1,35,34,38,53,17,51,17,20,23,22,23,
22,23,30,2,51,50,17,2,190,152,4,5,12,13,44,72,53,218,
152,152,7,22,2,13,23,25,23,22,40,36,48,116,74,75,27,26,
150,109,158,150,151,3,3,7,8,13,15,42,66,43,222,4,78,253,
221,78,49,61,51,55,78,46,1,159,2,38,250,53,1,154,182,15,
43,3,25,31,33,17,17,14,13,68,69,105,104,138,240,209,2,141,
253,225,59,47,54,43,56,30,36,60,30,1,153,0,0,1,0,129,
254,84,5,147,4,78,0,78,0,0,33,35,17,52,39,38,39,46,
2,35,34,25,1,35,17,51,21,62,1,55,54,55,54,55,54,55,
54,51,50,23,22,23,62,1,51,50,22,21,17,21,20,7,6,7,
6,7,6,7,6,35,34,39,38,39,38,39,55,31,4,50,61,1,
19,52,39,38,39,38,39,46,2,35,34,17,3,86,152,4,5,12,
13,44,72,53,218,152,152,7,22,2,13,23,25,23,22,40,36,48,
116,74,75,27,26,150,109,158,150,23,22,35,38,37,41,32,29,28,
42,36,35,17,8,36,107,15,16,18,22,27,102,1,3,3,7,8,
13,15,42,66,43,222,2,35,78,49,61,51,55,78,46,254,97,253,
218,4,49,182,15,42,4,25,31,33,17,17,14,13,68,69,105,104,
138,240,209,253,115,139,63,52,50,32,35,19,21,9,8,15,15,12,
6,34,102,14,12,12,8,3,123,170,2,31,59,47,54,43,56,30,
36,60,30,254,103,0,0,0,0,1,0,18,254,62,4,73,4,78,
0,53,0,0,33,35,17,51,21,62,1,51,50,23,22,23,22,23,
22,21,17,35,17,52,39,38,39,38,39,38,35,34,7,6,7,6,
7,6,21,17,21,23,21,20,7,6,7,6,7,6,43,1,54,55,
50,54,61,1,1,16,2,152,29,162,115,82,66,67,49,52,26,27,
151,14,16,28,30,52,51,67,70,50,53,30,32,15,16,2,36,20,
72,63,67,80,64,4,1,3,102,148,4,49,181,90,120,33,34,66,
71,104,108,145,253,227,2,29,95,70,79,55,58,34,33,34,36,57,
62,73,80,83,254,37,65,1,9,58,133,69,68,59,24,29,10,124,
148,134,33,0,0,0,0,1,0,108,254,63,4,166,4,78,0,54,
0,0,37,51,29,1,20,23,22,51,22,23,48,35,34,39,38,39,
38,39,38,53,48,53,17,52,39,38,39,46,1,35,34,7,6,7,
6,7,6,21,17,35,17,51,21,54,55,54,51,50,23,22,23,22,
23,22,21,3,167,1,73,74,103,3,1,4,65,80,65,65,72,20,
35,15,16,28,30,102,68,70,50,53,30,32,15,15,152,152,29,80,
81,115,82,66,69,48,50,27,28,66,66,33,135,73,74,124,10,29,
24,60,68,68,129,62,9,2,29,90,75,79,55,59,66,34,36,57,
62,73,75,88,253,228,4,49,181,91,59,60,33,34,66,69,106,112,
141,0,0,0,0,1,0,105,0,0,3,168,4,39,0,9,0,0,
51,17,51,1,17,51,17,35,1,17,105,135,2,29,155,147,253,223,
4,39,252,176,3,80,251,217,3,101,252,155,0,3,0,98,255,227,
3,170,4,70,0,12,0,22,0,44,0,0,36,50,55,54,55,54,
63,1,33,22,23,22,23,3,33,46,1,35,34,7,6,7,6,18,
32,23,22,23,22,21,20,7,6,7,6,32,39,38,39,38,53,52,
55,54,55,1,186,152,60,58,31,30,6,2,253,244,7,31,29,60,
127,2,10,9,140,112,76,60,58,31,30,126,1,2,97,95,50,49,
48,47,99,97,254,254,97,99,47,48,49,50,95,106,54,53,79,78,
90,9,95,81,78,55,1,188,146,208,54,53,79,78,1,144,74,73,
126,123,161,159,127,124,79,77,77,79,124,127,159,161,123,126,73,0,
0,0,0,3,0,102,255,227,5,118,4,70,0,25,0,74,0,82,
0,0,1,20,23,22,23,22,23,22,50,63,1,38,39,38,53,52,
55,54,55,38,35,34,7,6,7,6,7,52,55,54,55,54,55,54,
51,50,23,54,51,50,23,22,23,30,1,21,20,22,29,1,33,22,
23,22,23,22,51,50,55,54,55,23,6,7,6,35,34,39,6,35,
34,39,38,39,38,37,33,46,1,35,34,14,1,1,0,16,17,32,
32,57,55,148,55,7,31,24,49,49,25,28,53,81,99,64,65,27,
28,154,28,30,52,55,83,84,105,133,98,94,127,95,81,79,50,49,
52,1,253,100,7,31,30,58,58,77,74,69,70,32,133,52,103,106,
117,124,95,98,135,138,101,102,48,48,2,116,2,10,9,140,112,75,
120,60,2,25,92,74,79,58,59,35,34,34,4,46,61,130,156,161,
123,62,40,35,58,59,91,95,118,121,99,104,73,77,41,42,70,70,
46,45,75,74,190,99,1,32,14,49,95,81,79,54,54,38,39,60,
55,100,58,59,71,71,77,78,125,126,227,146,208,108,156,0,0,2,
0,55,0,0,4,139,4,72,0,36,0,72,0,0,37,6,7,6,
7,6,7,6,35,34,39,38,53,52,55,54,55,54,51,33,50,23,
22,23,22,21,20,7,6,35,34,39,38,39,38,39,38,3,34,14,
1,7,21,22,23,22,23,50,55,54,55,54,53,17,51,17,20,23,
22,23,22,51,54,55,54,55,53,38,39,38,39,38,35,2,97,10,
15,25,33,32,51,47,55,141,96,49,49,50,95,97,129,1,12,129,
97,95,50,49,48,96,142,54,47,51,32,33,25,17,143,75,120,60,
6,7,31,30,63,56,33,66,38,9,125,9,38,65,33,56,63,30,
31,7,6,30,31,58,60,76,221,30,26,42,36,35,27,25,253,130,
156,161,123,126,73,74,74,73,126,123,161,159,127,253,25,27,35,36,
42,30,2,253,108,156,90,135,95,81,79,54,24,42,115,36,37,1,
40,254,216,37,36,116,41,24,54,79,81,95,135,90,78,79,53,54,
0,0,0,3,0,100,254,116,4,204,5,176,0,8,0,19,0,54,
0,0,1,6,7,6,21,20,23,22,23,1,38,39,17,54,55,54,
55,48,53,52,1,33,21,35,21,22,23,22,23,22,23,48,21,20,
7,6,7,21,51,21,33,53,51,53,38,39,38,53,39,52,55,54,
55,53,35,2,50,113,86,111,134,80,96,1,136,76,139,105,109,132,
1,253,12,2,145,246,166,91,72,50,100,8,158,141,188,246,253,111,
232,170,126,164,2,166,130,166,232,3,209,9,86,116,222,186,134,80,
36,2,253,75,29,252,147,22,103,135,190,5,187,2,202,142,218,21,
83,53,69,108,227,21,215,155,139,21,238,142,142,243,28,127,164,236,
2,234,166,130,22,216,0,0,0,1,0,129,0,0,2,225,4,78,
0,19,0,0,63,1,22,51,50,55,54,55,54,53,17,51,17,35,
53,6,7,6,35,34,129,80,49,62,88,62,61,27,27,152,152,29,
81,83,112,82,36,131,30,60,59,94,93,119,2,28,251,207,181,91,
59,60,0,0,0,1,0,129,0,0,2,225,5,234,0,19,0,0,
63,1,22,51,50,55,54,55,54,53,17,51,17,35,53,6,7,6,
35,34,129,80,49,62,88,62,61,27,27,152,152,29,81,83,112,82,
36,131,30,60,59,94,93,119,3,184,250,51,181,91,59,60,0,0,
0,1,0,129,254,85,4,21,4,70,0,42,0,0,63,1,22,51,
50,55,54,55,54,53,17,51,19,20,51,63,4,23,6,7,6,7,
6,35,34,39,38,39,38,39,38,39,38,53,3,6,7,6,35,34,
129,80,49,62,88,62,57,31,27,152,1,102,26,22,19,16,15,107,
32,12,20,32,36,42,24,33,34,40,39,35,33,24,23,1,29,81,
83,112,82,36,131,30,60,55,98,81,131,2,20,251,17,123,3,8,
11,14,13,102,30,9,15,13,15,9,9,21,20,32,30,54,52,62,
1,92,91,59,60,0,0,1,0,129,254,131,2,225,4,78,0,19,
0,0,1,7,38,35,34,7,6,7,6,21,17,35,17,51,21,54,
55,54,51,50,2,225,80,49,62,88,62,61,27,27,152,152,29,81,
83,112,82,4,42,131,30,60,59,94,93,119,252,103,5,174,181,91,
59,60,0,1,0,129,254,84,2,225,4,79,0,46,0,0,1,7,
38,35,34,7,6,7,6,21,25,1,21,20,51,63,4,23,6,7,
6,7,6,35,34,39,38,39,38,39,38,39,38,61,1,25,1,51,
21,54,55,54,51,50,2,225,80,49,62,88,62,60,28,27,102,27,
22,18,16,15,107,36,8,17,35,36,42,28,29,32,41,37,38,35,
22,23,152,29,81,84,111,82,4,43,131,30,60,58,95,87,125,254,
243,254,240,170,123,3,8,12,12,14,102,34,6,12,15,15,8,9,
21,19,35,32,50,52,63,139,1,16,3,34,181,90,59,61,0,1,
0,15,0,0,2,86,4,143,0,30,0,0,55,19,52,55,54,55,
54,55,54,55,54,51,50,23,22,23,22,23,7,47,4,34,21,17,
51,21,33,53,135,1,24,25,34,33,42,41,32,33,24,42,36,32,
20,12,32,107,15,16,18,22,27,102,120,254,116,142,2,224,63,51,
53,31,30,22,21,9,9,15,13,15,9,30,102,13,14,11,8,3,
123,253,1,142,142,0,0,0,0,1,0,15,0,0,2,86,4,143,
0,30,0,0,37,51,21,33,53,51,17,52,35,15,4,39,54,55,
54,55,54,51,50,23,22,23,22,23,22,23,22,21,1,222,120,254,
116,120,102,26,22,19,16,15,107,32,12,20,32,36,42,24,33,34,
40,39,35,32,26,25,142,142,142,2,255,123,3,8,11,14,13,102,
30,9,15,13,15,9,9,21,20,32,30,54,53,61,0,2,0,98,
0,0,3,78,4,39,0,14,0,30,0,0,19,51,50,55,54,55,
54,55,62,1,53,52,38,43,1,9,1,35,17,35,17,59,1,50,
22,21,20,7,6,7,1,244,98,64,57,51,31,29,19,18,12,134,
147,98,1,169,254,199,112,146,146,150,177,224,72,71,123,1,61,2,
53,13,12,20,19,28,27,52,29,91,104,252,64,1,205,254,51,4,
39,158,140,108,81,80,23,254,39,0,0,2,0,98,0,0,3,78,
4,39,0,15,0,32,0,0,19,17,51,50,55,54,53,52,38,39,
38,39,38,39,38,35,1,51,1,22,23,22,21,20,7,6,43,2,
17,51,17,51,244,98,146,68,67,12,18,19,29,31,51,53,68,1,
71,177,254,195,124,70,72,112,113,176,150,146,146,112,1,242,254,117,
53,52,91,29,52,27,28,19,20,12,12,2,53,254,39,23,79,81,
108,140,79,80,4,39,254,52,0,0,0,1,0,96,254,84,3,72,
4,74,0,101,0,0,1,38,39,38,39,38,39,38,39,38,53,52,
55,54,55,50,22,23,22,23,22,23,7,38,35,34,6,21,20,23,
22,23,22,23,22,23,22,23,30,2,31,9,20,7,6,35,34,39,
29,1,20,51,63,4,23,6,7,6,7,6,35,34,39,38,39,38,
39,38,39,38,61,2,39,55,22,23,22,51,50,55,54,53,52,39,
38,39,38,39,38,1,213,62,39,42,50,47,34,34,19,21,100,101,
147,82,130,41,44,21,24,12,146,54,152,81,116,14,15,23,26,22,
29,23,28,17,2,11,20,10,49,49,50,45,43,36,30,17,7,108,
107,152,133,88,102,26,22,19,16,15,107,36,8,17,35,36,42,28,
29,34,40,34,40,35,22,23,4,147,30,52,53,91,101,58,58,19,
21,34,39,27,30,1,221,20,16,17,28,26,36,35,46,49,59,137,
75,76,1,44,38,41,31,36,37,30,122,78,72,38,28,29,19,21,
12,16,7,8,8,1,3,7,4,18,19,23,27,33,39,47,54,65,
137,90,89,51,22,170,123,3,8,12,12,14,102,34,6,12,15,15,
8,9,21,18,36,32,50,52,63,139,206,11,28,67,36,36,48,48,
85,41,31,34,21,25,11,13,0,0,0,1,255,214,254,104,2,211,
5,201,0,44,0,0,1,52,55,54,55,54,55,54,51,50,23,22,
23,7,38,39,38,39,38,35,34,6,21,19,20,6,7,6,7,6,
35,34,38,39,55,22,23,22,23,22,51,50,55,54,53,1,7,29,
30,44,43,49,47,40,58,39,37,44,109,12,11,10,19,21,27,39,
58,1,60,43,40,52,49,38,59,74,45,109,12,11,9,20,21,27,
40,29,28,4,184,62,51,52,35,34,20,19,21,20,41,105,16,11,
9,8,8,52,45,250,152,60,106,34,32,21,20,40,42,105,16,11,
10,7,8,26,25,46,0,1,255,137,254,84,1,252,5,77,0,56,
0,0,3,55,31,4,50,61,1,35,53,51,17,38,53,52,55,54,
55,54,55,54,63,1,23,7,6,7,6,7,6,21,20,23,22,7,
17,51,21,35,21,20,7,6,7,6,7,6,7,6,35,34,39,38,
39,38,119,107,15,16,19,22,26,102,170,170,26,14,14,27,39,10,
19,39,47,43,28,4,24,21,8,9,2,19,1,168,168,23,22,35,
40,34,40,34,29,28,42,36,35,17,8,254,166,102,14,12,12,8,
3,123,170,142,3,163,24,43,30,30,29,23,33,7,14,23,28,125,
22,3,20,18,13,15,13,7,8,39,1,252,93,142,139,63,52,50,
32,36,18,21,9,8,15,15,12,6,0,0,0,1,255,214,254,104,
2,211,4,53,0,43,0,0,1,3,20,22,51,50,55,54,55,54,
55,23,6,7,6,35,34,39,38,39,38,39,38,53,19,52,39,38,
35,34,7,6,7,6,7,39,62,1,51,50,23,30,2,1,162,1,
58,39,27,21,19,10,11,12,109,47,34,37,60,38,49,52,40,44,
30,29,1,28,29,40,27,21,19,10,11,12,109,43,78,57,40,47,
49,86,60,3,36,252,44,45,52,8,7,10,11,16,105,44,18,20,
20,21,32,35,52,51,62,3,212,46,25,26,8,8,9,11,16,105,
40,42,19,20,68,106,0,0,0,2,255,86,254,104,2,211,5,201,
0,55,0,72,0,0,1,52,55,54,55,54,55,54,51,50,23,22,
23,7,38,39,38,39,38,35,34,6,21,19,50,54,51,50,31,1,
38,35,21,20,6,7,6,7,6,35,34,39,38,39,38,39,38,53,
52,55,54,55,54,55,54,55,3,30,1,51,50,55,54,61,1,6,
7,6,7,6,21,20,23,1,7,29,30,44,43,49,47,40,58,39,
37,44,109,12,11,10,19,21,27,39,58,1,8,35,10,95,134,17,
187,112,60,43,40,52,49,38,59,37,85,43,59,17,6,11,15,53,
61,62,75,157,190,24,42,27,40,29,28,118,88,61,30,8,27,4,
184,62,51,52,35,34,20,19,21,20,41,105,16,11,9,8,8,52,
45,251,185,1,6,119,16,181,60,106,34,32,21,20,20,46,41,58,
65,24,24,33,36,46,41,47,19,23,26,254,117,3,16,26,25,46,
213,15,40,31,65,16,17,27,13,0,0,0,0,1,0,102,0,0,
2,80,5,72,0,19,0,0,1,51,21,35,21,35,53,35,53,51,
17,52,43,1,53,51,50,23,22,21,1,194,142,142,151,197,197,117,
70,70,147,61,60,1,129,135,250,250,135,2,211,117,127,56,56,128,
0,1,0,102,254,116,2,174,5,43,0,19,0,0,19,35,53,51,
53,51,21,51,21,35,17,20,59,1,21,35,34,39,38,53,244,142,
142,151,197,197,117,174,174,147,61,60,3,170,135,250,250,135,251,190,
117,127,56,56,128,0,0,2,0,50,255,227,4,0,4,49,0,28,
0,47,0,0,1,51,17,51,21,35,17,35,53,6,7,6,35,34,
39,38,39,38,39,38,61,1,35,53,51,17,51,17,33,21,33,21,
20,23,22,23,22,23,22,51,50,55,54,55,54,55,54,53,3,26,
152,78,78,152,29,81,82,114,82,66,67,49,52,26,28,68,68,151,
2,13,253,243,15,16,28,30,52,51,67,70,50,52,31,33,14,16,
4,49,254,151,142,253,198,181,89,60,61,33,34,66,70,106,112,140,
38,142,1,105,254,151,142,38,90,75,79,55,58,34,33,34,35,59,
62,72,80,83,0,0,0,1,0,50,255,227,3,236,4,68,0,50,
0,0,19,35,53,33,21,6,7,6,7,6,21,20,23,22,23,30,
1,51,50,54,55,54,55,54,53,52,39,38,47,1,53,33,21,35,
22,23,22,21,20,6,7,6,32,38,39,38,53,52,55,54,55,213,
163,1,126,32,36,65,27,28,16,16,34,33,110,75,73,110,33,34,
16,16,28,35,57,68,1,126,158,41,28,49,96,100,101,254,234,202,
48,49,29,30,52,3,182,142,142,17,33,59,91,95,118,92,74,76,
61,60,68,68,60,61,76,74,92,118,95,115,35,41,142,142,51,70,
127,156,161,252,76,77,154,126,129,157,118,102,104,73,0,1,0,31,
255,228,3,181,4,143,0,48,0,0,5,39,38,39,38,39,38,39,
38,53,17,39,35,53,51,21,7,17,20,23,22,23,22,23,22,23,
54,55,54,55,54,55,53,46,2,35,53,50,23,22,23,22,21,20,
7,6,7,6,2,16,24,60,84,86,50,52,26,28,4,83,239,1,
15,16,28,30,52,50,64,74,61,63,30,31,7,6,60,120,76,129,
97,96,50,49,49,48,97,97,28,1,1,31,33,66,70,106,112,140,
1,228,9,142,142,1,254,20,90,75,79,55,58,34,31,2,2,52,
54,79,81,95,135,90,156,108,136,74,74,125,123,161,156,130,126,78,
77,0,0,0,0,1,0,82,0,0,3,199,4,49,0,6,0,0,
1,51,1,35,9,1,35,1,190,152,1,113,158,254,225,254,232,160,
4,49,251,207,3,110,252,146,0,1,0,68,0,0,5,49,4,49,
0,12,0,0,37,19,51,1,35,11,1,35,11,1,35,1,51,2,
186,222,122,1,31,153,193,209,151,209,193,153,1,30,117,211,3,94,
251,207,3,55,252,209,3,47,252,201,4,49,0,0,0,1,0,82,
255,109,3,199,5,235,0,8,0,0,1,51,1,35,9,1,35,1,
23,2,88,3,1,108,160,254,232,254,225,158,2,57,159,3,158,251,
207,3,110,252,146,6,126,1,0,1,0,89,0,0,3,182,4,50,
0,8,0,0,19,51,9,1,51,1,17,35,17,89,146,1,29,1,
28,146,254,154,148,4,50,253,168,2,88,253,60,254,146,1,110,0,
0,0,0,1,0,90,254,84,4,160,4,49,0,32,0,0,1,6,
7,6,7,6,35,34,39,38,39,38,39,38,39,38,61,1,33,1,
33,53,33,1,33,17,20,51,63,4,4,160,36,8,17,35,36,42,
28,29,32,41,37,38,35,22,23,253,133,2,53,253,244,3,8,253,
203,2,23,102,27,22,18,16,15,254,166,34,6,12,15,15,8,9,
21,19,35,32,50,52,63,139,3,164,141,252,92,254,201,123,3,8,
12,12,14,0,0,0,0,2,0,90,255,108,4,66,4,49,0,31,
0,46,0,0,33,6,7,39,55,35,1,33,53,33,1,51,54,55,
54,55,54,55,54,51,50,23,22,23,22,21,48,21,20,7,6,35,
37,33,48,51,50,55,48,53,52,39,38,35,7,6,7,1,160,52,
77,72,48,173,2,53,253,244,3,8,253,203,58,64,39,155,69,57,
77,24,11,45,30,56,30,33,16,48,93,254,137,1,119,5,32,2,
53,37,35,60,116,112,56,92,96,52,3,164,141,252,92,62,29,111,
37,31,9,2,15,29,50,54,80,7,32,38,117,141,69,2,47,21,
14,10,44,98,0,0,0,1,2,189,254,116,6,155,4,50,0,38,
0,0,9,1,33,53,33,1,22,23,22,23,22,23,22,23,22,21,
20,7,6,35,34,39,38,39,55,22,23,22,51,50,55,54,53,52,
39,38,39,38,39,4,75,1,84,253,244,3,8,254,142,36,17,33,
47,25,55,38,26,26,141,140,208,125,127,126,56,155,37,80,79,83,
140,95,97,29,28,48,51,53,1,108,2,57,141,253,145,12,11,21,
22,12,67,46,66,67,70,196,129,128,76,75,130,47,81,53,52,85,
86,140,72,61,58,38,40,18,0,2,0,36,254,28,3,152,4,50,
0,55,0,70,0,0,9,1,33,53,33,1,22,23,22,23,22,23,
22,23,22,21,20,7,22,23,7,38,39,6,35,34,39,38,39,38,
53,48,53,52,55,54,55,54,51,50,23,22,23,22,23,30,1,23,
54,53,52,39,38,39,38,39,1,22,51,50,55,38,39,38,35,34,
7,6,7,21,20,1,72,1,84,253,244,3,8,254,142,36,17,33,
47,26,55,38,26,25,98,67,89,72,86,78,131,180,155,97,40,20,
16,33,33,53,30,45,11,24,77,57,86,138,3,14,4,52,28,28,
48,49,57,254,228,79,83,116,87,114,114,32,27,34,39,36,2,1,
108,2,57,141,253,145,12,11,21,22,12,67,46,66,65,72,164,116,
67,98,96,103,83,98,76,34,67,58,12,7,80,54,53,26,15,2,
9,31,45,103,2,11,3,73,104,74,59,58,38,39,19,253,222,52,
60,99,43,10,14,14,51,1,26,0,0,0,0,1,0,57,0,0,
3,164,5,217,0,51,0,0,1,17,35,17,52,55,54,55,54,55,
54,63,12,52,39,38,35,34,14,1,21,39,54,55,54,51,50,23,
30,2,21,20,7,6,7,6,15,3,2,61,157,11,11,14,15,27,
31,16,55,52,20,20,18,16,15,13,10,8,4,2,77,75,126,83,
138,72,146,20,121,122,169,88,76,79,124,76,37,41,58,26,36,62,
50,36,1,245,254,11,1,249,43,42,41,26,27,30,35,13,46,44,
18,18,18,20,20,22,26,29,33,38,125,69,68,90,124,57,25,165,
111,111,25,26,94,158,96,97,73,80,57,26,27,46,46,62,0,1,
0,57,0,0,3,164,5,217,0,54,0,0,1,47,3,38,39,38,
39,38,53,52,54,55,54,55,54,51,50,23,22,23,7,52,39,38,
39,38,35,34,7,6,21,31,11,22,23,22,23,22,23,22,21,17,
35,1,160,12,38,49,61,40,23,58,41,37,74,64,62,79,76,88,
170,121,121,20,146,36,36,70,69,82,126,75,77,2,5,8,10,12,
15,17,18,19,20,53,54,16,31,24,17,16,10,11,157,1,245,83,
62,46,46,30,23,57,80,73,97,98,154,49,47,26,25,111,111,165,
25,57,62,61,46,45,68,69,125,38,33,29,26,22,20,20,18,18,
18,44,46,13,35,27,30,29,38,42,43,254,7,0,0,1,0,57,
0,0,3,164,5,217,0,52,0,0,1,31,3,22,23,22,23,22,
21,20,14,1,7,6,35,34,39,38,39,55,20,23,30,1,51,50,
55,54,53,47,11,38,39,38,39,38,39,38,53,17,51,2,61,13,
36,50,62,40,22,59,40,37,76,124,79,76,88,168,123,121,20,146,
36,36,138,83,124,77,77,2,4,8,10,13,15,16,18,20,20,52,
55,20,27,26,16,14,11,11,157,3,228,84,61,45,48,30,22,57,
79,73,98,96,158,94,26,25,112,111,164,25,58,61,62,90,69,69,
124,38,33,29,25,23,21,18,19,18,18,45,45,17,30,28,30,26,
41,42,43,1,249,0,0,0,0,1,0,101,254,107,3,133,4,70,
0,64,0,0,1,38,39,38,35,34,7,6,7,20,7,6,21,20,
23,22,23,22,51,50,55,54,55,54,55,54,55,23,6,7,6,7,
6,7,6,35,34,39,38,39,38,39,48,53,60,1,38,52,53,52,
55,54,55,54,55,54,55,54,55,54,51,50,23,22,23,3,2,18,
60,61,69,128,90,88,1,1,5,5,6,82,88,130,43,39,43,24,
25,18,16,11,122,24,32,25,50,41,55,53,61,132,104,106,58,47,
11,1,1,5,14,20,40,41,54,56,72,74,84,115,85,86,53,3,
41,49,50,50,120,116,142,42,1,13,96,133,159,178,110,118,18,20,
24,25,26,24,21,77,40,37,29,39,32,20,19,76,77,128,105,151,
18,17,68,91,137,74,29,14,65,59,82,70,72,52,55,29,30,61,
62,96,0,3,0,92,255,227,4,238,5,215,0,37,0,77,0,95,
0,0,1,52,39,38,39,38,39,38,39,38,35,34,6,7,6,7,
14,1,21,20,23,22,23,22,23,22,23,22,51,50,55,54,55,54,
55,54,55,54,37,52,55,54,55,54,55,54,55,54,51,50,23,22,
23,22,23,22,23,22,21,20,7,6,7,6,7,6,7,6,35,34,
39,38,39,38,39,38,39,38,37,20,7,6,34,39,38,53,52,55,
62,1,51,50,23,22,23,22,4,72,23,17,32,29,48,46,70,67,
88,94,146,47,47,30,30,24,22,15,33,29,48,46,71,70,84,94,
73,75,45,45,32,33,11,12,252,20,19,20,44,43,67,64,103,101,
123,122,98,100,66,65,45,44,22,24,20,20,44,47,63,67,101,102,
122,120,99,98,68,65,45,43,23,23,3,2,54,55,150,55,54,24,
24,90,46,46,44,43,26,25,2,213,115,112,79,73,67,60,57,34,
32,80,64,63,85,84,168,85,114,104,75,74,65,59,57,32,32,39,
40,59,60,83,85,79,82,85,103,101,104,102,100,82,79,50,49,46,
47,78,76,97,93,108,116,109,98,103,104,98,105,73,77,48,48,45,
45,78,75,95,91,108,109,140,79,52,53,53,52,79,49,43,44,48,
24,24,44,43,0,0,0,3,0,92,0,0,3,61,4,47,0,24,
0,35,0,50,0,0,51,17,33,50,23,22,23,22,21,20,7,6,
15,1,23,22,23,22,23,22,21,20,7,6,35,3,51,50,54,53,
52,39,38,43,2,25,1,51,50,55,54,53,52,39,38,39,38,39,
38,35,92,1,98,76,76,73,45,46,32,33,37,74,78,42,36,45,
17,25,113,112,166,226,216,72,104,54,55,69,4,210,208,105,73,74,
28,24,44,39,37,44,42,4,47,34,34,61,62,76,55,53,54,23,
40,31,19,36,46,33,47,49,138,90,90,2,120,90,68,62,43,44,
254,86,254,134,52,51,87,45,37,32,27,25,10,12,0,2,0,101,
255,227,3,178,4,74,0,39,0,74,0,0,37,6,35,48,35,34,
38,53,52,55,54,55,54,63,1,38,39,38,39,38,53,52,55,54,
55,54,51,50,23,22,23,22,23,22,23,22,21,20,7,6,1,6,
21,20,23,22,59,1,21,35,34,7,6,7,6,7,6,21,20,23,
22,51,50,55,54,55,54,53,52,39,38,35,34,7,6,2,211,104,
128,4,160,226,25,25,37,59,19,85,40,42,45,23,32,45,51,67,
73,78,77,83,72,56,54,41,40,20,20,59,58,253,252,4,61,59,
73,72,57,47,40,34,43,42,25,28,102,65,84,40,38,67,51,88,
91,90,127,69,61,25,47,76,190,145,130,47,49,34,55,3,42,13,
20,22,23,34,74,51,60,67,33,35,34,29,55,52,72,70,82,83,
84,155,130,128,2,232,11,13,73,30,29,125,13,10,27,26,36,40,
122,89,75,36,13,29,69,118,195,180,121,120,50,21,0,1,0,98,
255,227,4,179,5,145,0,78,0,0,1,21,22,23,22,23,22,51,
50,55,54,55,35,55,33,20,6,29,1,20,7,6,7,6,7,6,
35,34,39,38,39,38,53,52,55,54,55,54,51,50,31,1,53,52,
55,54,55,54,55,54,55,54,51,50,23,22,23,22,23,7,47,4,
34,29,2,7,38,39,38,35,34,7,6,7,6,1,1,6,30,31,
58,60,76,111,71,70,9,239,1,1,128,1,26,25,51,52,76,80,
96,129,97,95,50,49,48,47,99,95,131,116,106,4,23,24,33,35,
39,40,34,33,24,42,36,32,20,12,32,107,15,16,19,22,26,102,
133,30,73,70,72,77,57,59,30,31,2,84,135,89,78,81,52,54,
105,104,145,135,2,32,14,48,99,95,90,78,79,43,45,74,73,126,
123,161,158,128,125,79,76,59,2,103,62,52,54,30,32,20,21,9,
9,15,13,15,9,30,102,13,14,11,8,3,123,170,120,55,58,40,
39,53,54,80,81,0,0,0,255,255,0,102,0,0,3,48,4,51,
16,6,2,133,0,0,0,3,255,41,254,28,2,148,5,147,0,13,
0,57,0,75,0,0,19,52,54,51,50,23,22,21,20,6,35,34,
39,38,1,7,38,39,6,7,6,7,6,7,6,7,6,35,34,39,
38,39,38,39,38,39,38,61,1,52,55,54,55,54,51,50,23,22,
23,30,1,23,17,51,17,21,23,22,5,31,4,50,61,1,38,39,
38,35,34,7,6,7,20,170,56,38,38,28,28,56,38,38,28,28,
1,234,72,153,103,7,8,22,35,40,34,40,34,29,28,42,36,35,
17,8,36,53,27,16,33,33,53,30,45,11,24,77,57,8,29,3,
152,32,89,254,39,15,16,19,22,26,102,41,59,32,27,34,39,36,
2,5,53,38,56,27,27,40,38,56,27,27,249,111,96,182,94,26,
20,50,32,36,18,21,9,8,15,15,12,6,34,47,80,48,22,7,
80,54,53,26,15,2,9,31,4,17,2,4,28,251,207,80,24,65,
75,14,12,12,8,3,123,70,25,23,10,14,13,52,26,0,0,0,
0,1,0,55,254,131,3,98,4,49,0,11,0,0,9,1,51,1,
55,17,51,17,35,17,1,35,2,4,254,51,174,1,123,106,152,152,
254,103,174,1,201,2,104,254,0,133,1,123,250,82,3,104,254,21,
0,0,0,1,0,121,0,0,3,98,4,70,0,5,0,0,19,51,
17,33,21,33,121,158,2,75,253,23,4,70,252,71,141,0,0,2,
0,96,254,63,4,225,5,176,0,14,0,79,0,0,19,20,23,22,
51,50,55,54,53,52,39,38,34,7,6,1,20,23,22,51,21,34,
39,38,61,2,6,7,6,35,34,39,38,39,38,39,38,53,52,55,
62,2,51,50,23,22,23,22,23,22,23,53,54,55,54,55,54,55,
54,55,54,51,50,23,22,23,22,23,7,47,4,34,29,1,17,250,
77,76,116,117,79,80,80,79,234,76,76,2,180,26,26,66,131,70,
69,52,75,73,101,98,80,77,46,48,21,23,23,22,94,154,102,63,
49,53,32,38,21,24,19,7,16,22,35,40,34,40,34,29,28,42,
36,35,17,8,36,107,15,16,19,22,26,102,2,27,199,118,116,116,
118,197,198,116,115,114,113,252,86,59,28,27,136,59,58,127,205,184,
119,48,46,49,47,83,86,94,101,108,110,101,96,164,92,18,19,31,
36,32,36,44,187,173,36,50,32,36,18,21,9,8,15,15,12,6,
34,102,14,12,12,8,3,123,125,251,207,0,0,0,0,1,0,57,
0,0,3,164,5,217,0,59,0,0,1,33,53,33,53,52,55,54,
55,54,55,54,63,12,52,39,38,35,34,14,1,21,39,54,55,54,
51,50,23,30,2,21,20,7,6,7,6,15,4,21,33,21,33,17,
35,1,160,254,193,1,63,11,11,14,15,27,31,16,55,52,20,20,
18,16,15,13,10,8,4,2,77,75,126,83,138,72,146,20,121,122,
169,88,76,79,124,76,37,41,58,32,30,62,50,36,13,1,95,254,
161,157,1,40,142,67,43,42,41,26,27,30,35,13,46,44,18,18,
18,20,20,22,26,29,33,38,125,69,68,90,124,57,25,165,111,111,
25,26,94,158,96,97,73,80,57,30,23,46,46,62,83,63,142,254,
216,0,0,1,0,57,0,0,3,164,5,217,0,62,0,0,1,17,
35,17,33,53,33,53,47,3,38,39,38,39,38,53,52,54,55,54,
55,54,51,50,23,22,23,7,52,39,38,39,38,35,34,7,6,21,
31,11,22,23,22,23,22,23,22,29,1,33,21,2,61,157,254,161,
1,95,12,38,49,61,36,27,58,41,37,74,64,62,79,76,88,170,
121,121,20,146,36,36,70,69,82,126,75,77,2,5,8,10,12,15,
17,18,19,20,53,54,16,31,24,17,16,10,11,1,63,1,40,254,
216,1,40,142,63,83,62,46,46,28,25,57,80,73,97,98,154,49,
47,26,25,111,111,165,25,57,62,61,46,45,68,69,125,38,33,29,
26,22,20,20,18,18,18,44,46,13,35,27,30,29,38,42,43,67,
142,0,0,2,0,128,255,227,6,226,5,174,0,14,0,59,0,0,
1,20,23,22,51,50,55,54,53,52,39,38,34,7,6,1,51,17,
1,33,53,33,1,33,21,33,43,1,53,6,7,6,7,6,7,6,
35,34,39,38,39,46,1,39,38,53,52,55,62,2,51,50,23,22,
23,22,23,22,23,1,26,77,76,116,117,79,80,80,79,234,76,76,
2,28,152,2,24,253,244,3,8,253,203,2,23,253,10,29,123,18,
25,23,34,35,50,47,66,80,69,66,46,44,64,13,14,23,22,94,
154,102,63,49,53,32,38,21,24,19,2,27,199,118,116,116,118,197,
198,116,115,114,113,2,203,250,130,3,116,141,252,92,141,184,42,38,
34,32,32,18,17,32,31,55,53,148,80,84,85,110,101,96,164,92,
18,19,31,36,32,36,44,0,0,0,0,2,0,128,254,116,6,155,
5,174,0,14,0,89,0,0,1,20,23,22,51,50,55,54,53,52,
39,38,34,7,6,1,51,17,33,1,22,23,22,23,22,23,22,23,
22,21,20,7,6,35,34,39,38,39,55,22,23,22,51,50,55,54,
53,52,39,38,39,38,47,1,1,33,17,35,53,6,7,6,7,6,
7,6,35,34,39,38,39,46,1,39,38,53,52,55,62,2,51,50,
23,22,23,22,23,22,23,1,26,77,76,116,117,79,80,80,79,234,
76,76,2,28,152,2,205,254,142,36,17,33,47,25,55,38,26,26,
141,140,208,125,127,126,56,155,37,80,79,83,140,95,97,29,28,48,
51,53,159,1,84,254,47,152,18,25,23,34,35,50,47,66,80,69,
66,46,44,64,13,14,23,22,94,154,102,63,49,53,32,38,21,24,
19,2,27,199,118,116,116,118,197,198,116,115,114,113,2,203,254,132,
253,145,12,11,21,22,12,67,46,66,67,70,196,129,128,76,75,130,
47,81,53,52,85,86,140,72,61,58,38,40,18,20,2,57,252,91,
184,42,38,34,32,32,18,17,32,31,55,53,148,80,84,85,110,101,
96,164,92,18,19,31,36,32,36,44,0,0,0,3,0,128,255,108,
7,211,5,174,0,14,0,82,0,94,0,0,1,20,23,22,51,50,
55,54,53,52,39,38,34,7,6,1,51,17,1,33,53,33,1,51,
54,55,54,55,54,55,54,51,50,23,22,23,22,29,1,6,7,6,
7,33,6,7,39,55,43,2,53,6,7,6,7,6,7,6,35,34,
39,38,39,46,1,39,38,53,52,55,62,2,51,50,23,22,23,22,
23,22,23,1,33,54,61,1,38,39,38,35,7,6,7,1,26,77,
76,116,117,79,80,80,79,234,76,76,2,28,152,2,39,253,244,3,
8,253,203,101,64,39,155,69,57,77,24,11,45,30,56,30,33,2,
14,60,81,253,251,52,77,72,48,202,14,138,18,25,23,34,35,50,
47,66,80,69,66,46,44,64,13,14,23,22,94,154,102,63,49,53,
32,38,21,24,19,2,137,1,119,24,3,35,37,35,60,116,112,2,
27,199,118,116,116,118,197,198,116,115,114,113,2,203,250,105,3,141,
141,252,92,62,29,111,37,31,9,2,15,29,50,54,80,7,50,20,
84,33,56,92,96,52,184,42,38,34,32,32,18,17,32,31,55,53,
148,80,84,85,110,101,96,164,92,18,19,31,36,32,36,44,253,23,
53,19,2,51,14,14,10,44,98,0,0,0,0,2,0,102,255,227,
4,156,5,43,0,54,0,84,0,0,19,35,53,51,53,51,21,33,
54,55,50,22,23,22,23,22,23,7,38,35,34,6,21,20,23,22,
23,22,23,22,23,22,23,30,2,31,9,20,7,6,35,33,34,39,
38,53,5,50,55,54,55,54,53,52,39,38,39,38,39,38,39,38,
39,38,39,38,39,38,39,38,53,52,55,35,17,20,244,142,142,151,
1,8,66,84,82,130,41,44,21,24,12,146,54,152,81,116,14,15,
23,26,22,29,23,28,17,2,11,20,10,49,49,50,45,43,36,30,
17,7,108,107,152,254,211,149,59,60,1,2,165,142,65,94,58,19,
21,34,39,27,30,47,38,63,42,50,47,34,34,19,21,29,95,3,
170,135,250,250,23,2,44,38,41,31,36,37,30,122,78,72,38,28,
29,19,21,12,16,7,8,8,1,3,7,4,18,19,23,27,33,39,
47,54,65,137,90,89,55,56,129,113,8,2,46,28,105,41,31,34,
21,25,11,13,14,12,24,17,28,26,36,35,46,49,59,73,56,253,
45,112,0,0,0,1,0,102,254,104,4,75,5,201,0,64,0,0,
19,35,53,51,53,51,21,51,53,52,55,54,55,54,55,54,51,50,
23,22,23,7,38,39,38,39,38,35,34,6,21,19,20,6,7,6,
7,6,35,34,38,39,55,22,23,22,23,22,51,50,55,54,53,3,
35,17,20,59,1,21,35,34,39,38,53,244,142,142,151,244,29,30,
44,43,49,47,40,58,39,37,44,109,12,11,9,20,21,27,39,58,
1,60,43,40,52,49,38,59,74,45,109,12,11,10,19,21,27,40,
29,28,1,244,117,70,70,149,59,60,3,170,135,250,250,135,62,51,
52,35,34,20,19,21,20,41,105,16,11,9,8,8,52,45,250,152,
60,106,34,32,21,20,40,42,105,16,11,10,7,8,26,25,46,4,
90,253,45,117,127,55,56,129,0,2,0,102,255,227,5,120,5,43,
0,77,0,92,0,0,19,35,53,51,53,51,21,51,21,35,17,20,
59,1,50,55,38,39,38,53,52,55,54,55,54,55,62,1,51,50,
23,22,23,7,38,39,38,35,34,7,6,21,20,23,54,55,54,55,
50,54,51,50,23,22,23,22,21,20,6,21,6,7,6,7,6,7,
35,34,39,38,39,6,7,35,34,39,38,53,5,22,51,50,55,54,
53,48,53,38,39,38,35,7,6,244,142,142,151,197,197,117,70,40,
80,24,20,58,20,20,40,42,52,56,146,85,114,85,87,53,131,18,
60,61,69,127,90,91,55,59,69,63,71,1,27,7,43,32,56,30,
33,1,2,14,60,80,16,67,10,123,104,28,17,102,93,70,149,59,
60,2,113,79,111,44,39,24,3,35,40,32,60,72,3,170,135,250,
250,135,253,45,117,75,36,43,128,157,84,83,82,70,74,50,54,60,
61,63,95,66,49,50,50,120,121,180,153,106,50,34,31,9,3,16,
29,50,54,80,1,4,1,51,20,85,32,8,3,76,21,17,113,1,
55,56,129,20,85,18,52,20,2,50,14,15,11,26,0,0,0,1,
0,125,254,63,5,160,5,201,0,81,0,0,1,17,35,17,35,53,
51,53,52,55,54,55,54,55,54,51,50,23,22,23,7,38,39,38,
39,38,35,34,6,29,1,33,21,62,1,51,50,23,22,23,22,23,
22,21,17,23,21,20,7,6,7,6,7,6,43,1,54,55,50,55,
54,61,1,17,52,39,38,39,46,1,35,34,7,6,7,6,7,6,
21,17,35,17,1,160,152,139,138,29,30,44,43,49,47,40,58,39,
37,44,109,12,11,10,19,21,27,39,58,1,91,29,162,114,83,66,
67,49,52,26,27,1,35,19,74,65,64,80,65,4,1,3,103,74,
73,14,15,30,30,102,68,69,50,55,29,31,15,16,152,3,170,252,
86,3,170,135,135,62,51,52,35,34,20,19,21,20,41,105,16,11,
9,8,8,52,45,176,181,90,120,33,34,66,71,104,108,145,253,228,
1,9,62,129,67,69,61,23,29,10,124,74,73,135,33,2,29,95,
70,76,58,59,66,34,37,56,58,77,80,83,253,228,3,170,0,0,
0,1,0,154,255,227,4,18,5,176,0,79,0,0,51,17,51,17,
55,22,23,22,51,50,55,54,53,52,39,38,39,38,39,38,39,38,
39,38,39,38,39,38,39,38,53,52,55,54,55,50,22,23,22,23,
22,23,7,38,35,34,6,21,20,23,22,23,22,23,22,23,22,23,
30,2,31,9,20,7,6,35,34,39,38,39,21,154,157,134,30,52,
53,91,101,58,58,19,21,34,39,27,30,47,62,39,42,50,47,34,
34,19,21,100,101,147,82,130,41,44,21,24,12,146,54,152,81,116,
14,15,23,26,22,29,23,28,17,2,11,20,10,49,49,50,45,43,
36,30,17,7,108,107,152,153,92,80,39,5,176,251,43,26,67,36,
36,48,48,85,41,31,34,21,25,11,13,14,20,16,17,28,26,36,
35,46,49,59,137,75,76,1,44,38,41,31,36,37,30,122,78,72,
38,28,29,19,21,12,16,7,8,8,1,3,7,4,18,19,23,27,
33,39,47,54,65,137,90,89,67,57,89,184,0,2,0,154,0,0,
3,241,5,176,0,7,0,10,0,0,51,17,51,17,33,1,33,21,
1,17,1,154,157,2,186,253,203,2,23,253,100,1,190,5,176,254,
129,252,92,141,3,164,253,32,2,224,0,2,0,66,0,0,3,243,
6,134,0,12,0,25,0,0,1,3,35,3,51,27,1,51,27,1,
51,3,35,7,3,35,3,51,27,1,51,27,1,51,3,35,2,26,
170,88,214,114,145,157,113,157,144,115,215,92,166,170,88,214,114,145,
157,113,157,144,115,215,92,5,232,253,122,3,36,253,151,2,99,253,
157,2,105,252,220,220,253,122,3,37,253,151,2,99,253,157,2,105,
252,219,0,2,0,121,0,197,4,74,5,176,0,7,0,15,0,0,
19,33,17,35,17,33,17,35,17,33,17,35,17,33,17,35,121,3,
209,158,253,107,158,3,209,158,253,107,158,2,200,253,253,1,118,254,
138,4,235,253,253,1,118,254,138,0,0,0,0,1,0,37,254,139,
4,143,4,78,0,64,0,0,19,54,55,54,55,54,51,50,23,22,
23,22,23,22,23,22,29,2,35,22,23,22,23,30,1,51,50,55,
54,55,54,55,54,61,1,17,53,51,17,35,17,53,6,7,6,35,
34,39,38,39,38,39,38,61,1,51,53,52,35,15,4,37,36,8,
17,35,36,42,28,29,34,40,34,40,35,22,23,3,3,10,16,28,
30,102,68,70,50,51,31,34,14,15,152,152,29,80,81,115,82,66,
69,48,48,29,28,4,102,26,22,19,16,15,3,252,34,6,12,15,
15,8,9,21,18,36,32,50,52,63,139,173,48,57,79,55,59,66,
34,35,58,65,70,75,88,30,1,96,158,250,61,2,43,28,91,59,
60,33,34,66,64,111,109,144,207,76,123,3,8,12,12,14,0,1,
0,37,254,154,5,194,4,78,0,85,0,0,1,51,17,21,20,51,
63,4,23,6,7,6,7,6,35,34,39,38,39,38,39,38,39,38,
61,3,6,7,6,35,34,39,38,39,38,39,38,39,55,53,52,35,
15,4,39,54,55,54,55,54,51,50,23,22,23,22,23,22,23,22,
21,17,35,22,23,22,23,30,1,51,50,55,54,55,54,55,54,53,
3,247,152,102,27,22,18,16,15,107,36,8,17,35,36,42,28,29,
32,41,37,38,35,22,23,29,80,81,115,82,66,69,48,48,29,22,
6,4,102,26,22,19,16,15,107,36,8,17,35,36,42,28,29,34,
40,34,40,35,22,23,3,3,10,16,28,30,102,68,70,50,51,31,
34,14,15,4,78,251,196,118,123,3,8,12,12,14,102,34,6,12,
15,15,8,9,21,19,35,32,50,52,63,87,164,28,91,59,60,33,
34,66,64,111,82,171,207,76,123,3,8,12,12,14,102,34,6,12,
15,15,8,9,21,18,36,32,50,52,63,254,200,48,57,79,55,59,
66,34,35,58,65,70,75,88,0,1,0,186,5,234,3,106,7,66,
0,6,0,0,1,35,39,7,35,1,51,3,106,188,156,158,186,1,
21,131,5,234,213,211,1,86,0,1,0,184,5,234,3,104,7,66,
0,6,0,0,9,1,35,1,51,23,55,3,104,254,232,131,254,235,
186,158,156,7,66,254,168,1,86,211,213,0,0,1,0,188,255,40,
3,97,255,146,0,3,0,0,23,33,21,33,188,2,165,253,91,110,
106,0,0,0,0,1,1,98,5,234,3,192,7,46,0,23,0,0,
1,54,55,54,55,51,48,21,20,7,6,7,6,34,39,38,39,38,
61,1,51,22,23,22,2,150,55,35,59,69,80,66,35,69,67,132,
67,69,35,66,81,49,78,38,6,112,3,23,42,122,10,68,111,57,
40,38,38,40,57,111,68,10,112,52,24,0,0,1,0,76,6,52,
1,8,6,241,0,16,0,0,19,52,54,51,50,22,23,22,21,20,
6,35,34,39,38,39,38,76,56,38,34,50,8,2,56,38,32,27,
25,8,2,6,147,38,56,42,33,10,9,39,56,22,21,33,8,0,
0,2,1,26,5,205,2,242,7,158,0,19,0,39,0,0,1,20,
23,22,23,22,51,50,55,54,53,52,39,38,39,38,35,34,7,6,
7,52,55,54,51,50,23,22,23,22,21,20,7,6,35,34,39,38,
39,38,1,132,3,10,35,33,49,54,38,38,3,10,35,33,49,54,
38,38,106,69,70,97,85,64,66,16,5,69,70,97,85,64,65,16,
6,6,185,15,15,45,30,29,39,40,55,15,15,46,30,29,39,40,
59,96,68,68,52,53,79,22,26,98,67,68,52,53,79,24,0,1,
0,117,254,197,1,113,0,74,0,28,0,0,5,7,38,39,38,39,
38,39,38,39,38,53,52,55,54,55,23,6,7,6,7,6,21,20,
22,23,22,23,22,1,113,43,7,40,39,19,10,39,29,13,13,4,
17,63,129,18,17,15,3,2,18,19,24,4,3,190,125,4,24,23,
14,7,33,24,28,27,33,17,21,74,60,56,24,25,22,18,14,1,
13,30,16,20,3,2,0,0,0,1,0,63,2,51,2,188,3,92,
0,43,0,0,19,54,55,62,1,51,50,23,22,23,30,1,23,30,
1,51,50,55,54,55,54,55,21,6,7,6,7,6,35,34,39,38,
39,38,39,38,39,38,35,34,6,7,6,7,63,24,27,25,70,37,
25,30,26,26,8,32,8,25,56,30,32,34,30,32,27,33,49,11,
27,33,34,34,32,32,30,27,16,34,26,23,26,22,36,66,24,27,
28,2,252,18,24,22,32,16,14,24,7,29,8,23,30,15,13,25,
21,24,145,38,9,23,14,15,15,14,24,14,32,25,13,15,30,21,
23,23,0,0,0,2,1,186,5,234,4,112,7,150,0,21,0,43,
0,0,1,19,54,51,50,23,22,23,22,21,20,7,3,6,35,34,
39,38,39,38,53,52,37,19,54,51,50,23,22,23,22,21,20,7,
3,6,35,34,39,38,39,38,53,52,3,26,206,24,36,26,20,23,
6,1,16,238,14,23,19,17,17,5,1,254,176,206,24,36,26,20,
23,6,1,16,238,14,23,19,17,17,5,1,6,59,1,58,33,17,
17,27,5,8,25,22,254,222,17,11,13,21,3,7,12,14,1,58,
33,17,17,27,5,8,25,22,254,222,17,11,13,21,3,7,12,0,
0,1,252,65,4,120,253,161,6,34,0,18,0,0,1,38,53,52,
55,54,51,22,23,22,23,19,23,21,20,6,35,34,39,252,81,16,
24,23,30,15,18,17,10,209,6,34,23,21,16,5,169,17,33,27,
22,22,1,7,6,16,254,198,14,13,21,34,16,0,0,1,252,56,
4,106,253,153,6,22,0,16,0,0,1,54,51,50,23,22,20,7,
3,6,35,34,39,38,53,52,55,253,16,21,38,35,21,22,16,240,
16,21,23,18,19,9,5,245,33,26,27,46,22,254,221,16,15,16,
22,11,18,0,0,0,255,255,252,151,4,172,255,71,6,4,16,7,
0,65,252,18,0,47,0,0,0,1,252,161,4,171,255,30,5,212,
0,49,0,0,1,54,55,54,55,54,55,54,51,50,23,22,23,30,
1,23,22,23,50,22,51,50,55,54,63,1,21,14,1,7,6,7,
6,43,1,34,39,38,39,38,39,38,35,34,7,14,1,7,6,35,
252,161,49,21,29,16,19,15,20,13,23,36,38,40,14,50,12,35,
19,2,6,2,24,34,44,44,32,17,55,10,31,15,19,10,31,28,
37,47,30,35,38,34,20,65,84,3,14,3,10,1,5,116,39,15,
21,8,9,2,2,23,24,27,9,35,8,23,2,1,17,24,33,25,
145,13,42,7,23,6,8,24,30,22,25,27,24,70,3,11,3,10,
0,0,255,255,252,147,4,191,255,56,5,41,16,7,0,113,251,215,
0,0,0,0,0,1,252,161,4,171,255,151,5,221,0,21,0,0,
1,22,23,22,51,50,55,54,63,1,51,6,7,6,7,6,35,34,
38,39,38,39,253,73,12,19,76,108,59,50,51,29,31,155,30,41,
54,75,77,98,88,152,57,52,34,5,221,33,23,115,26,26,59,58,
90,54,77,41,42,72,72,64,98,0,0,0,0,1,252,161,4,165,
253,94,5,98,0,17,0,0,1,52,55,54,51,50,31,1,22,21,
20,7,6,35,34,47,1,38,252,161,57,18,19,62,24,7,2,58,
16,21,62,24,6,2,5,3,62,24,9,56,20,8,11,62,24,8,
55,21,8,0,0,2,252,169,4,165,255,61,5,100,0,17,0,35,
0,0,1,52,55,54,51,50,31,1,22,21,20,7,6,35,34,47,
1,38,37,52,55,54,51,50,31,1,22,21,20,7,6,35,34,47,
1,38,254,129,57,18,19,62,24,6,2,57,16,21,62,24,6,2,
254,40,58,18,18,63,24,6,2,58,16,21,62,24,6,2,5,5,
62,24,9,56,20,8,11,62,24,8,55,21,8,8,62,24,9,56,
20,8,11,62,24,8,55,21,8,0,0,0,0,2,252,161,4,175,
254,174,6,180,0,21,0,41,0,0,1,20,23,22,23,22,51,50,
55,54,53,48,53,52,39,38,39,38,35,34,7,6,7,52,55,54,
51,50,23,22,23,22,21,20,7,6,35,34,39,38,39,38,253,22,
4,18,76,21,26,87,40,17,2,18,79,22,23,87,40,18,117,111,
70,81,138,78,34,7,6,111,70,82,139,76,34,7,6,5,182,14,
19,84,27,6,78,39,33,16,6,10,82,29,6,78,35,40,133,78,
47,111,46,48,29,24,136,76,47,111,46,48,27,0,255,255,252,160,
4,106,255,81,6,36,16,38,1,181,104,14,16,7,1,181,1,184,
0,0,255,255,252,143,4,159,255,63,5,247,16,7,1,172,251,215,
254,181,0,0,255,255,252,161,4,171,255,151,6,151,16,38,1,185,
0,0,16,7,1,186,1,35,1,53,0,1,252,165,254,161,253,98,
255,94,0,17,0,0,1,52,55,54,51,50,31,1,22,21,20,7,
6,35,34,47,1,38,252,165,57,16,21,62,24,7,2,58,18,19,
62,24,6,2,255,0,62,24,8,55,21,8,10,62,24,9,56,20,
8,0,0,2,252,169,254,159,255,61,255,94,0,17,0,35,0,0,
1,52,55,54,51,50,31,1,22,21,20,7,6,35,34,47,1,38,
37,52,55,54,51,50,31,1,22,21,20,7,6,35,34,47,1,38,
254,129,57,16,21,62,24,6,2,57,18,19,62,24,6,2,254,40,
58,16,20,63,24,6,2,58,18,19,62,24,6,2,255,0,62,24,
8,55,21,8,10,62,24,9,56,20,8,9,62,24,8,55,21,8,
10,62,24,9,56,20,8,0,0,0,0,2,252,161,253,120,254,174,
255,125,0,21,0,41,0,0,1,20,23,22,23,22,51,50,55,54,
53,48,53,52,39,38,39,38,35,34,7,6,7,52,55,54,51,50,
23,22,23,22,21,20,7,6,35,34,39,38,39,38,253,22,4,18,
76,21,26,87,40,17,2,18,79,22,23,87,40,18,117,111,70,81,
138,78,34,7,6,111,70,82,139,76,34,7,6,254,127,14,19,84,
27,6,78,39,33,16,6,10,82,29,6,78,35,41,134,78,47,111,
46,48,28,26,134,77,47,111,46,48,27,0,0,1,252,161,254,196,
253,157,0,74,0,15,0,0,5,54,53,52,39,38,39,55,22,23,
30,1,21,20,15,1,252,161,94,2,1,52,129,64,16,2,2,141,
68,191,69,36,8,6,17,73,56,62,71,14,12,13,92,85,41,0,
0,1,252,161,254,196,253,157,0,74,0,16,0,0,5,6,21,20,
23,22,23,7,38,39,38,39,38,53,52,63,1,253,157,94,2,1,
52,129,63,17,1,2,1,141,68,51,69,36,8,6,17,73,56,62,
72,7,12,6,13,92,85,41,0,0,0,1,1,98,254,116,3,192,
255,184,0,23,0,0,1,54,55,54,55,51,48,21,20,7,6,7,
6,34,39,38,39,38,61,1,51,22,23,22,2,150,55,35,59,69,
80,66,35,69,67,132,67,69,35,66,81,49,78,38,254,250,3,23,
42,122,10,68,111,57,40,38,38,40,57,111,68,10,112,52,24,0,
0,1,252,161,254,237,254,254,255,117,0,3,0,0,5,33,21,33,
252,161,2,93,253,163,139,136,0,0,0,1,0,121,0,0,3,51,
5,176,0,9,0,0,19,51,17,48,33,21,48,33,17,35,121,158,
2,28,253,228,158,5,176,253,127,141,253,94,0,0,0,1,0,121,
0,0,3,51,4,50,0,9,0,0,19,51,17,48,33,21,48,33,
17,35,121,158,2,28,253,228,158,4,50,254,29,141,254,62,0,0,
0,1,0,121,0,0,4,147,5,176,0,9,0,0,33,35,17,1,
35,17,51,17,1,51,4,147,158,253,21,145,157,2,228,153,4,166,
251,90,5,176,251,119,4,137,0,1,0,103,255,243,1,62,0,202,
0,18,0,0,55,52,54,51,50,23,22,23,22,21,20,7,6,35,
34,39,38,39,38,103,64,44,39,29,29,8,2,32,31,44,39,29,
30,7,3,94,44,64,24,25,36,10,13,44,32,31,24,25,36,10,
0,1,0,101,255,227,3,133,4,70,0,47,0,0,19,39,54,55,
54,51,50,23,22,23,22,23,22,23,22,21,20,7,6,7,6,35,
34,39,38,39,38,39,38,39,55,22,23,22,23,22,23,22,51,50,
54,53,52,2,35,34,7,6,202,101,53,86,85,115,84,74,72,56,
54,41,40,20,20,59,58,106,104,132,61,53,55,41,50,25,32,24,
122,11,16,18,25,24,43,39,43,130,176,196,126,96,50,55,3,72,
35,96,62,61,30,29,55,52,72,70,82,83,84,155,130,128,77,76,
19,20,32,39,29,37,40,77,21,24,26,25,24,20,18,236,195,182,
1,6,41,43,0,2,0,101,255,227,3,133,4,70,0,47,0,66,
0,0,1,38,39,38,35,34,2,21,20,22,51,50,55,54,55,54,
55,54,55,23,6,7,6,7,6,7,6,35,34,39,38,39,38,53,
52,55,54,55,54,55,54,55,54,51,50,23,22,23,5,52,54,51,
50,23,22,23,22,21,20,7,6,35,34,39,38,39,38,3,32,23,
55,50,96,126,196,176,130,43,39,43,24,25,18,16,11,122,24,32,
25,50,41,55,53,61,132,104,106,58,59,20,20,40,41,54,56,72,
74,84,115,85,86,53,254,82,64,44,40,28,29,8,2,32,31,44,
39,29,30,7,3,3,72,57,43,41,254,250,182,195,236,18,20,24,
25,26,24,21,77,40,37,29,39,32,20,19,76,77,128,130,155,84,
83,82,70,72,52,55,29,30,61,62,96,137,44,64,24,25,36,10,
13,44,32,31,24,25,36,10,0,0,255,255,0,101,255,227,3,133,
4,70,16,39,1,210,0,218,0,0,16,6,1,203,0,0,0,2,
0,113,255,82,1,72,3,163,0,23,0,41,0,0,23,19,54,55,
54,23,22,23,22,23,22,15,1,6,7,6,35,48,35,38,39,48,
39,38,3,52,55,54,51,50,22,23,22,21,20,6,35,34,39,38,
39,38,129,8,5,31,21,27,31,16,3,4,13,3,48,5,18,13,
18,6,23,13,6,6,16,32,31,45,38,60,7,2,64,43,39,29,
30,7,3,121,1,0,41,18,13,5,3,21,4,6,22,27,251,24,
10,8,3,15,9,12,3,190,45,32,31,50,35,10,13,43,64,24,
25,36,11,0,0,1,0,248,5,119,1,149,6,240,0,27,0,0,
27,1,54,55,54,51,50,23,22,23,22,23,22,21,20,6,21,7,
6,7,6,43,1,38,39,48,39,38,248,8,5,31,16,18,9,5,
31,16,3,4,11,1,48,5,18,13,18,6,22,14,6,6,5,172,
1,0,41,18,9,1,3,21,4,6,19,20,2,6,2,251,24,10,
8,3,15,9,12,0,255,255,0,76,5,253,2,223,7,118,16,38,
0,106,0,0,16,7,1,207,0,79,0,134,0,3,0,72,0,0,
4,223,6,240,0,2,0,10,0,37,0,0,1,3,33,23,33,3,
35,1,51,1,35,1,19,54,55,54,51,50,23,22,23,22,23,22,
21,20,6,21,7,6,7,6,43,1,38,47,1,38,2,147,204,1,
159,37,254,15,162,176,2,12,127,2,12,180,253,27,8,5,31,16,
18,9,5,31,16,3,4,11,1,48,5,18,13,18,6,22,14,6,
6,4,190,253,175,136,254,27,5,176,250,80,5,172,1,0,41,18,
9,1,3,21,4,6,19,20,2,6,2,251,24,10,8,3,15,9,
12,0,0,0,0,1,0,95,2,119,1,54,3,78,0,18,0,0,
19,52,54,51,50,23,22,23,22,21,20,7,6,35,34,39,38,39,
38,95,64,44,39,29,29,8,2,32,31,44,39,29,30,7,3,2,
226,44,64,24,25,36,10,13,44,32,31,24,25,36,10,0,0,0,
0,2,0,28,0,0,4,118,6,240,0,11,0,38,0,0,19,33,
21,33,17,33,21,33,17,33,21,33,3,19,54,55,54,51,50,23,
22,23,22,23,22,21,20,6,21,7,6,7,6,43,1,38,47,1,
38,221,3,153,253,5,2,208,253,48,2,251,252,103,193,8,5,31,
16,18,9,5,31,16,3,4,11,1,48,5,18,13,18,6,22,14,
6,6,5,176,141,254,14,141,253,233,141,5,172,1,0,41,18,9,
1,3,21,4,6,19,20,2,6,2,251,24,10,8,3,15,9,12,
0,0,0,2,0,27,0,0,4,172,6,240,0,11,0,38,0,0,
19,51,17,33,17,51,17,35,17,33,17,35,3,19,54,55,54,51,
50,23,22,23,22,23,22,21,20,6,21,7,6,7,6,43,1,38,
47,1,38,219,158,2,149,158,158,253,107,158,192,8,5,31,17,17,
9,5,31,16,3,4,11,1,48,5,18,13,18,6,23,13,6,6,
5,176,253,127,2,129,250,80,2,162,253,94,5,172,1,0,41,18,
9,1,3,21,4,6,19,20,2,6,2,251,24,10,8,3,15,9,
12,0,0,0,0,2,0,31,0,0,1,125,6,242,0,3,0,30,
0,0,51,17,51,17,1,19,54,55,54,51,50,23,22,23,22,23,
22,21,20,6,21,7,6,7,6,43,1,38,47,1,38,224,157,254,
162,8,5,31,17,17,9,5,31,16,3,4,11,1,48,5,18,13,
18,6,23,13,6,6,5,176,250,80,5,174,1,0,41,18,9,1,
3,21,4,6,19,20,2,6,2,251,24,10,8,3,15,9,12,0,
0,3,0,58,255,227,4,238,6,242,0,37,0,77,0,104,0,0,
1,52,39,38,39,38,39,38,39,38,35,34,6,7,6,7,14,1,
21,20,23,22,23,22,23,22,23,22,51,50,55,54,55,54,55,54,
55,54,37,52,55,54,55,54,55,54,55,54,51,50,23,22,23,22,
23,22,23,22,21,20,7,6,7,6,7,6,7,6,35,34,39,38,
39,38,39,38,39,38,3,19,54,55,54,51,50,23,22,23,22,23,
22,21,20,6,21,7,6,7,6,43,1,38,47,1,38,4,72,23,
17,32,29,48,46,70,67,88,94,146,47,47,30,30,24,22,15,33,
29,48,46,71,70,84,94,73,75,45,45,32,33,11,12,252,20,19,
20,44,43,67,64,103,101,123,122,98,100,66,65,45,44,22,24,20,
20,44,47,63,67,101,102,122,120,99,98,68,65,45,43,23,23,34,
8,5,31,17,17,9,5,31,16,3,4,11,1,48,5,18,13,18,
6,22,14,6,6,2,213,115,112,79,73,67,60,57,34,32,80,64,
63,85,84,168,85,114,104,75,74,65,59,57,32,32,39,40,59,60,
83,85,79,82,85,103,101,104,102,100,82,79,50,49,46,47,78,76,
97,93,108,116,109,98,103,104,98,105,73,77,48,48,45,45,78,75,
95,91,108,109,3,69,1,0,41,18,9,1,3,21,4,6,19,20,
2,6,2,251,24,10,8,3,15,9,12,0,0,0,255,255,0,41,
0,0,4,249,6,242,16,39,1,207,255,49,0,2,16,7,1,237,
0,159,0,0,0,0,255,255,0,25,0,0,5,53,6,242,16,39,
1,207,255,92,0,2,16,6,1,241,0,0,255,255,255,221,0,0,
2,112,6,44,16,39,1,208,255,145,254,182,16,6,2,1,0,0,
0,2,0,72,0,0,4,223,5,176,0,2,0,10,0,0,1,3,
33,23,33,3,35,1,51,1,35,2,147,204,1,159,37,254,15,162,
176,2,12,127,2,12,180,4,190,253,175,136,254,27,5,176,250,80,
0,0,0,3,0,121,0,0,4,61,5,176,0,18,0,42,0,81,
0,0,1,17,33,50,55,54,55,54,55,54,55,54,53,52,39,38,
39,38,35,1,17,51,50,54,55,54,55,54,55,54,53,52,39,38,
39,38,39,38,39,38,35,34,38,39,33,50,23,22,23,30,1,23,
22,21,20,6,35,50,23,22,23,22,23,22,23,22,21,20,7,6,
7,6,7,6,7,6,7,6,7,6,35,33,1,23,1,63,67,59,
55,39,40,24,27,10,11,7,19,81,82,143,254,193,237,85,122,36,
37,20,22,6,6,5,7,20,19,35,34,66,65,83,48,136,211,1,
139,116,93,92,55,53,66,11,8,168,86,75,56,59,38,36,24,22,
11,8,4,4,13,11,22,22,37,38,48,50,74,71,93,254,35,2,
193,253,204,17,16,28,29,35,39,40,42,43,37,27,94,58,59,2,
100,254,39,32,25,26,31,35,27,28,31,26,25,31,34,31,28,27,
17,17,2,139,26,26,44,43,106,55,45,32,117,180,26,27,44,42,
49,46,52,38,34,38,29,30,47,42,38,39,37,38,26,27,17,16,
0,0,0,1,0,121,0,0,4,11,5,176,0,5,0,0,19,33,
21,33,17,35,121,3,146,253,12,158,5,176,141,250,221,0,0,2,
0,120,0,0,5,182,5,160,0,3,0,6,0,0,51,1,51,1,
37,33,1,120,2,70,179,2,69,251,212,3,35,254,110,5,160,250,
96,157,4,66,0,0,0,1,0,121,0,0,4,18,5,176,0,11,
0,0,19,33,21,33,17,33,21,33,17,33,21,33,121,3,153,253,
5,2,208,253,48,2,251,252,103,5,176,141,254,14,141,253,233,141,
0,1,0,100,0,0,4,221,5,176,0,7,0,0,19,33,1,33,
21,33,1,33,129,4,80,252,160,3,108,251,135,3,105,252,180,5,
176,250,221,141,5,35,0,0,0,1,0,121,0,0,4,74,5,176,
0,11,0,0,19,51,17,33,17,51,17,35,17,33,17,35,121,158,
2,149,158,158,253,107,158,5,176,253,127,2,129,250,80,2,162,253,
94,0,0,3,0,92,255,227,4,238,5,215,0,37,0,77,0,81,
0,0,1,52,39,38,39,38,39,38,39,38,35,34,6,7,6,7,
14,1,21,20,23,22,23,22,23,22,23,22,51,50,55,54,55,54,
55,54,55,54,37,52,55,54,55,54,55,54,55,54,51,50,23,22,
23,22,23,22,23,22,21,20,7,6,7,6,7,6,7,6,35,34,
39,38,39,38,39,38,39,38,37,33,21,33,4,72,23,17,32,29,
48,46,70,67,88,94,146,47,47,30,30,24,22,15,33,29,48,46,
71,70,84,94,73,75,45,45,32,33,11,12,252,20,19,20,44,43,
67,64,103,101,123,122,98,100,66,65,45,44,22,24,20,20,44,47,
63,67,101,102,122,120,99,98,68,65,45,43,23,23,1,42,2,40,
253,216,2,213,115,112,79,73,67,60,57,34,32,80,64,63,85,84,
168,85,114,104,75,74,65,59,57,32,32,39,40,59,60,83,85,79,
82,85,103,101,104,102,100,82,79,50,49,46,47,78,76,97,93,108,
116,109,98,103,104,98,105,73,77,48,48,45,45,78,75,95,91,108,
109,188,142,0,0,0,0,1,0,154,0,0,1,55,5,176,0,3,
0,0,51,17,51,17,154,157,5,176,250,80,0,1,0,121,0,0,
4,211,5,176,0,11,0,0,19,51,17,1,51,9,1,35,1,7,
17,35,121,158,2,235,193,253,120,2,152,207,253,207,188,158,5,176,
253,14,2,242,253,115,252,221,2,190,186,253,252,0,0,1,0,123,
0,0,4,205,5,176,0,6,0,0,33,9,1,35,1,51,1,4,
41,254,125,254,127,170,1,190,219,1,185,5,8,250,248,5,176,250,
80,0,0,0,0,1,0,121,0,0,5,182,5,176,0,12,0,0,
51,17,51,9,1,51,17,35,17,1,35,1,17,121,215,1,203,1,
204,207,153,254,84,179,254,84,5,176,251,33,4,223,250,80,4,180,
251,92,4,164,251,76,0,1,0,121,0,0,4,147,5,176,0,9,
0,0,51,17,51,1,17,51,17,35,1,17,121,153,2,228,157,145,
253,21,5,176,251,119,4,137,250,80,4,166,251,90,0,3,0,110,
0,0,4,64,5,176,0,3,0,7,0,11,0,0,51,53,33,21,
1,33,21,33,19,33,21,33,110,3,209,252,47,3,210,252,46,178,
2,110,253,146,151,151,5,176,151,253,246,142,0,2,0,92,255,227,
4,238,5,215,0,37,0,77,0,0,1,52,39,38,39,38,39,38,
39,38,35,34,6,7,6,7,14,1,21,20,23,22,23,22,23,22,
23,22,51,50,55,54,55,54,55,54,55,54,37,52,55,54,55,54,
55,54,55,54,51,50,23,22,23,22,23,22,23,22,21,20,7,6,
7,6,7,6,7,6,35,34,39,38,39,38,39,38,39,38,4,72,
23,17,32,29,48,46,70,67,88,94,146,47,47,30,30,24,22,15,
33,29,48,46,71,70,84,94,73,75,45,45,32,33,11,12,252,20,
19,20,44,43,67,64,103,101,123,122,98,100,66,65,45,44,22,24,
20,20,44,47,63,67,101,102,122,120,99,98,68,65,45,43,23,23,
2,213,115,112,79,73,67,60,57,34,32,80,64,63,85,84,168,85,
114,104,75,74,65,59,57,32,32,39,40,59,60,83,85,79,82,85,
103,101,104,102,100,82,79,50,49,46,47,78,76,97,93,108,116,109,
98,103,104,98,105,73,77,48,48,45,45,78,75,95,91,108,109,0,
0,1,0,110,0,0,4,64,5,176,0,7,0,0,19,33,17,35,
17,33,17,35,110,3,210,158,253,106,158,5,176,250,80,5,25,250,
231,0,0,0,0,2,0,121,0,0,4,8,5,176,0,14,0,34,
0,0,1,51,32,17,52,39,38,39,38,39,38,39,38,43,1,39,
59,1,50,23,22,23,22,21,20,7,6,7,6,7,6,43,1,17,
35,1,23,206,1,129,6,9,22,24,39,43,71,68,103,206,158,158,
206,232,137,139,31,8,33,34,64,65,106,107,138,206,158,3,6,1,
17,35,25,42,33,37,29,32,18,17,141,88,89,147,48,37,87,74,
75,57,57,33,33,253,137,0,0,1,0,110,0,0,4,64,5,176,
0,11,0,0,19,33,21,33,9,1,33,21,33,53,9,1,110,3,
210,252,246,1,252,254,3,3,10,252,47,1,255,254,1,5,176,151,
253,197,253,185,151,151,2,69,2,61,0,1,0,88,0,0,4,156,
5,176,0,7,0,0,19,33,21,33,17,35,17,33,88,4,68,254,
55,158,254,35,5,176,141,250,221,5,35,0,0,0,0,1,0,66,
0,0,4,90,5,176,0,8,0,0,19,51,9,1,51,1,17,35,
17,66,168,1,100,1,100,168,254,66,158,5,176,253,168,2,88,253,
60,253,20,2,236,0,0,0,0,3,0,95,0,0,5,187,5,234,
0,41,0,61,0,82,0,0,1,53,51,21,22,23,22,23,22,23,
22,23,22,21,20,7,14,2,7,6,7,21,35,53,38,39,38,39,
38,39,46,1,53,52,54,55,54,55,54,55,54,19,17,6,7,6,
7,6,7,6,7,6,21,20,22,23,22,23,22,23,22,19,17,54,
55,54,55,54,55,54,55,54,53,52,39,38,39,38,39,38,39,38,
2,173,179,41,52,95,91,93,71,69,46,45,42,42,142,168,97,54,
58,179,45,47,92,90,93,67,70,86,82,69,68,85,82,97,52,55,
55,52,71,64,61,51,49,30,29,70,54,53,76,75,73,40,200,62,
52,72,65,60,54,51,31,29,36,36,57,59,74,76,76,44,5,33,
201,201,4,10,20,44,45,65,63,104,102,122,121,99,100,132,88,22,
13,6,153,153,4,11,20,44,46,64,67,202,123,119,200,66,65,45,
43,23,12,252,35,3,62,6,12,16,32,30,47,45,72,70,84,92,
150,45,44,33,32,12,6,3,60,252,194,6,13,17,32,29,48,45,
71,67,88,94,73,73,47,48,29,30,12,6,0,1,0,74,0,0,
4,137,5,176,0,11,0,0,19,51,9,1,51,9,1,35,9,1,
35,1,74,182,1,106,1,99,182,254,59,1,203,190,254,159,254,152,
178,1,199,5,176,253,162,2,94,253,41,253,39,2,74,253,182,2,
217,0,0,0,0,1,0,112,0,0,5,2,5,186,0,47,0,0,
1,20,23,22,23,22,23,22,23,22,23,17,51,17,54,55,54,55,
54,55,54,55,54,53,51,20,7,6,7,6,7,6,7,6,7,17,
35,17,38,39,38,39,38,39,38,39,38,53,1,22,22,15,33,29,
48,45,72,36,44,143,56,42,74,46,45,32,33,11,12,166,20,20,
44,47,63,67,101,69,86,143,74,71,98,68,65,45,43,23,23,5,
186,114,104,76,74,65,59,55,33,17,8,2,81,253,174,10,22,39,
61,60,83,85,79,83,84,98,103,104,98,105,73,77,48,33,11,253,
52,2,205,9,31,45,78,75,95,91,108,109,108,0,0,0,0,1,
0,25,0,0,5,53,5,215,0,75,0,0,37,38,39,38,39,38,
53,52,55,54,55,54,55,54,55,54,51,50,23,22,23,22,23,22,
23,22,21,20,7,6,7,6,15,1,33,21,33,53,54,55,54,55,
54,55,54,53,52,39,38,39,38,39,38,39,38,35,34,6,7,6,
7,14,1,21,20,23,22,23,22,23,22,23,51,21,33,55,1,32,
63,44,43,23,23,19,20,44,43,67,64,103,101,123,122,98,100,66,
65,45,44,22,24,20,20,44,45,72,4,1,20,253,253,75,57,59,
31,33,11,12,23,17,32,29,48,46,70,67,88,94,146,47,47,30,
30,24,22,15,33,31,55,57,69,1,253,252,1,142,73,94,91,108,
109,108,103,101,104,102,100,82,79,50,49,46,47,78,76,97,93,108,
116,109,98,103,104,98,101,75,4,142,142,40,64,66,82,85,79,82,
85,115,112,79,73,67,60,57,34,32,80,64,63,85,84,168,85,114,
104,75,74,69,57,58,32,142,142,0,0,3,255,157,0,0,2,48,
6,243,0,3,0,20,0,38,0,0,51,17,51,17,19,52,54,51,
50,22,23,22,21,20,6,35,34,39,38,39,38,37,52,54,51,50,
23,22,23,22,21,20,6,35,34,39,38,39,38,154,157,61,56,38,
34,50,8,2,56,38,32,27,25,8,2,254,41,56,38,33,26,25,
8,2,56,38,32,27,26,7,2,5,176,250,80,6,149,38,56,42,
33,10,9,39,56,22,21,33,16,1,38,56,21,21,33,10,9,39,
56,22,21,33,8,0,0,0,0,3,0,66,0,0,4,90,6,243,
0,8,0,25,0,42,0,0,19,51,9,1,51,1,17,35,17,19,
52,54,51,50,22,23,22,21,20,6,35,34,39,38,39,38,37,52,
54,51,50,22,23,22,21,20,6,35,34,39,38,39,38,66,168,1,
100,1,100,168,254,66,158,219,56,38,34,50,8,2,56,38,32,27,
26,7,2,254,41,56,38,34,50,8,2,56,38,32,27,25,8,2,
5,176,253,168,2,88,253,60,253,20,2,236,3,169,38,56,42,33,
10,9,39,56,22,21,33,16,1,38,56,42,33,10,9,39,56,22,
21,33,8,0,255,255,0,90,255,227,4,119,6,61,16,39,1,207,
1,5,255,77,16,6,1,249,0,0,255,255,0,138,255,227,3,107,
6,59,16,39,1,207,0,249,255,75,16,6,1,253,0,0,255,255,
0,118,254,116,3,177,6,60,16,38,1,255,0,0,16,7,1,207,
0,218,255,76,255,255,0,135,0,0,2,86,6,60,16,39,1,207,
255,162,255,76,16,6,2,1,0,0,255,255,0,118,255,228,3,181,
6,46,16,39,1,208,0,44,254,184,16,6,2,13,0,0,0,2,
0,90,255,227,4,119,4,70,0,25,0,63,0,0,19,20,23,22,
23,30,1,51,50,54,55,54,55,54,53,52,39,38,39,38,35,34,
7,6,7,6,1,38,47,1,53,6,7,6,32,38,39,38,53,52,
55,54,55,54,55,54,51,50,23,22,23,54,55,54,51,21,34,7,
6,7,21,30,1,51,244,16,16,34,33,110,75,73,110,33,34,16,
16,28,27,65,64,98,100,64,65,27,28,3,127,177,75,4,44,71,
101,254,234,202,48,49,29,30,52,56,81,84,106,138,100,71,44,10,
32,62,158,76,60,39,2,6,102,65,2,25,92,74,76,61,60,68,
68,60,61,76,74,92,118,95,91,59,58,58,59,91,95,253,103,3,
163,10,13,77,54,77,154,126,129,157,118,102,104,73,77,41,42,75,
53,75,18,43,122,138,98,64,130,228,150,140,0,0,0,3,0,111,
254,104,3,156,5,203,0,39,0,57,0,83,0,0,19,62,1,59,
1,22,23,22,23,22,29,1,20,7,6,7,6,7,6,7,6,7,
22,23,22,23,22,23,22,23,22,21,16,33,34,39,3,35,19,54,
31,1,51,50,55,54,55,54,53,52,39,38,35,34,7,6,7,6,
11,1,23,22,23,50,22,51,50,55,54,55,54,55,54,55,54,53,
52,39,38,39,38,43,1,34,157,49,178,125,13,103,123,124,27,8,
22,23,33,37,41,46,39,41,38,43,47,47,50,53,37,37,16,7,
254,6,68,89,2,148,1,12,141,52,42,92,87,91,64,65,8,42,
182,35,29,122,41,30,5,2,50,34,72,3,13,4,40,53,42,55,
51,29,30,20,19,5,24,124,126,139,36,39,4,128,157,174,3,82,
84,140,45,42,13,58,48,51,33,37,27,30,16,17,10,11,22,23,
35,37,53,52,68,27,41,254,104,39,254,95,4,236,201,229,3,29,
30,60,60,74,36,40,197,5,49,188,106,254,189,254,5,33,20,6,
1,7,4,21,19,28,28,50,47,65,17,28,111,72,73,0,0,0,
0,1,0,82,254,71,3,199,4,49,0,8,0,0,33,35,1,51,
9,1,51,1,39,1,193,3,254,148,160,1,24,1,31,158,253,251,
159,4,49,252,146,3,110,250,22,1,0,0,0,2,0,90,255,227,
3,225,5,174,0,26,0,53,0,0,19,20,23,22,23,30,1,51,
50,54,55,54,55,54,53,52,39,38,47,1,38,35,34,7,6,7,
6,7,52,55,54,55,54,55,54,55,37,53,33,21,33,1,22,23,
22,21,20,6,7,6,32,38,39,38,244,16,16,34,33,110,75,73,
110,33,34,16,16,28,27,65,24,58,80,100,64,65,27,28,154,29,
30,52,56,81,48,64,254,228,3,59,253,195,1,90,101,48,49,96,
100,101,254,234,202,48,49,2,25,92,74,76,61,60,68,68,60,61,
76,74,92,118,95,91,59,18,40,58,59,91,95,118,118,102,104,73,
77,41,25,11,224,142,142,254,219,76,123,127,156,161,252,76,77,154,
126,129,0,0,0,1,0,138,255,227,3,107,4,74,0,61,0,0,
37,6,7,6,35,34,38,53,52,55,54,55,54,63,1,38,39,38,
39,38,53,52,55,54,55,54,51,50,23,22,23,7,46,1,43,1,
34,7,6,21,20,23,22,59,1,21,35,34,7,6,7,6,7,6,
21,20,23,22,51,50,54,55,3,107,43,102,101,101,164,226,25,25,
37,59,20,84,40,42,45,23,32,45,51,67,73,78,99,77,79,41,
100,24,96,58,17,65,38,72,61,59,73,72,57,47,40,34,43,40,
26,29,73,75,103,63,120,29,195,102,61,61,190,145,130,47,49,34,
55,3,42,13,20,22,23,38,70,51,60,67,33,35,52,53,84,52,
47,66,26,49,51,73,30,29,125,13,10,27,25,37,41,121,91,54,
55,66,54,0,0,1,0,105,254,116,3,195,5,167,0,39,0,0,
1,33,53,33,21,7,0,17,48,21,18,33,50,55,54,51,48,51,
50,21,48,21,17,35,17,38,39,38,7,6,35,48,35,38,39,38,
39,38,53,18,1,179,254,187,2,110,54,254,80,7,1,31,106,71,
60,33,8,145,152,5,5,17,18,77,154,9,142,98,100,41,40,6,
5,25,142,142,3,254,124,254,23,29,254,223,43,36,181,5,254,116,
1,140,35,7,24,18,77,1,76,76,113,111,162,1,95,0,0,1,
0,118,254,116,3,177,4,78,0,34,0,0,33,35,17,51,21,62,
1,51,50,23,22,23,22,23,22,21,17,35,17,52,39,38,39,38,
39,38,35,34,7,6,7,6,7,6,21,1,14,152,152,29,162,115,
82,66,67,49,52,26,27,151,14,16,28,30,52,51,67,70,50,53,
30,32,15,16,4,49,181,90,120,33,34,66,71,104,108,145,252,87,
3,169,95,70,79,55,58,34,33,34,36,57,62,73,80,83,0,3,
0,100,255,227,4,25,5,213,0,24,0,39,0,54,0,0,19,52,
55,62,1,55,54,51,50,23,22,23,22,21,20,7,6,7,6,35,
34,39,38,39,38,37,33,22,23,22,23,22,51,50,55,54,55,54,
55,54,37,33,38,39,38,39,38,35,34,7,6,7,6,7,6,100,
33,33,120,93,92,111,164,114,114,46,29,55,54,110,110,147,167,116,
115,47,28,3,21,253,139,5,19,34,73,73,109,79,64,65,35,37,
19,12,253,145,2,116,6,20,33,70,71,107,78,66,64,38,40,18,
12,2,215,155,138,140,208,63,62,132,134,216,139,145,204,173,168,106,
105,133,132,218,130,79,100,91,160,100,99,56,57,90,93,104,65,227,
96,98,158,97,98,58,57,93,98,102,61,0,0,1,0,135,0,0,
2,86,4,50,0,26,0,0,19,51,17,20,51,63,4,23,6,7,
6,7,6,35,34,39,38,39,38,39,38,39,38,53,135,156,102,27,
22,18,16,15,107,36,8,17,35,36,42,28,29,32,41,37,38,36,
23,24,4,50,252,208,123,3,8,12,12,14,102,34,6,12,15,15,
8,9,21,19,35,33,49,51,64,0,0,1,0,90,0,0,3,136,
4,53,0,10,0,0,19,51,17,1,51,9,1,35,1,17,35,90,
158,1,160,186,254,6,2,48,216,254,72,158,4,48,254,80,1,181,
253,231,253,228,1,149,254,107,0,1,0,74,0,0,3,199,5,176,
0,32,0,0,51,1,39,38,35,15,4,39,54,55,54,55,54,51,
48,51,22,23,22,23,22,23,22,23,22,23,1,35,9,1,82,1,
108,94,22,51,27,22,18,16,15,107,36,8,17,35,36,44,11,43,
24,32,41,37,38,10,12,17,1,1,195,158,254,225,254,232,4,49,
224,24,3,8,12,12,14,102,34,6,12,15,15,2,6,9,21,19,
35,9,15,22,4,250,222,3,110,252,146,0,0,1,0,118,254,117,
3,178,4,50,0,35,0,0,37,17,35,17,51,17,20,23,22,51,
48,51,50,55,54,55,54,55,54,53,17,51,17,35,53,6,7,6,
35,34,39,38,39,38,39,38,1,5,143,145,12,39,191,7,154,52,
33,17,16,10,9,143,143,44,61,59,117,44,60,61,21,23,18,22,
74,254,43,5,189,253,108,76,56,171,64,41,38,35,47,40,38,2,
148,251,206,98,56,35,34,9,9,15,17,16,20,0,0,0,0,1,
0,82,0,0,3,165,4,94,0,21,0,0,33,1,51,1,19,55,
52,38,35,55,22,23,22,23,22,23,22,21,35,22,7,1,1,190,
254,148,160,1,24,249,9,180,128,158,72,56,54,41,40,20,20,3,
2,5,254,150,4,49,252,146,1,119,21,181,240,106,29,55,52,72,
70,82,83,84,15,6,253,198,0,0,0,1,0,51,254,116,3,195,
5,211,0,68,0,0,37,50,55,54,51,48,51,50,21,48,21,17,
35,17,38,39,38,7,6,35,48,35,34,0,53,52,55,54,55,54,
55,54,55,38,39,38,39,38,53,52,55,54,55,35,53,33,21,35,
6,7,6,21,20,23,22,59,1,21,35,34,7,14,1,7,6,21,
20,23,22,2,28,106,71,60,33,8,145,152,5,5,11,10,54,174,
12,207,254,230,25,26,38,39,42,44,36,38,40,39,33,33,58,20,
11,100,2,109,248,73,57,74,72,72,96,98,78,60,58,59,94,29,
28,96,95,107,43,36,181,5,254,116,1,140,35,7,15,15,77,1,
2,195,72,65,68,45,46,32,33,10,19,40,39,70,71,82,110,88,
28,13,142,142,12,56,71,100,112,74,74,125,20,20,74,61,59,73,
140,86,85,0,0,2,0,90,255,227,3,196,4,70,0,22,0,48,
0,0,19,52,55,54,55,54,55,54,51,50,23,22,23,22,21,20,
6,7,6,32,38,39,38,55,20,23,22,23,30,1,51,50,54,55,
54,55,54,53,52,39,38,39,38,35,34,7,6,7,6,90,29,30,
52,56,81,84,106,138,100,101,48,49,96,100,101,254,234,202,48,49,
154,16,16,34,33,110,75,73,110,33,34,16,16,28,27,65,64,98,
100,64,65,27,28,2,25,118,102,104,73,77,41,42,75,76,123,127,
156,161,252,76,77,154,126,129,157,92,74,76,61,60,68,68,60,61,
76,74,92,118,95,91,59,58,58,59,91,95,0,1,0,22,0,0,
4,17,4,84,0,11,0,0,19,35,53,33,21,35,17,35,17,33,
17,35,127,105,3,251,85,158,253,255,158,3,186,154,154,252,70,3,
186,252,70,0,0,0,0,2,0,90,254,116,3,195,4,79,0,15,
0,52,0,0,1,52,39,38,35,34,7,6,21,20,23,22,51,50,
55,54,37,52,55,54,55,54,55,54,51,50,23,22,23,22,23,22,
21,20,7,6,7,6,7,6,7,6,35,34,39,38,39,3,35,17,
55,53,38,3,15,77,76,116,117,79,80,80,80,116,116,76,77,253,
75,29,30,52,56,81,102,102,100,79,49,35,71,39,48,47,48,100,
64,70,16,30,27,33,139,101,20,24,1,152,1,2,2,28,199,115,
113,115,116,198,196,118,117,117,118,195,118,102,104,73,77,41,51,47,
29,41,66,100,124,159,164,123,126,76,48,17,4,4,4,77,15,24,
254,29,3,1,5,97,40,0,0,1,0,90,254,116,3,195,4,70,
0,56,0,0,1,20,23,22,51,50,55,54,51,48,51,50,21,48,
21,17,35,17,38,39,38,7,6,35,48,35,34,39,38,39,38,39,
46,1,53,52,55,54,55,54,55,54,55,54,51,50,23,22,23,7,
38,39,38,35,34,7,6,1,14,78,76,116,106,71,60,33,8,145,
152,5,5,17,18,77,154,9,24,36,30,16,75,59,100,96,20,20,
40,41,54,56,73,74,84,114,85,86,53,130,18,60,61,69,128,76,
78,2,28,197,119,117,43,36,181,5,254,116,1,140,35,7,24,18,
77,4,4,4,19,46,76,252,161,84,83,82,70,72,52,54,30,30,
61,62,96,66,49,50,50,118,121,0,0,2,0,90,255,227,4,25,
4,70,0,25,0,49,0,0,19,20,23,22,23,30,1,51,50,54,
55,54,55,54,53,52,39,38,39,38,35,34,7,6,7,6,7,52,
55,54,55,54,55,54,51,33,21,35,22,23,22,21,20,6,7,6,
32,38,39,38,244,16,16,34,33,110,75,73,110,33,34,16,16,28,
27,65,64,98,100,64,65,27,28,154,29,30,52,56,81,84,106,2,
9,217,51,32,49,96,100,101,254,234,202,48,49,2,25,92,74,76,
61,60,68,68,60,61,76,74,92,118,95,91,59,58,58,59,91,95,
118,118,102,104,73,77,41,42,136,57,81,127,156,161,252,76,77,154,
126,129,0,0,0,1,0,120,0,0,3,178,4,50,0,30,0,0,
19,33,21,33,3,20,51,63,4,23,6,7,6,7,6,35,34,39,
38,39,38,39,38,39,38,53,3,33,120,3,58,254,183,2,102,27,
22,18,16,15,107,36,8,17,35,36,42,28,29,32,41,37,38,36,
23,24,2,254,174,4,50,141,253,93,123,3,8,12,12,14,102,34,
6,12,15,15,8,9,21,19,35,33,49,51,64,2,132,0,0,0,
0,1,0,118,255,228,3,181,4,72,0,43,0,0,5,39,38,39,
38,39,38,39,38,53,17,51,17,20,23,22,23,22,23,22,23,54,
55,54,55,54,55,53,46,2,35,53,50,23,22,23,22,21,20,7,
6,7,6,2,16,24,60,84,86,50,52,26,28,151,15,16,28,30,
52,50,64,74,61,63,30,31,7,6,60,120,76,129,97,96,50,49,
49,48,97,97,28,1,1,31,33,66,70,106,112,140,2,29,253,227,
90,75,79,55,58,34,31,2,2,52,54,79,81,95,135,90,156,108,
136,74,74,125,123,161,156,130,126,78,77,0,0,0,0,2,0,55,
254,121,4,139,4,72,0,50,0,69,0,0,37,3,53,52,55,54,
55,54,55,54,51,50,23,22,23,22,21,20,7,6,7,6,7,6,
7,3,35,17,38,39,38,39,38,53,52,55,54,55,54,51,21,34,
14,1,7,21,22,23,22,23,22,37,54,55,54,55,54,55,53,38,
39,38,39,38,39,35,34,6,29,1,2,24,3,29,30,44,40,52,
49,38,60,37,151,60,40,48,3,8,58,111,119,129,1,152,131,119,
122,58,49,49,50,95,97,129,75,120,60,6,7,31,18,38,85,1,
38,141,83,36,19,31,7,6,30,31,58,52,39,4,39,58,106,2,
199,1,61,51,52,35,32,21,20,20,81,175,114,161,39,247,15,8,
113,69,75,1,254,149,1,107,2,74,78,127,130,156,161,123,126,73,
74,136,108,156,90,135,95,81,50,46,93,1,2,90,44,52,81,95,
135,90,78,79,53,47,2,52,45,176,0,1,0,74,254,116,3,182,
4,124,0,11,0,0,19,35,9,1,51,9,1,51,9,1,35,1,
232,158,1,103,254,153,158,1,24,1,24,158,254,153,1,103,158,254,
232,254,116,3,4,3,4,253,166,2,90,252,252,252,252,2,90,0,
0,0,0,1,0,90,254,116,3,196,4,50,0,41,0,0,1,17,
54,55,54,55,54,55,54,53,48,53,3,51,19,20,7,6,7,6,
7,17,35,17,38,39,38,39,38,53,3,51,17,20,23,22,23,22,
23,22,23,17,2,79,34,31,56,33,32,17,16,2,154,2,48,48,
100,76,101,143,91,69,100,48,49,1,155,16,17,32,34,54,20,30,
4,50,252,92,9,18,35,60,59,77,74,86,6,1,42,254,214,161,
126,127,76,58,14,254,112,1,147,17,53,76,127,127,159,1,42,254,
214,92,74,77,59,61,34,12,10,3,159,0,0,1,0,55,0,0,
4,139,4,72,0,72,0,0,37,6,7,6,7,6,7,6,35,34,
39,38,53,52,55,54,55,54,51,21,34,14,1,7,21,22,23,22,
23,50,55,54,55,54,53,17,51,17,20,23,22,23,22,51,54,55,
54,55,53,38,39,38,39,38,35,53,50,23,22,23,22,21,20,7,
6,35,34,39,38,39,38,39,38,2,97,10,15,25,33,32,51,47,
55,141,96,49,49,50,95,97,129,75,120,60,6,7,31,30,63,56,
33,66,38,9,125,9,38,65,33,56,63,30,31,7,6,30,31,58,
60,76,129,97,95,50,49,48,96,142,54,47,51,32,33,25,17,221,
30,26,42,36,35,27,25,253,130,156,161,123,126,73,74,136,108,156,
90,135,95,81,79,54,24,42,115,36,37,1,40,254,216,37,36,116,
41,24,54,79,81,95,135,90,78,79,53,54,136,74,73,126,123,161,
159,127,253,25,27,35,36,42,30,0,0,0,255,255,255,137,0,0,
2,86,5,172,16,38,2,1,0,0,16,7,0,106,255,61,254,185,
255,255,0,118,255,228,3,181,5,171,16,39,0,106,0,66,254,184,
16,6,2,13,0,0,0,3,0,90,255,227,3,196,6,63,0,22,
0,48,0,75,0,0,19,52,55,54,55,54,55,54,51,50,23,22,
23,22,21,20,6,7,6,32,38,39,38,55,20,23,22,23,30,1,
51,50,54,55,54,55,54,53,52,39,38,39,38,35,34,7,6,7,
6,1,19,54,55,54,51,50,23,22,23,22,23,22,21,20,6,21,
7,6,7,6,43,1,38,47,1,38,90,29,30,52,56,81,84,106,
138,100,101,48,49,96,100,101,254,234,202,48,49,154,16,16,34,33,
110,75,73,110,33,34,16,16,28,27,65,64,98,100,64,65,27,28,
1,4,8,5,31,17,17,9,5,31,16,3,4,11,1,48,5,18,
13,18,6,22,14,6,6,2,25,118,102,104,73,77,41,42,75,76,
123,127,156,161,252,76,77,154,126,129,157,92,74,76,61,60,68,68,
60,61,76,74,92,118,95,91,59,58,58,59,91,95,2,108,1,0,
41,18,9,1,3,21,4,6,19,20,1,8,1,251,24,10,8,3,
15,9,12,0,255,255,0,118,255,228,3,181,6,61,16,39,1,207,
0,156,255,77,16,6,2,13,0,0,255,255,0,55,0,0,4,139,
6,60,16,39,1,207,1,62,255,76,16,6,2,17,0,0,255,255,
0,121,0,0,4,211,5,176,16,6,1,227,0,0,0,3,0,111,
0,0,3,140,5,203,0,17,0,35,0,92,0,0,1,23,51,50,
55,54,55,54,53,52,39,38,35,34,7,6,7,6,3,22,23,22,
23,22,51,50,55,54,53,52,39,38,39,38,43,1,7,53,54,55,
62,1,59,1,22,23,22,23,22,29,1,20,7,6,7,6,7,6,
7,6,7,34,6,35,23,22,23,22,23,22,23,22,23,22,29,1,
20,7,6,7,6,7,35,34,39,38,39,38,39,52,38,52,54,1,
9,52,42,92,87,91,64,65,8,42,182,35,29,122,41,30,3,4,
30,41,122,35,29,182,42,8,65,63,92,90,89,42,206,12,33,49,
178,125,13,103,123,124,27,8,22,23,33,37,41,46,39,41,38,7,
24,6,38,38,41,39,46,41,37,32,24,22,8,27,124,123,103,13,
126,88,89,49,34,12,1,1,3,56,3,29,30,60,60,74,36,40,
197,5,49,188,106,254,172,175,106,188,49,6,198,40,36,74,60,58,
31,30,5,195,201,99,157,174,3,82,84,140,45,42,13,58,48,51,
33,37,27,30,16,17,10,1,10,10,17,16,30,27,37,32,53,48,
57,13,42,45,140,84,82,3,87,87,157,103,196,2,9,6,8,0,
0,0,0,3,0,100,255,227,4,25,5,213,0,24,0,39,0,54,
0,0,19,52,55,62,1,55,54,51,50,23,22,23,22,21,20,7,
6,7,6,35,34,39,38,39,38,37,33,22,23,22,23,22,51,50,
55,54,55,54,55,54,37,33,38,39,38,39,38,35,34,7,6,7,
6,7,6,100,33,33,120,93,92,111,164,114,114,46,29,55,54,110,
110,147,167,116,115,47,28,3,21,253,139,5,19,34,73,73,109,79,
64,65,35,37,19,12,253,145,2,116,6,20,33,70,71,107,78,66,
64,38,40,18,12,2,215,155,138,140,208,63,62,132,134,216,139,145,
204,173,168,106,105,133,132,218,130,79,100,91,160,100,99,56,57,90,
93,104,65,227,96,98,158,97,98,58,57,93,98,102,61,0,0,1,
0,25,0,0,5,167,5,176,0,50,0,0,9,1,17,35,17,1,
38,35,15,4,39,54,55,54,55,54,51,48,51,22,23,22,23,22,
23,9,1,54,55,54,55,54,55,48,51,50,23,22,23,22,23,7,
47,4,34,4,136,254,166,158,254,167,28,53,27,22,18,16,15,107,
36,8,17,35,36,44,11,43,24,44,29,74,36,1,18,1,18,36,
74,29,44,24,43,11,44,36,35,17,8,36,107,15,16,18,22,27,
56,5,18,253,218,253,20,2,236,2,38,23,3,8,11,13,14,102,
34,6,12,15,15,2,6,12,18,48,56,254,54,1,202,56,48,18,
12,6,2,15,15,12,6,34,102,14,13,11,8,3,255,255,0,54,
0,0,6,23,6,240,16,39,1,207,255,62,0,0,16,6,2,26,
112,0,255,255,0,25,0,0,5,167,6,243,16,38,2,26,0,0,
16,7,0,106,1,74,0,0,0,3,0,126,254,116,4,146,5,234,
0,23,0,32,0,41,0,0,1,22,21,20,7,6,7,17,35,17,
38,39,38,53,52,55,54,55,17,51,17,22,23,22,7,17,54,55,
54,53,52,39,38,1,17,6,7,6,21,20,23,22,3,250,152,153,
126,168,157,165,122,153,152,122,166,157,47,58,118,223,111,84,112,111,
83,254,242,106,84,112,112,81,3,98,152,214,216,152,124,23,254,131,
1,126,24,122,152,216,214,152,122,24,1,246,254,12,5,19,47,68,
253,18,21,84,112,158,160,111,83,253,40,2,236,21,82,112,159,158,
112,81,0,0,0,2,0,0,0,0,4,139,4,72,0,36,0,72,
0,0,37,6,7,6,7,6,7,6,35,34,39,38,53,52,55,54,
55,35,53,33,50,23,22,23,22,21,20,7,6,35,34,39,38,39,
38,39,38,19,33,34,14,1,7,21,22,23,22,23,50,55,54,55,
54,53,17,51,17,20,23,22,23,22,51,54,55,54,55,53,38,39,
38,39,38,2,97,10,15,25,33,32,51,47,55,141,96,49,49,33,
47,184,2,231,129,97,95,50,49,48,96,142,54,47,51,32,33,25,
17,125,254,244,75,120,60,6,7,31,30,63,56,33,66,38,9,125,
9,38,65,33,56,63,30,31,7,6,30,31,58,60,221,30,26,42,
36,35,27,25,253,130,156,161,123,81,56,136,74,73,126,123,161,159,
127,253,25,27,35,36,42,30,2,253,108,156,90,135,95,81,79,54,
24,42,115,36,37,1,40,254,216,37,36,116,41,24,54,79,81,95,
135,90,78,79,53,54,0,0,0,1,0,81,254,116,3,225,4,185,
0,51,0,0,19,54,53,52,39,38,39,38,39,38,39,53,22,23,
22,23,22,21,48,21,1,51,1,6,7,20,6,21,20,23,22,23,
22,59,1,50,21,17,35,17,38,39,38,35,48,35,34,39,38,39,
3,35,252,40,1,9,21,28,24,51,77,147,72,69,24,33,1,92,
158,254,210,46,2,1,43,39,66,73,57,17,117,152,5,5,5,30,
2,90,146,75,23,181,158,1,14,110,121,30,15,108,123,168,37,78,
13,136,24,87,82,155,211,129,19,2,60,254,16,102,77,2,9,2,
60,35,31,17,18,225,254,116,1,140,35,7,6,88,53,110,254,213,
0,0,0,2,0,92,254,116,4,238,5,215,0,42,0,80,0,0,
19,52,55,54,55,54,55,54,55,54,51,50,23,22,23,22,23,22,
23,22,21,20,7,6,7,6,7,6,7,6,7,17,35,17,38,39,
38,39,38,39,38,39,38,37,52,39,38,39,38,39,38,39,38,35,
34,6,7,6,7,14,1,21,20,23,22,23,22,23,22,23,22,51,
50,55,54,55,54,55,54,55,54,92,19,20,44,43,67,64,103,101,
123,122,98,100,66,65,45,44,22,24,20,20,44,47,63,67,101,75,
83,142,79,64,98,68,65,45,43,23,23,3,236,23,17,32,29,48,
46,70,67,88,94,146,47,47,30,30,24,22,15,33,29,48,46,71,
70,84,94,73,75,45,45,32,33,11,12,2,213,103,101,104,102,100,
82,79,50,49,46,47,78,76,97,93,108,116,109,98,103,104,98,105,
73,77,48,35,9,254,141,1,116,11,29,45,78,75,95,91,108,109,
108,115,112,79,73,67,60,57,34,32,80,64,63,85,84,168,85,114,
104,75,74,65,59,57,32,32,39,40,59,60,83,85,79,82,0,2,
0,90,254,116,3,196,4,70,0,25,0,53,0,0,19,20,23,22,
23,30,1,51,50,54,55,54,55,54,53,52,39,38,39,38,35,34,
7,6,7,6,7,52,55,54,55,54,55,54,51,50,23,22,23,22,
21,20,6,7,6,7,17,35,17,38,39,38,39,38,244,16,16,34,
33,110,75,73,110,33,34,16,16,28,27,65,64,98,100,64,65,27,
28,154,29,30,52,56,81,84,106,138,100,101,48,49,96,100,76,93,
142,96,73,101,48,49,2,25,92,74,76,61,60,68,68,60,61,76,
74,92,118,95,91,59,58,58,59,91,95,118,118,102,104,73,77,41,
42,75,76,123,127,156,161,252,76,57,15,254,140,1,116,15,57,77,
126,129,0,0,0,1,0,100,254,89,4,129,5,215,0,70,0,0,
37,6,7,6,35,34,39,38,39,38,39,38,39,38,53,52,55,54,
55,54,55,54,55,54,51,50,23,22,23,22,23,22,23,22,23,7,
38,39,38,43,1,34,7,6,7,6,7,6,21,20,23,22,23,22,
23,22,51,50,55,54,51,48,51,50,21,48,21,17,35,17,38,3,
198,41,50,79,96,117,102,100,69,71,47,50,22,22,23,22,49,47,
72,70,100,99,120,73,71,66,50,49,39,40,24,24,15,149,28,86,
83,105,2,104,84,86,52,51,29,28,30,30,54,53,85,82,100,106,
71,60,33,8,145,152,1,33,19,16,27,41,40,72,74,94,101,105,
107,120,116,113,109,101,97,75,73,43,43,19,18,30,30,40,42,40,
41,41,41,89,57,55,54,56,88,87,114,109,121,120,111,110,86,83,
53,51,43,36,181,5,254,85,1,171,16,0,0,0,0,1,0,101,
254,84,3,215,4,70,0,49,0,0,1,38,39,38,35,34,6,21,
20,22,51,50,55,54,59,1,50,29,1,17,35,17,38,39,38,7,
6,43,1,55,38,39,38,39,38,53,52,55,54,55,54,55,54,55,
54,51,50,23,22,23,3,2,18,60,61,69,128,180,176,130,106,71,
60,33,8,145,152,5,5,17,18,77,154,9,1,121,102,106,58,59,
20,20,40,41,54,56,72,74,84,115,85,86,53,3,41,49,50,50,
240,181,195,236,43,36,181,5,254,85,1,171,35,7,24,18,77,1,
3,73,77,128,130,155,84,83,82,70,72,52,55,29,30,61,62,96,
0,1,0,121,0,0,4,18,5,176,0,9,0,0,19,33,21,33,
17,33,21,33,17,35,121,3,153,253,5,2,208,253,48,158,5,176,
141,254,14,141,253,92,0,0,0,1,0,0,254,116,3,252,4,143,
0,65,0,0,1,47,3,34,7,6,7,6,7,6,29,1,33,21,
33,17,20,7,6,7,14,1,35,34,39,38,47,2,53,22,23,22,
23,30,1,51,50,55,54,55,54,55,54,53,17,35,53,51,52,55,
54,55,62,1,51,50,23,22,23,22,23,22,23,3,238,49,42,43,
50,71,43,44,25,26,9,10,1,40,254,214,28,29,54,55,160,102,
26,11,24,11,40,52,37,4,16,16,20,22,25,76,60,57,37,37,
16,17,220,220,19,20,42,43,144,106,24,32,22,25,19,29,24,31,
3,213,27,17,9,3,28,29,61,66,66,77,23,1,116,254,74,132,
97,100,66,67,66,1,2,2,7,12,112,7,1,4,2,2,2,23,
22,51,50,78,80,102,1,188,116,75,92,96,74,76,66,2,1,7,
5,12,10,17,0,0,0,1,0,91,254,223,3,204,6,35,0,67,
0,0,1,33,53,19,54,53,52,47,1,35,15,2,39,54,55,54,
55,48,51,50,23,22,23,22,23,22,23,22,21,48,21,20,7,3,
33,21,3,6,21,20,31,1,51,63,2,23,6,7,6,7,48,35,
34,39,38,39,38,39,38,39,38,53,48,53,52,55,3,27,253,91,
201,13,67,26,23,21,20,19,65,34,21,25,33,8,37,33,20,31,
32,27,32,20,26,34,168,2,165,201,13,67,26,23,21,20,19,65,
34,21,25,33,8,37,33,20,31,32,27,32,20,26,34,2,58,142,
2,46,37,26,63,24,7,5,6,8,132,15,7,8,1,13,7,21,
22,31,37,38,51,42,5,9,100,254,29,142,253,210,37,26,63,24,
7,5,7,7,132,15,7,8,1,13,7,21,22,31,37,38,51,42,
5,9,100,0,0,1,0,118,255,49,3,177,5,209,0,9,0,0,
1,33,21,1,39,1,33,53,1,23,1,13,2,164,254,229,133,1,
9,253,92,1,27,133,2,200,142,252,247,48,2,217,142,3,9,48,
0,0,0,1,0,131,0,50,5,86,5,238,0,81,0,0,19,39,
54,55,54,55,54,55,54,51,50,23,22,23,22,23,22,23,30,1,
23,22,21,20,7,14,1,7,6,7,6,35,34,39,38,39,38,39,
55,22,23,22,51,50,55,54,55,54,55,52,54,53,52,39,38,39,
4,7,6,7,3,35,3,54,55,54,55,38,47,1,38,39,38,39,
38,35,34,7,17,35,17,6,210,79,26,51,52,63,100,111,29,37,
73,66,97,92,92,75,73,61,58,72,6,1,20,24,132,103,81,84,
46,44,40,26,72,60,64,49,107,75,110,26,13,88,77,85,47,47,
4,1,26,20,32,254,249,175,111,24,2,88,2,46,105,222,249,30,
30,80,57,107,116,122,7,16,29,30,91,105,4,180,50,49,51,52,
36,58,14,4,19,29,61,62,84,82,105,101,214,107,14,28,82,80,
97,170,60,47,17,9,5,13,29,30,41,109,65,10,2,44,50,85,
86,100,5,18,4,87,98,76,68,42,87,56,67,254,255,1,24,123,
49,105,39,45,35,96,60,68,74,9,1,6,254,138,1,85,54,0,
0,0,0,1,0,78,0,0,4,97,5,115,0,41,0,0,19,54,
55,54,51,50,23,30,1,23,22,23,30,1,23,29,1,20,7,6,
7,6,7,54,19,53,52,39,38,39,1,39,1,38,39,1,39,37,
39,38,39,38,78,100,112,29,37,73,66,96,184,75,76,59,58,72,
6,19,24,67,66,103,115,3,29,21,38,254,68,35,1,189,41,40,
254,73,35,1,169,6,57,113,131,5,39,58,14,4,19,28,124,84,
85,102,101,214,107,14,28,86,76,95,87,85,60,66,1,131,3,87,
111,79,78,254,254,63,1,3,68,50,254,251,63,253,7,59,75,88,
0,0,0,1,0,42,254,84,3,102,5,176,0,57,0,0,41,1,
17,51,17,51,17,59,2,17,23,17,51,17,21,20,7,6,7,6,
7,6,7,6,35,34,39,38,39,38,47,1,34,7,6,7,6,7,
39,54,55,54,55,54,51,50,23,22,31,2,22,51,50,55,54,53,
2,206,253,171,158,151,1,157,1,123,158,23,22,35,34,33,30,105,
58,83,42,36,35,17,8,36,47,35,35,33,24,27,28,2,16,34,
24,37,35,37,25,30,28,24,48,53,79,56,26,22,102,5,176,250,
221,5,35,250,222,1,5,35,250,80,139,63,52,50,32,31,24,21,
11,5,15,15,12,6,34,16,16,15,21,23,23,186,12,30,21,17,
16,16,16,22,44,38,16,5,43,80,0,0,0,1,0,42,254,84,
3,102,4,50,0,57,0,0,41,1,17,51,17,51,17,59,2,17,
23,17,51,17,21,20,7,6,7,6,7,6,7,6,35,34,39,38,
39,38,47,1,34,7,6,7,6,7,39,54,55,54,55,54,51,50,
23,22,31,2,22,51,50,55,54,53,2,206,253,171,158,151,1,157,
1,123,158,23,22,35,34,33,30,105,58,83,42,36,35,17,8,36,
47,35,35,33,24,27,28,2,16,34,24,37,35,37,25,30,28,24,
48,53,79,56,26,22,102,4,50,252,91,3,165,252,92,1,3,165,
251,206,139,63,52,50,32,31,24,21,11,5,15,15,12,6,34,16,
16,15,21,23,23,186,12,30,21,17,16,16,16,22,44,38,16,5,
43,80,0,0,0,1,0,121,0,0,4,8,5,176,0,32,0,0,
1,51,17,35,17,35,34,39,46,1,39,38,53,52,55,54,55,54,
51,21,34,7,6,7,6,7,6,7,6,21,16,33,51,3,106,158,
158,206,138,106,108,128,34,33,8,30,141,137,231,102,68,71,43,41,
23,22,9,6,1,129,206,5,176,250,80,2,119,33,33,114,75,74,
87,43,42,146,90,88,141,17,18,32,31,35,33,42,25,35,254,239,
0,1,0,129,254,84,3,207,4,78,0,45,0,0,1,52,39,53,
51,17,35,17,6,7,6,7,6,7,6,35,34,39,38,39,38,39,
38,53,52,55,62,2,51,50,31,1,38,35,34,7,6,21,20,23,
22,51,50,55,54,3,60,5,152,152,18,25,22,35,35,50,47,65,
102,78,79,46,47,22,23,23,22,94,154,102,62,50,45,56,73,116,
76,77,77,76,116,117,79,80,2,25,156,193,187,250,35,2,100,42,
38,34,32,32,18,17,48,49,81,83,98,101,108,110,101,96,164,92,
18,161,43,114,115,198,199,118,116,116,118,0,0,0,0,1,0,129,
254,84,3,189,5,176,0,76,0,0,33,21,20,7,6,7,6,7,
6,7,6,35,34,39,38,39,38,47,1,34,6,7,6,7,39,54,
55,62,1,51,50,23,22,31,2,22,51,50,55,54,61,1,17,52,
39,38,39,46,1,35,34,7,6,7,6,7,6,21,17,35,17,51,
17,54,55,54,51,50,23,22,23,22,23,22,21,17,3,189,23,22,
35,34,33,30,105,58,83,42,36,35,17,8,36,48,33,70,23,37,
17,3,24,27,25,70,37,25,30,28,24,48,53,79,56,26,22,102,
15,16,28,30,102,68,70,50,51,31,34,14,15,152,152,29,80,81,
115,82,66,69,48,50,27,28,139,63,52,50,32,31,24,21,11,5,
15,15,12,6,34,16,32,20,33,13,186,18,24,22,32,16,16,22,
44,38,16,5,43,80,170,2,29,90,75,79,55,59,66,34,35,58,
65,70,75,88,253,228,5,176,253,204,91,59,60,33,34,66,69,106,
112,141,253,227,0,2,0,115,254,84,4,4,5,32,0,79,0,101,
0,0,1,7,6,7,6,7,6,7,48,35,34,39,38,39,38,53,
52,55,54,55,54,55,54,51,22,23,19,23,3,22,23,22,21,17,
51,21,20,7,6,7,6,7,6,7,6,35,34,39,38,39,38,47,
1,34,6,7,6,7,39,54,55,62,1,51,50,23,22,31,2,22,
51,50,55,54,61,1,17,52,39,1,6,7,6,21,20,23,22,23,
22,51,50,55,54,63,1,19,38,39,38,35,34,2,234,51,22,44,
49,50,54,51,8,66,75,64,42,55,3,13,83,102,74,76,120,141,
53,105,143,138,23,15,28,1,23,22,35,34,33,30,105,58,83,42,
36,35,17,8,36,48,33,70,23,37,17,3,24,27,25,70,37,25,
30,28,24,48,53,79,56,26,22,102,6,254,193,131,68,29,35,56,
62,13,18,24,22,39,15,46,137,28,26,43,42,53,1,233,141,59,
37,41,16,16,3,54,46,59,79,112,25,27,128,116,141,58,61,10,
44,1,28,52,254,136,50,61,134,118,253,247,139,63,52,50,32,31,
24,21,11,5,15,15,12,6,34,16,32,20,33,13,186,18,24,22,
32,16,16,22,44,38,16,5,43,80,170,2,9,59,53,1,11,92,
158,65,62,67,54,87,22,5,12,19,43,127,1,118,35,14,22,0,
0,0,0,1,0,45,255,227,4,10,5,215,0,85,0,0,1,6,
7,6,35,34,39,38,39,38,53,52,54,55,62,1,55,54,55,54,
55,54,63,2,54,55,54,55,54,55,54,55,54,55,54,53,52,38,
35,34,7,6,7,39,54,55,54,51,50,23,22,21,20,7,6,7,
6,7,6,7,14,1,7,6,15,2,6,7,6,7,6,7,6,7,
6,7,6,21,20,22,51,50,54,55,4,10,59,121,124,190,138,110,
109,69,69,26,22,21,66,32,35,38,50,24,39,33,67,67,21,40,
42,16,22,26,24,15,14,9,9,148,115,113,83,85,22,152,41,121,
121,172,182,121,122,11,11,15,17,27,32,20,18,86,20,41,22,55,
70,27,45,46,30,30,36,32,25,21,16,14,200,142,115,188,21,1,
71,162,96,98,42,42,91,92,130,58,98,41,39,72,26,28,22,29,
11,18,14,26,27,8,19,19,11,15,21,20,25,24,30,31,36,94,
124,56,57,72,25,130,86,85,97,98,164,49,47,49,29,34,30,35,
17,15,50,9,18,9,22,27,12,21,21,20,20,28,25,32,26,41,
35,44,114,144,158,87,0,2,0,45,255,227,4,10,5,215,0,66,
0,93,0,0,1,6,7,6,35,34,39,38,39,38,53,52,54,55,
62,1,55,54,55,54,55,38,39,38,61,1,54,55,54,51,50,23,
22,21,20,7,6,7,6,7,6,7,14,1,7,6,15,2,6,7,
6,7,6,7,6,7,6,7,6,21,20,22,51,50,54,55,1,6,
21,20,23,22,23,22,51,54,55,54,55,54,55,54,55,54,55,54,
53,52,38,35,34,7,6,4,10,59,121,124,190,138,110,109,69,69,
26,22,21,66,32,35,38,32,40,78,66,128,41,121,121,172,182,121,
122,11,11,15,17,27,32,20,18,86,20,41,22,55,70,27,45,46,
30,30,36,32,25,21,16,14,200,142,115,188,21,253,141,1,73,49,
79,80,48,22,39,42,16,22,26,24,15,14,9,9,148,115,113,83,
85,1,71,162,96,98,42,42,91,92,130,58,98,41,39,72,26,28,
22,19,19,34,66,128,165,11,130,86,85,97,98,164,49,47,49,29,
34,30,35,17,15,50,9,18,9,22,27,12,21,21,20,20,28,25,
32,26,41,35,44,114,144,158,87,3,43,8,15,87,73,49,30,30,
9,18,19,11,15,21,20,25,24,30,31,36,94,124,56,57,0,2,
0,16,0,0,3,216,4,175,0,2,0,65,0,0,37,33,3,55,
1,33,1,3,38,47,1,15,3,39,62,2,55,54,55,54,51,50,
23,50,22,51,23,22,23,22,23,22,31,1,55,54,55,54,55,54,
63,1,50,54,51,54,51,50,23,22,23,30,2,23,7,47,3,7,
6,7,1,88,1,50,153,71,1,11,253,97,1,12,147,23,54,26,
23,20,18,18,87,8,22,15,5,18,38,17,24,13,28,3,4,1,
2,52,13,42,25,66,24,64,64,24,66,25,42,13,52,2,1,4,
3,28,13,24,17,38,18,5,15,22,8,87,18,18,20,23,26,54,
23,136,1,136,134,253,106,2,150,1,102,29,9,1,4,8,10,11,
119,5,15,9,3,9,9,4,4,1,1,13,6,19,24,62,59,170,
170,59,62,24,19,6,13,1,1,4,4,9,9,3,9,15,5,119,
11,10,8,4,1,9,29,0,0,2,0,16,0,0,3,216,4,47,
0,2,0,65,0,0,37,33,3,55,1,33,1,3,38,47,1,15,
3,39,62,2,55,54,55,54,51,50,23,50,22,23,51,22,23,22,
23,22,31,1,55,54,55,54,55,54,55,51,62,1,51,54,51,50,
23,22,23,30,2,23,7,47,3,7,6,7,1,110,1,17,141,70,
1,11,253,97,1,12,147,23,54,26,23,20,18,18,87,8,22,15,
5,18,38,17,24,20,21,3,4,1,2,48,17,42,25,66,24,64,
64,24,66,25,42,17,48,2,1,4,3,21,20,24,17,38,18,5,
15,22,8,87,18,18,20,23,26,54,23,136,1,82,124,253,170,2,
86,1,38,29,9,1,4,8,10,11,119,5,15,9,3,9,9,4,
3,1,1,12,8,19,24,62,59,170,170,59,62,24,19,8,12,1,
1,3,4,9,9,3,9,15,5,119,11,10,8,4,1,9,29,0,
0,2,0,90,255,227,3,196,7,22,0,25,0,94,0,0,19,20,
23,22,23,30,1,51,50,54,55,54,55,54,53,52,39,38,39,38,
35,34,7,6,7,6,1,50,53,47,4,55,22,23,22,23,22,21,
20,7,6,7,14,1,7,6,43,1,34,7,6,29,2,54,55,54,
51,50,23,22,23,22,21,20,6,7,6,32,38,39,38,61,1,19,
52,55,54,55,54,55,54,51,50,22,51,55,58,1,51,50,22,244,
16,16,34,33,110,75,73,110,33,34,16,16,28,27,65,64,98,100,
64,65,27,28,1,167,123,3,8,11,14,13,102,30,9,15,13,15,
9,9,21,22,60,54,52,62,139,103,76,75,46,49,84,106,138,100,
101,48,49,96,100,101,254,234,202,48,49,1,35,34,58,56,74,73,
60,3,10,3,5,6,22,12,11,83,2,25,92,74,76,61,60,68,
68,60,61,76,74,92,118,95,91,59,58,58,59,91,95,3,84,102,
27,22,18,16,15,107,32,12,20,32,36,42,24,33,32,41,42,66,
24,23,65,64,135,33,75,45,24,42,75,76,123,127,156,161,252,76,
77,154,126,129,156,1,2,27,98,84,81,55,53,31,30,1,1,1,
0,0,0,2,0,109,255,227,3,234,6,31,0,9,0,78,0,0,
0,34,6,21,20,22,50,54,53,52,1,51,50,53,47,4,55,22,
23,22,23,22,21,20,7,6,7,6,7,6,7,6,43,1,34,7,
6,29,2,54,55,54,59,1,22,23,22,23,22,21,20,7,6,7,
6,35,34,39,38,39,38,39,38,53,52,50,53,17,52,55,54,55,
54,55,54,2,170,240,168,168,240,168,254,178,170,123,3,8,12,12,
14,102,34,6,12,15,15,8,9,21,18,36,32,50,52,63,139,103,
76,75,29,42,99,122,8,170,142,64,26,38,129,68,77,80,102,138,
101,90,49,19,12,28,1,35,34,59,53,76,72,2,194,168,120,118,
170,170,118,120,2,210,102,26,22,19,16,15,107,36,8,17,35,36,
42,28,29,34,40,34,40,35,22,23,65,65,134,33,75,29,26,63,
3,123,55,73,99,85,180,128,67,30,40,77,68,111,39,51,104,114,
1,1,1,36,98,84,81,56,50,32,30,0,0,0,0,1,0,17,
0,0,3,35,5,176,0,55,0,0,19,7,46,1,53,52,54,55,
54,55,54,55,62,2,55,17,51,17,22,23,22,23,22,21,20,7,
6,7,6,7,6,7,39,54,55,54,55,54,55,54,53,52,39,38,
39,17,35,17,6,7,6,21,20,23,22,216,46,67,86,42,38,40,
46,49,58,7,15,18,5,157,67,47,93,51,53,13,14,22,21,27,
23,31,54,16,15,20,16,19,12,13,83,52,82,157,79,60,84,35,
33,2,228,66,27,86,57,40,76,27,29,18,19,11,1,2,2,1,
1,130,254,125,8,16,31,51,53,66,30,26,29,20,19,18,15,13,
61,5,8,11,11,13,20,21,20,32,44,28,11,252,65,3,191,9,
32,45,29,36,30,29,0,1,0,10,0,0,2,120,5,176,0,11,
0,0,1,17,35,17,35,53,51,17,51,17,51,21,1,153,157,242,
242,157,223,3,164,252,92,3,164,142,1,126,254,130,142,0,0,0,
0,1,0,81,0,0,3,192,4,185,0,37,0,0,33,37,38,39,
3,35,19,54,53,52,39,38,39,38,39,38,39,53,22,23,22,23,
22,21,48,21,1,51,1,6,7,20,6,21,20,23,22,5,3,132,
254,170,75,23,181,158,131,40,1,9,21,28,24,51,77,147,72,69,
24,33,1,92,158,254,210,46,2,1,43,12,1,68,136,53,110,254,
213,1,14,110,121,30,15,108,123,168,37,78,13,136,24,87,82,155,
211,129,19,2,60,254,16,102,77,2,9,2,60,35,12,126,0,2,
0,90,254,99,3,196,4,99,0,25,0,66,0,0,19,20,23,22,
23,22,51,50,55,54,55,54,53,52,39,38,39,46,1,35,34,6,
7,6,7,6,1,7,35,34,39,38,39,38,39,38,53,3,53,52,
55,62,1,32,23,30,1,21,20,7,6,7,6,35,34,39,38,39,
29,1,20,22,59,1,50,23,22,244,28,27,65,64,100,98,64,65,
27,28,16,16,34,33,110,73,75,110,33,34,16,16,2,86,175,170,
79,70,74,56,58,34,35,1,49,48,202,1,22,101,100,96,49,48,
101,100,138,106,84,49,46,158,105,139,63,52,50,2,45,118,95,91,
59,58,58,59,91,95,118,92,74,76,61,60,68,68,60,61,76,74,
252,18,56,29,31,53,55,81,84,98,2,27,1,156,129,126,154,77,
76,252,161,156,127,123,76,75,42,24,45,75,33,134,146,23,22,0,
0,1,0,101,255,227,3,133,4,70,0,47,0,0,1,38,39,38,
35,34,6,21,20,22,51,50,55,54,55,54,55,54,55,23,6,7,
6,7,6,7,6,35,34,39,38,39,38,53,52,55,54,55,54,55,
54,55,54,51,50,23,22,23,3,2,18,60,61,69,128,180,176,130,
43,39,43,24,25,18,16,11,122,24,32,25,50,41,55,53,61,132,
104,106,58,59,20,20,40,41,54,56,72,74,84,115,85,86,53,3,
41,49,50,50,240,181,195,236,18,20,24,25,26,24,21,77,40,37,
29,39,32,20,19,76,77,128,130,155,84,83,82,70,72,52,55,29,
30,61,62,96,255,255,255,137,254,84,1,102,5,147,16,6,0,77,
0,0,0,3,0,100,255,227,4,25,5,213,0,24,0,39,0,54,
0,0,19,52,55,62,1,55,54,51,50,23,22,23,22,21,20,7,
6,7,6,35,34,39,38,39,38,37,33,22,23,22,23,22,51,50,
55,54,55,54,55,54,37,33,38,39,38,39,38,35,34,7,6,7,
6,7,6,100,33,33,120,93,92,111,164,114,114,46,29,55,54,110,
110,147,167,116,115,47,28,3,21,253,139,5,19,34,73,73,109,79,
64,65,35,37,19,12,253,145,2,116,6,20,33,70,71,107,78,66,
64,38,40,18,12,2,215,155,138,140,208,63,62,132,134,216,139,145,
204,173,168,106,105,133,132,218,130,79,100,91,160,100,99,56,57,90,
93,104,65,227,96,98,158,97,98,58,57,93,98,102,61,0,0,1,
0,101,255,227,3,133,4,70,0,52,0,0,1,38,39,38,35,34,
7,6,7,33,21,33,22,23,22,51,50,55,54,55,54,55,54,55,
23,6,7,6,7,6,7,6,35,34,39,38,39,38,53,52,55,54,
55,54,55,54,55,54,51,50,23,22,23,3,2,18,60,61,69,128,
90,71,15,2,76,253,179,14,71,88,130,43,39,43,24,25,18,16,
11,122,24,32,25,50,41,55,53,61,132,104,106,58,59,20,20,40,
41,54,56,72,74,84,115,85,86,53,3,41,49,50,50,120,93,135,
142,149,95,118,18,20,24,25,26,24,21,77,40,37,29,39,32,20,
19,76,77,128,130,155,84,83,82,70,72,52,55,29,30,61,62,96,
0,1,0,101,255,227,3,133,4,70,0,52,0,0,19,39,54,55,
54,51,50,23,22,23,22,23,22,23,22,21,20,7,6,7,6,35,
34,39,38,39,38,39,38,39,55,22,23,22,23,22,23,22,51,50,
55,54,55,33,53,33,38,39,38,35,34,7,6,232,131,53,86,85,
115,84,74,72,56,54,41,40,20,20,59,58,106,104,132,61,53,55,
41,50,25,32,24,122,11,16,18,25,24,43,39,43,130,88,71,14,
253,179,2,76,15,71,90,128,69,61,60,3,41,66,96,62,61,30,
29,55,52,72,70,82,83,84,155,130,128,77,76,19,20,32,39,29,
37,40,77,21,24,26,25,24,20,18,118,95,149,142,135,93,120,50,
50,0,0,2,0,129,0,0,3,166,5,174,0,35,0,58,0,0,
33,35,17,51,17,54,55,54,55,54,55,54,51,50,23,22,23,22,
21,20,7,6,7,6,7,6,7,6,35,34,39,38,39,38,47,1,
1,52,39,38,39,38,35,34,7,6,7,14,1,21,20,23,22,23,
22,51,50,55,54,1,25,152,152,36,15,24,34,35,41,40,55,139,
90,91,34,19,12,12,28,29,45,43,76,71,96,55,51,48,29,24,
19,15,1,245,17,24,51,52,67,53,52,51,43,44,52,16,29,68,
70,73,115,67,68,5,174,254,170,51,17,27,25,26,13,13,100,101,
161,86,103,90,78,80,73,76,54,52,34,32,23,22,29,24,26,23,
1,162,90,85,112,66,67,30,29,54,55,156,96,83,70,133,71,73,
113,115,0,2,0,145,0,0,4,3,5,176,0,14,0,35,0,0,
1,50,55,54,55,54,55,54,55,54,53,52,39,38,33,3,51,17,
32,19,22,21,20,7,6,7,6,7,6,7,6,7,6,35,17,35,
1,47,92,71,81,71,82,49,55,32,34,5,47,253,253,158,158,2,
135,69,8,27,26,54,50,66,61,89,87,81,78,105,158,1,221,7,
8,18,21,27,30,49,51,62,19,25,216,1,190,254,206,254,190,40,
38,84,66,64,46,43,32,30,17,17,7,7,254,175,0,1,0,100,
255,227,4,143,5,215,0,64,0,0,1,6,7,6,7,6,7,6,
35,34,39,38,39,38,39,38,39,38,53,52,55,54,55,54,55,54,
55,54,51,50,23,22,23,22,23,22,23,22,23,7,38,39,38,43,
1,34,7,6,7,6,7,6,21,20,23,22,23,22,23,22,51,50,
55,54,55,4,143,24,38,36,58,53,83,79,96,117,102,100,69,71,
47,50,22,22,23,22,49,47,72,70,100,99,120,73,71,66,50,49,
39,40,24,24,15,149,28,86,83,105,2,104,84,86,52,51,29,28,
30,30,54,53,85,82,100,107,90,91,32,1,37,64,55,52,50,46,
28,27,41,40,72,74,94,101,105,107,120,116,113,109,101,97,75,73,
43,43,19,18,30,30,40,42,40,41,41,41,89,57,55,54,56,88,
87,114,109,121,120,111,110,86,83,53,51,65,66,92,0,0,0,1,
0,121,0,0,5,182,5,176,0,12,0,0,51,17,51,9,1,51,
17,35,17,1,35,1,17,121,215,1,203,1,204,207,153,254,84,179,
254,84,5,176,253,35,2,221,250,80,4,233,253,81,2,175,251,23,
0,1,0,121,254,116,3,152,5,176,0,12,0,0,19,17,51,27,
1,51,17,35,17,3,35,3,17,121,215,186,191,207,153,159,179,155,
254,116,7,60,253,100,2,156,250,80,4,143,253,171,2,85,249,229,
0,0,0,2,0,12,254,116,3,195,4,79,0,44,0,60,0,0,
19,52,55,54,55,54,55,54,51,50,23,22,23,22,23,22,21,20,
7,6,7,6,7,6,7,6,35,34,39,38,39,7,33,21,33,21,
35,53,35,53,51,17,55,53,38,37,52,39,38,35,34,7,6,21,
20,23,22,51,50,55,54,90,29,30,52,56,81,102,102,100,79,49,
35,71,39,48,47,48,100,59,75,16,30,27,33,139,101,20,24,1,
1,203,254,53,152,79,79,1,2,2,181,77,76,116,117,79,80,80,
80,116,116,76,77,2,25,118,102,104,73,77,41,51,47,29,41,66,
100,124,159,164,123,126,76,46,19,4,4,4,77,15,24,251,142,90,
90,142,2,25,5,97,40,25,199,115,113,115,116,198,196,118,117,117,
118,0,0,1,0,100,255,227,4,143,5,215,0,60,0,0,19,55,
22,23,22,51,50,55,54,55,54,55,54,53,52,39,38,39,38,39,
38,43,1,34,7,6,15,1,54,55,54,55,54,55,54,55,54,51,
50,23,30,1,23,22,23,22,21,20,14,1,7,14,1,35,34,39,
38,39,38,39,38,100,147,32,91,90,107,99,83,84,53,56,29,30,
28,29,52,76,88,80,109,2,106,83,91,16,127,13,27,26,37,39,
49,49,68,71,72,120,99,100,140,48,51,21,23,46,94,71,68,204,
117,95,80,83,53,58,36,38,1,37,41,92,66,65,51,52,84,89,
107,111,120,121,109,111,90,130,61,54,55,59,66,27,36,46,43,39,
40,30,30,18,19,43,43,146,99,104,106,113,116,115,224,188,74,71,
82,27,28,46,50,52,55,0,0,0,0,2,0,100,255,227,4,143,
5,215,0,64,0,83,0,0,1,6,7,6,7,6,7,6,35,34,
39,38,39,38,39,38,39,38,53,52,55,54,55,54,55,54,55,54,
51,50,23,22,23,22,23,22,23,22,23,39,38,39,38,43,1,34,
7,6,7,6,7,6,21,20,23,22,23,22,23,22,51,50,55,54,
55,1,52,54,51,50,23,22,23,22,21,20,7,6,35,34,39,38,
39,38,4,143,24,38,36,58,53,83,79,96,117,102,100,69,71,47,
50,22,22,23,22,49,47,72,70,100,99,120,73,71,66,50,49,39,
40,24,24,15,127,16,92,83,105,2,108,80,91,75,51,29,28,30,
30,54,53,85,82,100,107,90,91,32,254,91,64,44,40,28,29,8,
2,32,31,44,39,29,30,7,3,1,37,64,55,52,50,46,28,27,
41,40,72,74,94,101,105,107,120,116,113,109,101,97,75,73,43,43,
19,18,30,30,40,42,40,41,41,27,65,60,55,54,63,128,87,114,
109,121,120,111,110,86,83,53,51,65,66,92,1,158,44,64,24,25,
36,10,13,44,32,31,24,25,36,11,0,2,0,100,255,227,4,143,
5,215,0,18,0,79,0,0,1,20,7,6,7,6,35,34,39,38,
53,52,55,54,55,54,51,50,22,1,55,22,23,22,51,50,55,54,
55,54,55,54,53,52,39,38,39,38,39,38,43,1,34,7,6,15,
1,54,55,54,55,54,55,54,55,54,51,50,23,30,1,23,22,23,
22,21,20,14,1,7,14,1,35,34,39,38,39,38,39,38,2,165,
3,7,30,29,39,44,31,32,2,8,29,29,39,44,64,253,191,147,
32,91,90,107,99,83,84,53,56,29,30,28,29,52,76,88,80,109,
2,106,83,91,16,127,13,27,26,37,39,49,49,68,71,72,120,99,
100,140,48,51,21,23,46,94,71,68,204,117,95,80,83,53,58,36,
38,2,226,12,10,36,25,24,31,32,44,13,10,36,25,24,64,254,
23,41,92,66,65,51,52,84,89,107,111,120,121,109,111,90,130,61,
54,55,59,66,27,36,46,43,39,40,30,30,18,19,43,43,146,99,
104,106,113,116,115,224,188,74,71,82,27,28,46,50,52,55,255,255,
0,88,0,0,3,242,7,152,16,39,0,67,0,219,0,0,16,6,
2,93,0,0,255,255,0,56,0,0,3,210,6,243,16,39,0,106,
0,170,0,0,16,6,2,93,224,0,0,1,0,18,0,0,4,107,
5,176,0,61,0,0,33,35,17,33,53,33,21,33,17,54,55,54,
51,50,23,22,23,22,23,22,31,1,20,7,6,7,6,7,6,7,
6,35,34,39,38,39,38,39,55,31,4,50,53,17,52,39,38,39,
46,1,35,34,7,6,7,6,7,6,21,1,199,152,254,227,2,226,
254,211,29,80,81,115,82,66,69,48,50,27,26,2,1,23,22,35,
38,37,41,32,29,28,42,36,35,17,8,36,107,15,16,18,22,27,
102,15,16,28,30,102,68,70,50,51,31,34,14,15,5,34,142,142,
254,90,91,59,60,33,34,66,69,106,104,149,252,63,52,50,32,35,
19,21,9,8,15,15,12,6,34,102,14,12,12,8,3,123,1,27,
90,75,79,55,59,66,34,35,58,65,70,75,88,0,255,255,0,63,
0,0,3,209,7,152,16,39,0,118,1,60,0,0,16,6,2,91,
227,0,0,1,0,56,255,227,4,98,5,215,0,65,0,0,1,6,
7,6,7,6,7,6,35,34,39,38,39,38,39,38,39,38,52,55,
54,55,62,1,55,54,51,50,23,22,23,22,23,22,23,22,23,7,
38,39,38,43,1,34,7,6,7,6,7,6,7,33,21,33,22,23,
22,23,22,23,22,51,50,55,54,55,4,98,24,38,36,58,53,83,
80,94,118,102,100,69,71,47,49,22,22,22,21,51,48,140,100,99,
121,72,71,67,50,49,39,37,26,24,15,148,28,86,83,105,2,105,
84,85,52,51,29,20,6,2,88,253,169,6,21,30,54,53,85,82,
100,106,90,93,31,1,37,64,55,52,50,46,28,27,41,40,72,74,
94,97,109,107,240,109,106,104,99,146,43,43,19,18,30,30,40,39,
43,41,41,41,89,57,55,54,55,89,87,114,76,89,142,79,75,110,
86,83,53,51,65,67,91,0,255,255,0,45,255,227,4,10,5,215,
16,6,0,54,0,0,255,255,0,154,0,0,1,55,5,176,16,6,
0,44,0,0,255,255,255,160,0,0,2,51,6,243,16,39,0,106,
255,84,0,0,16,6,0,44,0,0,0,1,0,113,255,227,4,4,
5,176,0,26,0,0,19,51,20,23,30,1,51,50,55,54,55,54,
53,17,33,53,33,21,17,20,0,35,34,39,38,39,38,113,141,11,
27,162,111,91,72,73,34,35,254,168,1,246,254,254,205,165,116,118,
37,16,2,23,50,55,129,180,63,64,91,94,102,3,11,142,142,252,
245,246,254,194,113,115,179,68,0,2,0,69,0,0,5,249,5,176,
0,45,0,60,0,0,33,35,17,35,3,6,7,6,7,6,7,6,
7,6,35,34,39,38,39,38,39,55,31,4,50,55,19,33,17,51,
50,23,30,1,23,22,21,20,7,6,7,6,35,39,51,50,55,54,
55,54,55,54,55,54,53,16,33,35,3,190,158,121,151,13,10,22,
35,40,34,40,34,29,28,42,36,35,17,8,36,107,15,16,19,22,
26,87,15,150,1,176,24,138,106,108,128,34,33,8,30,141,137,231,
24,24,102,68,71,43,41,23,22,9,6,254,127,24,5,35,251,254,
92,23,50,32,36,18,21,9,8,15,15,12,6,34,102,14,12,12,
8,3,123,4,174,253,137,33,33,114,75,73,88,43,42,146,90,88,
141,17,18,32,31,35,33,42,25,35,1,17,0,2,0,73,0,0,
4,201,5,176,0,26,0,41,0,0,33,17,33,17,35,17,51,17,
33,17,51,17,51,50,23,30,1,23,22,21,20,7,6,7,6,43,
1,25,1,51,50,55,54,55,54,55,54,55,54,53,16,33,1,240,
254,247,158,158,1,9,158,24,138,106,108,128,34,33,8,30,141,137,
231,24,24,102,68,71,43,41,23,22,9,6,254,127,2,167,253,89,
5,176,253,131,2,125,253,137,33,33,114,75,73,88,43,42,146,90,
88,2,170,253,227,17,18,32,31,35,33,42,25,35,1,17,0,0,
0,1,0,18,0,0,4,106,5,176,0,38,0,0,33,35,17,33,
53,33,21,33,17,54,55,54,51,50,23,22,23,22,23,22,21,17,
35,17,52,39,38,39,46,1,35,34,7,6,7,6,7,6,21,1,
199,152,254,227,2,226,254,211,29,80,81,115,82,66,69,48,50,27,
28,151,15,16,28,30,102,68,70,50,51,31,34,14,15,5,34,142,
142,254,90,91,59,60,33,34,66,69,106,112,141,253,227,2,29,90,
75,79,55,59,66,34,35,58,65,70,75,88,255,255,0,121,0,0,
4,211,7,152,16,39,0,118,1,150,0,0,16,6,2,98,0,0,
255,255,0,121,0,0,4,147,7,152,16,39,0,67,1,43,0,0,
16,6,2,96,0,0,255,255,0,26,0,0,4,221,6,243,16,39,
0,106,1,56,0,0,16,6,2,107,0,0,0,1,0,58,255,42,
4,11,5,176,0,11,0,0,33,21,35,53,37,17,51,17,33,17,
51,17,2,131,142,254,69,158,2,149,158,214,214,1,5,175,250,221,
5,35,250,81,0,0,0,2,0,72,0,0,4,223,5,176,0,2,
0,10,0,0,1,3,33,23,33,3,35,1,51,1,35,2,147,204,
1,159,37,254,15,162,176,2,12,127,2,12,180,4,190,253,175,136,
254,27,5,176,250,80,0,0,0,2,0,94,0,0,3,236,5,176,
0,21,0,36,0,0,51,17,51,33,21,33,17,51,50,23,30,1,
23,22,21,20,7,6,7,6,43,1,25,1,51,50,55,54,55,54,
55,54,55,54,53,16,33,94,158,2,166,253,90,206,138,106,108,128,
34,32,8,31,139,137,231,206,206,102,68,71,43,41,23,20,10,6,
254,128,5,176,141,254,22,33,33,114,75,71,90,37,48,147,89,88,
2,170,253,227,17,18,32,31,35,31,44,25,35,1,17,0,0,3,
0,67,0,0,4,7,5,176,0,18,0,42,0,81,0,0,19,17,
33,50,55,54,55,54,55,54,55,54,53,52,39,38,39,38,35,1,
17,51,50,54,55,54,55,54,55,54,53,52,39,38,39,38,39,38,
39,38,35,34,38,39,33,50,23,22,23,30,1,23,22,21,20,6,
35,50,23,22,23,22,23,22,23,22,21,20,7,6,7,6,7,6,
7,6,7,6,7,6,35,33,225,1,63,67,59,55,39,40,24,27,
10,11,7,19,81,82,143,254,193,237,85,122,36,37,20,22,6,6,
5,7,20,19,35,34,66,65,83,48,136,211,1,139,116,93,92,55,
53,66,11,8,168,86,75,56,59,38,36,24,22,11,8,4,4,13,
11,22,22,37,38,48,50,74,71,93,254,35,2,193,253,204,17,16,
28,29,35,39,40,42,43,37,27,94,58,59,2,100,254,39,32,25,
26,31,35,27,28,31,26,25,31,34,31,28,27,17,17,2,139,26,
26,44,43,106,55,45,32,117,180,26,27,44,42,49,46,52,38,34,
38,29,30,47,42,38,39,37,38,26,27,17,16,0,0,0,0,1,
0,92,0,0,3,238,5,176,0,5,0,0,19,33,21,33,17,35,
92,3,146,253,12,158,5,176,141,250,221,0,0,2,0,79,255,42,
4,207,5,170,0,7,0,21,0,0,1,3,6,7,6,7,33,17,
1,51,50,55,19,5,19,51,17,35,53,33,21,35,2,114,154,10,
13,7,24,1,157,253,16,139,87,15,152,2,4,1,242,142,252,156,
142,5,29,251,254,71,44,26,6,4,149,251,107,116,4,174,1,250,
223,254,162,213,213,0,0,1,0,88,0,0,3,242,5,176,0,11,
0,0,19,33,21,33,17,33,21,33,17,33,21,33,88,3,154,253,
4,2,208,253,48,2,252,252,102,5,176,141,254,14,141,253,233,141,
0,1,0,76,0,0,5,110,5,179,0,19,0,0,51,35,1,53,
1,51,1,17,51,17,1,51,1,21,1,35,1,17,35,17,254,178,
1,164,254,92,182,1,140,157,1,141,182,254,92,1,164,178,254,111,
157,2,157,142,2,136,253,151,2,102,253,154,2,105,253,120,142,253,
99,2,119,253,137,2,119,0,0,1,0,113,255,227,4,12,5,217,
0,62,0,0,63,1,22,23,22,51,50,55,54,53,52,38,39,38,
39,38,43,1,53,51,50,55,54,53,52,39,38,43,1,34,6,7,
39,54,55,54,51,50,23,22,23,22,21,20,7,6,7,6,7,22,
23,22,23,22,23,22,21,20,0,35,34,39,38,113,155,37,80,79,
83,140,95,97,58,47,49,55,58,61,78,98,97,72,71,73,74,95,
6,81,120,32,137,52,101,100,123,100,92,89,60,59,33,33,39,40,
38,36,44,39,41,38,26,26,254,230,207,124,128,126,252,47,81,53,
52,85,86,140,71,122,37,38,19,20,125,74,72,114,101,70,71,84,
74,64,104,65,64,47,45,91,89,109,82,71,70,39,40,19,10,33,
29,49,45,68,67,70,195,254,254,77,76,0,0,1,0,121,0,0,
4,147,5,176,0,9,0,0,19,51,17,1,51,17,35,17,1,35,
121,158,2,235,145,157,253,28,153,5,176,251,90,4,166,250,80,4,
137,251,119,0,0,0,0,2,0,121,0,0,4,147,7,88,0,23,
0,33,0,0,1,54,55,54,55,51,48,21,20,7,6,7,6,34,
39,38,39,38,61,1,51,22,23,22,5,51,17,1,51,17,35,17,
1,35,2,134,55,35,59,69,80,66,35,69,67,132,67,69,35,66,
81,49,78,38,254,49,158,2,235,145,157,253,28,153,6,154,3,23,
42,122,10,68,111,57,40,38,38,40,57,111,68,10,112,52,24,236,
251,90,4,166,250,80,4,137,251,119,0,1,0,121,0,0,4,211,
5,176,0,11,0,0,19,51,17,1,51,9,1,35,1,7,17,35,
121,158,2,235,193,253,120,2,152,207,253,207,188,158,5,176,253,14,
2,242,253,115,252,221,2,190,186,253,252,0,0,1,0,84,0,0,
4,36,5,176,0,30,0,0,1,33,17,35,17,35,3,6,7,6,
7,6,7,6,7,6,35,34,39,38,39,38,39,55,31,4,50,55,
2,29,2,7,158,208,151,13,10,22,35,38,37,41,32,29,28,42,
36,35,17,8,36,107,15,16,18,22,27,87,15,5,176,250,80,5,
35,251,254,92,23,50,32,35,19,21,9,8,15,15,12,6,34,102,
14,12,12,8,3,123,0,0,0,1,0,121,0,0,5,182,5,176,
0,12,0,0,51,17,51,9,1,51,17,35,17,1,35,1,17,121,
215,1,203,1,204,207,153,254,84,179,254,84,5,176,251,33,4,223,
250,80,4,180,251,92,4,164,251,76,0,1,0,121,0,0,4,74,
5,176,0,11,0,0,19,51,17,33,17,51,17,35,17,33,17,35,
121,158,2,149,158,158,253,107,158,5,176,253,127,2,129,250,80,2,
162,253,94,0,0,2,0,92,255,227,4,238,5,215,0,37,0,77,
0,0,1,52,39,38,39,38,39,38,39,38,35,34,6,7,6,7,
14,1,21,20,23,22,23,22,23,22,23,22,51,50,55,54,55,54,
55,54,55,54,37,52,55,54,55,54,55,54,55,54,51,50,23,22,
23,22,23,22,23,22,21,20,7,6,7,6,7,6,7,6,35,34,
39,38,39,38,39,38,39,38,4,72,23,17,32,29,48,46,70,67,
88,94,146,47,47,30,30,24,22,15,33,29,48,46,71,70,84,94,
73,75,45,45,32,33,11,12,252,20,19,20,44,43,67,64,103,101,
123,122,98,100,66,65,45,44,22,24,20,20,44,47,63,67,101,102,
122,120,99,98,68,65,45,43,23,23,2,213,115,112,79,73,67,60,
57,34,32,80,64,63,85,84,168,85,114,104,75,74,65,59,57,32,
32,39,40,59,60,83,85,79,82,85,103,101,104,102,100,82,79,50,
49,46,47,78,76,97,93,108,116,109,98,103,104,98,105,73,77,48,
48,45,45,78,75,95,91,108,109,0,0,1,0,121,0,0,4,74,
5,176,0,7,0,0,19,33,17,35,17,33,17,35,121,3,209,158,
253,107,158,5,176,250,80,5,35,250,221,0,0,0,0,2,0,121,
0,0,4,8,5,176,0,14,0,34,0,0,1,51,32,17,52,39,
38,39,38,39,38,39,38,43,1,39,59,1,50,23,22,23,22,21,
20,7,6,7,6,7,6,43,1,17,35,1,23,206,1,129,6,9,
22,24,39,43,71,68,103,206,158,158,206,232,137,139,31,8,33,34,
64,65,106,107,138,206,158,3,6,1,17,35,25,42,33,37,29,32,
18,17,141,88,89,147,48,37,87,74,75,57,57,33,33,253,137,0,
0,1,0,100,255,227,4,143,5,215,0,64,0,0,1,6,7,6,
7,6,7,6,35,34,39,38,39,38,39,38,39,38,53,52,55,54,
55,54,55,54,55,54,51,50,23,22,23,22,23,22,23,22,23,7,
38,39,38,43,1,34,7,6,7,6,7,6,21,20,23,22,23,22,
23,22,51,50,55,54,55,4,143,24,38,36,58,53,83,79,96,117,
102,100,69,71,47,50,22,22,23,22,49,47,72,70,100,99,120,73,
71,66,50,49,39,40,24,24,15,149,28,86,83,105,2,104,84,86,
52,51,29,28,30,30,54,53,85,82,100,107,90,91,32,1,37,64,
55,52,50,46,28,27,41,40,72,74,94,101,105,107,120,116,113,109,
101,97,75,73,43,43,19,18,30,30,40,42,40,41,41,41,89,57,
55,54,56,88,87,114,109,121,120,111,110,86,83,53,51,65,66,92,
0,0,0,1,0,88,0,0,4,156,5,176,0,7,0,0,19,33,
21,33,17,35,17,33,88,4,68,254,55,158,254,35,5,176,141,250,
221,5,35,0,0,0,0,1,0,26,0,0,4,221,5,176,0,32,
0,0,19,51,9,1,51,1,6,7,6,7,6,7,6,7,6,7,
48,35,34,39,38,39,38,39,55,31,4,50,55,1,198,168,1,100,
1,100,167,252,247,12,6,12,10,38,37,41,32,24,43,11,44,36,
35,17,8,36,107,15,16,18,22,27,51,22,1,82,5,176,253,168,
2,88,250,222,19,7,15,9,35,19,21,9,6,2,15,15,12,6,
34,102,14,12,12,8,3,24,2,77,0,3,0,95,0,0,5,187,
5,234,0,41,0,61,0,82,0,0,1,53,51,21,22,23,22,23,
22,23,22,23,22,21,20,7,14,2,7,6,7,21,35,53,38,39,
38,39,38,39,46,1,53,52,54,55,54,55,54,55,54,19,17,6,
7,6,7,6,7,6,7,6,21,20,22,23,22,23,22,23,22,19,
17,54,55,54,55,54,55,54,55,54,53,52,39,38,39,38,39,38,
39,38,2,173,179,41,52,95,91,93,71,69,46,45,42,42,142,168,
97,54,58,179,45,47,92,90,93,67,70,86,82,69,68,85,82,97,
52,55,55,52,71,64,61,51,49,30,29,70,54,53,76,75,73,40,
200,62,52,72,65,60,54,51,31,29,36,36,57,59,74,76,76,44,
5,33,201,201,4,10,20,44,45,65,63,104,102,122,121,99,100,132,
88,22,13,6,153,153,4,11,20,44,46,64,67,202,123,119,200,66,
65,45,43,23,12,252,35,3,62,6,12,16,32,30,47,45,72,70,
84,92,150,45,44,33,32,12,6,3,60,252,194,6,13,17,32,29,
48,45,71,67,88,94,73,73,47,48,29,30,12,6,0,1,0,74,
0,0,4,137,5,176,0,11,0,0,19,51,9,1,51,9,1,35,
9,1,35,1,74,182,1,106,1,99,182,254,59,1,203,190,254,159,
254,152,178,1,199,5,176,253,162,2,94,253,41,253,39,2,74,253,
182,2,217,0,0,0,0,1,0,121,255,48,5,60,5,176,0,11,
0,0,37,17,35,53,33,17,51,17,33,17,51,17,5,60,142,251,
203,158,2,149,158,142,254,162,208,5,176,250,221,5,35,250,222,0,
0,1,0,98,0,0,3,158,5,176,0,34,0,0,1,51,17,35,
17,14,1,35,34,39,38,39,38,39,38,53,17,51,17,20,23,22,
23,22,23,22,51,50,55,54,55,54,55,54,53,3,6,152,152,29,
162,115,82,66,67,49,52,26,28,151,15,16,28,30,52,51,67,70,
50,53,30,32,15,16,5,176,250,80,3,12,90,120,33,34,66,71,
104,112,141,1,69,254,187,90,75,79,55,58,34,33,34,36,57,62,
73,80,83,0,0,1,0,121,0,0,5,180,5,176,0,14,0,0,
37,21,33,17,51,17,33,17,59,2,17,5,17,51,5,180,250,197,
158,1,176,1,157,1,1,176,158,142,142,5,176,250,221,5,35,250,
222,1,5,35,0,0,0,1,0,121,255,48,6,166,5,176,0,17,
0,0,37,17,35,53,33,17,51,17,33,17,59,2,17,5,17,51,
17,6,166,142,250,97,158,1,176,1,157,1,1,176,158,142,254,162,
208,5,176,250,221,5,35,250,222,1,5,35,250,222,0,0,0,2,
0,40,0,0,4,147,5,176,0,21,0,36,0,0,33,17,35,53,
33,51,17,51,50,23,30,1,23,22,21,20,7,6,7,6,43,1,
25,1,51,50,55,54,55,54,55,54,55,54,53,16,33,1,4,220,
1,111,11,206,138,106,108,128,34,33,8,31,140,137,231,206,206,102,
68,71,43,41,23,22,9,6,254,127,5,34,142,253,137,33,33,114,
75,73,88,37,48,146,90,88,2,170,253,227,17,18,32,31,35,33,
42,25,35,1,17,0,0,3,0,121,0,0,4,75,5,176,0,3,
0,18,0,38,0,0,33,17,51,17,1,17,51,50,55,54,55,54,
55,54,55,54,53,16,33,3,17,51,17,51,50,23,22,23,22,23,
22,21,20,7,6,7,6,43,1,3,174,157,252,204,24,103,68,71,
43,39,24,22,9,6,254,127,182,158,24,139,106,106,65,64,34,33,
8,30,140,137,232,24,5,176,250,80,2,170,253,227,17,18,32,29,
37,33,42,25,35,1,17,253,86,5,176,253,137,33,33,57,57,75,
73,88,43,42,147,89,88,0,0,2,0,121,0,0,4,8,5,176,
0,14,0,34,0,0,1,17,51,50,55,54,55,54,55,54,55,54,
53,16,33,1,17,51,17,51,50,23,22,23,22,23,22,21,20,7,
6,7,6,43,1,1,23,206,103,68,71,43,39,24,22,9,6,254,
127,254,148,158,206,139,106,106,65,64,34,33,8,31,139,137,232,206,
2,170,253,227,17,18,32,29,37,33,42,25,35,1,17,253,86,5,
176,253,137,33,33,57,57,75,73,88,37,48,147,89,88,0,0,1,
0,100,255,227,4,143,5,215,0,63,0,0,19,55,22,23,22,51,
50,55,54,55,54,55,54,55,33,53,33,38,39,38,39,38,39,38,
43,1,34,7,6,7,39,54,55,54,55,54,55,54,55,54,51,50,
23,30,1,23,22,23,22,21,20,14,1,7,14,1,35,34,39,38,
39,38,39,38,100,147,32,91,90,107,99,83,84,53,56,29,21,6,
253,169,2,88,6,20,29,52,53,83,84,105,2,106,83,85,28,149,
13,27,26,37,39,49,49,68,71,72,120,99,100,140,48,51,21,23,
46,94,71,68,204,117,95,80,83,53,58,36,38,1,37,41,92,66,
65,51,52,84,89,107,75,79,142,89,76,111,90,91,53,54,55,56,
90,41,36,46,43,39,40,30,30,18,19,43,43,146,99,104,106,113,
116,115,224,188,74,71,82,27,28,46,50,52,55,0,0,2,0,125,
255,234,5,149,5,234,0,44,0,82,0,0,51,17,51,17,51,54,
55,54,55,54,55,54,55,54,50,23,22,23,22,23,22,23,22,21,
20,7,6,7,6,7,14,1,35,34,39,38,39,38,39,38,39,38,
39,35,17,1,52,39,38,39,38,39,38,39,38,35,34,7,14,1,
7,6,7,6,21,20,23,22,23,22,23,30,1,51,50,55,54,55,
54,55,54,55,54,125,157,97,5,9,16,42,40,59,57,93,92,220,
88,89,60,60,39,48,11,22,18,19,39,41,58,59,182,111,110,88,
89,60,60,39,37,22,16,4,95,3,230,21,16,28,27,42,39,66,
62,77,86,65,67,82,28,8,30,11,20,14,29,25,45,41,128,75,
86,64,67,41,40,29,26,13,12,5,234,253,71,78,53,98,108,101,
81,78,50,50,46,47,79,80,92,114,87,101,136,100,101,105,97,103,
75,77,96,45,45,78,77,93,88,111,83,78,253,92,2,220,130,109,
81,71,68,59,55,35,33,40,41,124,86,23,145,104,78,109,109,78,
72,63,61,56,64,38,39,61,58,85,76,88,83,0,0,2,0,121,
0,0,4,80,5,176,0,14,0,30,0,0,1,17,35,34,6,21,
20,23,22,23,22,23,30,1,51,1,35,1,38,39,38,53,52,36,
59,2,17,35,17,35,3,178,206,199,186,9,10,23,26,40,39,146,
92,254,74,181,1,178,165,100,99,1,50,243,206,158,158,215,3,6,
2,29,144,124,41,34,40,33,38,27,26,34,252,250,2,136,30,110,
110,149,193,216,250,80,2,119,0,0,0,2,0,106,255,227,3,119,
4,66,0,15,0,53,0,0,1,34,7,6,21,20,23,22,51,50,
55,54,53,52,39,38,39,50,23,22,23,53,52,38,35,34,7,6,
7,39,54,51,50,22,29,1,17,35,61,1,6,7,6,7,6,7,
6,35,34,38,53,52,55,54,1,254,108,72,70,71,73,106,96,72,
70,73,74,123,102,78,76,12,126,118,66,64,59,35,78,133,169,167,
218,139,1,22,23,32,33,53,51,55,164,208,108,109,2,70,70,69,
99,103,67,68,70,69,99,103,67,68,135,55,54,49,96,143,156,22,
20,35,104,109,230,205,123,253,236,156,2,19,31,33,29,30,23,22,
206,167,159,107,107,0,0,0,0,2,0,90,255,227,3,196,5,227,
0,25,0,65,0,0,19,20,23,22,23,30,1,51,50,54,55,54,
55,54,53,52,39,38,39,38,35,34,7,6,7,6,1,38,35,34,
6,29,2,54,55,54,51,50,23,22,23,22,21,20,6,7,6,32,
38,39,38,53,19,52,55,54,55,54,55,54,51,50,23,22,23,244,
16,16,34,33,110,75,73,110,33,34,16,16,28,27,65,64,98,100,
64,65,27,28,1,177,80,91,105,158,46,49,84,106,138,100,101,48,
49,96,100,101,254,234,202,48,49,1,35,34,58,56,74,70,79,91,
78,80,50,2,25,92,74,76,61,60,68,68,60,61,76,74,92,118,
95,91,59,58,58,59,91,95,2,145,59,146,134,33,75,45,24,42,
75,76,123,127,156,161,252,76,77,154,126,129,157,2,27,98,84,81,
55,53,31,29,33,34,50,0,0,0,0,3,0,92,0,0,3,61,
4,47,0,24,0,35,0,50,0,0,51,17,33,50,23,22,23,22,
21,20,7,6,15,1,23,22,23,22,23,22,21,20,7,6,35,3,
51,50,54,53,52,39,38,43,2,25,1,51,50,55,54,53,52,39,
38,39,38,39,38,35,92,1,98,76,76,73,45,46,32,33,37,74,
78,42,36,45,17,25,113,112,166,226,216,72,104,54,55,69,4,210,
208,105,73,74,28,24,44,39,37,44,42,4,47,34,34,61,62,76,
55,53,54,23,40,31,19,36,46,33,47,49,138,90,90,2,120,90,
68,62,43,44,254,86,254,134,52,51,87,45,37,32,27,25,10,12,
0,1,0,94,0,0,2,222,4,50,0,5,0,0,1,33,17,35,
17,33,2,222,254,23,151,2,128,3,170,252,86,4,50,0,0,0,
0,2,0,128,255,42,4,80,4,50,0,13,0,21,0,0,37,51,
17,35,53,33,21,35,17,51,54,55,19,33,1,51,17,35,3,6,
7,6,3,94,242,142,253,76,142,133,70,15,108,1,152,254,104,250,
100,106,16,8,6,136,254,162,213,213,1,94,9,113,3,48,252,86,
3,29,253,124,97,18,14,0,0,2,0,98,255,227,3,157,4,70,
0,9,0,49,0,0,1,33,46,1,35,34,7,6,7,6,7,22,
23,22,23,22,51,50,55,54,55,23,6,7,6,35,34,39,38,39,
38,53,52,55,54,55,54,51,50,23,22,23,22,23,22,29,1,20,
22,21,1,1,2,10,9,140,112,76,60,58,31,30,6,7,31,29,
60,58,76,73,69,72,31,133,51,105,106,116,129,97,99,47,48,49,
50,95,97,129,95,81,78,50,51,25,26,1,2,92,146,208,54,53,
79,78,225,95,81,78,55,54,38,40,59,55,100,58,59,77,79,124,
127,159,161,123,126,73,74,46,44,76,77,92,95,99,47,14,33,2,
0,0,0,1,0,94,0,0,5,126,4,50,0,19,0,0,33,35,
1,53,1,51,1,17,51,17,1,51,1,21,1,35,1,17,35,17,
1,16,178,1,164,254,92,182,1,140,157,1,139,182,254,92,1,164,
178,254,113,157,2,58,129,1,119,254,168,1,85,254,171,1,88,254,
137,129,253,198,2,20,253,236,2,20,0,1,0,97,255,227,3,65,
4,74,0,63,0,0,63,1,30,1,51,50,55,54,53,52,39,38,
39,38,39,38,43,1,53,51,50,55,54,53,52,39,38,43,1,34,
7,6,7,39,54,55,54,51,50,23,22,23,22,21,20,7,6,7,
6,7,30,1,23,22,23,22,21,20,7,6,35,34,39,38,97,117,
29,120,62,103,75,73,28,25,41,33,44,40,47,57,71,73,51,52,
54,55,68,4,58,45,42,26,101,41,80,77,98,79,73,70,47,46,
32,32,37,36,39,36,84,36,35,27,25,112,113,165,100,101,102,195,
38,54,66,55,54,91,48,38,39,23,23,14,13,125,47,48,72,65,
45,46,27,25,50,52,83,54,52,35,34,66,65,81,60,53,52,29,
27,16,7,50,33,32,51,47,54,146,94,95,61,61,0,1,0,122,
0,0,3,174,4,50,0,9,0,0,19,51,17,1,51,17,35,17,
1,35,122,156,2,0,152,140,253,240,152,4,50,252,222,3,34,251,
206,3,44,252,212,0,0,0,0,2,0,122,0,0,3,174,5,234,
0,23,0,33,0,0,1,54,55,54,55,51,48,21,20,7,6,7,
6,34,39,38,39,38,61,1,51,22,23,22,5,51,17,1,51,17,
35,17,1,35,2,36,55,35,59,69,80,66,35,69,67,132,67,69,
35,66,81,49,78,38,254,148,156,2,0,152,140,253,240,152,5,44,
3,23,42,122,10,68,111,57,40,38,38,40,57,111,68,10,112,52,
24,252,252,222,3,34,251,206,3,44,252,212,0,1,0,121,0,0,
3,168,4,53,0,10,0,0,19,51,17,1,51,9,1,35,1,3,
35,121,158,1,161,186,254,6,2,48,216,254,72,1,158,4,48,254,
80,1,181,253,231,253,228,1,149,254,107,0,0,0,0,1,0,69,
0,0,3,125,4,50,0,30,0,0,1,33,17,35,17,35,3,6,
7,6,7,6,7,6,7,6,35,34,39,38,39,38,39,55,31,4,
50,55,1,198,1,183,158,130,77,10,13,22,35,40,34,40,34,29,
28,42,36,35,17,8,36,107,15,16,19,22,26,90,12,4,50,251,
206,3,165,253,124,85,30,50,32,36,18,21,9,8,15,15,12,6,
34,102,14,12,12,8,3,123,0,0,0,1,0,98,0,0,4,52,
4,50,0,12,0,0,51,17,51,9,1,51,17,35,17,1,35,1,
17,98,156,1,80,1,79,151,151,254,239,130,254,239,4,50,252,160,
3,96,251,206,2,220,253,36,2,220,253,36,0,1,0,102,0,0,
3,48,4,51,0,11,0,0,19,51,17,37,17,23,17,39,17,33,
17,35,102,151,1,154,153,153,254,102,151,4,50,254,41,1,1,215,
1,251,206,1,1,210,254,45,0,0,0,2,0,90,255,227,3,196,
4,70,0,22,0,48,0,0,19,52,55,54,55,54,55,54,51,50,
23,22,23,22,21,20,6,7,6,32,38,39,38,55,20,23,22,23,
30,1,51,50,54,55,54,55,54,53,52,39,38,39,38,35,34,7,
6,7,6,90,29,30,52,56,81,84,106,138,100,101,48,49,96,100,
101,254,234,202,48,49,154,16,16,34,33,110,75,73,110,33,34,16,
16,28,27,65,64,98,100,64,65,27,28,2,25,118,102,104,73,77,
41,42,75,76,123,127,156,161,252,76,77,154,126,129,157,92,74,76,
61,60,68,68,60,61,76,74,92,118,95,91,59,58,58,59,91,95,
0,1,0,121,0,0,3,178,4,50,0,7,0,0,19,33,17,35,
17,33,17,35,121,3,57,158,254,3,158,4,50,251,206,3,165,252,
91,0,0,0,0,2,0,129,254,116,3,207,4,78,0,34,0,50,
0,0,1,21,54,55,54,55,54,55,54,51,50,30,1,23,22,21,
20,7,6,7,6,7,6,35,34,39,38,39,38,39,38,39,17,35,
17,1,52,39,38,35,34,7,6,21,20,23,22,51,50,55,54,1,
25,19,24,21,38,32,53,50,62,102,154,94,22,23,23,22,47,46,
79,78,102,65,47,50,35,35,22,25,18,152,2,180,77,76,116,117,
79,80,80,79,117,116,76,77,4,49,187,44,36,32,36,31,19,18,
92,164,96,101,110,108,101,98,83,81,49,48,17,18,32,32,34,38,
42,253,188,5,189,253,234,198,115,114,115,116,198,197,118,116,116,118,
0,0,0,1,0,101,255,227,3,133,4,70,0,47,0,0,1,38,
39,38,35,34,6,21,20,22,51,50,55,54,55,54,55,54,55,23,
6,7,6,7,6,7,6,35,34,39,38,39,38,53,52,55,54,55,
54,55,54,55,54,51,50,23,22,23,3,2,18,60,61,69,128,180,
176,130,43,39,43,24,25,18,16,11,122,24,32,25,50,41,55,53,
61,132,104,106,58,59,20,20,40,41,54,56,72,74,84,115,85,86,
53,3,41,49,50,50,240,181,195,236,18,20,24,25,26,24,21,77,
40,37,29,39,32,20,19,76,77,128,130,155,84,83,82,70,72,52,
55,29,30,61,62,96,0,1,0,82,0,0,3,139,4,50,0,7,
0,0,19,33,21,33,17,35,3,33,82,3,57,254,184,158,1,254,
174,4,50,141,252,91,3,165,0,0,0,1,0,74,254,129,3,199,
4,49,0,32,0,0,19,51,9,1,51,1,6,7,6,7,6,7,
6,7,6,7,48,35,34,39,38,39,38,39,55,31,4,50,63,1,
82,160,1,24,1,31,158,254,61,1,17,14,8,33,42,41,32,28,
39,11,44,36,32,20,12,32,107,15,16,18,22,27,51,22,94,4,
49,252,146,3,110,250,222,4,22,18,7,30,22,21,9,7,2,15,
13,15,9,30,102,13,14,11,8,3,24,224,0,0,0,3,0,100,
254,116,4,204,5,174,0,10,0,37,0,46,0,0,1,38,39,17,
54,55,54,55,48,53,52,1,17,38,39,38,53,39,52,55,54,55,
17,51,17,22,23,22,23,22,23,48,21,20,7,6,7,17,3,6,
7,6,21,20,23,22,23,3,186,76,139,105,109,132,1,253,244,170,
126,164,2,166,130,166,179,166,91,72,50,100,8,158,141,188,179,113,
86,111,134,80,96,3,105,75,29,252,147,22,103,135,190,5,187,251,
142,1,129,28,127,164,236,2,234,166,130,22,1,100,254,154,21,83,
53,69,108,227,21,215,155,139,21,254,132,5,93,9,86,116,222,186,
134,80,36,0,0,1,0,53,0,0,3,102,4,49,0,11,0,0,
33,35,11,1,35,9,1,51,27,1,51,1,3,102,170,241,230,176,
1,58,254,200,170,234,233,170,254,201,1,184,254,72,2,27,2,22,
254,78,1,178,253,238,0,1,0,121,255,48,4,164,4,50,0,11,
0,0,37,17,35,53,33,17,51,17,33,17,51,17,4,164,142,252,
99,158,1,253,158,142,254,162,208,4,50,252,91,3,165,252,92,0,
0,1,0,129,0,0,3,188,4,50,0,33,0,0,1,51,17,35,
17,14,1,35,34,39,38,39,38,39,38,61,1,51,21,20,23,22,
23,30,1,51,50,55,54,55,54,55,54,53,3,36,152,152,29,162,
114,83,66,67,49,52,26,27,151,14,15,30,30,102,68,69,50,55,
29,31,15,16,4,50,251,206,2,52,90,120,33,34,66,71,104,108,
145,159,159,95,70,76,58,59,66,34,37,56,58,77,80,83,0,0,
0,1,0,125,0,0,5,153,4,51,0,13,0,0,41,1,17,51,
17,5,17,59,2,17,5,17,51,5,153,250,228,158,1,160,1,157,
1,1,159,160,4,51,252,90,1,3,166,252,91,1,3,166,0,1,
0,125,255,47,6,137,4,51,0,17,0,0,37,17,35,53,37,17,
51,17,5,17,59,2,17,5,17,51,17,6,137,142,250,130,158,1,
160,1,157,1,1,159,158,141,254,162,208,1,4,51,252,90,1,3,
166,252,91,1,3,166,252,91,0,2,0,12,0,0,4,53,4,50,
0,21,0,38,0,0,51,17,35,53,33,17,51,50,23,22,23,22,
23,22,23,20,7,6,7,6,43,1,25,1,51,50,55,54,55,54,
55,54,55,54,53,52,39,38,33,232,220,1,122,140,138,106,108,64,
36,50,43,2,8,31,140,137,231,140,140,102,68,71,43,41,23,22,
9,7,1,54,254,181,3,164,142,254,170,33,33,44,25,75,63,50,
47,38,146,90,88,2,77,254,64,17,18,32,31,35,33,42,31,18,
8,3,180,0,0,0,0,3,0,51,0,0,4,107,4,50,0,3,
0,25,0,42,0,0,1,51,17,35,5,17,51,17,51,50,23,22,
23,22,23,22,23,48,21,20,7,6,7,6,43,1,25,1,51,50,
55,54,55,54,55,54,55,54,53,52,39,38,33,3,212,151,151,252,
95,158,140,139,106,108,64,34,51,43,2,8,31,139,137,232,140,140,
103,68,71,43,39,24,22,9,7,1,54,254,181,4,50,251,207,1,
4,50,254,170,33,33,44,24,76,63,50,9,38,38,147,89,88,2,
77,254,64,17,18,32,29,37,33,42,31,18,8,3,180,0,0,2,
0,129,255,255,3,206,4,49,0,21,0,37,0,0,23,17,51,17,
51,50,23,22,23,22,23,22,23,48,21,20,7,6,7,6,43,1,
25,1,51,50,55,62,1,55,54,55,54,53,52,39,38,33,129,158,
140,139,106,108,64,34,51,43,2,8,31,139,137,232,140,140,99,72,
75,78,24,21,10,7,1,54,254,181,1,4,50,254,170,33,33,44,
24,76,63,50,9,38,38,147,89,88,2,77,254,64,18,19,58,37,
33,43,31,18,8,3,180,0,0,0,0,1,0,101,255,227,3,133,
4,70,0,52,0,0,19,39,54,55,54,51,50,23,22,23,22,23,
22,23,22,21,20,7,6,7,6,35,34,39,38,39,38,39,38,39,
55,22,23,22,23,22,23,22,51,50,55,54,55,33,53,33,38,39,
38,35,34,7,6,232,131,53,86,85,115,84,74,72,56,54,41,40,
20,20,59,58,106,104,132,61,53,55,41,50,25,32,24,122,11,16,
18,25,24,43,39,43,130,88,71,14,254,127,1,128,15,71,90,128,
69,61,60,3,41,66,96,62,61,30,29,55,52,72,70,82,83,84,
155,130,128,77,76,19,20,32,39,29,37,40,77,21,24,26,25,24,
20,18,118,95,149,142,135,93,120,50,50,0,0,2,0,97,255,240,
5,121,4,81,0,46,0,85,0,0,51,17,51,17,51,54,55,54,
55,54,55,54,55,54,51,50,23,22,23,22,23,22,23,22,21,20,
7,6,7,6,7,6,7,6,35,34,39,38,39,38,39,38,39,38,
39,35,17,1,52,39,38,39,46,1,39,38,35,34,7,6,7,6,
7,6,7,6,21,20,23,22,23,22,23,22,23,22,51,50,55,54,
55,54,55,54,55,54,97,157,97,5,9,16,42,42,57,60,90,92,
110,110,88,88,61,60,39,48,11,22,18,19,39,42,57,60,90,93,
109,110,88,89,60,61,38,37,22,16,4,95,3,230,21,16,28,26,
86,62,59,80,84,67,66,42,41,28,8,30,11,20,14,29,26,44,
43,62,60,79,85,65,68,40,39,30,26,13,12,4,81,254,3,57,
39,72,78,77,56,59,35,36,33,33,59,58,68,83,64,74,99,72,
74,77,71,76,54,57,34,35,33,33,57,58,66,65,80,62,55,254,
19,2,22,96,79,58,53,49,86,24,23,29,29,46,46,63,16,106,
75,58,79,80,56,53,47,43,41,24,23,28,30,42,42,63,55,64,
60,0,0,2,0,117,0,0,3,75,4,50,0,3,0,20,0,0,
1,17,32,16,5,34,39,3,35,1,38,39,38,53,52,55,54,33,
51,17,35,2,175,254,158,1,96,48,100,239,181,1,0,77,46,76,
77,150,1,28,158,158,2,58,1,128,254,128,133,17,254,58,1,244,
33,46,73,103,101,74,144,251,206,0,255,255,0,98,255,227,3,157,
6,60,16,39,0,67,0,112,254,164,16,6,2,125,0,0,255,255,
0,98,255,227,3,157,5,171,16,39,0,106,0,114,254,184,16,6,
2,125,0,0,0,1,0,0,254,116,3,188,5,176,0,68,0,0,
33,35,17,35,53,51,53,51,21,33,21,33,17,54,55,54,51,50,
23,22,23,22,23,22,21,17,21,20,7,6,7,6,7,6,7,6,
35,34,39,38,39,38,39,55,31,4,50,61,1,17,51,52,39,38,
39,46,1,35,34,7,6,7,6,7,6,21,1,25,152,129,129,152,
1,63,254,193,29,80,81,115,82,66,69,48,50,27,28,23,22,35,
40,34,40,34,29,28,42,36,35,17,8,36,107,15,16,19,22,26,
102,1,15,16,28,30,102,68,70,50,51,31,34,14,15,4,143,142,
147,147,142,254,237,91,59,60,33,34,66,69,106,112,141,253,227,107,
63,52,50,32,36,18,21,9,8,15,15,12,6,34,102,14,12,12,
8,3,123,138,2,29,90,75,79,55,59,66,34,35,58,65,70,75,
88,0,255,255,0,94,0,0,3,18,6,60,16,39,0,118,1,50,
254,164,16,6,2,123,0,0,0,1,0,101,255,227,3,133,4,70,
0,52,0,0,1,38,39,38,35,34,7,6,7,33,21,33,22,23,
22,51,50,55,54,55,54,55,54,55,23,6,7,6,7,6,7,6,
35,34,39,38,39,38,53,52,55,54,55,54,55,54,55,54,51,50,
23,22,23,3,2,18,60,61,69,128,90,71,15,1,128,254,127,14,
71,88,130,43,39,43,24,25,18,16,11,122,24,32,25,50,41,55,
53,61,132,104,106,58,59,20,20,40,41,54,56,72,74,84,115,85,
86,53,3,41,49,50,50,120,93,135,142,149,95,118,18,20,24,25,
26,24,21,77,40,37,29,39,32,20,19,76,77,128,130,155,84,83,
82,70,72,52,55,29,30,61,62,96,0,1,0,96,255,227,3,72,
4,74,0,73,0,0,1,38,39,38,39,38,39,38,39,38,53,52,
55,54,55,50,22,23,22,23,22,23,7,38,35,34,6,21,20,23,
22,23,22,23,22,23,22,23,30,1,31,9,20,7,6,35,34,39,
38,39,55,22,23,22,51,50,55,54,53,52,39,38,39,38,39,38,
1,213,62,39,42,50,47,34,34,19,21,100,101,147,82,130,41,44,
21,24,12,146,54,152,81,116,14,15,23,26,22,29,23,28,17,2,
29,12,49,49,50,45,43,36,30,17,7,108,107,152,153,92,95,37,
147,30,52,53,91,101,58,58,19,21,34,39,27,30,1,221,20,16,
17,28,26,36,35,46,49,59,137,75,76,1,44,38,41,31,36,37,
30,122,78,72,38,28,29,19,21,12,16,7,8,8,1,9,5,18,
19,23,27,33,39,47,54,65,137,90,89,67,69,110,28,67,36,36,
48,48,85,41,31,34,21,25,11,13,255,255,0,131,0,0,1,63,
5,147,16,6,0,76,0,0,255,255,255,144,0,0,2,35,5,79,
16,39,0,106,255,68,254,92,16,6,0,243,0,0,255,255,255,137,
254,84,1,102,5,147,16,6,0,77,0,0,0,2,0,72,0,0,
6,46,4,50,0,48,0,65,0,0,1,33,17,51,50,23,22,23,
22,23,22,23,48,21,20,7,6,7,6,43,2,17,35,3,6,7,
6,7,6,7,6,7,6,35,34,39,38,39,38,39,55,31,4,50,
55,5,51,50,55,54,55,54,55,54,55,54,53,52,39,38,33,35,
1,201,1,182,140,139,106,108,64,34,51,43,2,8,33,137,137,232,
140,158,129,77,10,13,22,35,38,37,41,32,29,28,42,36,35,17,
8,36,107,15,16,18,22,27,90,12,2,49,140,103,68,71,43,39,
24,22,9,7,1,54,254,181,140,4,50,254,170,33,33,44,24,76,
63,50,9,36,40,150,86,88,3,165,253,124,85,30,50,32,35,19,
21,9,8,15,15,12,6,34,102,14,12,12,8,3,123,117,17,18,
32,29,37,33,42,31,18,8,3,180,0,2,0,88,0,0,5,54,
4,50,0,29,0,46,0,0,33,17,7,17,35,17,51,17,55,17,
51,17,51,50,23,22,23,22,23,22,23,48,21,20,7,6,7,6,
43,1,19,3,51,50,55,54,55,54,55,54,55,54,53,52,39,38,
33,1,233,250,151,151,250,158,140,139,106,108,64,34,51,43,2,8,
33,137,137,232,140,2,2,140,103,68,71,43,39,24,22,9,7,1,
54,254,181,2,83,1,253,174,4,50,254,169,1,1,86,254,170,33,
33,44,24,76,63,50,9,36,40,150,86,88,2,77,254,64,17,18,
32,29,37,33,42,31,18,8,3,180,0,1,0,0,0,0,3,188,
5,176,0,45,0,0,33,35,53,7,17,51,52,39,38,39,46,1,
35,34,7,6,7,6,7,6,21,17,35,17,35,53,51,53,51,21,
33,21,33,17,54,55,54,51,50,23,22,23,22,23,22,21,3,188,
151,1,1,15,16,28,30,102,68,70,50,51,31,34,14,15,152,129,
129,152,1,63,254,193,29,80,81,115,82,66,69,48,50,27,28,1,
1,2,29,90,75,79,55,59,66,34,35,58,65,70,75,88,253,228,
4,143,142,147,147,142,254,237,91,59,60,33,34,66,69,106,112,141,
0,0,255,255,0,121,0,0,3,168,6,59,16,39,0,118,1,47,
254,163,16,6,2,130,0,0,255,255,0,122,0,0,3,174,6,60,
16,39,0,67,0,147,254,164,16,6,2,128,0,0,0,2,0,74,
254,129,3,199,5,234,0,23,0,55,0,0,1,54,55,54,55,51,
48,21,20,7,6,7,6,34,39,38,39,38,61,1,51,22,23,22,
5,51,9,1,51,1,6,7,6,7,6,7,6,7,6,7,35,34,
39,38,39,38,39,55,31,4,50,63,1,2,36,55,35,59,69,80,
66,35,69,67,132,67,69,35,66,81,49,78,38,254,108,160,1,24,
1,31,158,254,61,1,17,14,8,33,42,41,32,28,39,11,44,36,
32,20,12,32,107,15,16,18,22,27,51,22,94,5,44,3,23,42,
122,10,68,111,57,40,38,38,40,57,111,68,10,112,52,24,253,252,
146,3,110,250,222,4,22,18,7,30,22,21,9,7,2,15,13,15,
9,30,102,13,14,11,8,3,24,224,0,1,0,121,255,42,3,178,
4,50,0,11,0,0,33,37,17,51,17,33,17,51,17,33,21,35,
1,217,254,160,158,1,253,158,254,181,142,1,4,49,252,91,3,165,
251,206,214,0,255,255,0,121,0,0,4,147,7,88,16,6,2,97,
0,0,255,255,0,122,0,0,3,174,5,234,16,6,2,129,0,0,
0,2,0,121,0,0,4,8,5,176,0,14,0,34,0,0,1,17,
51,50,55,54,55,54,55,54,55,54,53,16,33,1,17,51,17,51,
50,23,22,23,22,23,22,21,20,7,6,7,6,43,1,1,23,206,
103,68,71,43,39,24,22,9,6,254,127,254,148,158,206,139,106,106,
65,64,34,33,8,31,139,137,232,206,2,170,253,227,17,18,32,29,
37,33,42,25,35,1,17,253,86,5,176,253,137,33,33,57,57,75,
73,88,37,48,147,89,88,0,0,2,0,129,255,255,3,206,4,49,
0,21,0,37,0,0,23,17,51,17,51,50,23,22,23,22,23,22,
23,48,21,20,7,6,7,6,43,1,25,1,51,50,55,62,1,55,
54,55,54,53,52,39,38,33,129,158,140,139,106,108,64,34,51,43,
2,8,31,139,137,232,140,140,99,72,75,78,24,21,10,7,1,54,
254,181,1,4,50,254,170,33,33,44,24,76,63,50,9,38,38,147,
89,88,2,77,254,64,18,19,58,37,33,43,31,18,8,3,180,0,
0,0,0,2,0,121,0,0,4,8,5,176,0,14,0,34,0,0,
1,51,32,17,52,39,38,39,38,39,38,39,38,43,1,39,59,1,
50,23,22,23,22,21,20,7,6,7,6,7,6,43,1,17,35,1,
23,206,1,129,6,9,22,24,39,43,71,68,103,206,158,158,206,232,
137,139,31,8,33,34,64,65,106,107,138,206,158,3,6,1,17,35,
25,42,33,37,29,32,18,17,141,88,89,147,48,37,87,74,75,57,
57,33,33,253,137,0,0,2,0,129,254,84,3,207,4,78,0,34,
0,50,0,0,1,21,54,55,54,55,54,55,54,51,50,30,1,23,
22,21,20,7,6,7,6,7,6,35,34,39,38,39,38,39,38,39,
17,35,17,1,52,39,38,35,34,7,6,21,20,23,22,51,50,55,
54,1,25,19,24,21,38,32,53,50,62,102,154,94,22,23,23,22,
47,46,79,78,102,65,47,50,35,35,22,25,18,152,2,180,77,76,
116,117,79,80,80,79,117,116,76,77,4,49,187,44,36,32,36,31,
19,18,92,164,96,101,110,108,101,98,83,81,49,48,17,18,32,32,
34,38,42,253,156,5,221,253,234,198,115,114,115,116,198,197,118,116,
116,118,0,0,0,2,0,92,0,0,4,148,6,244,0,27,0,33,
0,0,1,19,54,55,54,51,50,23,22,23,22,23,22,21,20,6,
21,7,6,7,6,43,1,38,39,48,39,38,37,33,21,33,17,35,
3,247,8,5,31,16,18,9,5,31,16,3,4,11,1,48,5,18,
13,18,6,23,13,6,6,252,101,3,146,253,12,158,5,176,1,0,
41,18,9,1,3,21,4,6,19,20,2,6,2,251,24,10,8,3,
15,9,12,14,141,250,221,0,0,2,0,94,0,0,3,136,5,171,
0,27,0,33,0,0,1,19,54,55,54,51,50,23,22,23,22,23,
22,21,20,6,21,7,6,7,6,43,1,38,39,48,39,38,7,33,
17,35,17,33,2,235,8,5,30,16,19,9,5,31,16,3,4,11,
1,48,5,18,13,18,6,23,13,6,6,13,254,23,151,2,128,4,
103,1,0,42,17,9,1,3,21,4,6,19,20,1,8,1,251,24,
10,8,3,15,9,12,175,252,86,4,50,0,0,1,255,127,0,0,
3,238,5,176,0,13,0,0,19,33,21,33,17,33,21,33,17,35,
17,35,53,51,92,3,146,253,12,1,42,254,214,158,221,221,5,176,
141,254,5,142,253,102,2,154,142,0,0,1,255,111,255,253,2,222,
4,48,0,13,0,0,1,33,17,33,21,33,17,35,17,35,53,51,
17,33,2,222,254,23,1,31,254,225,151,239,239,2,128,3,167,255,
0,142,253,228,2,28,142,1,136,0,0,0,0,1,0,92,254,63,
3,238,5,176,0,54,0,0,1,50,55,54,61,1,17,52,39,38,
39,46,1,35,34,7,6,7,6,7,6,21,17,43,2,17,33,21,
33,19,62,1,51,50,23,22,23,22,23,22,21,17,23,21,20,7,
6,7,6,7,6,43,1,54,2,14,103,74,73,14,15,30,30,102,
68,69,50,55,29,31,15,16,2,150,8,3,146,253,12,2,29,162,
114,83,66,67,49,52,26,27,1,35,19,74,65,64,80,65,4,1,
254,197,74,73,135,33,2,29,95,70,76,58,59,66,34,37,56,58,
77,80,83,253,228,5,176,141,254,89,90,120,33,34,66,71,104,108,
145,253,228,1,9,62,129,67,69,61,23,29,10,0,255,255,0,94,
0,0,2,222,4,50,16,6,2,123,0,0,255,255,0,76,0,0,
5,110,5,179,16,6,2,94,0,0,255,255,0,94,0,0,5,126,
4,50,16,6,2,126,0,0,255,255,0,113,255,227,4,12,5,217,
16,6,2,95,0,0,255,255,0,97,255,227,3,65,4,74,16,6,
2,127,0,0,255,255,0,121,0,0,4,211,5,176,16,6,2,98,
0,0,255,255,0,121,0,0,3,168,4,53,16,6,2,130,0,0,
255,255,0,121,0,0,4,211,5,176,16,6,2,98,0,0,255,255,
0,121,0,0,3,168,4,53,16,6,2,130,0,0,255,255,0,121,
0,0,4,211,5,176,16,6,2,98,0,0,255,255,0,121,0,0,
3,168,4,53,16,6,2,130,0,0,255,255,0,121,0,0,4,211,
5,176,16,6,2,98,0,0,255,255,0,121,0,0,3,168,4,53,
16,6,2,130,0,0,255,255,0,121,0,0,4,74,5,176,16,6,
2,101,0,0,255,255,0,102,0,0,3,48,4,51,16,6,2,133,
0,0,0,1,0,121,0,0,5,149,5,176,0,15,0,0,19,51,
17,33,17,33,21,33,17,43,2,17,33,17,35,121,158,1,237,2,
145,254,13,2,131,25,254,19,158,5,176,253,127,2,129,141,250,221,
2,162,253,94,0,1,0,102,0,0,5,24,4,51,0,13,0,0,
19,51,17,37,17,33,21,33,17,39,17,33,17,35,102,151,1,154,
2,129,254,24,153,254,102,151,4,50,254,41,1,1,215,136,252,85,
1,1,209,254,46,0,255,255,0,121,0,0,4,74,5,176,16,6,
2,103,0,0,255,255,0,121,0,0,3,178,4,50,16,6,2,135,
0,0,255,255,0,100,255,227,4,143,5,215,16,6,2,105,0,0,
255,255,0,101,255,227,3,133,4,70,16,6,2,137,0,0,255,255,
0,100,255,227,4,143,5,215,16,6,2,105,0,0,255,255,0,101,
255,227,3,133,4,70,16,6,2,137,0,0,255,255,0,88,0,0,
4,156,5,176,16,6,2,106,0,0,255,255,0,82,0,0,3,139,
4,50,16,6,2,138,0,0,0,1,0,66,0,0,4,90,5,176,
0,8,0,0,19,51,9,1,51,1,17,35,17,66,168,1,100,1,
100,168,254,66,158,5,176,253,168,2,88,253,60,253,20,2,236,0,
0,0,0,1,0,120,254,63,3,179,4,49,0,54,0,0,5,20,
7,6,7,6,7,6,35,34,39,55,22,51,50,55,54,55,54,55,
54,61,1,6,7,6,35,34,39,38,39,38,39,38,53,17,51,17,
20,23,22,23,30,1,51,50,55,54,55,54,55,54,53,17,51,3,
179,38,36,63,60,78,73,79,213,150,106,103,154,52,44,51,37,41,
25,25,29,80,82,114,82,66,69,48,50,27,28,151,15,16,28,30,
102,68,70,50,51,31,34,14,15,152,18,97,85,81,55,53,31,29,
174,85,123,17,20,30,33,55,54,71,214,90,59,61,33,34,66,68,
108,112,140,2,29,253,227,90,75,79,55,59,66,34,34,60,65,69,
75,88,2,28,0,1,0,66,0,0,4,90,5,176,0,8,0,0,
19,51,9,1,51,1,17,35,17,66,168,1,100,1,100,168,254,66,
158,5,176,253,168,2,88,253,60,253,20,2,236,0,0,0,0,1,
0,120,254,63,3,179,4,49,0,54,0,0,5,20,7,6,7,6,
7,6,35,34,39,55,22,51,50,55,54,55,54,55,54,61,1,6,
7,6,35,34,39,38,39,38,39,38,53,17,51,17,20,23,22,23,
30,1,51,50,55,54,55,54,55,54,53,17,51,3,179,38,36,63,
60,78,73,79,213,150,106,103,154,52,44,51,37,41,25,25,29,80,
82,114,82,66,69,48,50,27,28,151,15,16,28,30,102,68,70,50,
51,31,34,14,15,152,18,97,85,81,55,53,31,29,174,85,123,17,
20,30,33,55,54,71,214,90,59,61,33,34,66,68,108,112,140,2,
29,253,227,90,75,79,55,59,66,34,34,60,65,69,75,88,2,28,
255,255,0,74,0,0,4,137,5,176,16,6,2,109,0,0,255,255,
0,53,0,0,3,102,4,49,16,6,2,141,0,0,255,255,0,121,
255,48,5,60,5,176,16,6,2,110,0,0,255,255,0,121,255,48,
4,164,4,50,16,6,2,142,0,0,255,255,0,98,0,0,3,158,
5,176,16,6,2,111,0,0,255,255,0,129,0,0,3,188,4,50,
16,6,2,143,0,0,255,255,0,98,0,0,3,158,5,176,16,6,
2,111,0,0,255,255,0,129,0,0,3,188,4,50,16,6,2,143,
0,0,0,1,0,129,0,0,3,188,6,243,0,34,0,0,33,35,
17,51,17,54,55,54,51,50,23,22,23,22,23,22,21,17,35,17,
52,39,38,39,46,1,35,34,7,6,7,6,7,6,21,1,25,152,
152,29,80,81,115,82,66,69,48,50,27,28,151,15,16,28,30,102,
68,70,50,51,31,34,14,15,6,243,252,137,91,59,60,33,34,66,
69,106,112,141,253,227,2,29,90,75,79,55,59,66,34,35,58,65,
70,75,88,0,0,0,0,1,0,129,0,0,3,188,5,176,0,34,
0,0,33,35,17,51,17,54,55,54,51,50,23,22,23,22,23,22,
21,17,35,17,52,39,38,39,46,1,35,34,7,6,7,6,7,6,
21,1,25,152,152,29,80,81,115,82,66,69,48,50,27,28,151,15,
16,28,30,102,68,70,50,51,31,34,14,15,5,176,253,204,91,59,
60,33,34,66,69,106,112,141,253,227,2,29,90,75,79,55,59,66,
34,35,58,65,70,75,88,0,0,0,255,255,0,100,255,227,4,143,
5,215,16,6,2,105,0,0,255,255,0,101,255,227,3,133,4,70,
16,6,2,137,0,0,0,1,0,100,255,16,4,143,5,215,0,67,
0,0,1,6,7,6,7,6,7,6,7,21,35,53,38,39,38,39,
38,39,38,39,38,53,52,55,54,55,54,55,54,55,54,51,50,23,
22,23,22,23,22,23,22,23,7,38,39,38,43,1,34,7,6,7,
6,7,6,21,20,23,22,23,22,23,22,51,50,55,54,55,4,143,
24,38,36,58,53,83,49,55,150,73,67,100,69,71,47,50,22,22,
23,22,49,47,72,70,100,99,120,73,71,66,50,49,39,40,24,24,
15,149,28,86,83,105,2,104,84,86,52,51,29,28,30,30,54,53,
85,82,100,107,90,91,32,1,37,64,55,52,50,46,28,17,6,215,
216,9,27,40,72,74,94,101,105,107,120,116,113,109,101,97,75,73,
43,43,19,18,30,30,40,42,40,41,41,41,89,57,55,54,56,88,
87,114,109,121,120,111,110,86,83,53,51,65,66,92,0,0,0,1,
0,101,255,32,3,133,4,70,0,50,0,0,1,38,39,38,35,34,
6,21,20,22,51,50,55,54,55,54,55,54,55,23,6,7,6,7,
6,7,6,7,21,35,53,38,39,38,39,38,53,52,55,54,55,54,
55,54,55,54,51,50,23,22,23,3,2,18,60,61,69,128,180,176,
130,43,39,43,24,25,18,16,11,122,24,32,25,50,41,55,22,23,
136,92,77,106,58,59,20,20,40,41,54,56,72,74,84,115,85,86,
53,3,41,49,50,50,240,181,195,236,18,20,24,25,26,24,21,77,
40,37,29,39,32,20,8,4,202,200,15,56,77,128,130,155,84,83,
82,70,72,52,55,29,30,61,62,96,255,255,0,131,0,0,1,63,
5,147,16,6,0,76,0,0,255,255,0,76,0,0,5,110,7,46,
16,38,1,174,79,0,16,6,2,94,0,0,0,0,255,255,0,94,
0,0,5,126,5,230,16,39,1,174,0,87,254,184,16,6,2,126,
0,0,0,1,0,121,254,154,4,211,5,176,0,30,0,0,19,51,
17,1,51,9,1,14,3,7,14,3,7,53,50,30,1,62,4,53,
1,7,17,35,121,158,2,235,193,253,120,2,152,5,5,8,45,40,
46,104,81,85,28,11,48,32,47,31,36,21,14,253,207,188,158,5,
176,253,14,2,242,253,115,252,221,3,63,78,97,33,38,40,2,3,
1,184,2,2,5,11,26,37,60,39,2,190,186,253,252,0,0,1,
0,121,254,154,3,168,4,53,0,28,0,0,33,14,2,7,14,3,
7,53,50,30,1,62,4,53,1,3,35,17,51,17,1,51,1,3,
168,5,9,47,51,46,104,81,85,28,11,48,32,47,31,36,21,14,
254,72,1,158,158,1,161,186,254,6,3,97,132,42,38,40,2,3,
1,184,2,2,5,11,26,37,60,39,1,149,254,107,4,48,254,80,
1,181,253,231,0,1,0,84,255,6,4,36,5,176,0,31,0,0,
1,33,17,7,55,17,35,3,6,7,6,7,6,7,6,7,6,35,
34,39,38,39,38,39,55,31,4,50,55,2,29,2,7,250,92,208,
151,13,10,22,35,38,37,41,32,29,28,42,36,35,17,8,36,107,
15,16,18,22,27,87,15,5,176,250,80,250,250,5,35,251,254,92,
23,50,32,35,19,21,9,8,15,15,12,6,34,102,14,12,12,8,
3,123,0,0,0,1,0,69,255,42,3,125,4,50,0,31,0,0,
1,33,17,7,55,17,35,3,6,7,6,7,6,7,6,7,6,35,
34,39,38,39,38,39,55,31,4,50,55,1,198,1,183,251,93,130,
77,10,13,22,35,40,34,40,34,29,28,42,36,35,17,8,36,107,
15,16,19,22,26,90,12,4,50,251,206,214,214,3,165,253,124,85,
30,50,32,36,18,21,9,8,15,15,12,6,34,102,14,12,12,8,
3,123,0,0,0,1,0,121,254,162,4,79,5,176,0,31,0,0,
37,14,3,7,14,3,7,53,50,30,1,62,4,53,17,33,17,35,
17,51,17,33,17,51,17,4,79,5,5,8,45,40,46,104,81,85,
28,12,50,39,54,41,42,28,18,253,107,158,158,2,149,158,8,3,
63,78,97,33,38,40,2,3,1,184,3,2,3,10,24,36,59,39,
2,162,253,94,5,176,253,127,2,129,250,80,0,0,0,1,0,102,
254,154,3,56,4,51,0,31,0,0,33,14,3,7,14,3,7,53,
50,30,1,62,4,53,17,33,17,35,17,51,17,37,17,23,17,3,
56,5,5,8,45,40,46,104,81,85,28,11,53,37,56,39,44,28,
18,254,102,151,151,1,154,153,3,63,78,97,33,38,40,2,3,1,
184,2,1,4,12,25,38,60,39,1,210,254,45,4,50,254,41,1,
1,215,1,251,206,0,0,1,0,121,254,250,4,74,5,176,0,12,
0,0,19,51,17,33,17,51,17,1,19,17,33,17,35,121,158,2,
149,158,254,242,112,253,107,158,5,176,253,127,2,129,250,80,254,250,
1,6,2,162,253,94,0,0,0,1,0,102,255,42,3,48,4,51,
0,12,0,0,19,51,17,37,17,23,17,7,55,17,33,17,35,102,
151,1,154,153,221,68,254,102,151,4,50,254,41,1,1,215,1,251,
206,214,215,1,210,254,45,0,0,0,0,1,0,98,255,14,3,158,
5,176,0,37,0,0,1,51,17,35,7,53,51,17,14,1,35,34,
39,38,39,38,39,38,53,17,51,17,20,23,22,23,22,23,22,51,
50,55,54,55,54,55,54,53,3,6,152,71,133,52,29,162,115,82,
66,67,49,52,26,28,151,15,16,28,30,52,51,67,70,50,53,30,
32,15,16,5,176,250,80,242,242,3,12,90,120,33,34,66,71,104,
112,141,1,69,254,187,90,75,79,55,58,34,33,34,36,57,62,73,
80,83,0,0,0,1,0,129,255,9,3,188,4,50,0,36,0,0,
1,51,17,35,7,53,51,17,14,1,35,34,39,38,39,38,39,38,
61,1,51,21,20,23,22,23,30,1,51,50,55,54,55,54,55,54,
53,3,36,152,60,141,49,29,162,114,83,66,67,49,52,26,27,151,
14,15,30,30,102,68,69,50,55,29,31,15,16,4,50,251,206,247,
247,2,52,90,120,33,34,66,71,104,108,145,159,159,95,70,76,58,
59,66,34,37,56,58,77,80,83,0,0,0,0,1,0,121,255,6,
5,182,5,176,0,13,0,0,51,17,51,9,1,51,17,7,55,17,
1,35,1,17,121,215,1,203,1,204,207,250,97,254,84,179,254,84,
5,176,251,33,4,223,250,80,250,250,4,180,251,92,4,164,251,76,
0,1,0,98,255,0,4,52,4,50,0,13,0,0,51,17,51,9,
1,51,17,1,19,17,1,35,1,17,98,156,1,80,1,79,151,254,
255,106,254,239,130,254,239,4,50,252,160,3,96,251,206,255,0,1,
0,2,220,253,36,2,220,253,36,0,255,255,0,154,0,0,1,55,
5,176,16,6,0,44,0,0,255,255,0,72,0,0,4,223,7,46,
16,38,1,174,0,0,16,6,2,88,0,0,0,0,255,255,0,106,
255,227,3,119,5,211,16,39,1,174,255,99,254,165,16,6,2,120,
0,0,0,4,0,72,0,0,4,223,6,204,0,16,0,34,0,37,
0,45,0,0,1,52,54,51,50,22,23,22,21,20,6,35,34,39,
38,39,38,37,52,54,51,50,23,22,23,22,21,20,6,35,34,39,
38,39,38,1,3,33,23,33,3,35,1,51,1,35,3,26,56,38,
34,50,8,2,56,38,32,27,25,8,2,254,41,56,38,33,26,25,
8,2,56,38,32,27,26,7,2,1,80,204,1,159,37,254,15,162,
176,2,12,127,2,12,180,6,110,38,56,42,33,10,9,39,56,22,
21,33,16,1,38,56,21,21,33,10,9,39,56,22,21,33,8,254,
93,253,175,136,254,27,5,176,250,80,0,4,0,106,255,227,3,119,
5,172,0,17,0,34,0,50,0,88,0,0,1,52,54,51,50,23,
22,23,22,21,20,6,35,34,39,38,39,38,37,52,54,51,50,22,
23,22,21,20,6,35,34,39,38,39,38,1,34,7,6,21,20,23,
22,51,50,55,54,53,52,39,38,39,50,23,22,23,53,52,38,35,
34,7,6,7,39,54,51,50,22,29,1,17,35,61,1,6,7,6,
7,6,7,6,35,34,38,53,52,55,54,2,141,56,38,33,26,25,
8,2,56,38,32,27,26,7,2,254,41,56,38,34,50,8,2,56,
38,32,27,25,8,2,1,72,108,72,70,71,73,106,96,72,70,73,
74,123,102,78,76,12,126,118,66,64,59,35,78,133,169,167,218,139,
1,22,23,32,33,53,51,55,164,208,108,109,5,78,38,56,21,21,
33,10,9,39,56,22,21,33,16,1,38,56,42,33,10,9,39,56,
22,21,33,8,253,5,70,69,99,103,67,68,70,69,99,103,67,68,
135,55,54,49,96,143,156,22,20,35,104,109,230,205,123,253,236,156,
2,19,31,33,29,30,23,22,206,167,159,107,107,0,0,2,0,83,
0,0,5,103,5,176,0,15,0,19,0,0,1,33,1,35,1,33,
21,33,17,33,21,33,17,33,21,33,3,53,3,51,3,17,254,248,
254,253,179,2,79,2,197,254,70,1,186,254,70,1,186,253,170,2,
202,204,2,133,253,123,5,176,149,253,249,147,254,18,147,4,213,74,
253,245,0,0,0,3,0,84,255,227,5,96,4,70,0,17,0,120,
0,133,0,0,1,34,7,6,21,20,23,22,51,50,55,54,53,52,
39,38,39,38,19,54,55,54,51,50,23,22,23,22,21,20,7,6,
21,33,20,23,22,23,22,51,50,54,55,54,55,54,55,54,55,62,
2,55,62,1,55,54,55,23,14,1,35,34,39,38,39,38,39,38,
39,38,39,46,1,39,6,7,6,7,6,7,14,1,35,34,39,38,
39,38,53,52,55,54,51,50,22,23,54,39,38,55,52,39,38,35,
34,7,6,7,39,54,55,54,55,54,55,54,51,50,23,22,19,33,
38,39,38,35,34,7,6,7,6,7,6,1,180,104,48,48,8,34,
158,92,54,55,7,16,52,50,209,60,59,60,101,145,88,88,33,21,
2,1,253,178,15,19,49,48,87,23,20,16,13,10,11,8,10,7,
2,5,6,2,3,9,2,15,1,133,56,130,110,39,32,31,27,18,
27,18,22,23,10,3,23,9,14,17,15,21,27,21,26,88,54,135,
91,89,27,10,100,101,151,88,80,37,1,2,2,2,10,34,156,66,
39,41,38,78,32,18,36,18,28,38,45,47,95,65,68,115,1,182,
6,13,46,155,59,43,43,24,23,13,11,2,90,70,71,107,47,38,
163,72,73,103,33,38,78,50,49,1,52,97,43,44,90,89,159,94,
125,3,30,15,20,73,71,92,64,63,4,6,5,7,8,8,10,10,
3,8,10,3,5,18,3,27,2,55,111,106,6,6,15,10,18,12,
28,28,17,4,35,14,23,33,29,23,29,15,19,22,77,76,127,53,
50,164,109,110,50,54,4,25,22,8,56,41,165,19,19,39,102,28,
13,26,10,16,8,10,44,46,254,116,75,53,226,33,32,55,53,61,
56,0,0,0,255,255,0,88,0,0,3,242,7,46,16,38,1,174,
152,0,16,6,2,93,0,0,0,0,255,255,0,98,255,227,3,157,
5,213,16,39,1,174,255,118,254,167,16,6,2,125,0,0,0,2,
0,23,255,227,4,143,5,215,0,7,0,62,0,0,1,33,22,18,
51,50,62,1,1,33,52,39,38,39,38,39,38,43,1,34,7,6,
7,39,54,55,54,55,54,55,54,55,54,51,50,23,30,1,23,22,
23,22,21,20,14,1,7,14,1,35,34,39,38,39,38,39,38,39,
38,53,52,54,53,3,213,252,241,13,210,169,114,178,90,252,76,3,
213,30,30,53,53,83,84,105,2,106,83,85,28,149,13,27,26,37,
39,49,49,68,71,72,120,99,100,140,48,51,21,23,46,94,71,68,
204,117,95,80,83,53,58,36,91,33,15,1,2,79,188,254,240,140,
204,1,1,118,108,106,92,91,53,54,55,56,90,41,36,46,43,39,
40,30,30,18,19,43,43,146,99,104,106,113,116,115,224,188,74,71,
82,27,28,46,50,52,130,130,58,130,1,37,17,0,0,2,0,98,
255,227,3,157,4,70,0,10,0,48,0,0,1,33,22,23,22,51,
50,55,54,55,54,55,46,2,35,34,7,6,7,39,54,55,54,51,
50,23,22,23,22,21,20,7,6,7,6,35,34,39,38,39,38,39,
38,53,52,38,61,1,2,254,253,246,9,70,71,111,75,60,59,31,
30,6,7,62,114,78,73,70,71,31,133,52,103,106,117,132,95,96,
48,49,49,50,95,97,129,97,79,77,52,50,25,26,1,1,205,145,
104,105,54,53,80,78,224,95,162,106,39,39,59,55,100,58,59,76,
76,128,130,156,161,123,126,73,74,45,44,78,75,93,95,99,1,33,
14,48,0,0,255,255,0,23,255,227,4,143,6,243,16,39,0,106,
0,165,0,0,16,6,2,246,0,0,255,255,0,98,255,227,3,157,
5,171,16,39,0,106,0,88,254,184,16,6,2,247,0,0,255,255,
0,76,0,0,5,110,6,243,16,39,0,106,1,68,0,0,16,6,
2,94,0,0,255,255,0,94,0,0,5,126,5,172,16,39,0,106,
1,88,254,185,16,6,2,126,0,0,255,255,0,113,255,227,4,12,
6,243,16,39,0,106,0,144,0,0,16,6,2,95,0,0,255,255,
0,97,255,227,3,65,5,171,16,39,0,106,0,46,254,184,16,6,
2,127,0,0,255,255,0,113,255,227,4,12,5,217,16,6,2,95,
0,0,255,255,0,97,255,227,3,65,4,74,16,6,2,127,0,0,
0,2,0,121,0,0,4,147,6,204,0,3,0,13,0,0,1,33,
21,33,7,51,17,1,51,17,35,17,1,35,1,56,2,165,253,91,
191,158,2,235,145,157,253,28,153,6,204,106,178,251,90,4,166,250,
80,4,137,251,119,0,0,2,0,122,0,0,3,174,5,43,0,3,
0,13,0,0,19,33,21,33,7,51,17,1,51,17,35,17,1,35,
210,2,165,253,91,88,156,2,0,152,140,253,240,152,5,43,106,143,
252,222,3,34,251,206,3,44,252,212,0,0,255,255,0,121,0,0,
4,147,6,243,16,39,0,106,0,242,0,0,16,6,2,96,0,0,
0,3,0,122,0,0,3,174,5,172,0,9,0,26,0,44,0,0,
19,51,17,1,51,17,35,17,1,35,1,52,54,51,50,22,23,22,
21,20,6,35,34,39,38,39,38,37,52,54,51,50,23,22,23,22,
21,20,6,35,34,39,38,39,38,122,156,2,0,152,140,253,240,152,
2,42,56,38,34,50,8,2,56,38,32,27,25,8,2,254,41,56,
38,33,26,25,8,2,56,38,32,27,26,7,2,4,50,252,222,3,
34,251,206,3,44,252,212,5,78,38,56,42,33,10,9,39,56,22,
21,33,16,1,38,56,21,21,33,10,9,39,56,22,21,33,8,0,
255,255,0,92,255,227,4,238,6,243,16,38,0,50,0,0,16,7,
0,106,1,2,0,0,255,255,0,102,255,227,3,207,5,171,16,38,
0,82,0,0,16,7,0,106,0,123,254,184,0,3,0,92,255,227,
4,238,5,215,0,39,0,60,0,80,0,0,19,52,55,54,55,54,
55,54,55,54,51,50,23,22,23,22,23,22,23,22,21,20,7,6,
7,6,7,6,7,6,35,34,39,38,39,38,39,38,39,38,37,33,
22,23,22,23,22,23,22,23,22,51,50,55,54,55,54,55,54,55,
54,37,33,38,39,38,39,38,39,38,39,38,35,34,6,7,6,7,
6,7,6,92,19,20,44,43,67,64,103,101,123,122,98,100,66,65,
45,44,22,24,20,20,44,47,63,67,101,102,122,120,99,98,68,65,
45,43,23,23,3,235,252,188,5,16,15,33,29,48,46,71,70,84,
94,73,75,45,45,32,33,11,8,252,193,3,64,7,13,17,32,29,
48,46,70,67,88,94,146,47,47,30,30,12,6,2,213,103,101,104,
102,100,82,79,50,49,46,47,78,76,97,93,108,116,109,98,103,104,
98,105,73,77,48,48,45,45,78,75,95,91,108,109,52,83,79,75,
74,65,59,57,32,32,39,40,59,60,83,85,79,46,207,79,62,79,
73,67,60,57,34,32,80,64,63,85,84,84,43,0,0,0,0,3,
0,98,255,226,3,170,4,70,0,24,0,34,0,47,0,0,0,32,
23,22,23,22,21,20,7,6,7,6,35,21,53,34,39,38,39,38,
53,52,55,54,55,3,33,46,1,35,34,7,6,7,6,18,50,55,
54,55,54,63,1,33,22,23,22,23,1,133,1,2,97,95,50,49,
48,47,99,97,129,129,97,99,47,48,49,50,95,35,2,10,9,140,
112,76,60,58,31,30,179,152,60,58,31,30,6,2,253,244,7,31,
29,60,4,70,74,73,126,123,161,159,127,124,79,77,1,1,77,79,
124,127,159,161,123,126,73,254,96,146,208,54,53,79,78,253,180,54,
53,79,78,90,9,95,81,78,55,0,0,5,0,92,255,227,4,238,
6,243,0,39,0,60,0,80,0,97,0,115,0,0,19,52,55,54,
55,54,55,54,55,54,51,50,23,22,23,22,23,22,23,22,21,20,
7,6,7,6,7,6,7,6,35,34,39,38,39,38,39,38,39,38,
37,33,22,23,22,23,22,23,22,23,22,51,50,55,54,55,54,55,
54,55,54,37,33,38,39,38,39,38,39,38,39,38,35,34,6,7,
6,7,6,7,6,1,52,54,51,50,22,23,22,21,20,6,35,34,
39,38,39,38,37,52,54,51,50,23,22,23,22,21,20,6,35,34,
39,38,39,38,92,19,20,44,43,67,64,103,101,123,122,98,100,66,
65,45,44,22,24,20,20,44,47,63,67,101,102,122,120,99,98,68,
65,45,43,23,23,3,235,252,188,5,16,15,33,29,48,46,71,70,
84,94,73,75,45,45,32,33,11,8,252,193,3,64,7,13,17,32,
29,48,46,70,67,88,94,146,47,47,30,30,12,6,2,44,56,38,
34,50,8,2,56,38,32,27,25,8,2,254,41,56,38,33,26,25,
8,2,56,38,32,27,26,7,2,2,213,103,101,104,102,100,82,79,
50,49,46,47,78,76,97,93,108,116,109,98,103,104,98,105,73,77,
48,48,45,45,78,75,95,91,108,109,52,83,79,75,74,65,59,57,
32,32,39,40,59,60,83,85,79,46,207,79,62,79,73,67,60,57,
34,32,80,64,63,85,84,84,43,3,66,38,56,42,33,10,9,39,
56,22,21,33,16,1,38,56,21,21,33,10,9,39,56,22,21,33,
8,0,0,5,0,98,255,226,3,170,5,171,0,24,0,34,0,47,
0,65,0,82,0,0,0,32,23,22,23,22,21,20,7,6,7,6,
35,21,53,34,39,38,39,38,53,52,55,54,55,3,33,46,1,35,
34,7,6,7,6,18,50,55,54,55,54,63,1,33,22,23,22,23,
1,52,54,51,50,23,22,23,22,21,20,6,35,34,39,38,39,38,
37,52,54,51,50,22,23,22,21,20,6,35,34,39,38,39,38,1,
133,1,2,97,95,50,49,48,47,99,97,129,129,97,99,47,48,49,
50,95,35,2,10,9,140,112,76,60,58,31,30,179,152,60,58,31,
30,6,2,253,244,7,31,29,60,1,23,56,38,33,26,25,8,2,
56,38,32,27,26,7,2,254,41,56,38,34,50,8,2,56,38,32,
27,25,8,2,4,70,74,73,126,123,161,159,127,124,79,77,1,1,
77,79,124,127,159,161,123,126,73,254,96,146,208,54,53,79,78,253,
180,54,53,79,78,90,9,95,81,78,55,4,173,38,56,21,21,33,
10,9,39,56,22,21,33,16,1,38,56,42,33,10,9,39,56,22,
21,33,8,0,0,0,0,3,0,100,255,227,4,143,6,243,0,63,
0,81,0,98,0,0,19,55,22,23,22,51,50,55,54,55,54,55,
54,55,33,53,33,38,39,38,39,38,39,38,43,1,34,7,6,7,
39,54,55,54,55,54,55,54,55,54,51,50,23,30,1,23,22,23,
22,21,20,14,1,7,14,1,35,34,39,38,39,38,39,38,1,52,
54,51,50,23,22,23,22,21,20,6,35,34,39,38,39,38,37,52,
54,51,50,22,23,22,21,20,6,35,34,39,38,39,38,100,147,32,
91,90,107,99,83,84,53,56,29,21,6,253,169,2,88,6,20,29,
52,53,83,84,105,2,106,83,85,28,149,13,27,26,37,39,49,49,
68,71,72,120,99,100,140,48,51,21,23,46,94,71,68,204,117,95,
80,83,53,58,36,38,2,85,56,38,33,26,25,8,2,56,38,32,
27,26,7,2,254,41,56,38,34,50,8,2,56,38,32,27,25,8,
2,1,37,41,92,66,65,51,52,84,89,107,75,79,142,89,76,111,
90,91,53,54,55,56,90,41,36,46,43,39,40,30,30,18,19,43,
43,146,99,104,106,113,116,115,224,188,74,71,82,27,28,46,50,52,
55,5,176,38,56,21,21,33,10,9,39,56,22,21,33,16,1,38,
56,42,33,10,9,39,56,22,21,33,8,0,0,0,0,3,0,101,
255,227,3,133,5,173,0,52,0,70,0,87,0,0,19,39,54,55,
54,51,50,23,22,23,22,23,22,23,22,21,20,7,6,7,6,35,
34,39,38,39,38,39,38,39,55,22,23,22,23,22,23,22,51,50,
55,54,55,33,53,33,38,39,38,35,34,7,6,1,52,54,51,50,
23,22,23,22,21,20,6,35,34,39,38,39,38,37,52,54,51,50,
22,23,22,21,20,6,35,34,39,38,39,38,232,131,53,86,85,115,
84,74,72,56,54,41,40,20,20,59,58,106,104,132,61,53,55,41,
50,25,32,24,122,11,16,18,25,24,43,39,43,130,88,71,14,254,
127,1,128,15,71,90,128,69,61,60,1,79,56,38,33,26,25,8,
2,56,38,32,27,26,7,2,254,41,56,38,34,50,8,2,56,38,
32,27,25,8,2,3,41,66,96,62,61,30,29,55,52,72,70,82,
83,84,155,130,128,77,76,19,20,32,39,29,37,40,77,21,24,26,
25,24,20,18,118,95,149,142,135,93,120,50,50,1,245,38,56,21,
21,33,10,9,39,56,22,21,33,16,1,38,56,42,33,10,9,39,
56,22,21,33,8,0,0,0,0,2,0,26,0,0,4,221,6,184,
0,3,0,35,0,0,1,33,21,33,7,51,9,1,51,1,6,7,
6,7,6,7,6,7,6,7,35,34,39,38,39,38,39,55,31,4,
50,55,1,1,120,2,165,253,91,178,168,1,100,1,100,167,252,247,
12,6,12,10,38,37,41,32,24,43,11,44,36,35,17,8,36,107,
15,16,18,22,27,51,22,1,82,6,184,106,158,253,168,2,88,250,
222,19,7,15,9,35,19,21,9,6,2,15,15,12,6,34,102,14,
12,12,8,3,24,2,77,0,0,0,0,2,0,74,254,129,3,199,
5,41,0,3,0,35,0,0,19,33,21,33,7,51,9,1,51,1,
6,7,6,7,6,7,6,7,6,7,35,34,39,38,39,38,39,55,
31,4,50,63,1,188,2,165,253,91,106,160,1,24,1,31,158,254,
61,1,17,14,8,33,42,41,32,28,39,11,44,36,32,20,12,32,
107,15,16,18,22,27,51,22,94,5,41,106,142,252,146,3,110,250,
222,4,22,18,7,30,22,21,9,7,2,15,13,15,9,30,102,13,
14,11,8,3,24,224,0,0,255,255,0,26,0,0,4,221,6,243,
16,39,0,106,1,61,0,0,16,6,2,107,0,0,255,255,0,74,
254,129,3,199,5,172,16,39,0,106,0,117,254,185,16,6,2,139,
0,0,255,255,0,26,0,0,4,221,7,150,16,38,1,179,0,0,
16,6,2,107,0,0,0,0,255,255,0,74,254,129,3,245,6,61,
16,39,1,179,255,133,254,167,16,6,2,139,0,0,255,255,0,98,
0,0,3,158,6,243,16,38,0,106,104,0,16,6,2,111,0,0,
0,0,255,255,0,129,0,0,3,188,5,172,16,39,0,106,0,139,
254,185,16,6,2,143,0,0,255,255,0,92,0,0,3,238,5,176,
16,6,2,91,0,0,255,255,0,94,0,0,2,222,4,50,16,6,
2,123,0,0,255,255,0,121,0,0,4,75,6,243,16,39,0,106,
0,204,0,0,16,6,2,115,0,0,0,5,0,51,0,0,4,107,
5,173,0,3,0,25,0,42,0,60,0,77,0,0,1,51,17,35,
5,17,51,17,51,50,23,22,23,22,23,22,23,48,21,20,7,6,
7,6,43,1,25,1,51,50,55,54,55,54,55,54,55,54,53,52,
39,38,33,1,52,54,51,50,23,22,23,22,21,20,6,35,34,39,
38,39,38,37,52,54,51,50,22,23,22,21,20,6,35,34,39,38,
39,38,3,212,151,151,252,95,158,140,139,106,108,64,34,51,43,2,
8,31,139,137,232,140,140,103,68,71,43,39,24,22,9,7,1,54,
254,181,1,102,56,38,33,26,25,8,2,56,38,32,27,26,7,2,
254,41,56,38,34,50,8,2,56,38,32,27,25,8,2,4,50,251,
207,1,4,50,254,170,33,33,44,24,76,63,50,9,38,38,147,89,
88,2,77,254,64,17,18,32,29,37,33,42,31,18,8,3,180,3,
2,38,56,21,21,33,10,9,39,56,22,21,33,16,1,38,56,42,
33,10,9,39,56,22,21,33,8,0,0,0,255,255,0,121,0,0,
4,61,6,241,16,39,1,175,1,101,0,0,16,6,0,37,0,0,
255,255,0,129,255,227,3,207,6,241,16,39,1,175,1,101,0,0,
16,6,0,69,0,0,255,255,0,121,0,0,4,129,6,241,16,39,
1,175,1,119,0,0,16,6,0,39,0,0,255,255,0,73,255,227,
3,151,6,241,16,39,1,175,1,184,0,0,16,6,0,71,0,0,
0,3,0,131,254,161,4,140,5,178,0,15,0,33,0,56,0,0,
1,52,38,39,38,39,38,35,33,17,33,50,62,1,55,54,55,20,
7,6,7,6,7,6,35,33,17,33,50,22,23,22,23,22,1,52,
55,54,51,50,23,22,23,22,21,20,6,21,20,7,6,35,34,39,
38,39,38,3,230,64,60,58,81,80,99,254,245,1,11,97,160,120,
33,32,166,45,45,81,80,112,109,136,254,87,1,169,121,222,83,83,
50,49,253,14,62,27,18,69,29,5,1,3,1,61,27,18,70,29,
4,2,2,2,216,134,210,80,78,43,43,251,105,86,156,108,105,132,
154,133,133,98,97,57,56,5,178,100,92,91,138,134,251,133,69,29,
9,62,12,10,6,8,1,6,2,70,28,9,62,12,11,14,0,0,
0,3,0,129,254,161,3,167,5,176,0,25,0,56,0,79,0,0,
1,51,17,35,53,6,7,6,43,1,34,39,46,2,53,52,55,54,
55,54,55,54,51,50,23,1,20,23,22,23,22,23,22,51,50,55,
54,55,62,1,53,52,39,38,39,38,39,38,35,34,7,6,7,6,
7,6,19,52,55,54,51,50,23,22,23,22,21,20,6,21,20,7,
6,35,34,39,38,39,38,3,15,152,152,73,62,63,79,4,76,67,
68,102,60,25,23,50,49,68,69,91,171,108,254,12,17,19,28,30,
40,41,46,60,49,51,39,40,44,20,20,39,37,53,50,64,48,39,
40,30,28,19,17,127,62,27,18,69,29,5,1,3,1,61,27,18,
70,29,4,2,2,5,176,250,80,164,110,41,42,36,36,144,210,142,
115,106,99,76,74,42,42,197,254,155,103,75,84,53,58,29,30,33,
34,59,60,152,92,90,73,74,59,56,35,33,29,30,55,51,82,72,
252,142,69,29,9,62,12,10,6,8,1,6,2,70,28,9,62,12,
11,14,255,255,0,121,255,40,4,129,5,176,16,38,1,173,0,0,
16,6,0,39,0,0,0,0,255,255,0,73,255,40,3,151,5,174,
16,38,1,173,0,0,16,6,0,71,0,0,0,0,255,255,0,121,
0,0,4,18,6,241,16,39,1,175,1,170,0,0,16,6,0,41,
0,0,255,255,0,125,0,0,2,211,6,241,16,39,1,175,1,13,
0,0,16,6,0,73,0,0,0,2,0,131,254,161,4,85,5,178,
0,11,0,33,0,0,19,51,17,33,17,51,17,35,17,33,17,35,
5,52,55,54,51,50,23,22,23,22,21,48,21,20,7,6,35,34,
39,38,39,38,131,158,2,150,158,158,253,106,158,1,117,62,27,18,
69,29,5,1,3,62,27,18,70,29,4,2,2,5,178,253,126,2,
130,250,78,2,162,253,94,244,69,29,9,62,12,10,7,10,6,69,
29,9,62,12,11,14,0,0,0,2,0,139,254,161,3,159,5,176,
0,27,0,50,0,0,33,35,17,51,17,54,55,54,55,62,1,51,
50,22,21,17,35,17,16,35,34,7,6,7,6,7,6,21,19,52,
55,54,51,50,23,22,23,22,21,20,6,21,20,7,6,35,34,39,
38,39,38,1,35,152,152,45,36,35,34,35,58,42,163,188,152,199,
53,51,50,42,40,24,25,135,62,27,18,69,29,6,1,3,1,62,
27,18,69,29,6,1,2,5,176,253,234,56,34,33,19,19,14,218,
221,253,110,2,146,1,45,24,24,43,41,55,56,56,252,120,69,29,
9,62,17,5,6,8,1,6,2,69,29,9,62,16,7,14,255,255,
0,121,254,116,4,74,5,176,16,38,1,197,206,0,16,6,0,43,
0,0,0,0,255,255,0,129,254,116,3,188,5,176,16,38,1,197,
132,0,16,6,0,75,0,0,0,0,0,2,0,131,254,239,4,222,
5,178,0,3,0,15,0,0,5,33,21,33,3,51,17,1,51,9,
1,35,1,7,17,35,1,8,2,93,253,163,133,158,2,195,193,253,
67,2,246,207,253,116,98,158,137,136,6,195,253,58,2,198,253,68,
253,10,2,142,103,253,217,0,0,0,0,2,0,139,254,239,3,183,
5,176,0,3,0,15,0,0,23,33,21,33,9,1,35,1,7,17,
35,17,51,17,1,51,176,2,93,253,163,1,7,2,0,174,254,71,
45,152,152,1,146,174,137,136,3,104,253,169,1,244,53,254,65,5,
176,252,206,1,180,0,0,2,0,131,254,161,4,32,5,178,0,5,
0,28,0,0,19,51,17,33,21,33,5,52,55,54,51,50,23,22,
23,22,21,20,6,21,20,7,6,35,34,39,38,39,38,131,158,2,
255,252,99,1,54,61,27,18,70,29,5,1,3,1,62,27,18,69,
29,4,2,2,5,178,250,219,141,244,70,28,9,62,12,10,6,8,
1,6,2,69,29,9,62,12,11,14,0,0,0,2,0,160,254,161,
1,174,5,176,0,9,0,32,0,0,37,20,51,21,34,39,38,53,
17,51,3,52,55,54,51,50,23,22,23,22,21,20,6,21,20,7,
6,35,34,39,38,39,38,1,56,118,137,67,66,152,132,62,27,18,
69,29,6,1,3,1,62,27,18,69,29,6,1,2,207,105,131,58,
57,117,4,229,249,92,69,29,9,62,17,5,6,8,1,6,2,69,
29,9,62,16,7,14,0,0,0,3,255,154,254,161,4,32,6,182,
0,3,0,9,0,32,0,0,3,33,21,33,23,51,17,33,21,33,
5,52,55,54,51,50,23,22,23,22,21,20,6,21,20,7,6,35,
34,39,38,39,38,102,2,92,253,164,233,158,2,255,252,99,1,54,
61,27,18,70,29,5,1,3,1,62,27,18,69,29,4,2,2,6,
182,135,125,250,219,141,244,70,28,9,62,12,10,6,8,1,6,2,
69,29,9,62,12,11,14,0,0,3,255,190,254,161,2,27,6,184,
0,3,0,13,0,36,0,0,3,33,21,33,1,20,51,21,34,39,
38,53,17,51,3,52,55,54,51,50,23,22,23,22,21,20,6,21,
20,7,6,35,34,39,38,39,38,66,2,93,253,163,1,122,118,137,
67,66,152,132,62,27,18,69,29,6,1,3,1,62,27,18,69,29,
6,1,2,6,184,135,250,158,105,131,58,57,117,4,229,249,92,69,
29,9,62,17,5,6,8,1,6,2,69,29,9,62,16,7,14,0,
0,0,0,2,0,131,254,239,4,32,5,178,0,3,0,9,0,0,
23,33,21,33,3,51,17,33,21,33,248,2,93,253,163,117,158,2,
255,252,99,137,136,6,195,250,219,141,0,2,0,113,254,237,1,199,
5,176,0,9,0,13,0,0,37,20,51,21,34,39,38,53,17,51,
3,33,21,33,1,56,118,137,67,66,152,199,1,86,254,170,207,105,
131,58,57,117,4,229,249,197,136,0,0,0,255,255,0,121,0,0,
5,182,6,241,16,39,1,175,2,104,0,0,16,6,0,48,0,0,
255,255,0,129,0,0,5,147,5,170,16,39,1,175,2,95,254,185,
16,6,0,80,0,0,0,2,0,131,254,161,5,194,5,178,0,12,
0,35,0,0,51,17,51,9,1,51,17,35,17,1,35,1,17,5,
52,55,54,51,50,23,22,23,22,21,20,6,21,20,7,6,35,34,
39,38,39,38,131,215,1,204,1,205,207,154,254,84,179,254,84,1,
158,62,27,18,69,29,5,1,3,1,61,27,18,70,29,4,2,2,
5,178,251,31,4,225,250,78,4,181,251,91,4,165,251,75,244,69,
29,9,62,12,10,6,8,1,6,2,70,28,9,62,12,11,14,0,
0,2,0,139,254,161,5,159,4,73,0,43,0,66,0,0,33,35,
17,52,39,38,35,34,7,6,7,14,1,21,17,35,17,51,21,62,
1,51,50,23,62,1,51,50,23,22,21,17,35,17,52,38,35,34,
7,6,7,14,1,21,3,52,55,54,51,50,23,22,23,22,21,20,
6,21,20,7,6,35,34,39,38,39,38,3,97,152,42,42,75,52,
45,47,37,36,46,152,152,63,122,78,203,73,72,142,84,164,74,73,
152,86,73,52,45,47,37,36,46,180,61,27,18,70,29,5,1,3,
1,62,27,18,69,29,4,2,2,2,146,148,77,76,23,24,40,39,
110,63,253,108,4,50,152,99,76,205,111,94,109,107,227,253,114,2,
142,153,152,23,24,40,39,110,63,252,120,70,28,9,62,12,10,6,
8,1,6,2,69,29,9,62,12,11,14,0,0,2,0,131,0,0,
4,159,6,225,0,19,0,29,0,0,1,52,55,54,51,50,23,22,
23,22,21,20,7,6,35,34,39,38,39,38,1,17,51,1,17,51,
17,35,1,17,2,50,57,18,19,62,24,4,2,2,57,20,17,62,
24,5,1,2,254,81,154,2,228,158,146,253,20,6,131,62,24,8,
55,10,11,10,8,62,24,9,56,11,9,10,249,134,5,178,251,117,
4,139,250,78,4,167,251,89,0,2,0,139,0,0,3,159,5,98,
0,19,0,48,0,0,1,52,55,54,51,50,23,22,23,22,21,20,
7,6,35,34,39,38,39,38,3,35,17,51,21,54,51,50,31,1,
22,23,22,23,17,35,17,52,39,38,39,34,7,6,7,6,7,6,
21,1,183,57,20,17,62,24,5,1,2,57,18,19,62,24,5,1,
2,148,152,152,125,168,230,80,18,10,2,2,1,152,55,55,81,50,
53,50,45,40,28,27,5,3,62,24,9,56,11,9,10,9,62,24,
8,55,10,11,10,251,5,4,50,162,185,228,65,34,37,36,39,253,
110,2,146,146,74,75,6,24,23,43,38,57,54,60,0,0,0,2,
0,131,254,161,4,159,5,178,0,9,0,32,0,0,51,17,51,1,
17,51,17,35,1,17,23,52,55,54,51,50,23,22,23,22,21,20,
6,21,20,7,6,35,34,39,38,39,38,131,154,2,228,158,146,253,
20,254,62,27,18,69,29,5,1,3,1,61,27,18,70,29,4,2,
2,5,178,251,117,4,139,250,78,4,167,251,89,244,69,29,9,62,
12,10,6,8,1,6,2,70,28,9,62,12,11,14,0,0,0,2,
0,139,254,161,3,159,4,73,0,28,0,50,0,0,33,35,17,51,
21,54,51,50,31,1,22,23,22,23,17,35,17,52,39,38,39,34,
7,6,7,6,7,6,21,19,52,55,54,51,50,23,22,23,22,21,
48,21,20,7,6,35,34,39,38,39,38,1,35,152,152,125,168,230,
80,18,10,2,2,1,152,55,55,81,50,53,50,45,40,28,27,131,
62,27,18,69,29,5,1,3,62,27,18,70,29,4,2,2,4,50,
162,185,228,65,34,37,36,39,253,110,2,146,146,74,75,6,24,23,
43,38,57,54,60,252,120,69,29,9,62,12,10,7,10,6,69,29,
9,62,12,11,14,0,0,2,0,131,254,239,4,159,5,178,0,3,
0,13,0,0,5,33,21,33,3,17,51,1,17,51,17,35,1,17,
1,111,2,93,253,163,236,154,2,228,158,146,253,20,137,136,1,17,
5,178,251,117,4,139,250,78,4,167,251,89,0,2,0,139,254,239,
3,159,4,73,0,3,0,32,0,0,23,33,21,33,19,35,17,51,
21,54,51,50,31,1,22,23,22,23,17,35,17,52,39,38,39,34,
7,6,7,6,7,6,21,248,2,93,253,163,43,152,152,125,168,230,
80,18,10,2,2,1,152,55,55,81,50,53,50,45,40,28,27,137,
136,1,17,4,50,162,185,228,65,34,37,36,39,253,110,2,146,146,
74,75,6,24,23,43,38,57,54,60,0,0,255,255,0,121,0,0,
4,8,6,241,16,39,1,175,1,107,0,0,16,6,0,51,0,0,
255,255,0,129,254,84,3,207,5,173,16,39,1,175,1,116,254,188,
16,6,0,83,0,0,0,3,0,131,254,161,4,91,5,178,0,8,
0,28,0,50,0,0,1,51,32,17,52,39,38,43,1,9,1,35,
17,35,17,33,50,23,22,23,22,23,22,21,20,7,6,7,1,5,
52,55,54,51,50,23,22,23,22,21,48,21,20,7,6,35,34,39,
38,39,38,1,33,207,1,130,98,99,189,207,2,132,254,83,215,158,
1,109,118,101,103,72,74,40,42,97,96,172,1,178,253,118,62,27,
18,69,29,5,1,3,62,27,18,69,29,6,1,2,3,7,1,17,
135,66,67,250,220,2,119,253,137,5,178,27,28,51,53,75,79,97,
148,109,108,33,253,118,244,69,29,9,62,12,10,7,10,6,69,29,
9,62,16,7,14,0,0,0,0,2,0,113,254,161,2,224,4,77,
0,25,0,48,0,0,1,38,35,34,7,6,7,6,7,6,21,17,
35,17,51,21,54,55,54,55,54,55,54,51,50,23,1,52,55,54,
51,50,23,22,23,22,21,20,6,21,20,7,6,35,34,39,38,39,
38,2,158,68,71,47,43,43,33,31,22,21,152,152,18,25,30,30,
34,33,37,33,116,89,253,145,61,27,18,70,29,5,1,3,1,62,
27,18,69,29,4,2,2,3,154,42,24,24,42,40,60,58,72,253,
124,4,50,152,38,29,35,22,25,14,16,55,250,246,70,28,9,62,
12,10,6,8,1,6,2,69,29,9,62,12,11,14,0,0,0,4,
0,131,254,161,4,91,6,182,0,3,0,12,0,32,0,54,0,0,
19,33,21,33,19,51,32,17,52,39,38,43,1,9,1,35,17,35,
17,33,50,23,22,23,22,23,22,21,20,7,6,7,1,5,52,55,
54,51,50,23,22,23,22,21,48,21,20,7,6,35,34,39,38,39,
38,248,2,93,253,163,41,207,1,130,98,99,189,207,2,132,254,83,
215,158,1,109,118,101,103,72,74,40,42,97,96,172,1,178,253,118,
62,27,18,69,29,5,1,3,62,27,18,69,29,6,1,2,6,182,
135,252,216,1,17,135,66,67,250,220,2,119,253,137,5,178,27,28,
51,53,75,79,97,148,109,108,33,253,118,244,69,29,9,62,12,10,
7,10,6,69,29,9,62,16,7,14,0,0,0,3,0,82,254,161,
2,224,5,55,0,3,0,29,0,52,0,0,19,33,21,33,1,38,
35,34,7,6,7,6,7,6,21,17,35,17,51,21,54,55,54,55,
54,55,54,51,50,23,1,52,55,54,51,50,23,22,23,22,21,20,
6,21,20,7,6,35,34,39,38,39,38,82,2,93,253,163,2,76,
68,71,47,43,43,33,31,22,21,152,152,18,25,30,30,34,33,37,
33,116,89,253,145,61,27,18,70,29,5,1,3,1,62,27,18,69,
29,4,2,2,5,55,136,254,235,42,24,24,42,40,60,58,72,253,
124,4,50,152,38,29,35,22,25,14,16,55,250,246,70,28,9,62,
12,10,6,8,1,6,2,69,29,9,62,12,11,14,0,3,0,131,
254,239,4,91,5,178,0,3,0,12,0,32,0,0,23,33,21,33,
19,51,32,17,52,39,38,43,1,9,1,35,17,35,17,33,50,23,
22,23,22,23,22,21,20,7,6,7,1,248,2,93,253,163,41,207,
1,130,98,99,189,207,2,132,254,83,215,158,1,109,118,101,103,72,
74,40,42,97,96,172,1,178,137,136,4,24,1,17,135,66,67,250,
220,2,119,253,137,5,178,27,28,51,53,75,79,97,148,109,108,33,
253,118,0,0,0,2,0,29,254,237,2,224,4,77,0,25,0,29,
0,0,1,38,35,34,7,6,7,6,7,6,21,17,35,17,51,21,
54,55,54,55,54,55,54,51,50,23,1,33,21,33,2,158,68,71,
47,43,43,33,31,22,21,152,152,18,25,30,30,34,33,37,33,116,
89,253,61,1,131,254,125,3,154,42,24,24,42,40,60,58,72,253,
124,4,50,152,38,29,35,22,25,14,16,55,251,95,136,0,0,0,
255,255,0,45,255,227,4,10,6,241,16,39,1,175,1,155,0,0,
16,6,0,54,0,0,255,255,0,96,255,227,3,72,5,173,16,39,
1,175,1,51,254,188,16,6,0,86,0,0,0,2,0,76,254,161,
4,62,5,216,0,63,0,86,0,0,19,55,22,23,22,51,50,55,
62,1,55,54,53,52,39,38,47,1,36,17,52,55,54,55,54,55,
54,51,32,31,1,7,38,39,38,35,34,7,6,7,14,1,21,20,
31,1,22,23,22,23,22,23,22,21,20,7,6,7,6,7,6,7,
38,36,1,52,55,54,51,50,23,22,23,22,21,20,6,21,20,7,
6,35,34,39,38,39,38,76,135,90,90,89,110,70,60,61,90,27,
27,94,90,181,23,254,110,35,34,62,63,82,83,96,1,10,157,37,
125,50,87,86,112,60,54,52,42,39,46,207,144,134,78,88,47,50,
21,20,37,38,66,65,92,92,106,158,254,250,1,72,62,27,18,69,
29,5,1,3,1,61,27,18,70,29,4,2,2,1,31,80,141,58,
57,22,22,82,53,54,66,97,74,71,55,6,108,1,20,82,75,73,
54,55,30,30,194,52,79,87,49,48,18,17,36,33,96,58,139,83,
51,52,37,42,44,47,58,56,90,89,77,79,57,56,35,35,1,2,
156,254,141,69,29,9,62,12,10,6,8,1,6,2,70,28,9,62,
12,11,14,0,0,0,0,2,0,107,254,161,3,83,4,75,0,68,
0,91,0,0,1,38,39,38,39,38,39,38,53,52,55,54,55,54,
55,54,55,51,50,23,22,23,22,23,22,23,7,38,35,34,7,6,
7,6,7,6,21,20,31,1,22,23,22,23,22,23,22,21,20,7,
6,7,14,1,35,32,39,55,22,51,50,55,54,55,54,55,54,53,
52,1,52,55,54,51,50,23,22,23,22,21,20,6,21,20,7,6,
35,34,39,38,39,38,1,224,107,62,70,37,39,17,17,25,23,47,
44,65,69,76,6,58,62,58,48,50,30,32,10,141,40,171,37,36,
40,24,29,15,16,154,43,100,75,68,46,42,19,19,28,26,51,50,
132,80,254,204,69,141,33,199,46,36,39,30,31,18,17,254,184,61,
27,19,69,29,5,1,3,1,61,27,18,70,29,4,2,2,1,236,
35,32,36,35,36,44,43,47,58,56,52,42,40,24,26,1,16,15,
30,31,40,42,54,28,121,12,13,19,22,28,29,35,103,51,14,37,
40,36,43,39,47,48,51,63,62,58,45,44,54,246,27,137,14,15,
24,25,34,33,45,123,253,104,70,28,9,62,12,10,6,8,1,6,
2,70,28,9,62,12,11,14,255,255,0,88,0,0,4,156,6,241,
16,39,1,175,1,216,0,0,16,6,0,55,0,0,255,255,0,102,
255,227,2,80,6,241,16,39,1,175,0,148,0,0,16,6,0,87,
0,0,0,2,0,98,254,161,4,167,5,178,0,7,0,29,0,0,
19,33,21,33,17,35,17,33,1,52,55,54,51,50,23,22,23,22,
21,48,21,20,7,6,35,34,39,38,39,38,98,4,69,254,55,158,
254,34,1,193,62,27,18,69,29,5,1,3,62,27,18,69,29,6,
1,2,5,178,142,250,220,5,36,249,232,69,29,9,62,12,10,7,
10,6,69,29,9,62,16,7,14,0,0,0,0,2,0,113,254,161,
2,91,5,44,0,18,0,41,0,0,19,35,53,51,53,51,21,51,
21,35,17,20,59,1,21,35,34,38,53,19,52,55,54,51,50,23,
22,23,22,21,20,6,21,20,7,6,35,34,39,38,39,38,254,141,
141,152,197,197,117,69,69,151,118,23,61,27,18,70,29,5,1,3,
1,62,27,18,69,29,4,2,2,3,171,135,250,250,135,253,44,117,
127,122,118,254,57,70,28,9,62,12,10,6,8,1,6,2,69,29,
9,62,12,11,14,0,0,2,0,98,254,239,4,167,5,178,0,3,
0,11,0,0,5,33,21,33,3,33,21,33,17,35,17,33,1,97,
2,92,253,164,255,4,69,254,55,158,254,34,137,136,6,195,142,250,
220,5,36,0,0,2,0,113,254,237,2,91,5,44,0,18,0,22,
0,0,19,35,53,51,53,51,21,51,21,35,17,20,59,1,21,35,
34,38,53,3,33,21,33,254,141,141,152,197,197,117,69,69,151,118,
141,1,234,254,22,3,171,135,250,250,135,253,44,117,127,122,118,254,
162,136,0,0,255,255,0,84,0,0,5,236,7,152,16,39,0,67,
1,140,0,0,16,6,0,58,0,0,255,255,0,68,0,0,5,49,
6,61,16,39,0,67,1,38,254,165,16,6,0,90,0,0,255,255,
0,84,0,0,5,236,7,152,16,39,0,118,2,128,0,0,16,6,
0,58,0,0,255,255,0,68,0,0,5,49,6,61,16,39,0,118,
2,44,254,165,16,6,0,90,0,0,255,255,0,84,0,0,5,236,
6,243,16,39,0,106,1,144,0,0,16,6,0,58,0,0,255,255,
0,68,0,0,5,49,5,169,16,39,0,106,1,36,254,182,16,6,
0,90,0,0,0,2,0,86,0,0,4,112,6,225,0,17,0,26,
0,0,1,52,55,54,51,50,31,1,22,21,20,7,6,35,34,47,
1,38,5,51,9,1,51,1,17,35,17,2,5,57,16,21,62,24,
6,2,57,18,19,62,24,6,2,254,81,168,1,101,1,101,168,254,
65,158,6,131,62,24,8,55,21,8,10,62,24,9,56,20,8,198,
253,167,2,89,253,58,253,20,2,236,0,2,0,129,254,63,3,148,
5,98,0,17,0,68,0,0,1,52,55,54,51,50,31,1,22,21,
20,7,6,35,34,47,1,38,3,55,22,23,22,51,50,55,54,61,
1,6,7,6,35,34,39,38,39,38,39,38,53,17,51,17,20,23,
22,51,50,55,54,55,54,55,54,53,17,51,17,20,7,6,7,6,
7,6,35,34,39,1,162,58,18,18,63,24,6,2,58,16,21,62,
24,6,2,250,105,62,50,54,71,111,72,72,37,68,69,79,71,70,
69,54,52,34,33,152,62,63,111,50,44,43,36,32,22,21,151,29,
30,54,52,78,74,89,184,131,5,3,62,24,9,56,20,8,11,62,
24,8,55,21,8,249,244,84,71,25,27,74,74,133,179,72,48,49,
32,31,59,56,86,82,105,2,134,253,122,149,81,83,22,21,43,38,
59,57,65,2,142,251,188,94,75,77,59,56,36,34,141,0,0,2,
0,139,254,239,3,159,5,176,0,3,0,31,0,0,23,33,21,33,
19,35,17,51,17,54,55,54,55,62,1,51,50,22,21,17,35,17,
16,35,34,7,6,7,6,7,6,21,234,2,92,253,164,57,152,152,
45,36,35,34,35,58,42,163,188,152,199,53,51,50,42,40,24,25,
137,136,1,17,5,176,253,234,56,34,33,19,19,14,218,221,253,110,
2,146,1,45,24,24,43,41,55,56,56,0,0,1,0,131,0,0,
4,220,5,178,0,43,0,0,1,33,1,22,23,22,23,22,23,22,
21,20,14,1,7,6,7,53,50,55,54,55,54,55,54,53,52,39,
38,47,1,1,33,34,2,21,17,35,17,52,55,62,2,2,142,2,
78,254,106,109,64,88,48,50,21,20,76,130,92,92,106,66,63,62,
45,45,27,26,94,82,139,144,1,111,254,182,171,190,162,37,38,136,
194,5,178,253,148,42,31,40,45,47,58,56,91,87,158,112,35,34,
2,141,23,23,40,41,53,52,68,98,72,65,46,43,2,39,254,232,
255,252,243,3,13,169,126,128,166,88,0,0,255,255,0,76,0,0,
4,100,7,152,16,39,0,67,0,184,0,0,16,6,0,60,0,0,
255,255,0,120,254,63,3,179,6,60,16,39,0,67,0,92,254,164,
16,6,0,92,0,0,0,2,0,126,0,0,5,39,5,176,0,5,
0,19,0,0,1,17,33,53,33,17,1,20,23,22,51,21,34,39,
38,39,38,53,17,51,1,140,3,155,253,3,254,235,3,16,100,113,
65,69,16,7,151,5,176,250,80,141,5,35,251,60,16,14,75,131,
37,40,86,35,34,4,200,0,0,0,0,3,0,0,255,227,3,64,
5,174,0,3,0,16,0,29,0,0,17,33,21,33,1,20,23,22,
51,21,34,38,39,38,53,17,51,1,20,23,22,51,21,34,38,39,
38,53,17,51,3,64,252,192,2,161,3,16,100,113,130,20,7,151,
254,116,3,16,100,113,130,20,7,151,4,23,106,253,34,17,13,75,
131,74,89,35,34,4,227,251,33,17,13,75,131,74,89,35,34,4,
227,0,255,255,0,90,255,227,4,119,6,60,16,39,4,6,1,108,
255,73,16,6,1,249,0,0,255,255,0,90,255,227,4,119,6,61,
16,39,4,64,1,84,255,74,16,6,1,249,0,0,255,255,0,90,
255,227,4,119,6,60,16,39,4,6,0,176,255,73,16,39,0,67,
1,203,254,163,16,6,1,249,0,0,255,255,0,90,255,227,4,119,
6,60,16,39,4,64,0,144,255,73,16,39,0,67,1,228,254,163,
16,6,1,249,0,0,255,255,0,90,255,227,4,119,6,61,16,39,
4,6,0,155,255,73,16,39,0,118,1,220,254,165,16,6,1,249,
0,0,255,255,0,90,255,227,4,119,6,60,16,39,4,64,0,189,
255,73,16,39,0,118,1,229,254,164,16,6,1,249,0,0,255,255,
0,90,255,227,4,119,6,242,16,39,1,178,0,181,3,150,16,39,
4,6,0,213,255,41,16,6,1,249,0,0,255,255,0,90,255,227,
4,119,6,242,16,39,1,178,0,180,3,150,16,39,4,64,0,203,
255,47,16,6,1,249,0,0,255,255,0,72,0,0,4,223,6,243,
16,39,4,6,0,162,0,0,16,6,1,218,0,0,255,255,0,72,
0,0,4,223,6,243,16,39,4,64,0,151,0,0,16,6,1,218,
0,0,255,255,0,20,0,0,5,91,6,244,16,38,4,6,176,0,
16,39,0,67,0,204,255,92,16,6,1,218,124,0,0,0,255,255,
0,196,0,0,5,91,6,248,16,39,0,67,0,212,255,96,16,6,
1,218,124,0,255,255,0,19,0,0,5,91,6,244,16,38,4,6,
175,0,16,39,0,118,0,250,255,92,16,6,1,218,124,0,0,0,
255,255,0,196,0,0,5,91,6,244,16,39,0,118,0,234,255,92,
16,6,1,218,124,0,255,255,0,19,0,0,5,91,6,244,16,39,
1,178,0,216,3,152,16,38,4,6,175,0,16,6,1,218,124,0,
0,0,255,255,0,19,0,0,5,91,6,244,16,39,1,178,0,224,
3,152,16,38,4,6,175,0,16,6,1,218,124,0,0,0,255,255,
0,138,255,227,3,107,6,61,16,39,4,6,1,73,255,74,16,6,
1,253,0,0,255,255,0,138,255,227,3,107,6,59,16,39,4,64,
1,60,255,72,16,6,1,253,0,0,255,255,0,138,255,227,3,107,
6,61,16,39,4,6,0,40,255,73,16,39,0,67,1,110,254,165,
16,6,1,253,0,0,255,255,0,138,255,227,3,177,6,61,16,39,
4,64,0,150,255,74,16,39,0,67,1,209,254,165,16,6,1,253,
0,0,255,255,0,138,255,227,3,107,6,60,16,39,4,6,0,72,
255,73,16,39,0,118,1,116,254,163,16,6,1,253,0,0,255,255,
0,138,255,227,3,131,6,61,16,39,4,64,0,117,255,73,16,39,
0,118,1,163,254,165,16,6,1,253,0,0,255,255,0,19,0,0,
4,150,6,243,16,38,4,6,175,0,16,7,1,222,0,132,0,0,
255,255,0,19,0,0,4,147,6,243,16,38,4,64,175,0,16,7,
1,222,0,129,0,0,255,255,0,19,0,0,6,126,6,244,16,38,
4,6,175,0,16,39,0,67,0,224,255,92,16,7,1,222,2,108,
0,0,255,255,0,19,0,0,6,114,6,244,16,38,4,64,175,0,
16,39,0,67,0,204,255,92,16,7,1,222,2,96,0,0,255,255,
0,19,0,0,5,138,6,244,16,38,4,6,175,0,16,39,0,118,
0,222,255,92,16,7,1,222,1,120,0,0,255,255,0,19,0,0,
5,206,6,244,16,38,4,64,175,0,16,39,0,118,0,218,255,92,
16,7,1,222,1,188,0,0,255,255,0,118,254,116,3,177,6,54,
16,39,4,6,1,113,255,67,16,6,1,255,0,0,255,255,0,118,
254,116,3,177,6,60,16,39,4,64,1,89,255,73,16,6,1,255,
0,0,255,255,0,118,254,116,3,177,6,60,16,39,4,6,0,108,
255,72,16,39,0,67,1,140,254,164,16,6,1,255,0,0,255,255,
0,118,254,116,3,177,6,59,16,39,4,64,0,136,255,72,16,39,
0,67,1,161,254,163,16,6,1,255,0,0,255,255,0,118,254,116,
3,177,6,59,16,39,4,6,0,124,255,72,16,39,0,118,1,155,
254,163,16,6,1,255,0,0,255,255,0,118,254,116,3,177,6,59,
16,39,4,64,0,136,255,72,16,39,0,118,1,185,254,162,16,6,
1,255,0,0,255,255,0,118,254,116,3,177,6,244,16,39,1,178,
0,156,3,152,16,39,4,6,0,196,255,31,16,6,1,255,0,0,
255,255,0,118,254,116,3,177,6,242,16,39,1,178,0,126,3,150,
16,39,4,64,0,162,255,37,16,6,1,255,0,0,255,255,0,19,
0,0,4,206,6,243,16,38,4,6,175,0,16,7,1,224,0,132,
0,0,255,255,0,19,0,0,4,206,6,243,16,38,4,64,175,0,
16,7,1,224,0,132,0,0,255,255,0,19,0,0,6,182,6,244,
16,38,4,6,175,0,16,39,0,67,0,213,255,92,16,7,1,224,
2,108,0,0,255,255,0,19,0,4,6,162,6,244,16,38,4,64,
175,0,16,39,0,67,0,207,255,92,16,7,1,224,2,88,0,4,
255,255,0,19,0,0,5,223,6,243,16,38,4,6,175,0,16,39,
0,118,0,209,255,91,16,7,1,224,1,149,0,0,255,255,0,19,
0,0,6,26,6,244,16,38,4,64,175,0,16,39,0,118,0,214,
255,92,16,7,1,224,1,208,0,0,255,255,0,19,0,0,5,223,
6,244,16,39,1,178,0,200,3,152,16,38,4,6,175,0,16,7,
1,224,1,149,0,0,255,255,0,19,0,0,5,214,6,244,16,39,
1,178,0,204,3,152,16,38,4,64,175,0,16,7,1,224,1,140,
0,0,255,255,0,76,0,0,2,86,6,59,16,39,4,6,255,232,
255,72,16,6,2,1,0,0,255,255,0,135,0,0,2,86,6,60,
16,39,4,64,0,35,255,73,16,6,2,1,0,0,255,255,0,56,
0,0,2,202,6,61,16,39,4,6,255,212,255,74,16,39,0,67,
0,234,254,162,16,6,2,1,96,0,255,255,0,8,0,0,2,169,
6,59,16,39,4,64,255,164,255,72,16,39,0,67,0,201,254,162,
16,6,2,1,0,0,255,255,0,19,0,0,2,179,6,59,16,39,
4,6,255,175,255,72,16,39,0,118,0,211,254,163,16,6,2,1,
32,0,255,255,0,12,0,0,2,141,6,59,16,39,4,64,255,168,
255,72,16,39,0,118,0,173,254,163,16,6,2,1,0,0,255,255,
0,27,0,0,2,152,6,243,16,39,1,178,255,220,3,151,16,39,
4,6,0,5,255,33,16,6,2,1,0,0,255,255,0,27,0,0,
2,152,6,242,16,39,1,178,255,220,3,150,16,39,4,64,0,5,
255,55,16,6,2,1,0,0,255,255,0,16,0,0,1,132,6,243,
16,38,4,6,172,0,16,6,1,226,77,0,0,0,255,255,0,19,
0,0,1,163,6,243,16,38,4,64,175,0,16,6,1,226,108,0,
0,0,255,255,0,19,0,0,2,188,6,244,16,38,4,6,175,1,
16,39,0,67,0,220,255,87,16,6,1,226,96,0,0,0,255,255,
0,19,255,252,3,127,6,244,16,38,4,64,175,0,16,39,0,67,
0,198,255,92,16,7,1,226,2,72,255,252,255,255,0,19,0,0,
2,170,6,245,16,38,4,6,175,2,16,39,0,118,0,202,255,92,
16,7,1,226,1,72,0,0,255,255,0,19,0,0,2,207,6,244,
16,38,4,64,175,0,16,39,0,118,0,185,255,92,16,7,1,226,
1,152,0,0,255,255,0,19,255,250,3,130,6,243,16,39,1,178,
0,198,3,150,16,38,4,6,175,0,16,7,1,226,1,242,255,250,
255,255,0,19,0,0,3,154,6,243,16,38,4,64,175,0,16,39,
1,178,0,222,3,150,16,7,1,226,2,28,0,0,255,255,0,90,
255,227,3,196,6,60,16,39,4,6,1,67,255,73,16,6,2,7,
0,0,255,255,0,90,255,227,3,196,6,60,16,39,4,64,1,76,
255,73,16,6,2,7,0,0,255,255,0,90,255,227,3,196,6,60,
16,39,4,6,0,144,255,73,16,39,0,67,1,207,254,164,16,6,
2,7,0,0,255,255,0,90,255,227,3,196,6,61,16,39,0,67,
0,187,254,165,16,6,2,7,0,0,255,255,0,90,255,227,3,196,
6,60,16,39,4,6,0,153,255,73,16,39,0,118,1,196,254,163,
16,6,2,7,0,0,255,255,0,90,255,227,3,196,6,61,16,39,
4,64,0,111,255,73,16,39,0,118,1,195,254,165,16,6,2,7,
0,0,255,255,0,92,255,227,4,238,6,243,16,38,4,6,250,0,
16,6,1,232,0,0,0,0,255,255,0,19,255,227,4,238,6,243,
16,38,4,64,175,0,16,6,1,232,0,0,0,0,255,255,0,100,
255,227,6,142,6,244,16,38,4,6,0,0,16,39,0,67,1,41,
255,92,16,7,1,232,1,160,0,0,255,255,0,19,255,227,6,102,
6,244,16,38,4,64,175,0,16,39,0,67,0,211,255,92,16,7,
1,232,1,120,0,0,255,255,0,100,255,227,5,243,6,244,16,38,
4,6,0,0,16,39,0,118,1,36,255,92,16,7,1,232,1,5,
0,0,255,255,0,19,255,227,5,186,6,245,16,38,4,64,175,0,
16,39,0,118,0,219,255,93,16,7,1,232,0,204,0,0,255,255,
0,118,255,228,3,181,6,61,16,39,4,6,0,186,255,74,16,6,
2,13,0,0,255,255,0,118,255,228,3,181,6,59,16,39,4,64,
0,170,255,72,16,6,2,13,0,0,255,255,0,118,255,228,3,181,
6,61,16,39,4,6,0,105,255,73,16,39,0,67,1,127,254,165,
16,6,2,13,0,0,255,255,0,118,255,228,3,181,6,61,16,39,
4,64,0,78,255,72,16,39,0,67,1,141,254,165,16,6,2,13,
0,0,255,255,0,118,255,228,3,181,6,60,16,39,4,6,0,123,
255,73,16,39,0,118,1,157,254,164,16,6,2,13,0,0,255,255,
0,118,255,228,3,181,6,60,16,39,4,64,0,90,255,73,16,39,
0,118,1,144,254,164,16,6,2,13,0,0,255,255,0,118,255,228,
3,181,6,244,16,39,1,178,0,147,3,152,16,39,4,6,0,171,
255,14,16,6,2,13,0,0,255,255,0,118,255,228,3,181,6,242,
16,39,1,178,0,129,3,150,16,39,4,64,0,169,255,15,16,6,
2,13,0,0,255,255,0,19,0,0,5,2,6,243,16,38,4,64,
175,0,16,7,1,237,0,168,0,0,255,255,0,19,0,0,6,242,
6,245,16,38,4,64,175,0,16,39,0,67,0,213,255,93,16,7,
1,237,2,152,0,0,255,255,0,19,0,0,6,94,6,243,16,38,
4,64,175,0,16,39,0,118,0,241,255,91,16,7,1,237,2,4,
0,0,255,255,0,19,0,0,6,123,6,243,16,38,4,64,175,0,
16,39,1,178,0,213,3,151,16,7,1,237,2,33,0,0,255,255,
0,55,0,0,4,139,6,54,16,39,4,6,1,143,255,67,16,6,
2,17,0,0,255,255,0,55,0,0,4,139,6,60,16,39,4,64,
1,146,255,73,16,6,2,17,0,0,255,255,0,55,0,0,4,139,
6,59,16,39,4,6,0,180,255,68,16,39,0,67,1,231,254,163,
16,6,2,17,0,0,255,255,0,55,0,0,4,139,6,59,16,39,
4,64,0,164,255,72,16,39,0,67,1,214,254,163,16,6,2,17,
0,0,255,255,0,55,0,0,4,139,6,60,16,39,0,118,2,10,
254,164,16,39,4,6,0,225,255,73,16,6,2,17,0,0,255,255,
0,55,0,0,4,139,6,60,16,39,0,118,1,244,254,164,16,39,
4,64,0,243,255,73,16,6,2,17,0,0,255,255,0,55,0,0,
4,139,6,242,16,39,4,6,1,10,255,34,16,39,1,178,0,240,
3,150,16,6,2,17,0,0,255,255,0,55,0,0,4,139,6,244,
16,39,4,64,0,252,255,40,16,39,1,178,0,231,3,152,16,6,
2,17,0,0,255,255,0,19,0,0,5,53,6,243,16,38,4,6,
175,0,16,6,1,241,0,0,0,0,255,255,0,19,0,0,5,53,
6,243,16,38,4,64,175,0,16,6,1,241,0,0,0,0,255,255,
0,19,0,0,6,181,6,244,16,38,4,6,175,0,16,39,0,67,
0,228,255,92,16,7,1,241,1,128,0,0,255,255,0,19,0,8,
6,189,6,244,16,38,4,64,175,0,16,39,0,67,0,216,255,92,
16,7,1,241,1,136,0,8,255,255,0,19,0,0,6,17,6,244,
16,39,0,118,0,212,255,92,16,38,4,6,175,0,16,7,1,241,
0,220,0,0,255,255,0,19,0,0,5,198,6,244,16,39,0,118,
0,191,255,92,16,38,4,64,175,0,16,7,1,241,0,145,0,0,
255,255,0,19,0,0,6,221,6,244,16,39,1,178,0,200,3,152,
16,38,4,6,175,0,16,7,1,241,1,168,0,0,255,255,0,19,
0,0,6,241,6,244,16,39,1,178,0,200,3,152,16,38,4,64,
175,0,16,7,1,241,1,188,0,0,255,255,0,90,255,227,4,119,
6,61,16,39,0,67,0,174,254,165,16,6,1,249,0,0,255,255,
0,90,255,227,4,119,6,61,16,39,0,118,1,174,254,165,16,6,
1,249,0,0,255,255,0,138,255,227,3,107,6,60,16,39,0,67,
0,179,254,164,16,6,1,253,0,0,255,255,0,138,255,227,3,107,
6,60,16,39,0,118,1,94,254,164,16,6,1,253,0,0,255,255,
0,118,254,116,3,177,6,58,16,39,0,67,0,173,254,162,16,6,
1,255,0,0,255,255,0,118,254,116,3,177,6,58,16,39,0,118,
1,131,254,162,16,6,1,255,0,0,255,255,255,127,0,0,2,86,
6,58,16,39,0,67,255,67,254,162,16,6,2,1,0,0,255,255,
0,134,0,0,2,86,6,59,16,39,0,118,0,74,254,163,16,6,
2,1,0,0,255,255,0,90,255,227,3,196,6,60,16,39,0,67,
0,87,254,164,16,6,2,7,0,0,255,255,0,90,255,227,3,196,
6,60,16,39,0,118,1,98,254,164,16,6,2,7,0,0,255,255,
0,87,255,228,3,181,6,59,16,39,0,67,0,27,254,163,16,6,
2,13,0,0,255,255,0,118,255,228,3,181,6,60,16,39,0,118,
1,10,254,164,16,6,2,13,0,0,255,255,0,55,0,0,4,139,
6,58,16,39,0,67,0,161,254,162,16,6,2,17,0,0,255,255,
0,55,0,0,4,139,6,60,16,39,0,118,1,194,254,164,16,6,
2,17,0,0,255,255,0,90,254,116,4,119,6,54,16,39,4,6,
1,107,255,67,16,6,3,253,0,0,255,255,0,90,254,116,4,119,
6,61,16,39,4,64,1,74,255,74,16,6,3,253,0,0,255,255,
0,90,254,116,4,119,6,60,16,39,0,67,1,196,254,162,16,39,
4,6,0,165,255,73,16,6,3,253,0,0,255,255,0,90,254,116,
4,119,6,59,16,38,3,253,0,0,16,39,0,67,1,226,254,162,
16,7,4,64,0,145,255,72,255,255,0,90,254,116,4,119,6,60,
16,39,0,118,1,228,254,164,16,39,4,6,0,192,255,73,16,6,
3,253,0,0,255,255,0,90,254,116,4,119,6,60,16,39,0,118,
1,229,254,164,16,39,4,64,0,186,255,73,16,6,3,253,0,0,
255,255,0,90,254,116,4,119,6,244,16,39,1,178,0,208,3,152,
16,39,4,6,0,243,255,45,16,6,3,253,0,0,255,255,0,90,
254,116,4,119,6,243,16,39,1,178,0,180,3,151,16,39,4,64,
0,195,255,49,16,6,3,253,0,0,255,255,0,72,254,116,4,223,
6,243,16,39,4,6,0,150,0,0,16,6,4,5,0,0,255,255,
0,72,254,116,4,223,6,243,16,39,4,64,0,153,0,0,16,6,
4,5,0,0,255,255,0,19,254,116,5,183,6,245,16,38,4,6,
175,0,16,39,4,5,0,216,0,0,16,7,0,67,0,220,255,93,
255,255,0,19,254,116,5,143,6,243,16,38,4,64,175,0,16,39,
4,5,0,176,0,0,16,7,0,67,0,214,255,90,255,255,0,19,
254,116,5,183,6,243,16,38,4,6,175,0,16,39,4,5,0,216,
0,0,16,7,0,67,0,210,255,90,255,255,0,32,254,116,4,223,
6,244,16,39,0,118,0,216,255,92,16,38,4,64,188,0,16,6,
4,5,0,0,0,0,255,255,0,19,254,116,4,223,6,244,16,39,
1,178,0,232,3,152,16,38,4,6,175,0,16,6,4,5,0,0,
0,0,255,255,0,28,254,116,4,223,6,243,16,38,4,64,184,0,
16,39,1,178,0,207,3,150,16,6,4,5,0,0,0,0,255,255,
0,118,254,116,3,177,6,60,16,39,4,6,1,98,255,73,16,39,
4,7,254,47,0,0,16,6,1,255,0,0,255,255,0,118,254,116,
3,177,6,60,16,39,4,64,1,92,255,73,16,39,4,7,254,47,
0,0,16,6,1,255,0,0,255,255,0,118,254,116,3,177,6,61,
16,39,4,6,0,108,255,74,16,39,4,7,254,52,0,0,16,39,
0,67,1,151,254,163,16,6,1,255,0,0,255,255,0,118,254,116,
3,177,6,59,16,39,4,64,0,108,255,72,16,39,4,7,254,48,
0,0,16,39,0,67,1,166,254,163,16,6,1,255,0,0,255,255,
0,118,254,116,3,177,6,60,16,39,0,118,1,156,254,162,16,39,
4,6,0,129,255,73,16,39,4,7,254,47,0,0,16,6,1,255,
0,0,255,255,0,118,254,116,3,177,6,60,16,39,0,118,1,173,
254,164,16,39,4,64,0,129,255,73,16,39,4,7,254,50,0,0,
16,6,1,255,0,0,255,255,0,118,254,116,3,177,6,244,16,39,
1,178,0,160,3,152,16,39,4,6,0,193,255,25,16,39,4,7,
254,47,0,0,16,6,1,255,0,0,255,255,0,118,254,116,3,177,
6,242,16,39,4,64,0,192,255,40,16,39,1,178,0,165,3,150,
16,39,4,7,254,50,0,0,16,6,1,255,0,0,255,255,0,19,
254,116,4,206,6,243,16,38,4,6,175,0,16,7,4,20,0,132,
0,0,255,255,0,19,254,116,4,197,6,243,16,38,4,64,175,0,
16,6,4,20,123,0,0,0,255,255,0,19,254,116,6,182,6,243,
16,39,0,67,0,216,255,90,16,39,4,20,2,108,0,0,16,6,
4,6,175,0,255,255,0,19,254,116,6,166,6,244,16,38,4,64,
175,0,16,39,4,20,2,92,0,0,16,7,0,67,0,211,255,92,
255,255,0,19,254,116,6,178,6,244,16,38,4,6,175,0,16,39,
4,20,2,104,0,0,16,7,0,67,0,216,255,92,255,255,0,20,
254,116,5,213,6,244,16,39,0,118,0,196,255,92,16,38,4,64,
176,0,16,7,4,20,1,139,0,0,255,255,0,19,254,116,5,70,
6,244,16,39,1,178,0,228,3,152,16,38,4,6,175,0,16,7,
4,20,0,252,0,0,255,255,0,19,254,116,5,70,6,243,16,38,
4,64,175,0,16,39,1,178,0,192,3,150,16,7,4,20,0,252,
0,0,255,255,0,55,254,116,4,139,6,60,16,39,4,6,1,143,
255,73,16,6,4,54,0,0,255,255,0,55,254,116,4,139,6,60,
16,39,4,64,1,145,255,73,16,6,4,54,0,0,255,255,0,55,
254,116,4,139,6,59,16,39,4,6,0,188,255,72,16,38,4,54,
0,0,16,7,0,67,2,33,254,163,255,255,0,55,254,116,4,139,
6,59,16,39,4,64,0,220,255,72,16,38,4,54,0,0,16,7,
0,67,2,19,254,163,255,255,0,55,254,116,4,139,6,60,16,39,
0,118,2,36,254,163,16,39,4,6,1,16,255,73,16,6,4,54,
0,0,255,255,0,55,254,116,4,139,6,60,16,39,0,118,1,230,
254,164,16,6,4,54,0,0,255,255,0,55,254,116,4,139,6,243,
16,39,1,178,0,212,3,151,16,39,4,6,1,127,254,209,16,6,
4,54,0,0,255,255,0,55,254,116,4,139,6,243,16,39,4,64,
1,140,254,208,16,39,1,178,0,250,3,151,16,6,4,54,0,0,
255,255,0,19,254,116,5,53,6,243,16,38,4,6,175,0,16,38,
4,7,0,0,16,6,1,241,0,0,255,255,0,19,254,116,5,53,
6,243,16,38,4,64,175,0,16,38,4,7,0,0,16,6,1,241,
0,0,255,255,0,19,254,116,6,193,6,244,16,38,4,6,175,0,
16,39,4,7,1,158,0,0,16,39,0,67,0,204,255,92,16,7,
1,241,1,140,0,0,255,255,0,25,254,116,5,53,7,151,16,38,
4,7,0,0,16,39,0,67,1,36,255,255,16,6,1,241,0,0,
0,0,255,255,0,19,254,116,5,253,6,244,16,39,0,118,0,188,
255,92,16,38,4,6,175,0,16,38,4,7,0,0,16,7,1,241,
0,200,0,0,0,0,255,255,0,19,254,116,5,251,6,247,16,38,
4,64,175,0,16,39,0,118,0,213,255,95,16,39,4,7,1,46,
0,0,16,7,1,241,0,198,0,0,255,255,0,19,254,116,6,177,
6,244,16,39,1,178,0,232,3,152,16,38,4,6,175,0,16,39,
4,7,1,144,0,0,16,7,1,241,1,124,0,0,255,255,1,53,
254,116,6,177,6,243,16,39,1,178,0,246,3,151,16,39,4,7,
1,137,0,0,16,7,1,241,1,124,0,0,0,0,255,255,0,90,
255,227,4,119,5,250,16,39,1,174,255,161,254,204,16,6,1,249,
0,0,255,255,0,90,255,227,4,119,5,87,16,38,0,113,56,46,
16,6,1,249,0,0,0,0,255,255,0,90,254,116,4,119,6,58,
16,38,3,253,0,0,16,7,0,67,0,144,254,162,255,255,0,90,
254,116,4,119,4,70,16,38,4,7,135,0,16,6,1,249,0,0,
0,0,255,255,0,90,254,116,4,119,6,58,16,38,3,253,0,0,
16,7,0,118,1,148,254,162,255,255,0,90,255,227,4,119,6,60,
16,39,1,178,0,209,2,224,16,6,1,249,0,0,255,255,0,90,
254,116,4,119,6,59,16,39,1,178,0,213,2,223,16,6,3,253,
0,0,255,255,0,72,0,0,4,223,7,46,16,38,1,174,0,0,
16,6,1,218,0,0,0,0,255,255,0,72,0,0,4,223,6,166,
16,39,0,113,0,132,1,125,16,6,1,218,0,0,255,255,0,59,
0,0,4,223,6,242,16,39,0,67,255,255,255,90,16,6,1,218,
0,0,255,255,0,72,0,0,4,223,6,244,16,39,0,118,0,17,
255,92,16,6,1,218,0,0,255,255,0,72,254,116,4,223,5,176,
16,38,4,7,0,0,16,6,1,218,0,0,0,0,0,1,0,100,
5,76,1,59,6,243,0,26,0,0,1,20,7,6,7,6,7,6,
15,1,39,54,53,34,39,38,39,38,53,52,55,54,51,50,22,23,
22,1,59,9,8,20,13,19,9,24,21,56,72,41,27,30,7,3,
32,31,45,38,60,7,2,6,135,45,43,40,43,28,34,17,36,29,
31,103,75,23,25,36,11,11,45,32,31,50,35,10,0,0,0,1,
2,72,254,116,2,221,255,136,0,24,0,0,1,39,52,55,54,51,
48,51,50,23,30,3,23,22,21,7,14,1,35,34,47,1,38,2,
91,19,29,19,23,5,31,18,1,3,2,2,1,15,22,3,34,18,
21,17,7,6,254,164,153,41,21,13,19,1,3,1,3,1,22,26,
152,24,24,15,7,8,0,1,0,100,5,76,1,59,6,243,0,26,
0,0,1,20,7,6,7,6,7,6,15,1,39,54,53,34,39,38,
39,38,53,52,55,54,51,50,22,23,22,1,59,9,8,20,13,19,
9,24,21,56,72,41,27,30,7,3,32,31,45,38,60,7,2,6,
135,45,43,40,43,28,34,17,36,29,31,103,75,23,25,36,11,11,
45,32,31,50,35,10,0,0,0,1,0,49,4,193,2,174,5,234,
0,43,0,0,19,54,55,62,1,51,50,23,22,23,30,1,23,30,
1,51,50,55,54,55,54,55,21,6,7,6,7,6,35,34,39,38,
39,38,39,38,39,38,35,34,6,7,6,7,49,24,27,25,70,37,
25,30,26,26,8,32,8,25,56,30,32,34,30,32,27,33,49,11,
27,33,34,34,32,32,30,27,16,34,26,23,26,22,36,66,24,27,
28,5,138,18,24,22,32,16,14,24,7,30,7,23,30,15,13,25,
21,24,145,38,9,23,14,15,15,14,24,14,32,25,13,15,30,21,
23,23,0,0,0,3,0,57,4,232,2,204,6,243,0,16,0,34,
0,81,0,0,1,52,54,51,50,22,23,22,21,20,6,35,34,39,
38,39,38,37,52,54,51,50,23,22,23,22,21,20,6,35,34,39,
38,39,38,19,54,55,54,55,54,51,50,23,22,31,1,22,23,22,
51,50,55,54,55,54,55,21,6,7,6,7,6,35,34,39,38,39,
46,2,39,38,39,38,35,34,7,6,7,6,7,2,16,56,38,34,
50,8,2,56,38,32,27,25,8,2,254,41,56,38,33,26,25,8,
2,56,38,32,27,26,7,2,10,33,18,25,35,37,35,26,29,26,
26,48,22,31,30,28,29,37,36,26,47,13,49,11,27,33,34,34,
30,34,30,27,6,20,17,7,26,23,27,21,36,33,31,26,13,42,
5,73,38,56,42,33,10,9,39,56,22,21,33,16,1,38,56,21,
21,33,10,9,39,56,22,21,33,8,1,87,25,16,22,16,17,15,
14,24,45,21,16,16,16,15,21,36,10,145,38,9,23,14,15,16,
14,24,5,18,14,7,25,13,16,15,14,23,12,33,255,255,0,118,
254,116,3,177,6,58,16,39,4,7,254,48,0,0,16,39,0,67,
0,145,254,162,16,6,1,255,0,0,255,255,0,117,254,116,3,177,
4,78,16,39,4,7,254,45,0,0,16,6,1,255,0,0,255,255,
0,116,254,116,3,177,5,250,16,39,4,7,254,44,0,0,16,39,
0,118,1,60,254,98,16,6,1,255,0,0,255,255,0,118,254,116,
3,177,6,59,16,39,1,178,0,154,2,223,16,6,1,255,0,0,
255,255,0,113,254,116,3,177,6,59,16,39,1,178,0,153,2,223,
16,39,4,7,254,41,0,0,16,6,1,255,0,0,255,255,0,19,
0,0,5,122,6,244,16,39,0,67,255,215,255,92,16,7,1,222,
1,104,0,0,0,0,255,255,0,121,0,0,4,18,5,176,16,6,
1,222,0,0,255,255,0,19,0,0,5,182,6,244,16,39,0,67,
255,215,255,92,16,7,1,224,1,108,0,0,0,0,255,255,0,22,
255,252,5,182,6,244,16,39,0,118,255,218,255,92,16,7,1,224,
1,108,255,252,0,0,255,255,0,121,254,116,4,74,5,176,16,38,
4,7,202,0,16,6,1,224,0,0,0,0,255,255,0,100,5,76,
3,36,6,244,16,38,4,8,0,0,16,7,4,52,1,68,0,0,
255,255,0,100,5,76,3,4,6,245,16,39,4,63,1,36,0,0,
16,6,4,8,0,0,255,255,0,49,4,100,2,174,6,243,16,39,
4,8,0,8,255,24,16,7,4,9,0,0,1,9,0,0,255,255,
255,175,0,0,2,86,5,156,16,39,1,174,254,77,254,110,16,6,
2,1,0,0,255,255,255,125,0,0,2,86,5,86,16,39,0,113,
254,193,0,45,16,6,2,1,0,0,255,255,255,134,0,0,2,86,
5,79,16,39,0,106,255,58,254,92,16,6,2,1,0,0,255,255,
0,135,0,0,2,86,6,243,16,39,0,118,0,78,255,91,16,6,
2,1,0,0,255,255,255,177,0,0,2,86,5,183,16,39,1,178,
255,114,2,91,16,6,2,1,0,0,255,255,255,140,0,0,2,86,
6,59,16,39,1,178,255,89,2,223,16,39,0,106,255,64,254,0,
16,6,2,1,0,0,255,255,255,190,0,0,2,28,7,43,16,39,
1,174,254,92,255,253,16,6,1,226,0,0,255,255,255,139,0,0,
2,48,6,166,16,39,0,113,254,207,1,125,16,6,1,226,0,0,
255,255,0,19,0,0,2,135,6,243,16,39,0,67,255,215,255,91,
16,7,1,226,1,80,0,0,0,0,255,255,0,19,0,4,2,85,
6,244,16,39,0,118,255,215,255,92,16,7,1,226,1,30,0,4,
0,0,0,2,0,100,5,76,3,24,6,244,0,23,0,50,0,0,
1,22,23,22,21,20,7,6,7,6,39,37,38,39,38,39,38,55,
54,55,54,51,50,23,5,52,55,62,1,51,50,23,22,21,20,7,
6,7,6,35,20,23,7,39,38,39,38,39,38,39,38,3,8,11,
3,2,13,12,20,23,17,254,207,21,6,2,1,1,18,16,24,6,
12,26,22,254,117,2,7,60,38,45,31,32,3,7,30,27,41,72,
56,21,24,9,13,18,20,8,10,5,232,11,12,8,6,17,18,15,
5,6,13,219,18,23,8,5,28,22,22,6,2,18,91,13,10,35,
50,31,32,45,11,11,36,25,23,75,103,31,29,36,17,24,38,43,
40,48,0,0,0,2,0,100,5,76,3,24,6,244,0,23,0,50,
0,0,1,37,54,51,50,23,22,23,22,21,20,7,6,7,5,6,
39,38,39,38,55,52,55,54,37,52,55,62,1,51,50,23,22,21,
20,7,6,7,6,35,20,23,7,39,38,39,38,39,38,39,38,1,
132,1,25,22,26,12,6,24,16,17,3,6,21,254,207,17,23,20,
12,14,1,2,3,254,235,2,7,60,38,45,31,32,3,7,30,27,
41,72,56,21,24,9,13,18,20,8,10,5,232,250,18,2,6,22,
20,26,2,15,23,18,219,13,6,5,15,19,20,4,6,12,170,13,
10,35,50,31,32,45,11,11,36,25,23,75,103,31,29,36,17,24,
38,43,40,48,0,0,0,2,0,49,4,121,2,174,6,244,0,43,
0,70,0,0,19,54,55,62,1,51,50,23,22,23,30,1,23,30,
1,51,50,55,54,55,54,55,21,6,7,6,7,6,35,34,39,38,
39,38,39,38,39,38,35,34,6,7,6,7,23,52,55,54,55,54,
51,50,22,21,20,7,6,7,6,35,20,23,7,39,38,39,38,39,
38,39,38,49,24,27,25,70,37,25,30,26,26,8,32,8,25,56,
30,32,34,30,32,27,33,49,11,27,33,35,33,32,32,30,27,16,
34,26,23,26,22,36,66,24,27,28,68,2,8,29,29,39,44,64,
3,7,30,29,39,72,56,21,19,14,19,13,20,8,9,6,148,18,
24,22,32,16,14,24,7,29,8,23,30,15,13,25,21,24,145,38,
9,23,14,15,15,14,24,14,32,25,13,15,30,21,23,23,78,13,
10,36,25,24,64,44,12,10,35,25,24,74,104,31,29,30,24,34,
28,43,39,43,0,0,255,255,0,118,255,228,3,181,5,212,16,39,
1,174,255,27,254,166,16,6,2,13,0,0,255,255,0,118,255,228,
3,181,5,32,16,38,0,113,188,247,16,6,2,13,0,0,0,0,
255,255,0,118,255,228,3,181,6,243,16,39,0,67,0,108,255,91,
16,39,0,106,0,42,254,91,16,6,2,13,0,0,255,255,0,118,
255,228,3,181,6,243,16,39,0,118,0,248,255,91,16,39,0,106,
0,43,254,94,16,6,2,13,0,0,255,255,0,90,254,116,3,195,
6,60,16,39,4,6,1,65,255,73,16,6,2,9,0,0,255,255,
0,90,254,116,3,195,6,60,16,39,4,64,1,71,255,73,16,6,
2,9,0,0,255,255,0,118,255,228,3,181,6,60,16,39,1,178,
0,91,2,224,16,6,2,13,0,0,255,255,0,118,255,228,3,181,
6,242,16,39,1,178,0,69,3,150,16,39,0,106,0,44,254,91,
16,6,2,13,0,0,255,255,0,66,0,0,4,90,7,46,16,38,
1,174,187,0,16,6,1,237,0,0,0,0,255,255,0,66,0,0,
4,90,6,166,16,39,0,113,0,61,1,125,16,6,1,237,0,0,
255,255,0,19,0,0,5,226,6,244,16,39,0,67,255,215,255,92,
16,7,1,237,1,136,0,0,0,0,255,255,0,19,255,251,5,6,
6,244,16,39,0,118,255,215,255,92,16,7,1,237,0,172,255,251,
0,0,255,255,0,19,0,0,4,143,6,243,16,38,4,64,175,0,
16,7,1,234,0,135,0,0,0,3,0,60,4,240,2,223,6,245,
0,23,0,40,0,57,0,0,1,22,23,22,21,22,7,6,7,6,
39,37,38,39,38,53,52,55,54,55,54,51,50,23,1,52,54,51,
50,22,23,22,21,20,6,35,34,39,38,39,38,37,52,54,51,50,
22,23,22,21,20,6,35,34,39,38,39,38,1,208,11,3,2,1,
14,12,20,23,17,254,207,21,6,3,17,16,24,6,12,26,22,1,
108,56,38,34,50,8,2,56,38,32,27,26,7,2,254,41,56,38,
34,50,8,2,56,38,32,27,25,8,2,5,233,11,12,6,4,20,
19,15,5,6,13,219,18,23,15,2,26,20,22,6,2,18,254,110,
38,56,42,33,10,9,39,56,22,21,33,16,1,38,56,42,33,10,
9,39,56,22,21,33,8,0,0,3,0,188,4,237,3,80,6,243,
0,23,0,41,0,58,0,0,1,37,54,51,50,23,22,23,22,21,
20,7,6,7,5,6,39,38,39,38,55,52,55,54,23,52,54,51,
50,23,22,23,22,21,20,6,35,34,39,38,39,38,37,52,54,51,
50,23,22,23,22,21,20,6,35,34,38,39,38,1,189,1,25,22,
26,12,6,24,16,16,2,6,21,254,207,17,23,20,12,14,1,2,
3,225,56,38,32,27,25,8,2,56,38,33,26,25,8,2,254,41,
56,38,32,27,25,8,2,56,38,34,50,8,2,5,231,250,18,2,
6,22,19,26,8,10,23,18,219,13,6,5,15,19,20,4,6,12,
142,38,56,22,21,32,10,9,39,56,21,21,34,16,1,38,56,22,
21,32,10,9,39,56,42,34,8,0,0,0,0,1,0,60,5,138,
1,224,6,244,0,25,0,0,1,22,23,22,21,20,7,6,7,6,
35,34,39,37,38,39,38,53,52,55,54,55,54,51,50,23,1,208,
11,3,2,13,12,20,10,4,14,12,254,207,21,6,3,17,16,24,
6,12,26,22,5,232,11,12,8,6,17,18,15,5,2,9,219,18,
23,15,2,26,20,22,6,2,18,0,255,255,0,55,0,0,4,139,
5,250,16,39,0,67,0,168,254,98,16,6,2,17,0,0,255,255,
0,55,254,116,4,139,4,72,16,38,4,7,205,0,16,6,2,17,
0,0,0,0,255,255,0,55,254,116,4,139,6,60,16,39,0,118,
1,182,254,164,16,6,4,54,0,0,255,255,0,55,0,0,4,139,
6,59,16,39,1,178,0,225,2,223,16,6,2,17,0,0,255,255,
0,55,254,116,4,139,6,59,16,39,1,178,0,224,2,223,16,6,
4,54,0,0,255,255,0,19,255,227,5,118,6,244,16,39,0,67,
255,215,255,92,16,7,1,232,0,136,0,0,0,0,255,255,0,19,
255,227,4,238,6,243,16,39,0,118,255,215,255,91,16,6,1,232,
0,0,255,255,0,19,0,0,5,173,6,244,16,39,0,67,255,215,
255,92,16,6,1,241,120,0,255,255,0,19,0,0,5,53,6,244,
16,39,0,118,255,215,255,92,16,6,1,241,0,0,255,255,0,25,
254,116,5,53,5,215,16,38,4,7,17,0,16,6,1,241,0,0,
0,0,0,1,0,60,5,139,1,224,6,245,0,25,0,0,19,37,
54,51,50,23,22,23,22,21,20,7,6,7,5,6,35,34,39,38,
39,38,53,52,55,54,76,1,25,22,26,12,6,24,16,17,3,6,
21,254,207,12,14,4,10,20,12,13,2,3,5,233,250,18,2,6,
22,20,26,2,15,23,18,219,9,2,5,15,18,17,6,8,12,0,
0,1,0,100,5,76,1,59,6,243,0,26,0,0,19,52,55,62,
1,51,50,23,22,21,20,7,6,7,6,35,20,23,7,39,38,39,
38,39,38,39,38,100,2,7,60,38,45,31,32,3,7,30,27,41,
72,56,21,24,9,13,18,20,8,10,6,135,13,10,35,50,31,32,
45,11,11,36,25,23,75,103,31,29,36,17,24,38,43,40,48,0,
0,0,0,1,0,118,2,58,3,177,2,200,0,3,0,0,19,33,
21,33,118,3,59,252,197,2,200,142,0,0,0,1,0,118,2,58,
3,177,2,200,0,3,0,0,19,33,21,33,118,3,59,252,197,2,
200,142,0,0,0,1,0,170,2,29,3,170,2,164,0,3,0,0,
19,33,21,33,170,3,0,253,0,2,164,135,0,0,0,1,0,170,
2,29,3,88,2,164,0,3,0,0,19,33,21,33,170,2,174,253,
82,2,164,135,0,0,0,1,0,150,2,29,4,135,2,164,0,3,
0,0,19,33,21,33,150,3,241,252,15,2,164,135,0,0,0,1,
0,0,2,58,6,26,2,200,0,3,0,0,17,33,21,33,6,26,
249,230,2,200,142,0,0,0,0,2,0,69,0,0,1,239,4,50,
0,3,0,7,0,0,1,17,35,17,35,17,35,17,1,239,141,144,
141,4,50,251,206,4,50,251,206,4,50,0,255,255,0,83,4,68,
1,42,5,235,16,15,0,15,1,145,5,14,192,0,255,255,0,95,
4,62,1,54,5,229,16,7,0,15,255,248,5,27,0,0,255,255,
0,99,255,52,1,58,0,219,16,7,4,78,0,4,250,246,0,0,
255,255,0,106,4,68,1,65,5,235,16,6,4,77,23,0,255,255,
0,81,4,68,2,114,5,237,16,39,4,77,1,72,0,0,16,6,
4,77,254,2,255,255,0,97,4,62,2,128,5,231,16,39,4,78,
1,74,0,0,16,6,4,78,2,2,255,255,0,113,255,50,2,144,
0,219,16,7,4,82,0,16,250,244,0,0,255,255,0,91,4,62,
2,124,5,231,16,6,4,81,10,250,0,1,0,134,0,0,3,42,
5,174,0,11,0,0,1,17,35,17,33,53,33,17,51,17,33,21,
2,41,143,254,236,1,20,143,1,1,3,117,252,139,3,117,142,1,
171,254,85,142,0,1,0,134,0,0,3,42,5,174,0,19,0,0,
1,17,33,21,33,17,35,17,33,53,33,17,33,53,33,17,51,17,
33,21,2,41,1,1,254,255,143,254,236,1,20,254,236,1,20,143,
1,1,3,239,254,21,142,254,138,1,118,142,1,235,142,1,49,254,
207,142,0,0,0,1,0,59,1,101,2,72,3,105,0,19,0,0,
19,52,55,54,51,50,23,22,23,22,21,20,7,6,35,34,39,38,
39,38,59,111,68,84,138,77,31,10,6,110,68,84,138,77,31,10,
7,2,103,133,78,47,110,44,51,27,26,134,77,47,110,44,51,32,
0,1,0,199,1,142,2,50,3,70,0,2,0,0,19,13,1,199,
1,107,254,151,3,70,223,217,0,0,0,1,0,92,0,0,1,51,
0,215,0,17,0,0,51,34,38,53,52,55,54,55,54,51,50,22,
21,20,7,6,7,6,200,44,64,24,25,36,10,13,45,62,24,21,
40,10,64,44,40,28,29,8,2,62,45,40,28,25,12,3,0,2,
0,92,0,0,3,131,0,215,0,17,0,35,0,0,51,34,38,53,
52,55,54,55,54,51,50,22,21,20,7,6,7,6,33,34,38,53,
52,55,54,55,54,51,50,22,21,20,7,6,7,6,200,44,64,24,
25,36,10,13,45,62,24,21,40,10,2,68,44,64,25,24,37,10,
12,45,62,23,21,41,7,64,44,40,28,29,8,2,62,45,40,28,
25,12,3,64,44,38,30,28,8,2,62,44,41,27,26,12,2,0,
0,0,0,3,0,92,0,0,5,207,0,215,0,17,0,35,0,53,
0,0,33,34,38,53,52,55,54,55,54,51,50,22,21,20,7,6,
7,6,33,34,38,53,52,55,54,55,54,51,50,22,21,20,7,6,
7,6,33,34,38,53,52,55,54,55,54,51,50,22,21,20,7,6,
7,6,5,100,44,64,24,25,36,10,13,45,62,24,21,40,10,251,
88,44,64,24,25,36,10,13,45,62,24,21,40,10,2,68,44,64,
25,24,37,10,12,45,62,23,21,41,7,64,44,40,28,29,8,2,
62,45,40,28,25,12,3,64,44,40,28,29,8,2,62,45,40,28,
25,12,3,64,44,38,30,28,8,2,62,44,41,27,26,12,2,0,
0,1,0,253,2,68,3,9,4,73,0,19,0,0,19,52,55,54,
51,50,23,22,23,22,21,20,7,6,35,34,39,38,39,38,253,77,
76,109,95,71,70,21,5,77,78,107,94,71,70,21,6,3,71,108,
75,75,58,56,91,23,30,108,75,76,58,58,89,25,0,7,0,115,
0,105,7,182,5,69,0,12,0,26,0,30,0,60,0,92,0,105,
0,136,0,0,1,20,23,22,50,54,53,52,39,38,35,34,6,1,
20,23,22,51,50,54,53,52,39,38,35,34,6,19,35,1,51,1,
52,55,54,55,54,55,54,51,50,22,23,30,1,21,20,7,6,7,
6,7,6,35,34,39,38,39,38,39,38,1,52,55,54,55,54,55,
54,51,50,23,22,23,22,23,22,21,20,7,6,7,6,7,6,35,
34,39,38,39,38,39,38,1,20,23,22,50,54,53,52,39,38,35,
34,6,7,52,55,54,55,54,55,54,51,50,23,22,23,30,1,21,
20,7,6,7,6,7,6,35,34,39,38,39,38,39,38,3,134,40,
41,120,88,43,44,61,51,90,253,108,39,39,65,60,88,43,44,61,
53,90,193,150,2,210,143,254,135,19,19,37,36,50,51,61,48,100,
38,40,48,20,21,37,38,49,48,61,52,47,52,35,40,23,24,253,
110,19,19,37,36,50,51,60,49,50,50,38,40,24,24,20,21,37,
38,49,48,62,51,47,52,35,40,23,24,5,161,40,41,120,88,43,
44,61,51,90,129,19,19,37,36,50,51,60,49,50,50,38,40,48,
20,21,37,38,49,48,62,51,47,52,35,40,23,24,1,117,73,40,
41,82,72,66,42,42,78,2,121,72,40,41,82,71,66,42,42,78,
252,11,4,159,252,77,53,48,49,38,37,23,23,36,34,35,100,66,
55,46,48,37,37,23,22,17,19,32,37,47,49,3,4,53,48,49,
38,37,23,23,18,18,34,35,50,49,67,55,46,48,37,38,22,22,
17,19,32,37,47,50,253,129,73,40,41,82,72,66,42,42,78,72,
53,48,49,38,37,23,23,18,18,34,35,100,66,55,46,48,37,37,
23,22,17,19,32,37,47,49,0,9,0,115,0,105,10,68,5,69,
0,12,0,26,0,30,0,60,0,92,0,105,0,136,0,149,0,180,
0,0,1,20,23,22,50,54,53,52,39,38,35,34,6,1,20,23,
22,51,50,54,53,52,39,38,35,34,6,19,35,1,51,1,52,55,
54,55,54,55,54,51,50,22,23,30,1,21,20,7,6,7,6,7,
6,35,34,39,38,39,38,39,38,1,52,55,54,55,54,55,54,51,
50,23,22,23,22,23,22,21,20,7,6,7,6,7,6,35,34,39,
38,39,38,39,38,1,20,23,22,50,54,53,52,39,38,35,34,6,
7,52,55,54,55,54,55,54,51,50,23,22,23,30,1,21,20,7,
6,7,6,7,6,35,34,39,38,39,38,39,38,37,20,23,22,50,
54,53,52,39,38,35,34,6,7,52,55,54,55,54,55,54,51,50,
23,22,23,30,1,21,20,7,6,7,6,7,6,35,34,39,38,39,
38,39,38,3,134,40,41,120,88,43,44,61,51,90,253,108,39,39,
65,60,88,43,44,61,53,90,193,150,2,210,143,254,135,19,19,37,
36,50,51,61,48,100,38,40,48,20,21,37,38,49,48,61,52,47,
52,35,40,23,24,253,110,19,19,37,36,50,51,60,49,50,50,38,
40,24,24,20,21,37,38,49,48,62,51,47,52,35,40,23,24,5,
161,40,41,120,88,43,44,61,51,90,129,19,19,37,36,50,51,60,
49,50,50,38,40,48,20,21,37,38,49,48,62,51,47,52,35,40,
23,24,3,15,40,41,120,88,43,44,61,51,90,129,19,19,37,36,
50,51,60,49,50,50,38,40,48,20,21,37,38,49,48,62,51,47,
52,35,40,23,24,1,117,73,40,41,82,72,66,42,42,78,2,121,
72,40,41,82,71,66,42,42,78,252,11,4,159,252,77,53,48,49,
38,37,23,23,36,34,35,100,66,55,46,48,37,37,23,22,17,19,
32,37,47,49,3,4,53,48,49,38,37,23,23,18,18,34,35,50,
49,67,55,46,48,37,38,22,22,17,19,32,37,47,50,253,129,73,
40,41,82,72,66,42,42,78,72,53,48,49,38,37,23,23,18,18,
34,35,100,66,55,46,48,37,37,23,22,17,19,32,37,47,49,67,
73,40,41,82,72,66,42,42,78,72,53,48,49,38,37,23,23,18,
18,34,35,100,66,55,46,48,37,37,23,22,17,19,32,37,47,49,
0,1,0,129,4,143,1,23,6,6,0,22,0,0,19,39,52,55,
54,59,1,50,23,22,23,22,21,7,6,7,6,35,34,39,38,39,
38,150,21,21,22,29,4,25,20,22,5,2,21,1,17,16,21,19,
14,11,8,1,4,191,251,36,20,20,14,15,27,16,4,251,21,14,
13,10,7,22,2,0,0,0,0,2,0,129,4,143,2,44,6,6,
0,21,0,44,0,0,1,39,52,54,59,1,50,23,22,23,22,21,
7,6,7,6,35,34,39,38,39,38,37,39,52,55,54,59,1,50,
23,22,23,22,21,7,6,7,6,35,34,39,38,39,38,1,171,21,
44,28,4,26,20,21,5,2,21,1,17,16,21,20,14,10,8,1,
254,235,21,21,22,29,4,25,20,22,5,2,21,1,17,16,21,19,
14,11,8,1,4,191,251,36,40,14,14,28,16,4,251,21,14,13,
10,6,23,2,7,251,36,20,20,14,15,27,16,4,251,21,14,13,
10,7,22,2,0,1,0,70,1,68,1,142,3,138,0,5,0,0,
1,51,3,19,35,3,1,6,136,193,193,136,192,3,138,254,221,254,
221,1,35,0,0,1,0,109,1,68,1,181,3,138,0,5,0,0,
27,1,3,35,19,3,244,193,193,135,192,192,3,138,254,221,254,221,
1,35,1,35,0,4,0,103,255,243,2,127,5,203,0,16,0,34,
0,51,0,70,0,0,1,20,7,6,35,38,39,38,53,3,52,54,
51,50,23,22,21,3,52,54,51,50,23,22,23,22,21,20,6,35,
34,39,38,39,38,3,20,7,6,35,38,39,38,53,3,52,55,54,
51,50,22,21,3,52,54,51,50,23,22,23,22,21,20,7,6,35,
34,39,38,39,38,2,86,18,19,21,27,15,17,41,60,38,40,30,
31,219,64,44,40,28,29,8,2,62,45,40,28,30,7,3,139,17,
19,22,27,15,17,41,29,30,39,41,60,219,64,44,39,29,29,8,
2,32,31,44,39,29,30,7,3,1,184,26,16,17,2,15,17,25,
3,181,40,54,27,28,37,250,239,44,64,24,25,36,10,13,45,62,
24,25,36,10,1,102,26,16,17,2,15,17,25,3,181,41,26,27,
54,38,250,239,44,64,24,25,36,10,13,44,32,31,24,25,36,10,
0,2,0,55,255,243,3,162,5,217,0,17,0,70,0,0,37,52,
54,51,50,23,22,23,22,21,20,6,35,34,39,38,39,38,19,63,
11,52,39,38,35,34,14,1,21,39,54,55,54,51,50,23,30,2,
21,20,7,6,7,6,15,4,21,35,53,3,52,54,51,50,23,22,
21,1,138,64,44,40,28,29,8,2,62,45,40,28,30,7,3,189,
11,52,20,20,18,16,15,13,10,8,4,2,77,75,126,83,138,72,
146,20,121,122,169,88,76,79,124,76,37,38,61,32,30,62,50,36,
13,157,18,60,38,40,30,31,94,44,64,24,25,36,10,13,45,62,
24,25,36,10,2,205,9,44,18,18,18,20,20,22,26,29,33,38,
125,69,68,90,124,57,25,165,111,111,25,26,94,158,96,97,73,75,
62,30,23,46,46,62,83,141,145,2,56,40,54,27,28,37,0,1,
0,1,0,0,6,99,1,160,0,15,0,0,37,6,7,6,35,34,
39,38,39,53,0,33,50,55,54,55,6,99,169,212,210,232,198,218,
217,178,1,127,1,182,216,214,215,168,238,110,64,64,62,62,114,178,
254,248,74,74,116,0,0,0,0,3,0,32,1,90,6,6,6,82,
0,9,0,19,0,29,0,0,1,39,7,19,39,33,27,1,33,7,
1,39,7,19,39,33,27,1,33,7,1,39,7,19,39,33,27,1,
33,7,3,239,220,220,84,220,1,16,84,84,1,16,220,1,227,220,
220,84,220,1,16,84,84,1,16,220,253,54,220,220,84,220,1,16,
84,84,1,16,220,3,173,160,160,1,2,160,1,3,254,253,160,252,
171,160,160,1,2,160,1,3,254,253,160,254,254,160,160,1,2,160,
1,3,254,253,160,0,0,1,0,47,1,167,2,153,4,17,0,15,
0,0,1,39,7,55,39,55,39,23,55,23,55,7,23,7,23,39,
1,100,56,162,82,173,173,82,162,56,56,162,82,173,173,82,162,1,
167,173,82,162,56,56,162,82,173,173,82,162,56,56,162,82,0,1,
254,34,255,109,2,219,6,63,0,3,0,0,5,35,1,51,254,184,
150,4,41,144,147,6,210,0,0,3,0,57,255,243,5,148,5,217,
0,17,0,36,0,139,0,0,37,52,54,51,50,23,22,23,22,21,
20,6,35,34,39,38,39,38,37,52,54,51,50,23,22,23,22,21,
20,7,6,35,34,39,38,39,38,1,21,35,53,52,55,54,55,54,
55,54,63,12,52,39,38,35,34,14,1,21,39,54,55,54,51,50,
23,22,23,54,55,51,50,23,22,23,22,23,22,20,7,6,7,6,
15,4,21,35,53,52,55,54,55,54,55,54,63,12,52,39,38,35,
34,7,22,23,22,21,20,7,6,7,6,15,3,1,140,64,44,40,
28,29,8,2,62,45,40,28,30,7,3,1,239,64,44,39,29,29,
8,2,32,31,44,39,29,30,7,3,254,194,157,11,11,14,15,27,
31,16,55,52,20,20,18,16,15,13,10,8,4,2,77,75,126,83,
138,72,146,20,121,122,169,88,76,57,44,77,153,17,69,78,79,62,
64,37,38,38,41,58,27,36,61,49,38,12,157,11,10,16,17,24,
31,16,54,53,20,19,18,17,15,12,10,8,6,1,77,75,126,67,
60,17,13,38,37,38,61,32,30,62,50,36,94,44,64,24,25,36,
10,13,45,62,24,25,36,10,12,44,64,24,25,36,10,13,44,32,
31,24,25,36,10,1,163,141,145,43,42,41,26,27,30,35,13,46,
44,18,18,18,20,20,22,26,29,33,38,125,69,68,90,124,57,25,
165,111,111,25,19,27,64,7,25,26,47,49,77,79,192,74,80,57,
25,28,46,46,62,83,141,145,43,42,38,29,30,27,35,13,46,44,
18,18,18,20,20,22,26,29,33,38,125,69,68,31,25,27,79,96,
97,73,75,62,30,23,46,46,62,0,0,4,0,57,255,243,4,16,
5,217,0,49,0,67,0,86,0,105,0,0,19,54,55,48,51,50,
23,30,2,21,20,7,6,7,6,15,4,21,35,53,52,55,54,55,
54,55,54,63,12,52,39,38,35,34,7,1,20,7,6,35,38,39,
38,53,3,52,55,54,51,50,23,22,21,3,52,54,51,50,23,22,
23,22,21,20,7,6,35,34,39,38,39,38,37,52,54,51,50,23,
22,23,22,21,20,7,6,35,34,39,38,39,38,57,77,153,17,69,
78,79,124,76,37,41,58,27,36,61,50,37,12,157,11,11,14,15,
27,32,15,54,53,20,19,18,17,15,12,10,8,5,2,77,75,126,
67,60,3,64,18,19,21,27,15,17,41,29,30,39,40,30,31,219,
64,44,39,29,29,8,2,32,31,44,39,29,30,7,3,253,141,64,
44,40,28,29,8,2,32,31,44,40,28,30,7,3,5,146,64,7,
25,26,94,158,96,97,73,80,57,25,28,46,46,62,83,141,145,43,
42,41,26,27,30,35,13,46,44,18,18,18,20,20,22,26,29,33,
38,125,69,68,31,252,139,26,16,17,2,15,17,25,3,181,41,26,
27,27,28,37,250,239,44,64,24,25,36,10,13,44,32,31,24,25,
36,10,12,44,64,24,25,36,10,13,44,32,31,24,25,36,10,0,
0,4,0,103,255,243,4,32,5,217,0,50,0,69,0,86,0,105,
0,0,1,54,55,48,51,50,23,22,23,22,23,22,20,7,6,7,
6,15,4,21,35,53,52,55,54,55,54,55,54,63,12,52,39,38,
35,34,7,19,52,54,51,50,23,22,23,22,21,20,7,6,35,34,
39,38,39,38,3,20,7,6,35,38,39,38,53,3,52,55,54,51,
50,22,21,3,52,54,51,50,23,22,23,22,21,20,7,6,35,34,
39,38,39,38,1,126,77,153,17,69,78,79,62,64,37,38,38,41,
58,27,36,61,49,38,12,157,11,10,16,17,24,32,15,54,53,20,
19,18,17,15,12,10,8,6,1,77,75,126,67,60,27,64,44,39,
29,29,8,2,32,31,44,39,29,30,7,3,238,17,19,22,27,15,
17,41,29,30,39,41,60,219,64,44,39,29,29,8,2,32,31,44,
39,29,30,7,3,5,146,64,7,25,26,47,49,77,79,192,74,80,
57,25,28,46,46,62,83,141,145,43,42,38,29,30,27,35,13,46,
44,18,18,18,20,20,22,26,29,33,38,125,69,68,31,251,49,44,
64,24,25,36,10,13,44,32,31,24,25,36,10,1,102,26,16,17,
2,15,17,25,3,181,41,26,27,54,38,250,239,44,64,24,25,36,
10,13,44,32,31,24,25,36,10,0,0,0,0,4,0,121,0,0,
3,246,5,117,0,8,0,29,0,36,0,60,0,0,1,34,38,35,
17,50,55,54,51,19,17,54,55,54,55,54,55,54,55,54,55,54,
53,52,39,38,39,38,39,38,3,17,34,7,6,35,17,5,33,17,
51,50,23,22,23,22,23,22,21,20,7,6,7,6,7,6,7,6,
7,6,7,1,234,20,180,17,9,100,80,28,143,42,19,24,32,27,
25,23,16,17,8,5,21,22,38,39,35,39,187,34,75,90,18,1,
104,254,0,197,140,121,119,102,99,57,58,8,10,25,26,31,32,47,
41,53,32,76,4,236,12,253,235,5,4,1,223,254,59,10,6,8,
14,12,20,18,24,26,34,28,21,50,39,41,26,27,16,18,251,203,
1,232,5,6,254,35,135,5,117,25,25,49,48,78,79,98,38,45,
47,41,43,25,26,23,20,17,10,17,0,2,0,131,0,232,4,1,
3,249,0,5,0,21,0,0,1,17,23,51,17,7,19,39,35,39,
38,39,38,39,38,53,52,37,54,59,1,17,2,144,215,2,215,215,
215,2,144,250,78,33,12,8,1,7,183,251,197,3,111,254,0,8,
2,21,13,253,121,10,20,54,110,45,62,40,42,215,111,76,252,245,
0,2,0,131,0,232,4,1,3,249,0,15,0,21,0,0,55,17,
51,50,23,4,21,20,7,6,7,6,15,1,35,7,19,39,17,51,
55,17,131,197,252,183,1,6,8,12,33,78,250,144,2,215,215,215,
2,215,238,3,11,76,111,215,42,40,62,45,110,54,20,10,2,135,
13,253,235,8,2,0,0,0,0,1,0,32,1,90,2,232,3,255,
0,9,0,0,1,39,7,19,39,33,27,1,33,7,2,96,220,220,
84,220,1,16,84,84,1,16,220,1,90,160,160,1,2,160,1,3,
254,253,160,0,0,0,0,2,0,113,255,35,1,72,3,163,0,26,
0,44,0,0,55,52,55,54,55,54,51,50,22,21,20,7,6,7,
6,35,20,23,7,39,38,39,38,39,38,39,38,17,52,55,54,51,
50,22,23,22,21,20,6,35,34,39,38,39,38,113,2,8,29,28,
40,44,64,3,7,30,28,40,72,56,21,19,14,19,13,20,8,9,
32,31,45,38,60,7,2,64,43,39,29,30,7,3,94,13,10,36,
25,24,64,44,12,10,35,25,24,74,104,31,29,30,24,34,28,43,
39,43,3,6,45,32,31,50,35,10,13,43,64,24,25,36,11,0,
0,0,0,3,0,62,0,136,3,172,5,39,0,18,0,37,0,41,
0,0,37,34,39,38,53,52,54,55,54,51,50,23,22,21,20,7,
6,7,6,1,34,38,53,52,55,54,55,54,51,50,23,22,21,20,
7,6,7,6,19,35,1,51,3,65,45,32,31,50,35,10,13,44,
31,32,24,21,40,11,253,94,44,64,24,25,36,10,13,44,32,31,
24,21,40,10,37,150,2,209,144,136,32,31,45,38,60,7,2,31,
32,44,39,29,25,12,3,3,189,64,44,39,29,29,8,2,32,31,
44,39,29,25,12,3,252,68,4,158,0,0,0,1,0,63,2,51,
2,188,3,92,0,43,0,0,19,54,55,62,1,51,50,23,22,23,
30,1,23,30,1,51,50,55,54,55,54,55,21,6,7,6,7,6,
35,34,39,38,39,38,39,38,39,38,35,34,6,7,6,7,63,24,
27,25,70,37,25,30,26,26,8,32,8,25,56,30,32,34,30,32,
27,33,49,11,27,33,34,34,32,32,30,27,16,34,26,23,26,22,
36,66,24,27,28,2,252,18,24,22,32,16,14,24,7,29,8,23,
30,15,13,25,21,24,145,38,9,23,14,15,15,14,24,14,32,25,
13,15,30,21,23,23,0,0,0,3,0,26,255,109,3,63,4,224,
0,19,0,37,0,55,0,0,19,50,23,22,21,20,7,6,7,6,
35,34,39,38,53,52,55,54,55,54,1,20,6,35,34,39,38,39,
38,53,52,54,51,50,23,22,23,22,17,20,6,35,34,39,38,39,
38,53,52,54,51,50,23,22,23,22,134,44,32,31,24,25,36,10,
12,45,31,32,24,20,42,10,2,197,62,45,38,30,31,7,2,64,
44,40,28,24,12,3,62,45,38,30,31,7,2,64,44,40,28,24,
12,3,2,146,32,31,45,40,28,29,8,2,31,32,44,40,28,25,
12,3,1,227,46,62,25,26,34,10,13,43,64,24,20,41,11,251,
89,46,62,25,26,34,10,13,43,64,24,20,41,11,0,4,0,26,
255,109,5,141,4,224,0,19,0,39,0,57,0,75,0,0,19,50,
23,22,21,20,7,6,7,6,35,34,39,38,53,52,55,54,55,54,
33,50,23,22,21,20,7,6,7,6,35,34,39,38,53,52,55,54,
55,54,1,20,6,35,34,39,38,39,38,53,52,54,51,50,23,22,
23,22,17,20,6,35,34,39,38,39,38,53,52,54,51,50,23,22,
23,22,134,44,32,31,24,25,36,10,12,45,31,32,24,20,42,10,
4,168,44,32,31,24,25,36,10,12,45,31,32,24,20,42,10,254,
41,62,45,38,30,31,7,2,64,44,40,28,24,12,3,62,45,38,
30,31,7,2,64,44,40,28,24,12,3,2,146,32,31,45,40,28,
29,8,2,31,32,44,40,28,25,12,3,32,31,45,40,28,29,8,
2,31,32,44,40,28,25,12,3,1,227,46,62,25,26,34,10,13,
43,64,24,20,41,11,251,89,46,62,25,26,34,10,13,43,64,24,
20,41,11,0,0,5,0,26,255,109,5,141,4,224,0,18,0,37,
0,56,0,74,0,92,0,0,1,50,23,22,21,20,6,7,6,35,
34,39,38,53,52,55,54,55,54,19,50,23,22,21,20,6,7,6,
35,34,39,38,53,52,55,54,55,54,1,50,23,22,21,20,6,7,
6,35,34,39,38,53,52,55,54,55,54,1,20,7,6,35,34,38,
39,38,53,52,54,51,50,23,22,23,22,17,20,7,6,35,34,38,
39,38,53,52,54,51,50,23,22,23,22,5,33,45,32,31,50,35,
10,13,44,31,32,24,21,40,11,11,45,32,31,50,35,10,13,44,
31,32,24,21,40,11,253,191,45,32,31,50,35,10,13,44,31,32,
24,21,40,11,254,39,32,31,45,38,60,7,2,64,43,39,29,25,
12,3,32,31,45,38,60,7,2,64,43,39,29,25,12,3,4,224,
32,31,45,38,60,7,2,31,32,44,40,28,25,12,3,251,100,32,
31,45,38,60,7,2,31,32,44,39,29,25,12,3,2,78,32,31,
45,38,60,7,2,31,32,44,40,28,25,12,3,1,227,45,32,31,
50,35,10,13,43,64,24,21,40,11,251,89,45,32,31,50,35,10,
13,43,64,24,21,40,11,0,0,0,0,2,0,100,1,190,1,59,
7,43,0,17,0,35,0,0,1,20,6,35,34,39,38,39,38,53,
52,54,51,50,23,22,23,22,19,20,6,35,34,39,38,39,38,53,
52,54,51,50,23,22,23,22,1,58,64,44,38,30,28,8,2,62,
44,41,27,26,12,2,1,62,45,40,28,31,7,2,64,44,38,30,
24,12,3,6,192,44,64,25,24,37,10,12,45,62,23,21,41,7,
251,91,46,62,24,26,34,10,14,43,64,25,20,40,10,0,0,0,
0,4,0,37,1,190,5,147,7,43,0,19,0,39,0,58,0,78,
0,0,19,50,23,22,21,20,7,6,7,6,35,34,39,38,53,52,
55,54,55,54,37,50,23,22,21,20,7,6,7,6,35,34,39,38,
53,52,55,54,55,54,1,20,6,35,34,39,38,39,38,53,52,55,
54,51,50,23,22,23,22,19,20,7,6,35,34,39,38,39,38,53,
52,55,54,51,50,23,22,23,22,144,45,31,32,24,26,35,10,13,
44,32,31,24,20,41,11,4,162,45,32,31,25,24,36,10,13,44,
31,32,24,22,39,7,254,47,64,44,38,30,29,8,2,32,31,44,
41,27,25,12,3,1,32,31,45,40,28,30,7,2,31,32,44,38,
30,25,12,3,4,223,31,32,44,40,28,31,7,2,32,31,45,40,
28,24,12,3,1,32,31,45,38,30,28,8,2,31,32,43,40,28,
26,12,2,1,224,44,64,25,25,36,10,12,44,32,31,23,20,42,
10,251,94,45,32,31,24,25,35,10,14,44,31,32,25,21,39,10,
0,0,0,3,0,100,0,0,1,60,5,115,0,18,0,37,0,56,
0,0,1,20,6,35,34,39,38,39,38,53,52,55,54,51,50,23,
22,23,22,17,20,6,35,34,39,38,39,38,53,52,55,54,51,50,
23,22,23,22,19,20,6,35,34,39,38,39,38,53,52,55,54,51,
50,23,22,23,22,1,59,64,44,40,28,29,8,2,32,31,44,39,
29,25,12,3,64,44,40,28,29,8,2,32,31,44,39,29,25,12,
3,1,64,44,38,30,31,7,2,32,31,45,41,27,23,13,4,5,
8,44,64,24,25,36,10,13,44,32,31,24,21,40,11,251,89,44,
64,24,25,36,10,13,44,32,31,24,21,40,11,2,69,44,64,25,
26,35,10,12,44,32,31,23,19,43,14,0,0,4,0,100,255,109,
1,60,7,43,0,17,0,35,0,53,0,72,0,0,1,20,6,35,
34,39,38,39,38,53,52,54,51,50,23,22,23,22,19,20,7,6,
35,34,38,39,38,53,52,54,51,50,23,22,23,22,17,20,7,6,
35,34,38,39,38,53,52,54,51,50,23,22,23,22,19,20,7,6,
35,34,39,38,39,38,53,52,54,51,50,23,22,23,22,1,58,64,
44,38,30,28,8,2,62,44,41,27,26,12,2,1,32,31,45,38,
60,7,2,64,43,39,29,25,12,3,32,31,45,38,60,7,2,64,
43,39,29,25,12,3,1,32,31,45,40,28,31,7,2,64,44,38,
30,24,12,4,6,192,44,64,25,24,37,10,12,45,62,23,21,41,
7,253,166,45,32,31,50,35,10,13,43,64,24,21,40,11,251,89,
45,32,31,50,35,10,13,43,64,24,21,40,10,2,69,45,32,31,
24,26,34,10,14,43,64,25,20,40,14,0,0,2,0,48,3,173,
2,81,6,236,0,22,0,49,0,0,19,54,55,62,1,51,50,22,
23,22,21,20,7,14,1,35,34,39,38,39,38,53,52,23,20,23,
22,23,22,51,50,54,55,54,55,54,53,52,39,38,39,38,35,34,
7,6,7,6,7,6,66,18,33,33,108,66,100,128,26,15,29,30,
126,88,99,67,65,26,15,149,13,15,29,28,38,26,48,16,16,9,
9,13,14,29,27,37,25,25,24,17,18,8,10,5,229,73,59,59,
72,150,119,72,77,113,88,92,120,76,74,119,70,74,82,82,58,62,
73,40,39,42,40,39,50,49,52,68,61,69,41,39,22,21,42,43,
48,57,0,1,0,49,3,173,1,64,6,203,0,5,0,0,19,35,
55,51,17,35,172,123,174,97,148,6,8,195,252,226,0,0,0,1,
0,68,3,173,2,80,6,222,0,66,0,0,19,39,55,54,55,54,
51,50,22,23,30,1,23,22,21,20,7,6,7,6,7,6,7,6,
7,6,15,2,6,7,14,1,15,1,33,21,33,53,52,55,54,55,
54,55,54,55,54,63,1,62,2,63,6,52,38,35,34,7,6,7,
202,134,9,22,74,73,88,38,68,32,33,46,14,14,8,8,12,12,
18,18,16,24,13,28,6,29,22,13,28,26,40,9,8,1,95,253,
244,15,17,19,23,32,33,28,20,46,22,6,11,6,1,22,21,16,
14,8,4,60,38,40,32,35,14,5,205,53,30,79,56,55,18,21,
22,58,44,45,48,28,30,29,23,22,23,22,15,22,10,22,4,20,
14,8,27,25,44,17,16,140,35,52,48,54,32,39,33,34,24,17,
33,16,4,7,3,1,17,19,19,23,23,31,53,60,25,27,46,0,
0,1,0,51,3,173,2,83,6,238,0,62,0,0,19,55,23,30,
1,51,50,55,54,53,52,39,38,39,38,39,38,43,1,53,51,50,
55,54,53,52,38,43,1,34,7,6,15,1,39,55,54,55,54,51,
50,23,22,23,22,21,20,7,6,7,22,23,22,23,22,21,20,7,
6,35,34,38,39,51,144,13,16,60,32,56,38,37,11,9,20,19,
22,24,24,74,84,34,25,26,52,34,3,30,21,20,13,15,134,17,
32,57,58,72,56,56,53,35,35,19,18,26,23,21,23,15,14,81,
82,116,72,146,31,4,115,43,27,33,40,33,33,54,28,24,19,17,
16,7,8,132,27,28,40,36,50,15,15,28,32,62,32,62,37,37,
28,26,54,53,65,49,41,39,26,18,26,28,38,36,45,114,73,74,
88,74,0,0,0,2,0,65,3,173,2,130,6,203,0,9,0,12,
0,0,1,51,21,35,21,35,53,33,1,51,3,51,53,2,36,94,
94,148,254,177,1,87,140,245,99,5,0,140,199,199,2,87,254,54,
173,0,0,1,0,48,3,173,2,72,6,217,0,50,0,0,1,6,
7,6,7,6,7,14,1,7,6,15,1,39,19,33,21,33,7,54,
51,50,23,22,23,22,21,20,7,6,7,6,35,34,39,38,47,1,
55,23,22,51,50,54,53,52,39,46,1,35,34,1,45,10,13,7,
10,7,7,10,2,10,7,5,16,111,55,1,145,254,237,19,41,38,
95,67,69,19,7,30,29,62,59,80,98,70,72,25,11,146,10,34,
86,50,62,3,10,62,34,18,5,78,1,4,2,4,3,4,6,2,
8,6,3,8,57,1,133,140,125,9,57,58,92,32,38,73,63,61,
42,40,57,58,90,37,26,28,99,74,65,17,17,46,58,0,0,0,
0,2,0,48,3,173,2,55,6,216,0,18,0,49,0,0,1,52,
39,38,39,38,35,34,7,6,21,20,23,22,23,22,51,50,54,3,
50,23,22,23,22,21,20,7,6,7,14,1,35,34,39,38,39,38,
53,52,55,54,55,54,55,54,63,1,19,51,1,167,3,9,31,32,
43,49,31,32,2,8,31,32,40,51,66,118,95,70,73,19,5,19,
21,31,32,104,56,98,66,69,18,5,6,4,16,12,9,2,15,25,
177,157,4,170,12,13,40,25,26,34,35,45,17,7,38,24,24,66,
1,46,57,59,89,23,32,46,44,48,34,35,46,59,62,83,20,31,
32,32,23,39,30,18,4,27,42,1,53,0,0,1,0,50,3,173,
2,108,6,202,0,5,0,0,9,1,35,1,33,53,2,108,254,208,
167,1,2,254,155,6,202,252,227,2,141,144,0,3,0,58,3,173,
2,99,6,238,0,37,0,54,0,73,0,0,1,22,23,22,21,20,
7,22,23,22,23,22,21,20,6,7,6,35,34,39,38,39,38,53,
52,55,54,55,54,55,38,39,38,53,52,54,51,50,7,20,23,22,
23,22,51,50,54,53,52,39,46,1,35,34,6,19,50,55,54,53,
52,39,38,39,38,35,34,6,21,20,23,22,23,22,1,230,65,18,
4,65,21,32,33,13,4,76,65,64,74,97,76,75,20,6,15,15,
25,26,18,45,14,5,138,102,89,180,2,6,24,25,35,41,50,2,
6,46,38,45,46,90,53,39,38,2,9,35,37,45,57,70,3,9,
34,36,6,190,48,79,20,27,94,61,15,32,33,63,20,28,76,120,
35,34,59,59,92,27,28,47,39,38,27,28,13,42,62,21,29,96,
126,222,15,7,31,16,17,46,40,6,14,28,34,46,254,6,37,36,
51,19,8,41,25,26,64,55,14,13,42,27,28,0,0,0,0,2,
0,45,3,173,2,52,6,221,0,19,0,58,0,0,19,20,23,22,
23,22,51,50,55,54,53,52,39,38,39,38,35,34,7,6,19,34,
39,38,39,38,53,52,55,54,55,54,55,54,55,54,51,50,23,22,
23,22,21,20,7,6,7,14,1,7,6,7,14,2,21,3,35,19,
190,2,9,31,32,43,50,31,32,3,9,30,33,39,50,34,32,117,
94,71,72,19,6,12,13,22,22,32,30,44,42,46,96,69,68,18,
5,6,7,12,5,14,2,7,17,5,9,4,172,164,168,5,222,16,
8,40,25,26,34,35,44,12,12,40,23,25,34,32,254,208,58,58,
90,27,27,38,36,38,31,31,26,24,16,15,60,59,86,28,22,33,
32,34,28,11,32,5,15,28,8,14,6,1,254,198,1,45,0,1,
0,70,4,10,2,6,5,206,0,11,0,0,19,53,51,21,51,21,
35,21,35,53,35,53,224,140,154,154,140,154,5,51,155,155,141,156,
156,141,0,1,0,80,4,155,2,52,5,40,0,3,0,0,19,33,
21,33,80,1,228,254,28,5,40,141,0,0,0,2,0,64,4,103,
2,22,5,170,0,3,0,7,0,0,19,33,21,33,17,33,21,33,
64,1,214,254,42,1,214,254,42,4,244,141,1,67,140,0,0,1,
0,60,3,108,1,114,6,228,0,19,0,0,19,38,53,52,55,54,
63,1,51,7,6,21,20,23,22,31,1,35,39,38,93,33,32,30,
63,10,175,38,126,35,34,57,38,175,10,60,4,68,111,120,103,114,
108,99,17,55,182,209,101,103,99,84,55,16,94,0,0,0,0,1,
0,51,3,114,1,104,6,234,0,21,0,0,19,35,55,54,55,54,
53,52,39,38,47,1,51,23,22,23,22,21,20,7,6,7,224,173,
37,61,32,33,35,36,55,37,173,10,57,34,35,32,32,62,3,114,
55,91,100,100,95,101,104,107,80,55,17,90,111,116,113,109,111,110,
95,0,0,1,0,66,3,173,2,38,6,26,0,33,0,0,19,35,
17,51,21,54,51,50,23,22,23,22,23,22,21,17,35,17,52,39,
38,39,38,39,38,35,34,7,6,7,6,7,6,21,212,146,146,50,
68,47,42,39,32,29,15,16,146,6,6,13,13,16,19,21,24,18,
19,11,11,8,7,3,173,2,95,22,36,20,19,41,37,62,64,73,
254,207,1,49,43,33,31,25,24,10,12,12,12,23,22,35,31,43,
0,0,0,2,0,48,254,185,2,81,1,248,0,22,0,49,0,0,
55,54,55,62,1,51,50,22,23,22,21,20,7,14,1,35,34,39,
38,39,38,53,52,23,20,23,22,23,22,51,50,54,55,54,55,54,
53,52,39,38,39,38,35,34,7,6,7,6,7,6,66,18,33,33,
108,66,100,128,26,15,29,30,126,88,99,67,65,26,15,149,13,15,
29,28,38,26,48,16,16,9,9,13,14,29,27,37,25,25,24,17,
18,8,10,241,73,59,59,72,150,119,72,77,113,88,92,120,76,74,
119,70,74,81,81,58,62,73,40,39,42,40,39,50,49,52,68,61,
69,41,39,22,21,42,43,48,57,0,0,1,0,49,254,185,1,64,
1,215,0,5,0,0,19,35,55,51,17,35,172,123,174,97,148,1,
20,195,252,226,0,0,0,1,0,68,254,185,2,80,1,234,0,66,
0,0,55,39,55,54,55,54,51,50,22,23,30,1,23,22,21,20,
7,6,7,6,7,6,7,6,7,6,15,2,6,7,14,1,15,1,
33,21,33,53,52,55,54,55,54,55,54,55,54,63,1,62,2,63,
6,52,38,35,34,7,6,7,202,134,9,22,74,73,88,38,68,32,
33,46,14,14,8,8,12,12,18,18,16,24,13,28,6,29,22,13,
28,26,40,9,8,1,95,253,244,15,17,19,23,32,33,28,20,46,
22,6,11,6,1,22,21,16,14,8,4,60,38,40,32,35,14,217,
53,30,79,56,55,18,21,22,58,44,45,48,28,30,29,23,22,23,
22,15,22,10,22,4,20,14,8,27,25,44,17,16,140,35,52,48,
54,32,39,33,34,24,17,33,16,4,7,3,1,17,19,19,23,23,
31,53,60,25,27,46,0,0,0,1,0,51,254,185,2,83,1,250,
0,62,0,0,23,55,23,30,1,51,50,55,54,53,52,39,38,39,
38,39,38,43,1,53,51,50,55,54,53,52,38,43,1,34,7,6,
15,1,39,55,54,55,54,51,50,23,22,23,22,21,20,7,6,7,
22,23,22,23,22,21,20,7,6,35,34,38,39,51,144,13,16,60,
32,56,38,37,11,9,20,19,22,24,24,74,84,34,25,26,52,34,
3,30,21,20,13,15,134,17,32,57,58,72,56,56,53,35,35,19,
18,26,23,21,23,15,14,81,82,116,72,146,31,129,43,27,33,40,
33,33,54,28,24,19,17,16,7,8,132,27,28,40,36,50,15,15,
28,32,62,32,62,37,37,28,26,54,53,65,49,41,39,26,18,26,
28,38,36,45,114,73,74,88,74,0,0,0,0,2,0,65,254,185,
2,130,1,215,0,9,0,12,0,0,37,51,21,35,21,35,53,33,
1,51,3,51,53,2,36,94,94,148,254,177,1,87,140,245,99,12,
140,199,199,2,87,254,54,173,0,0,0,1,0,48,254,185,2,72,
1,229,0,51,0,0,37,6,7,6,7,6,7,14,2,7,6,15,
1,39,19,33,21,33,7,54,51,50,23,22,23,22,21,20,7,6,
7,6,35,34,39,38,47,1,55,23,22,51,50,54,53,52,39,46,
1,35,34,1,45,10,13,7,10,2,12,2,8,2,10,7,5,16,
111,55,1,145,254,237,19,41,38,95,67,69,19,7,30,29,62,59,
80,98,70,72,25,11,146,10,34,86,50,62,3,10,62,34,18,90,
1,4,2,4,1,7,1,4,2,8,6,3,8,57,1,133,140,125,
9,57,58,92,32,38,73,63,61,42,40,57,58,90,37,26,28,99,
74,65,18,16,46,58,0,0,0,2,0,48,254,185,2,55,1,228,
0,18,0,49,0,0,5,52,39,38,39,38,35,34,7,6,21,20,
23,22,23,22,51,50,54,3,50,23,22,23,22,21,20,7,6,7,
14,1,35,34,39,38,39,38,53,52,55,54,55,54,55,54,63,1,
19,51,1,167,3,9,31,32,43,49,31,32,2,8,31,32,40,51,
66,118,95,70,73,19,5,19,21,31,32,104,56,98,66,69,18,5,
6,4,16,12,9,2,15,25,177,157,74,12,13,40,25,26,34,35,
45,17,7,38,24,24,66,1,46,57,59,89,22,33,46,44,48,34,
35,46,59,62,83,20,31,32,32,23,39,30,18,4,27,42,1,53,
0,0,0,1,0,50,254,185,2,108,1,214,0,5,0,0,9,1,
35,1,33,53,2,108,254,208,167,1,2,254,155,1,214,252,227,2,
141,144,0,3,0,58,254,185,2,99,1,250,0,37,0,54,0,73,
0,0,1,22,23,22,21,20,7,22,23,22,23,22,21,20,6,7,
6,35,34,39,38,39,38,53,52,55,54,55,54,55,38,39,38,53,
52,54,51,50,7,20,23,22,23,22,51,50,54,53,52,39,46,1,
35,34,6,19,50,55,54,53,52,39,38,39,38,35,34,6,21,20,
23,22,23,22,1,230,65,18,4,65,21,32,33,13,4,76,65,64,
74,97,76,75,20,6,15,15,25,26,18,45,14,5,138,102,89,180,
2,6,24,25,35,41,50,2,6,46,38,45,46,90,53,39,38,2,
9,35,37,45,57,70,3,9,34,36,1,202,48,79,20,27,94,61,
15,32,33,63,20,28,76,120,35,34,59,59,92,27,28,47,39,38,
27,28,13,42,61,21,30,96,126,222,15,7,31,16,17,46,40,6,
14,28,34,46,254,6,37,36,51,19,8,41,25,26,64,55,14,13,
42,27,28,0,0,0,0,2,0,45,254,185,2,52,1,233,0,19,
0,58,0,0,55,20,23,22,23,22,51,50,55,54,53,52,39,38,
39,38,35,34,7,6,19,34,39,38,39,38,53,52,55,54,55,54,
55,54,55,54,51,50,23,22,23,22,21,20,7,6,7,14,1,7,
6,7,14,2,21,3,35,19,190,2,9,31,32,43,50,31,32,3,
9,30,33,39,50,34,32,117,94,71,72,19,6,12,13,22,22,32,
30,44,42,46,96,69,68,18,5,6,7,12,5,14,2,7,17,5,
9,4,172,164,168,234,16,8,40,25,26,34,35,44,12,12,40,23,
25,34,32,254,208,58,58,90,27,27,38,36,38,31,31,26,24,16,
15,60,59,86,28,22,34,31,34,28,11,32,5,15,28,8,14,6,
1,254,198,1,45,0,0,1,0,70,255,22,2,6,0,218,0,11,
0,0,55,53,51,21,51,21,35,21,35,53,35,53,224,140,154,154,
140,154,63,155,155,141,156,156,141,0,0,1,0,80,255,167,2,52,
0,52,0,3,0,0,55,33,21,33,80,1,228,254,28,52,141,0,
0,0,0,2,0,64,255,115,2,22,0,182,0,3,0,7,0,0,
51,33,21,33,17,33,21,33,64,1,214,254,42,1,214,254,42,141,
1,67,140,0,0,0,0,1,0,60,254,120,1,114,1,240,0,19,
0,0,23,38,53,52,55,54,63,1,51,7,6,21,20,23,22,31,
1,35,39,38,93,33,32,30,63,10,175,38,126,35,34,57,38,175,
10,60,176,111,120,103,114,108,99,17,55,181,210,101,103,99,84,55,
16,94,0,1,0,51,254,126,1,104,1,246,0,21,0,0,19,35,
55,54,55,54,53,52,39,38,47,1,51,23,22,23,22,21,20,7,
6,7,224,173,37,60,33,33,35,36,55,37,173,10,57,34,35,32,
32,62,254,126,55,90,101,100,95,101,104,107,80,55,17,90,111,116,
113,109,111,110,95,0,0,2,0,63,254,170,2,12,1,32,0,12,
0,44,0,0,5,34,6,21,20,22,51,50,55,54,53,52,38,19,
6,7,6,35,34,39,38,53,52,55,54,51,50,23,38,39,38,35,
34,7,6,15,1,39,55,54,50,22,21,17,35,1,44,40,50,50,
40,32,27,25,52,52,16,18,33,33,94,64,63,65,66,90,59,37,
6,13,22,43,31,21,24,11,29,83,26,75,196,130,140,36,50,34,
36,48,25,24,35,36,48,254,238,11,7,14,62,62,98,95,63,64,
23,27,16,28,8,9,11,29,111,22,62,136,116,254,149,0,0,2,
0,39,254,185,2,11,1,48,0,10,0,50,0,0,55,51,38,39,
38,35,34,7,6,7,6,23,22,23,22,51,50,55,54,63,1,23,
7,14,1,35,34,38,39,38,53,52,55,54,55,54,51,50,23,30,
1,23,22,29,1,20,22,29,1,33,22,194,181,7,24,22,38,26,
20,22,9,7,8,9,21,20,26,29,25,28,10,15,131,18,30,122,
68,77,114,27,27,27,27,58,56,77,58,47,49,54,16,14,1,254,
183,4,60,36,37,33,19,21,23,18,210,25,20,19,14,16,19,28,
54,34,59,68,90,71,70,87,85,71,69,45,43,27,28,84,53,48,
59,24,7,16,1,35,19,0,0,0,0,2,0,42,254,185,2,37,
1,48,0,23,0,47,0,0,55,54,55,54,55,54,51,50,22,23,
22,20,7,6,7,6,35,34,39,38,39,38,53,52,23,20,23,22,
23,30,1,51,50,55,54,55,54,55,54,53,52,39,38,39,38,34,
14,1,58,15,32,30,51,49,61,82,116,28,27,27,27,58,59,82,
82,58,59,27,28,147,8,9,11,14,36,29,28,18,20,13,11,9,
7,12,12,23,24,70,48,24,111,56,44,42,26,25,86,71,69,174,
71,70,45,45,45,45,71,73,84,61,61,40,35,38,20,25,22,11,
12,24,20,38,31,44,55,39,40,20,21,42,78,0,0,1,0,52,
254,185,2,71,1,23,0,11,0,0,1,35,39,7,35,19,3,51,
23,55,51,3,2,71,167,99,95,170,177,176,167,96,95,167,176,254,
185,181,181,1,48,1,46,178,178,254,213,0,0,2,0,26,254,185,
1,254,1,49,0,10,0,53,0,0,5,35,22,23,22,51,50,55,
54,55,54,39,38,39,38,35,34,7,6,15,1,39,55,54,55,54,
51,50,23,22,23,22,21,20,7,6,7,6,35,34,39,38,39,38,
39,38,53,48,53,48,61,1,33,38,1,98,181,7,24,22,38,24,
22,22,9,7,8,9,21,20,26,27,27,28,10,15,131,18,30,61,
62,67,76,58,57,27,28,28,26,59,58,75,58,47,48,28,27,16,
14,1,72,4,82,36,37,34,20,21,23,18,210,25,20,19,15,16,
19,28,54,34,59,34,35,46,45,71,73,84,83,73,68,45,44,27,
28,43,42,53,48,58,24,24,36,19,0,1,0,253,2,68,3,9,
4,73,0,19,0,0,19,52,55,54,51,50,23,22,23,22,21,20,
7,6,35,34,39,38,39,38,253,77,76,109,95,71,70,21,5,77,
78,107,94,71,70,21,6,3,71,108,75,75,58,56,91,23,30,108,
75,76,58,58,89,25,0,1,0,253,2,68,3,9,4,73,0,19,
0,0,19,52,55,54,51,50,23,22,23,22,21,20,7,6,35,34,
39,38,39,38,253,77,76,109,95,71,70,21,5,77,78,107,94,71,
70,21,6,3,71,108,75,75,58,56,91,23,30,108,75,76,58,58,
89,25,0,1,0,178,0,0,3,230,5,42,0,41,0,0,33,17,
38,39,38,53,52,55,54,55,54,55,54,51,50,22,23,7,38,35,
34,7,6,7,6,7,6,21,20,22,23,17,33,21,33,21,33,21,
33,21,33,21,1,170,109,70,69,27,27,47,46,69,68,81,89,130,
66,125,74,86,42,39,37,30,30,18,17,52,44,2,60,254,86,1,
146,254,110,1,170,1,154,44,114,112,171,95,85,86,65,64,38,38,
80,96,64,101,25,24,43,43,62,58,77,85,140,44,1,56,140,225,
142,248,139,0,0,3,0,117,0,0,4,36,6,10,0,51,0,57,
0,64,0,0,1,6,7,6,35,34,39,38,39,7,35,55,38,39,
7,35,19,38,39,38,53,52,55,54,55,62,1,63,1,51,7,50,
23,22,23,55,51,7,22,23,7,38,39,1,22,23,22,51,50,54,
63,1,3,38,35,1,22,23,19,6,7,6,21,20,23,4,36,84,
94,96,130,25,24,35,14,15,158,29,32,31,41,158,78,52,31,30,
30,32,51,55,150,94,39,158,35,15,24,13,22,37,157,51,77,63,
119,22,38,254,235,16,16,20,12,81,128,43,37,213,42,32,254,248,
28,31,33,100,60,60,25,1,21,125,53,54,3,4,3,55,109,18,
25,152,1,33,81,112,108,136,123,111,117,84,90,124,27,144,127,2,
1,6,136,193,50,96,59,35,31,251,246,4,2,2,54,59,51,3,
179,11,252,42,35,27,3,220,67,137,136,172,107,98,0,1,0,64,
255,225,4,89,5,216,0,74,0,0,1,23,6,7,6,35,34,39,
38,39,38,2,53,52,55,54,55,54,55,54,51,50,23,22,23,7,
38,39,38,43,1,34,7,6,7,6,7,6,21,20,23,22,23,22,
23,22,23,17,51,21,54,55,54,55,54,55,54,51,50,23,7,38,
35,34,7,6,7,14,1,21,17,50,55,54,55,3,216,129,94,105,
108,142,119,111,108,84,82,96,44,42,82,80,110,111,133,149,102,105,
77,131,46,83,80,93,2,93,79,81,57,60,32,32,20,20,39,36,
54,53,60,152,17,26,29,31,34,33,37,33,116,89,66,68,71,46,
44,43,33,32,42,90,70,73,46,1,37,67,137,59,61,50,49,99,
97,1,26,180,157,143,137,108,105,60,60,59,61,115,66,66,48,46,
49,50,84,87,113,112,134,107,87,89,77,73,58,58,29,3,158,152,
35,31,35,23,25,14,16,55,124,42,24,24,42,41,120,69,253,235,
29,30,66,0,0,1,0,68,0,0,4,85,5,178,0,21,0,0,
51,17,35,53,51,53,35,53,51,17,33,21,33,17,33,21,33,21,
33,21,33,17,187,119,119,119,119,3,154,253,3,2,210,253,46,2,
210,253,46,1,121,135,216,135,2,83,142,254,59,135,216,135,254,135,
0,1,0,100,0,0,4,54,5,188,0,47,0,0,19,51,18,55,
54,51,50,19,7,38,39,38,35,34,7,6,29,1,33,21,33,7,
33,21,33,6,7,6,7,33,50,63,1,23,6,15,1,33,55,54,
55,54,55,35,53,51,55,35,100,238,24,224,10,15,221,107,144,33,
100,27,24,57,39,25,1,105,254,151,6,1,111,254,126,17,20,17,
34,1,249,55,43,18,80,45,121,43,253,59,84,32,2,12,13,203,
226,10,236,3,105,2,54,27,2,254,215,7,132,30,9,191,113,96,
62,141,135,142,79,70,60,111,49,23,115,68,18,6,250,100,8,40,
57,142,135,0,0,1,0,16,255,30,5,36,5,42,0,48,0,0,
33,35,17,52,39,38,35,34,7,3,17,35,53,3,35,1,53,52,
39,38,35,34,7,6,7,14,1,21,17,35,17,51,21,62,1,51,
50,23,54,55,19,51,7,59,1,50,23,22,21,5,36,152,43,43,
74,45,32,185,152,205,157,1,106,42,42,76,51,45,47,37,36,46,
152,152,63,122,77,204,73,45,48,145,158,105,6,7,160,72,73,2,
142,154,76,75,14,254,110,253,225,217,254,69,3,16,100,148,77,76,
23,24,40,39,110,63,253,108,4,50,152,99,76,205,69,48,1,57,
225,107,107,229,0,5,0,16,0,0,5,26,5,178,0,27,0,31,
0,35,0,38,0,41,0,0,1,21,35,17,35,3,33,17,35,17,
35,53,51,53,35,53,51,17,51,1,33,17,51,17,51,21,35,21,
41,1,39,33,5,51,53,33,37,51,3,1,53,35,5,26,119,146,
237,254,1,158,119,119,119,119,154,1,121,1,107,158,119,119,252,130,
1,171,136,254,221,2,85,139,254,235,254,53,205,205,2,224,53,2,
0,135,254,135,1,121,254,135,1,121,135,216,135,2,83,253,173,2,
83,253,173,135,216,216,216,216,135,1,72,252,128,82,0,3,0,16,
255,227,7,110,5,178,0,84,0,101,0,108,0,0,37,17,35,53,
51,53,51,21,51,21,35,17,20,51,48,51,37,50,55,54,55,54,
55,54,53,52,39,38,39,38,39,38,39,38,53,52,55,54,55,54,
55,54,59,1,50,23,22,23,22,23,22,23,7,38,35,34,7,6,
7,6,7,6,21,20,31,1,22,23,22,23,22,23,22,21,20,7,
6,7,14,1,35,33,34,39,38,5,17,51,50,23,22,23,22,23,
22,21,20,7,6,33,35,25,2,51,32,17,16,33,3,85,142,142,
151,197,197,110,7,1,154,46,36,41,29,30,18,18,218,107,62,67,
39,40,17,16,24,24,46,44,66,65,79,7,57,62,59,48,50,30,
32,10,141,40,172,36,36,40,24,29,15,16,153,43,104,74,67,46,
43,18,17,27,26,51,50,132,81,254,98,151,59,58,252,187,214,121,
102,99,73,71,41,40,141,142,254,248,56,56,1,129,254,127,211,2,
216,135,250,250,135,253,44,117,9,14,16,23,24,35,35,43,126,69,
35,32,35,36,37,43,41,49,61,54,55,41,39,25,24,16,15,30,
31,40,42,54,28,121,12,13,19,22,28,29,35,103,51,14,34,39,
36,44,42,46,44,56,65,60,58,45,44,54,61,59,91,5,178,26,
25,52,50,78,76,103,194,111,112,253,137,5,36,253,227,1,17,1,
12,0,0,2,0,16,255,227,6,94,5,178,0,104,0,122,0,0,
1,20,7,6,7,6,7,6,35,34,38,39,38,39,38,39,1,35,
17,35,17,33,50,23,22,23,30,1,21,20,7,6,7,6,7,6,
7,22,23,22,23,30,1,23,22,23,22,51,50,55,54,55,54,55,
54,53,52,38,39,38,39,38,39,46,1,53,52,55,54,55,54,55,
54,51,50,23,22,23,22,23,22,23,7,38,39,38,35,34,6,7,
6,7,6,21,20,23,22,23,22,23,22,23,22,23,22,1,52,39,
38,39,38,39,38,43,1,17,51,50,55,54,55,62,1,6,94,37,
39,54,54,74,72,66,76,166,68,74,62,61,48,254,223,216,158,1,
109,91,104,94,83,80,98,29,30,48,49,67,62,80,2,126,73,57,
40,90,48,50,56,57,65,38,44,39,41,35,25,24,84,63,84,52,
72,64,63,84,31,28,52,47,66,65,66,52,59,56,50,51,33,35,
12,141,23,61,63,64,34,72,26,32,15,18,42,38,67,50,86,70,
66,62,43,42,252,161,35,34,56,54,70,66,71,207,207,76,63,71,
53,55,68,1,41,75,59,63,41,42,23,23,22,25,27,46,45,71,
1,168,253,137,5,178,22,20,50,48,158,112,82,67,69,48,49,35,
32,16,3,192,111,80,57,64,15,15,3,3,12,11,26,22,38,36,
45,62,78,27,36,17,24,36,36,102,85,71,59,54,39,36,20,20,
14,13,29,29,42,44,57,28,70,25,26,22,20,25,25,30,36,56,
34,31,29,21,32,26,39,37,58,57,2,150,83,53,52,30,29,11,
10,253,227,11,12,29,30,106,0,0,0,7,0,16,0,0,6,63,
5,178,0,2,0,5,0,8,0,12,0,16,0,20,0,52,0,0,
1,11,1,1,23,55,33,23,63,2,35,23,33,39,35,7,33,55,
35,23,5,35,3,35,3,33,3,35,3,35,53,51,39,35,53,51,
3,51,19,51,19,51,19,51,19,51,3,51,21,35,7,51,3,120,
78,80,1,150,45,26,252,225,29,43,28,50,201,30,2,65,46,219,
45,2,62,31,201,49,1,236,246,57,220,82,254,141,80,223,60,244,
222,33,189,168,92,160,84,250,125,195,123,250,86,160,94,168,191,32,
223,3,95,1,111,254,145,254,26,195,195,195,195,135,216,216,216,216,
216,216,135,254,135,1,121,254,135,1,121,135,216,135,2,83,253,173,
2,46,253,210,2,83,253,173,135,216,0,2,0,16,0,0,5,20,
5,178,0,17,0,35,0,0,1,51,17,33,34,39,38,39,38,39,
38,53,17,51,17,16,33,51,5,35,17,33,50,23,22,23,22,23,
22,21,17,35,17,16,33,35,4,118,158,254,147,122,102,101,71,70,
42,40,162,1,130,207,252,56,158,1,109,122,102,99,73,71,41,40,
162,254,126,207,5,178,250,78,26,26,50,50,79,76,103,1,88,254,
168,254,243,141,5,178,26,25,52,50,78,76,103,254,167,1,89,1,
12,0,0,0,0,3,1,74,3,13,3,70,6,157,0,27,0,47,
0,51,0,0,1,35,17,35,53,6,7,6,35,34,38,53,52,55,
54,51,50,23,22,23,53,35,53,51,53,51,21,51,3,52,46,1,
39,38,35,34,6,21,20,22,51,50,55,54,55,54,55,54,1,53,
33,21,3,70,55,102,33,34,31,42,87,124,54,55,104,40,36,35,
27,150,150,102,55,153,22,36,27,24,33,48,62,62,48,31,24,26,
19,16,14,12,254,202,1,150,5,249,253,129,65,45,19,18,160,156,
135,87,88,22,22,38,112,93,71,71,254,79,41,84,56,19,17,118,
99,105,118,17,18,30,25,46,40,254,151,51,51,0,0,0,0,1,
0,135,0,211,3,188,4,172,0,48,0,0,1,35,53,51,62,1,
51,50,22,23,7,46,1,35,34,6,7,33,21,33,6,21,20,23,
33,21,33,30,1,51,50,54,55,23,14,4,35,34,38,39,35,53,
51,38,53,52,1,14,129,153,39,179,125,113,125,77,96,50,88,81,
60,95,31,1,14,254,206,3,3,1,44,254,247,34,105,48,69,92,
62,96,27,29,60,57,91,55,132,173,38,159,136,3,2,250,135,134,
165,58,75,96,51,43,90,74,135,28,27,32,30,135,77,87,43,68,
97,31,30,47,23,18,164,135,135,33,33,17,0,1,0,16,0,0,
4,226,5,178,0,19,0,0,33,35,1,7,17,35,17,35,53,51,
17,51,17,51,1,51,1,33,21,33,4,226,207,253,117,99,158,119,
119,158,76,2,119,193,253,133,1,158,254,102,2,142,103,253,217,2,
177,135,2,122,253,134,2,122,253,134,135,0,0,1,0,43,0,0,
4,112,5,178,0,23,0,0,1,33,17,37,21,5,21,37,21,5,
17,35,17,5,53,37,53,5,53,37,17,33,53,33,4,112,254,55,
1,53,254,203,1,53,254,203,158,254,178,1,78,254,178,1,78,254,
34,4,69,5,36,254,153,109,141,109,142,109,141,109,253,235,1,222,
119,141,119,142,119,141,119,1,158,142,0,4,1,2,0,0,3,124,
5,163,0,12,0,19,0,23,0,30,0,0,1,20,7,6,43,1,
21,35,17,51,50,23,22,7,52,43,1,21,51,50,9,1,51,9,
1,14,1,7,6,7,33,3,48,73,72,134,70,129,199,124,77,78,
133,146,70,70,146,254,87,1,13,102,1,7,254,196,6,49,12,23,
43,1,14,1,197,104,60,59,230,2,162,55,55,111,96,192,1,88,
2,230,253,26,2,9,17,148,38,71,134,0,0,0,0,2,0,166,
255,227,3,245,5,178,0,31,0,100,0,0,1,20,23,22,23,22,
23,22,51,50,55,54,55,54,55,54,53,52,39,38,39,38,39,38,
35,34,7,6,7,6,7,6,19,50,23,30,1,23,22,23,22,23,
30,1,23,22,23,22,23,22,21,20,7,6,7,6,7,6,35,34,
38,39,38,39,38,53,52,55,54,55,54,55,54,51,50,23,30,1,
23,30,1,23,52,39,38,39,38,39,38,39,38,39,38,35,34,7,
6,7,39,54,51,1,62,16,16,33,33,48,46,66,65,52,51,39,
34,23,21,26,25,44,43,61,59,66,53,41,44,25,27,15,14,14,
61,28,38,86,35,44,36,58,57,50,90,28,31,16,20,1,2,26,
25,53,53,79,79,112,109,162,51,49,25,24,25,25,47,49,70,70,
95,52,42,39,66,31,11,47,10,25,21,45,40,57,58,60,41,37,
37,45,19,38,30,28,14,28,13,1,199,55,60,61,52,53,34,33,
32,31,52,45,67,61,60,62,63,62,46,46,29,28,36,39,49,53,
56,53,3,185,1,1,14,13,17,24,38,62,54,148,70,77,68,85,
89,128,50,95,99,96,80,79,50,49,76,66,64,91,88,103,81,86,
85,65,67,42,42,11,10,36,28,10,44,9,62,83,69,82,72,59,
60,26,18,3,3,2,2,4,148,2,0,0,0,4,0,41,0,0,
4,114,5,178,0,4,0,39,0,44,0,55,0,0,1,33,21,51,
50,1,51,21,35,22,23,22,21,20,7,6,7,51,21,35,6,7,
6,43,1,17,35,17,35,53,51,53,35,53,51,53,33,50,23,22,
7,38,43,1,21,5,52,39,38,39,33,21,33,54,55,54,3,62,
254,0,207,205,1,39,113,70,1,2,1,1,2,1,70,113,60,126,
127,187,207,158,119,119,119,119,1,109,180,129,130,138,95,206,207,2,
80,1,2,1,253,180,2,76,1,2,1,3,87,80,1,209,135,10,
18,9,20,21,9,18,10,135,107,58,59,253,137,3,87,135,115,135,
218,54,55,109,76,76,192,20,9,18,10,115,10,18,9,0,0,0,
0,2,0,156,0,0,3,255,5,176,0,44,0,56,0,0,1,20,
7,6,7,6,7,6,7,21,35,53,38,39,38,39,38,39,38,53,
52,55,54,55,54,55,54,55,53,51,21,22,31,1,7,38,39,17,
54,55,54,55,35,53,51,1,17,6,7,6,7,6,7,6,21,20,
22,3,255,24,24,43,42,67,65,82,143,81,68,71,49,52,28,28,
26,27,49,48,71,68,88,143,151,85,35,133,68,70,84,54,52,5,
92,244,254,22,47,39,38,31,29,17,16,126,2,177,103,88,89,68,
66,47,45,15,168,168,15,43,45,69,74,96,97,125,108,92,95,76,
74,54,52,17,156,154,22,120,53,66,95,18,252,182,24,81,79,133,
142,254,57,3,66,18,39,38,56,52,71,67,77,167,216,0,0,0,
0,3,0,0,0,0,4,153,5,178,0,23,0,26,0,30,0,0,
33,35,3,33,3,35,19,35,53,51,55,33,53,33,19,51,19,33,
21,33,23,51,21,35,1,11,1,1,39,33,7,4,153,170,162,253,
253,164,166,174,174,223,50,254,239,1,64,205,127,205,1,64,254,239,
49,224,175,254,215,117,112,1,59,43,254,197,41,1,228,254,28,1,
228,135,135,136,2,56,253,200,136,135,135,1,150,1,111,254,145,254,
243,133,133,0,0,1,0,43,255,225,4,110,5,216,0,92,0,0,
1,33,6,21,20,22,23,22,23,22,51,50,55,54,55,54,55,54,
55,23,14,1,35,34,39,38,39,38,39,38,53,52,55,54,55,35,
53,51,54,55,54,55,54,55,54,55,33,53,33,54,53,52,39,38,
39,38,39,38,35,34,6,7,39,54,55,54,55,54,55,54,51,50,
23,22,23,22,23,22,21,20,7,51,21,35,6,7,6,7,6,7,
6,7,33,4,110,252,171,12,56,47,48,59,60,64,69,54,55,45,
44,39,41,32,135,86,254,174,93,89,92,67,69,43,43,1,2,1,
68,117,28,49,44,59,46,65,28,72,254,4,3,25,60,25,24,40,
41,53,51,59,105,176,53,125,47,45,47,54,51,68,60,87,85,83,
81,64,65,38,39,29,105,222,62,62,80,51,88,44,66,59,2,222,
1,220,30,36,68,110,39,40,21,21,19,19,35,34,48,51,50,80,
148,170,30,31,54,56,78,79,101,27,12,18,21,135,38,34,30,29,
22,25,11,26,135,60,76,59,50,49,32,33,18,17,92,92,79,66,
45,47,30,28,16,14,27,26,54,54,72,74,92,75,61,135,42,23,
30,16,28,15,22,39,0,2,0,195,0,0,3,216,5,176,0,43,
0,60,0,0,1,6,7,6,7,21,35,53,38,39,38,39,46,1,
53,52,55,54,55,54,55,54,55,53,51,21,22,23,22,23,7,38,
39,46,3,39,17,54,55,54,63,1,1,14,1,7,6,7,6,7,
6,21,20,22,23,22,23,22,23,3,216,71,82,55,65,143,49,47,
82,62,61,72,33,34,58,60,82,49,57,143,69,53,80,61,107,37,
60,7,15,14,15,8,27,23,51,35,32,254,201,13,24,12,59,41,
43,23,25,50,42,42,59,23,24,1,123,106,45,31,10,187,189,9,
22,38,73,73,210,136,120,105,107,76,78,46,28,11,135,132,10,31,
47,90,53,52,35,4,8,6,5,2,252,123,5,10,21,50,45,2,
255,5,12,7,37,62,64,83,89,93,95,172,58,59,35,14,8,0,
0,1,0,144,255,227,4,9,5,176,0,25,0,0,5,34,39,38,
53,17,33,17,35,17,35,53,51,17,51,17,33,17,51,17,51,21,
35,17,20,51,4,9,140,66,64,254,192,152,147,147,152,1,64,151,
119,119,119,29,58,57,117,2,148,252,161,3,95,135,1,202,254,54,
1,202,254,54,135,253,112,105,0,4,0,76,255,172,4,79,5,216,
0,106,0,117,0,128,0,150,0,0,1,20,7,14,1,7,6,7,
21,35,53,35,34,39,21,35,53,38,39,21,35,17,38,39,46,1,
39,38,39,38,53,52,54,53,54,55,54,55,54,23,30,1,29,1,
54,55,54,51,50,23,62,1,51,50,22,29,1,54,55,54,55,54,
55,54,53,52,37,39,36,17,52,55,54,55,54,55,54,51,50,23,
22,31,1,7,38,39,38,35,34,7,6,7,14,1,21,20,23,22,
31,1,22,23,22,23,22,23,22,1,52,35,34,7,6,29,1,22,
51,55,39,53,52,35,34,7,6,7,22,23,22,39,53,52,39,38,
35,34,7,6,29,1,22,23,22,31,1,22,23,20,22,23,22,4,
79,30,30,108,75,79,84,84,6,75,52,103,71,62,84,12,10,5,
13,3,19,6,16,1,3,29,17,19,20,21,22,36,6,25,24,33,
84,29,31,56,36,69,60,52,44,46,32,34,17,19,254,147,22,254,
110,35,34,62,63,81,82,98,135,107,109,71,37,125,51,85,85,113,
61,54,51,42,41,44,51,52,104,143,121,93,87,48,47,22,21,254,
22,45,40,25,23,63,64,6,236,45,40,20,22,6,22,43,45,194,
8,7,14,10,3,2,2,3,5,5,4,4,2,8,2,3,1,142,
81,70,71,110,38,40,11,61,53,19,72,94,33,76,203,1,15,12,
15,7,23,4,28,11,23,31,1,8,1,34,17,10,2,2,8,8,
36,18,49,41,16,15,86,48,38,90,92,113,18,34,35,44,46,52,
57,50,196,101,6,111,1,17,82,75,73,54,56,29,30,46,47,101,
52,79,88,48,48,18,17,36,35,94,58,70,57,58,37,51,44,42,
39,46,44,63,60,254,213,104,25,23,54,111,19,3,36,89,104,20,
22,46,36,28,30,162,71,12,11,10,6,6,5,5,14,8,12,7,
7,7,3,1,9,3,5,0,0,2,0,43,0,0,4,112,5,178,
0,3,0,11,0,0,19,53,33,21,5,33,21,33,17,35,17,33,
43,4,69,251,187,4,69,254,55,158,254,34,5,36,142,142,141,142,
251,247,4,9,0,0,0,1,0,131,0,0,4,22,5,178,0,58,
0,0,1,7,35,22,23,22,23,51,21,7,35,6,7,6,7,6,
7,14,1,7,6,35,7,1,21,35,1,53,51,50,22,51,50,55,
54,55,54,55,54,55,54,63,1,39,33,39,55,33,55,38,39,46,
1,39,38,43,1,53,55,4,22,82,222,26,13,17,8,237,79,152,
6,17,16,23,28,41,39,104,48,53,47,5,1,199,184,254,34,15,
15,56,15,58,51,53,48,47,34,36,17,3,2,3,2,254,16,2,
84,1,134,4,12,22,21,58,35,34,42,252,82,5,178,144,34,36,
48,28,6,135,39,47,44,38,42,37,35,50,13,14,4,253,135,31,
2,130,129,4,10,10,25,24,40,42,58,11,14,24,2,8,133,5,
17,26,24,46,15,15,6,136,0,0,0,3,0,57,255,214,4,143,
6,60,0,62,0,83,0,103,0,0,1,6,7,6,7,14,1,35,
34,39,38,39,38,39,38,39,38,53,52,55,54,55,54,55,54,55,
54,51,50,23,22,23,22,23,22,23,22,23,7,38,39,38,43,1,
34,7,6,7,6,7,6,21,20,23,22,23,22,23,51,50,55,54,
55,1,20,23,22,23,22,59,1,50,55,54,53,52,39,38,39,38,
35,34,7,6,7,52,55,54,51,50,23,22,23,22,21,20,7,6,
35,34,39,38,39,38,4,143,16,34,29,46,45,128,76,95,80,81,
55,54,46,56,24,22,23,39,32,48,57,59,82,79,96,61,54,55,
38,35,35,31,20,20,12,120,22,68,67,84,2,70,66,71,46,49,
23,22,35,40,47,108,117,7,78,73,72,26,252,123,2,6,26,25,
33,2,38,25,27,2,6,26,24,34,39,26,27,91,53,55,75,64,
52,49,15,4,54,55,75,66,50,48,15,4,1,24,56,62,52,50,
48,54,41,41,72,68,99,120,85,84,144,146,84,138,71,103,69,71,
45,43,18,20,29,27,44,41,39,42,41,41,90,56,55,57,61,81,
88,112,109,121,122,110,126,76,176,4,66,63,94,4,73,6,16,32,
21,20,27,28,40,5,16,31,23,21,28,28,43,76,52,53,41,40,
63,20,17,75,53,53,41,39,64,16,0,0,0,1,0,34,255,227,
3,93,5,176,0,43,0,0,1,2,7,20,23,22,21,20,7,6,
7,6,35,34,39,38,39,38,39,38,39,55,22,23,22,23,22,23,
22,51,50,55,54,55,54,53,52,39,38,39,52,19,33,53,3,93,
158,1,99,59,54,58,106,104,133,60,53,59,39,46,28,32,24,122,
13,13,15,29,25,41,39,44,130,88,58,20,2,46,102,3,106,253,
144,5,176,254,144,239,43,151,89,109,85,120,128,77,76,19,21,31,
36,32,37,40,77,26,19,22,29,25,19,18,118,78,112,16,10,70,
90,132,120,144,1,62,142,0,0,4,0,121,0,0,5,146,5,176,
0,3,0,23,0,43,0,53,0,0,1,33,21,33,19,20,23,22,
23,22,51,50,55,54,53,52,39,38,39,38,35,34,7,6,7,52,
55,54,51,50,23,22,23,22,21,20,7,6,35,34,39,38,39,38,
1,17,51,1,17,51,17,35,1,17,3,134,2,11,253,245,118,3,
10,40,39,52,60,42,42,3,10,40,39,52,60,42,42,118,76,76,
110,95,71,70,21,5,76,78,108,95,71,69,21,6,252,243,153,1,
102,157,145,254,147,2,58,142,2,55,18,16,49,34,33,43,44,63,
17,16,50,34,33,44,43,67,108,75,75,58,56,91,23,30,108,75,
76,58,57,90,25,252,62,5,176,251,235,4,21,250,80,4,50,251,
206,0,0,0,0,2,0,121,0,0,4,8,5,176,0,14,0,34,
0,0,1,51,32,17,52,39,38,39,38,39,38,39,38,43,1,39,
59,1,50,23,22,23,22,21,20,7,6,7,6,7,6,43,1,17,
35,1,23,206,1,129,6,9,22,24,39,43,71,68,103,206,158,158,
206,232,137,139,31,8,33,34,64,65,106,107,138,206,158,3,6,1,
17,35,25,42,33,37,29,32,18,17,141,88,89,147,48,37,87,74,
75,57,57,33,33,253,137,0,0,2,0,121,0,0,4,80,5,176,
0,14,0,31,0,0,1,51,50,54,55,54,55,54,55,54,53,52,
38,43,1,9,1,35,17,35,17,59,1,50,23,22,21,20,7,6,
7,1,1,23,206,92,146,39,40,26,24,10,8,186,199,206,2,132,
254,83,215,158,158,206,242,153,154,99,100,165,1,178,3,6,34,26,
27,38,36,37,31,44,124,144,250,221,2,119,253,137,5,176,108,109,
192,149,110,110,30,253,120,0,0,2,0,23,3,119,4,153,6,42,
0,12,0,20,0,0,1,17,51,27,1,51,17,35,17,3,35,3,
17,1,33,21,35,17,35,17,35,2,43,115,174,196,137,116,171,95,
146,253,142,2,9,185,98,238,3,119,2,179,253,241,2,15,253,77,
1,201,254,62,1,194,254,55,2,179,99,253,176,2,80,0,0,1,
0,25,0,0,5,53,5,215,0,75,0,0,37,38,39,38,39,38,
53,52,55,54,55,54,55,54,55,54,51,50,23,22,23,22,23,22,
23,22,21,20,7,6,7,6,15,1,33,21,33,53,54,55,54,55,
54,55,54,53,52,39,38,39,38,39,38,39,38,35,34,6,7,6,
7,14,1,21,20,23,22,23,22,23,22,23,51,21,33,55,1,32,
63,44,43,23,23,19,20,44,43,67,64,103,101,123,122,98,100,66,
65,45,44,22,24,20,20,44,45,72,4,1,20,253,253,75,57,59,
31,33,11,12,23,17,32,29,48,46,70,67,88,94,146,47,47,30,
30,24,22,15,33,31,55,57,69,1,253,252,1,142,73,94,91,108,
109,108,103,101,104,102,100,82,79,50,49,46,47,78,76,97,93,108,
116,109,98,103,104,98,101,75,4,142,142,40,64,66,82,85,79,82,
85,115,112,79,73,67,60,57,34,32,80,64,63,85,84,168,85,114,
104,75,74,69,57,58,32,142,142,0,0,2,0,49,0,0,4,198,
4,48,0,43,0,66,0,0,1,17,20,23,22,23,22,23,22,51,
50,55,54,55,51,6,7,6,7,6,35,34,39,38,39,38,53,52,
55,54,55,54,51,50,23,22,23,22,19,33,34,7,14,1,37,17,
52,39,38,39,38,35,34,7,6,7,6,7,6,21,17,20,51,33,
50,55,54,1,10,27,24,50,48,70,72,79,109,97,99,66,109,112,
107,63,55,60,83,140,102,101,82,162,164,85,98,100,140,125,98,96,
86,167,14,252,91,9,3,5,6,2,226,57,57,88,90,79,71,74,
71,47,48,27,29,23,2,177,16,5,5,1,237,254,250,21,32,28,
34,33,20,21,47,48,75,124,44,25,9,10,36,36,77,153,233,228,
159,79,35,36,32,31,70,135,254,228,1,2,12,74,1,1,42,46,
47,31,32,23,22,32,32,29,31,18,254,232,14,6,7,0,0,1,
0,141,0,0,3,255,3,63,0,57,0,0,33,3,35,34,21,31,
4,7,38,39,38,39,38,53,52,55,54,55,54,55,54,55,54,59,
1,1,51,19,51,50,53,47,4,55,22,23,22,23,22,21,20,7,
6,7,6,7,6,7,6,35,7,1,3,72,255,145,123,3,8,12,
12,14,102,26,14,12,15,15,8,9,21,18,36,33,49,53,62,31,
254,151,183,217,135,123,3,8,12,12,14,102,26,14,12,15,15,8,
9,21,18,36,33,49,53,62,21,1,143,1,47,82,18,16,13,11,
10,75,19,12,11,25,26,29,20,20,22,29,25,27,25,16,17,1,
174,254,253,82,19,15,13,12,10,75,19,12,11,25,25,30,20,20,
22,29,25,27,25,16,17,1,254,38,0,0,0,3,0,29,254,185,
3,177,6,203,0,62,0,68,0,72,0,0,5,55,23,30,1,51,
50,55,54,53,52,39,38,39,38,39,38,43,1,53,51,50,55,54,
53,52,38,43,1,34,7,6,15,1,39,55,54,55,54,51,50,23,
22,23,22,21,20,7,6,7,22,23,22,23,22,21,20,7,6,35,
34,38,39,3,35,55,51,17,35,3,39,1,23,1,91,144,13,16,
60,32,56,38,37,11,9,20,19,22,24,24,74,84,34,25,26,52,
34,3,30,21,20,13,15,134,17,32,57,58,72,56,56,53,35,35,
19,18,26,23,21,23,15,14,81,82,116,72,146,31,191,123,174,97,
148,4,139,3,15,133,129,43,27,33,40,33,33,54,28,24,19,17,
16,7,8,132,27,28,40,36,50,15,15,28,32,62,32,62,37,37,
28,26,54,53,65,49,41,39,26,18,26,28,38,36,45,114,73,74,
88,74,6,173,195,252,226,254,11,57,2,65,55,0,0,0,0,3,
0,72,254,185,4,53,6,222,0,66,0,128,0,132,0,0,19,39,
55,54,55,54,51,50,22,23,30,1,23,22,21,20,7,6,7,6,
7,6,7,6,7,6,15,2,6,7,14,1,15,1,33,21,33,53,
52,55,54,55,54,55,54,55,54,63,1,62,2,63,6,52,38,35,
34,7,6,7,1,55,23,30,1,51,50,54,53,52,39,38,39,38,
39,38,43,1,53,51,50,55,54,53,52,38,43,1,34,7,6,15,
1,39,55,54,55,54,51,50,23,22,23,22,21,20,7,6,7,22,
23,22,23,22,21,20,7,6,35,34,38,39,3,39,1,23,206,134,
9,22,74,73,88,38,68,32,33,46,14,14,8,7,13,12,18,18,
16,24,13,28,6,29,22,13,28,26,40,9,8,1,95,253,244,15,
16,20,23,32,38,23,20,46,22,5,12,6,1,22,21,16,14,8,
4,60,38,40,32,35,14,1,6,144,13,16,60,32,57,74,11,9,
20,19,22,24,24,74,84,34,25,26,52,34,3,30,21,20,13,15,
134,17,32,57,58,72,56,56,53,35,35,19,18,26,23,21,23,15,
14,81,82,116,72,146,31,195,139,3,15,133,5,204,53,31,79,56,
55,18,21,22,58,44,45,48,29,30,27,24,22,23,22,15,22,10,
22,4,20,14,8,27,25,44,17,16,140,35,52,48,52,33,39,33,
39,20,17,33,15,4,7,4,1,17,19,19,22,24,30,54,60,25,
27,46,249,143,43,27,33,40,66,54,28,24,19,17,16,7,8,132,
27,28,40,36,50,15,15,28,32,62,32,62,37,37,28,26,54,53,
65,49,41,39,26,18,26,28,38,36,45,114,73,74,88,74,2,93,
57,2,65,55,0,3,0,29,254,185,3,177,6,203,0,51,0,57,
0,61,0,0,37,6,7,6,7,6,7,14,2,7,6,15,1,39,
19,33,21,33,7,54,51,50,23,22,23,22,21,20,7,6,7,6,
35,34,39,38,47,1,55,23,22,51,50,54,53,52,39,46,1,35,
34,1,35,55,51,17,35,3,39,1,23,2,77,10,13,7,10,2,
12,2,8,2,10,7,5,16,111,55,1,145,254,237,19,41,38,95,
67,69,19,7,30,29,62,59,80,98,70,72,25,11,146,10,34,86,
50,62,3,10,62,34,18,254,87,123,174,97,148,4,139,3,15,133,
90,1,4,2,4,1,7,1,4,2,8,6,3,8,57,1,133,140,
125,9,57,58,92,32,38,73,63,61,42,40,57,58,90,37,26,28,
99,74,65,18,16,46,58,5,173,195,252,226,254,11,57,2,65,55,
0,0,0,3,0,76,254,185,4,45,6,222,0,66,0,118,0,122,
0,0,19,39,55,54,55,54,51,50,22,23,30,1,23,22,21,20,
7,6,7,6,7,6,7,6,7,6,15,2,6,7,14,1,15,1,
33,21,33,53,52,55,54,55,54,55,54,55,54,63,1,62,2,63,
6,52,38,35,34,7,6,7,1,6,7,6,7,6,7,14,2,7,
6,15,1,39,19,33,21,33,7,54,51,50,23,22,23,22,21,20,
7,6,7,6,35,34,39,38,47,1,55,23,22,51,50,54,53,52,
39,46,1,35,34,1,39,1,23,210,134,9,22,74,73,88,38,68,
32,33,46,14,14,8,7,13,12,18,18,16,24,13,28,6,29,22,
13,28,26,40,9,8,1,95,253,244,15,16,20,23,32,38,23,20,
46,22,5,12,6,1,22,21,16,14,8,4,60,38,40,32,35,14,
1,236,10,13,7,10,2,12,2,8,2,10,7,5,16,111,55,1,
145,254,237,19,41,38,95,67,69,19,7,30,29,62,59,80,98,70,
72,25,11,146,10,34,86,50,62,3,10,62,34,18,254,83,139,3,
15,133,5,204,53,31,79,56,55,18,21,22,58,44,45,48,29,30,
27,24,22,23,22,15,22,10,22,4,20,14,8,27,25,44,17,16,
140,35,52,48,52,33,39,33,39,20,17,33,15,4,7,4,1,17,
19,19,22,24,30,54,60,25,27,46,250,106,1,4,2,4,1,7,
1,4,2,8,6,3,8,57,1,133,140,125,9,57,58,92,32,38,
73,63,61,42,40,57,58,90,37,26,28,99,74,65,18,16,46,58,
1,93,57,2,65,55,0,3,0,51,254,185,4,45,6,238,0,62,
0,114,0,118,0,0,19,55,23,30,1,51,50,55,54,53,52,39,
38,39,38,39,38,43,1,53,51,50,55,54,53,52,38,43,1,34,
7,6,15,1,39,55,54,55,54,51,50,23,22,23,22,21,20,7,
6,7,22,23,22,23,22,21,20,7,6,35,34,38,39,1,6,7,
6,7,6,7,14,2,7,6,15,1,39,19,33,21,33,7,54,51,
50,23,22,23,22,21,20,7,6,7,6,35,34,39,38,47,1,55,
23,22,51,50,54,53,52,39,46,1,35,34,1,39,1,23,51,144,
13,16,60,32,56,38,37,11,9,20,19,22,24,24,74,84,34,25,
26,52,34,3,30,21,20,13,15,134,17,32,57,58,72,56,56,53,
35,35,19,18,26,23,21,23,15,14,81,82,116,72,146,31,2,134,
10,13,7,10,2,12,2,8,2,10,7,5,16,111,55,1,145,254,
237,19,41,38,95,67,69,19,7,30,29,62,59,80,98,70,72,25,
11,146,10,34,86,50,62,3,10,62,34,18,254,83,139,3,15,133,
4,115,43,27,33,40,33,33,54,28,24,19,17,16,7,8,132,27,
28,40,36,50,15,15,28,32,62,32,62,37,37,28,26,54,53,65,
49,41,39,26,18,26,28,38,36,45,114,73,74,88,74,252,11,1,
4,2,4,1,7,1,4,2,8,6,3,8,57,1,133,140,125,9,
57,58,92,32,38,73,63,61,42,40,57,58,90,37,26,28,99,74,
65,18,16,46,58,1,93,57,2,65,55,0,0,4,0,65,254,185,
4,45,6,203,0,9,0,12,0,64,0,68,0,0,1,51,21,35,
21,35,53,33,1,51,3,51,53,1,6,7,6,7,6,7,14,2,
7,6,15,1,39,19,33,21,33,7,54,51,50,23,22,23,22,21,
20,7,6,7,6,35,34,39,38,47,1,55,23,22,51,50,54,53,
52,39,46,1,35,34,1,39,1,23,2,36,94,94,148,254,177,1,
87,140,245,99,1,55,10,13,7,10,2,12,2,8,2,10,7,5,
16,111,55,1,145,254,237,19,41,38,95,67,69,19,7,30,29,62,
59,80,98,70,72,25,11,146,10,34,86,50,62,3,10,62,34,18,
254,83,139,3,15,133,5,0,140,199,199,2,87,254,54,173,250,172,
1,4,2,4,1,7,1,4,2,8,6,3,8,57,1,133,140,125,
9,57,58,92,32,38,73,63,61,42,40,57,58,90,37,26,28,99,
74,65,18,16,46,58,1,93,57,2,65,55,0,4,0,29,254,185,
3,177,6,203,0,18,0,49,0,55,0,59,0,0,5,52,39,38,
39,38,35,34,7,6,21,20,23,22,23,22,51,50,54,3,50,23,
22,23,22,21,20,7,6,7,14,1,35,34,39,38,39,38,53,52,
55,54,55,54,55,54,63,1,19,51,1,35,55,51,17,35,3,39,
1,23,2,219,3,9,31,32,43,49,31,32,2,8,31,32,40,51,
66,118,95,70,73,19,5,19,21,31,32,104,56,98,66,69,18,5,
6,4,16,12,9,2,15,25,177,157,253,161,123,174,97,148,4,139,
3,15,133,74,12,13,40,25,26,34,35,45,17,7,38,24,24,66,
1,46,57,59,89,22,33,46,44,48,34,35,46,59,62,83,20,31,
32,32,23,39,30,18,4,27,42,1,53,4,36,195,252,226,254,11,
57,2,65,55,0,0,0,4,0,50,254,185,4,5,6,217,0,50,
0,69,0,100,0,104,0,0,0,6,7,6,7,14,1,7,6,7,
6,15,1,39,19,33,21,33,7,54,51,50,23,22,23,22,21,20,
7,6,7,6,35,34,39,38,47,1,55,23,22,51,50,54,53,52,
39,38,39,38,35,1,52,39,38,39,38,35,34,7,6,21,20,23,
22,23,22,51,50,54,3,50,23,22,23,22,21,20,7,6,7,14,
1,35,34,39,38,39,38,53,52,55,54,55,54,55,54,63,1,19,
51,5,39,1,23,1,54,16,14,10,8,7,14,3,1,10,3,10,
16,110,54,1,146,254,236,19,41,38,96,67,69,19,7,31,29,62,
59,80,97,71,72,25,10,145,10,35,85,51,62,4,11,29,31,35,
1,231,3,9,31,32,43,49,31,32,2,8,31,32,40,51,66,118,
95,70,73,19,5,19,21,31,32,104,56,98,66,69,18,5,6,4,
16,12,9,2,15,25,177,157,253,157,139,3,15,133,5,79,2,4,
3,3,3,8,3,1,8,2,7,8,57,1,133,140,125,9,57,58,
92,32,38,71,65,61,42,40,57,58,90,37,26,28,99,74,65,12,
22,47,28,29,250,103,12,13,40,25,26,34,35,45,17,7,38,24,
24,66,1,46,57,59,89,22,33,46,44,48,34,35,46,59,62,83,
20,31,32,32,23,39,30,18,4,27,42,1,53,44,57,2,65,55,
0,0,0,5,0,29,254,185,3,177,6,203,0,37,0,54,0,73,
0,79,0,83,0,0,1,22,23,22,21,20,7,22,23,22,23,22,
21,20,6,7,6,35,34,39,38,39,38,53,52,55,54,55,54,55,
38,39,38,53,52,54,51,50,7,20,23,22,23,22,51,50,54,53,
52,39,46,1,35,34,6,19,50,55,54,53,52,39,38,39,38,35,
34,6,21,20,23,22,23,22,1,35,55,51,17,35,3,39,1,23,
2,254,65,18,4,65,21,32,33,13,4,76,65,64,74,97,76,75,
20,6,15,15,25,26,18,45,14,5,138,102,89,180,2,6,24,25,
35,41,50,2,6,46,38,45,46,90,53,39,38,2,9,35,37,45,
57,70,3,9,34,36,254,115,123,174,97,148,4,139,3,15,133,1,
202,48,79,20,27,94,61,15,32,33,63,20,28,76,120,35,34,59,
59,92,27,28,47,39,38,27,28,13,42,61,21,30,96,126,222,15,
7,31,16,17,46,40,6,14,28,34,46,254,6,37,36,51,19,8,
41,25,26,64,55,14,13,42,27,28,6,194,195,252,226,254,11,57,
2,65,55,0,0,0,0,5,0,53,254,185,3,249,6,238,0,62,
0,100,0,117,0,136,0,140,0,0,19,55,23,30,1,51,50,55,
54,53,52,39,38,39,46,1,43,1,53,51,50,55,54,53,52,39,
38,43,1,34,7,6,15,1,39,55,54,55,54,51,50,23,22,23,
22,21,20,7,6,7,22,23,22,23,22,21,20,7,6,35,34,38,
39,1,22,23,22,21,20,7,22,23,22,23,22,21,20,6,7,6,
35,34,39,38,39,38,53,52,55,54,55,54,55,38,39,38,53,52,
54,51,50,7,20,23,22,23,22,51,50,54,53,52,39,46,1,35,
34,6,19,50,55,54,53,52,39,38,39,38,35,34,6,21,20,23,
22,23,22,1,39,1,23,53,144,13,16,60,32,56,37,38,11,9,
20,18,48,23,74,84,34,25,26,27,26,33,3,30,21,22,12,14,
134,16,31,59,58,72,56,56,53,35,35,20,19,24,23,21,22,15,
15,81,82,116,72,146,31,3,1,65,18,4,65,21,32,33,13,4,
76,65,64,74,97,76,75,20,6,15,15,25,26,18,45,14,5,138,
102,89,180,2,6,24,25,35,41,50,2,6,46,38,45,46,90,53,
39,38,2,9,35,37,45,57,70,3,9,34,36,254,111,139,3,15,
133,4,115,43,27,33,40,33,33,54,28,24,19,17,15,16,132,27,
28,40,36,25,25,15,16,27,32,62,32,62,37,37,28,26,54,53,
65,47,43,41,24,18,26,26,40,39,42,114,73,74,88,74,253,123,
48,79,20,27,94,61,15,32,33,63,20,28,76,120,35,34,59,59,
92,27,28,47,39,38,27,28,13,42,61,21,30,96,126,222,15,7,
31,16,17,46,40,6,14,28,34,46,254,6,37,36,51,19,8,41,
25,26,64,55,14,13,42,27,28,2,114,57,2,65,55,0,0,0,
0,5,0,48,254,185,3,249,6,217,0,50,0,88,0,105,0,124,
0,128,0,0,1,6,7,6,7,6,7,14,1,7,6,15,1,39,
19,33,21,33,7,54,51,50,23,22,23,22,21,20,7,6,7,6,
35,34,39,38,47,1,55,23,22,51,50,54,53,52,39,46,1,35,
34,1,22,23,22,21,20,7,22,23,22,23,22,21,20,6,7,6,
35,34,39,38,39,38,53,52,55,54,55,54,55,38,39,38,53,52,
54,51,50,7,20,23,22,23,22,51,50,54,53,52,39,46,1,35,
34,6,19,50,55,54,53,52,39,38,39,38,35,34,6,21,20,23,
22,23,22,1,39,1,23,1,45,10,13,7,10,7,7,10,2,10,
7,5,16,111,55,1,145,254,237,19,41,38,95,67,69,19,7,30,
29,62,59,80,98,70,72,25,11,146,10,34,86,50,62,3,10,62,
34,18,2,17,65,18,4,65,21,32,33,13,4,76,65,64,74,97,
76,75,20,6,15,15,25,26,18,45,14,5,138,102,89,180,2,6,
24,25,35,41,50,2,6,46,38,45,46,90,53,39,38,2,9,35,
37,45,57,70,3,9,34,36,254,111,139,3,15,133,5,78,1,4,
2,4,3,4,6,2,8,6,3,8,57,1,133,140,125,9,57,58,
92,32,38,73,63,61,42,40,57,58,90,37,26,28,99,74,65,17,
17,46,58,252,123,48,79,20,27,94,61,15,32,33,63,20,28,76,
120,35,34,59,59,92,27,28,47,39,38,27,28,13,42,61,21,30,
96,126,222,15,7,31,16,17,46,40,6,14,28,34,46,254,6,37,
36,51,19,8,41,25,26,64,55,14,13,42,27,28,2,114,57,2,
65,55,0,5,0,50,254,185,3,249,6,202,0,5,0,43,0,60,
0,79,0,83,0,0,9,1,35,1,33,53,1,22,23,22,21,20,
7,22,23,22,23,22,21,20,6,7,6,35,34,39,38,39,38,53,
52,55,54,55,54,55,38,39,38,53,52,54,51,50,7,20,23,22,
23,22,51,50,54,53,52,39,46,1,35,34,6,19,50,55,54,53,
52,39,38,39,38,35,34,6,21,20,23,22,23,22,1,39,1,23,
2,108,254,208,167,1,2,254,155,3,20,65,18,4,65,21,32,33,
13,4,76,65,64,74,97,76,75,20,6,15,15,25,26,18,45,14,
5,138,102,89,180,2,6,24,25,35,41,50,2,6,46,38,45,46,
90,53,39,38,2,9,35,37,45,57,70,3,9,34,36,254,111,139,
3,15,133,6,202,252,227,2,141,144,251,0,48,79,20,27,94,61,
15,32,33,63,20,28,76,120,35,34,59,59,92,27,28,47,39,38,
27,28,13,42,61,21,30,96,126,222,15,7,31,16,17,46,40,6,
14,28,34,46,254,6,37,36,51,19,8,41,25,26,64,55,14,13,
42,27,28,2,114,57,2,65,55,0,0,2,0,29,1,184,3,177,
6,203,0,5,0,9,0,0,19,35,55,51,17,35,3,39,1,23,
172,123,174,97,148,4,139,3,15,133,6,8,195,252,226,254,11,57,
2,65,55,0,0,1,0,154,0,0,1,55,5,176,0,3,0,0,
51,17,51,17,154,157,5,176,250,80,0,2,0,154,0,0,2,92,
5,176,0,3,0,7,0,0,33,17,51,17,33,17,51,17,1,191,
157,254,62,157,5,176,250,80,5,176,250,80,0,0,0,3,0,154,
0,0,3,129,5,176,0,3,0,7,0,11,0,0,33,17,51,17,
33,17,51,17,33,17,51,17,2,228,157,254,62,157,254,62,157,5,
176,250,80,5,176,250,80,5,176,250,80,0,0,2,0,154,0,0,
6,17,5,176,0,6,0,10,0,0,1,51,1,35,1,51,1,5,
17,51,17,5,109,164,254,71,219,254,66,170,1,129,252,176,157,5,
176,250,80,5,176,250,248,168,5,176,250,80,0,0,0,1,0,123,
0,0,4,205,5,176,0,6,0,0,1,51,1,35,1,51,1,4,
41,164,254,71,219,254,66,170,1,129,5,176,250,80,5,176,250,248,
0,2,0,123,0,0,5,242,5,176,0,3,0,10,0,0,33,17,
51,17,1,51,1,35,1,51,1,5,85,157,254,55,164,254,71,219,
254,66,170,1,129,5,176,250,80,5,176,250,80,5,176,250,248,0,
0,0,0,3,0,123,0,0,7,23,5,176,0,3,0,7,0,14,
0,0,33,17,51,17,33,17,51,17,1,51,1,35,1,51,1,6,
122,157,254,62,157,254,55,164,254,71,219,254,66,170,1,129,5,176,
250,80,5,176,250,80,5,176,250,80,5,176,250,248,0,0,0,3,
0,123,0,0,7,23,5,176,0,3,0,7,0,14,0,0,33,17,
51,17,33,17,51,17,1,51,1,35,1,51,1,6,122,157,254,62,
157,254,55,164,254,71,219,254,66,170,1,129,5,176,250,80,5,176,
250,80,5,176,250,80,5,176,250,248,0,0,0,2,0,154,0,0,
5,245,5,176,0,11,0,15,0,0,1,51,9,1,51,9,1,35,
9,1,35,9,1,17,51,17,1,182,182,1,106,1,99,182,254,59,
1,203,190,254,159,254,152,178,1,199,253,23,157,5,176,253,162,2,
94,253,41,253,39,2,74,253,182,2,217,253,39,5,176,250,80,0,
0,0,0,1,0,74,0,0,4,137,5,176,0,11,0,0,19,51,
9,1,51,9,1,35,9,1,35,1,74,182,1,106,1,99,182,254,
59,1,203,190,254,159,254,152,178,1,199,5,176,253,162,2,94,253,
41,253,39,2,74,253,182,2,217,0,0,0,0,2,0,74,0,0,
5,174,5,176,0,3,0,15,0,0,33,17,51,17,1,51,9,1,
51,9,1,35,9,1,35,1,5,17,157,250,156,182,1,106,1,99,
182,254,59,1,203,190,254,159,254,152,178,1,199,5,176,250,80,5,
176,253,162,2,94,253,41,253,39,2,74,253,182,2,217,0,0,3,
0,74,0,0,6,211,5,176,0,3,0,7,0,19,0,0,33,17,
51,17,33,17,51,17,1,51,9,1,51,9,1,35,9,1,35,1,
6,54,157,254,62,157,250,156,182,1,106,1,99,182,254,59,1,203,
190,254,159,254,152,178,1,199,5,176,250,80,5,176,250,80,5,176,
253,162,2,94,253,41,253,39,2,74,253,182,2,217,0,1,0,121,
0,0,4,20,5,176,0,5,0,0,19,51,17,33,21,33,121,158,
2,253,252,101,5,176,250,221,141,0,0,1,0,100,255,227,4,143,
5,215,0,64,0,0,1,6,7,6,7,6,7,6,35,34,39,38,
39,38,39,38,39,38,53,52,55,54,55,54,55,54,55,54,51,50,
23,22,23,22,23,22,23,22,23,7,38,39,38,43,1,34,7,6,
7,6,7,6,21,20,23,22,23,22,23,22,51,50,55,54,55,4,
143,24,38,36,58,53,83,79,96,117,102,100,69,71,47,50,22,22,
23,22,49,47,72,70,100,99,120,73,71,66,50,49,39,40,24,24,
15,149,28,86,83,105,2,104,84,86,52,51,29,28,30,30,54,53,
85,82,100,107,90,91,32,1,37,64,55,52,50,46,28,27,41,40,
72,74,94,101,105,107,120,116,113,109,101,97,75,73,43,43,19,18,
30,30,40,42,40,41,41,41,89,57,55,54,56,88,87,114,109,121,
120,111,110,86,83,53,51,65,66,92,0,0,0,2,0,121,0,0,
4,129,5,176,0,22,0,41,0,0,1,52,39,38,39,38,39,38,
39,38,39,38,43,1,17,51,50,55,54,55,54,55,54,55,20,7,
6,7,6,7,6,35,33,17,33,50,23,22,23,22,23,22,3,219,
10,11,20,21,37,42,44,50,72,73,83,245,245,126,92,91,53,53,
24,24,166,39,39,74,73,112,114,137,254,68,1,188,138,112,113,73,
75,38,39,2,215,69,61,70,63,68,56,64,40,46,25,26,251,106,
42,42,80,81,102,104,135,154,132,131,100,99,55,56,5,176,61,62,
101,104,128,130,0,1,0,121,0,0,5,182,5,176,0,12,0,0,
51,17,51,9,1,51,17,35,17,1,35,1,17,121,215,1,203,1,
204,207,153,254,84,179,254,84,5,176,251,33,4,223,250,80,4,180,
251,92,4,164,251,76,0,2,0,121,0,0,1,53,5,147,0,17,
0,21,0,0,19,52,54,51,50,23,22,23,22,21,20,6,35,34,
39,38,39,38,19,51,17,35,121,56,38,33,26,25,8,2,56,38,
33,26,25,8,2,19,151,151,5,53,38,56,21,21,33,8,11,38,
56,21,21,33,16,254,255,251,207,0,0,4,0,121,0,0,2,90,
5,147,0,16,0,20,0,38,0,42,0,0,1,52,54,51,50,23,
22,23,22,21,20,6,35,34,38,39,38,19,51,17,35,1,52,54,
51,50,23,22,23,22,21,20,6,35,34,39,38,39,38,19,51,17,
35,1,158,56,38,34,26,24,8,2,56,38,34,50,8,2,19,151,
151,254,200,56,38,33,26,25,8,2,56,38,33,26,25,8,2,19,
151,151,5,53,38,56,21,20,34,8,11,38,56,42,33,16,254,255,
251,207,5,53,38,56,21,21,33,8,11,38,56,21,21,33,16,254,
255,251,207,0,0,0,0,6,0,121,0,0,3,127,5,147,0,17,
0,21,0,38,0,42,0,60,0,64,0,0,1,52,54,51,50,23,
22,23,22,21,20,6,35,34,39,38,39,38,19,51,17,35,1,52,
54,51,50,23,22,23,22,21,20,6,35,34,38,39,38,19,51,17,
35,1,52,54,51,50,23,22,23,22,21,20,6,35,34,39,38,39,
38,19,51,17,35,2,195,56,38,33,26,25,8,2,56,38,33,26,
25,8,2,19,151,151,254,200,56,38,34,26,24,8,2,56,38,34,
50,8,2,19,151,151,254,200,56,38,33,26,25,8,2,56,38,33,
26,25,8,2,19,151,151,5,53,38,56,21,21,33,8,11,38,56,
21,21,33,16,254,255,251,207,5,53,38,56,21,20,34,8,11,38,
56,42,33,16,254,255,251,207,5,53,38,56,21,21,33,8,11,38,
56,21,21,33,16,254,255,251,207,0,0,0,0,2,0,121,0,0,
1,53,5,147,0,17,0,21,0,0,19,52,54,51,50,23,22,23,
22,21,20,6,35,34,39,38,39,38,19,51,17,35,121,56,38,33,
26,25,8,2,56,38,33,26,25,8,2,19,151,151,5,53,38,56,
21,21,33,8,11,38,56,21,21,33,16,254,255,251,207,0,0,1,
0,82,0,0,3,199,4,49,0,6,0,0,33,1,51,9,1,51,
1,1,190,254,148,160,1,24,1,31,158,254,143,4,49,252,146,3,
110,251,207,0,0,0,0,3,0,82,0,0,4,254,5,147,0,17,
0,21,0,28,0,0,1,52,54,51,50,23,22,23,22,21,20,6,
35,34,39,38,39,38,19,51,17,35,33,1,51,9,1,51,1,4,
66,56,38,34,26,19,13,2,56,38,34,25,28,5,2,19,151,151,
253,105,254,148,160,1,24,1,31,158,254,143,5,53,38,56,21,15,
39,8,11,38,56,21,22,32,16,254,255,251,207,4,49,252,146,3,
110,251,207,0,0,0,0,7,0,82,0,0,7,72,5,147,0,16,
0,20,0,37,0,41,0,59,0,63,0,70,0,0,1,52,54,51,
50,23,22,23,22,21,20,6,35,34,38,39,38,19,51,17,35,1,
52,54,51,50,22,23,22,21,20,6,35,34,39,38,39,38,19,51,
17,35,1,52,54,51,50,23,22,23,22,21,20,6,35,34,39,38,
39,38,19,51,17,35,33,1,51,9,1,51,1,6,140,56,38,34,
26,24,8,2,56,38,34,50,8,2,19,151,151,254,200,56,38,34,
50,8,2,56,38,33,26,25,8,2,19,151,151,254,200,56,38,34,
26,19,13,2,56,38,34,25,28,5,2,19,151,151,253,105,254,148,
160,1,24,1,31,158,254,143,5,53,38,56,21,20,34,8,11,38,
56,42,33,16,254,255,251,207,5,53,38,56,42,33,8,11,38,56,
21,21,33,16,254,255,251,207,5,53,38,56,21,15,39,8,11,38,
56,21,22,32,16,254,255,251,207,4,49,252,146,3,110,251,207,0,
0,5,0,82,0,0,6,35,5,147,0,16,0,20,0,38,0,42,
0,49,0,0,1,52,54,51,50,22,23,22,21,20,6,35,34,39,
38,39,38,19,51,17,35,1,52,54,51,50,23,22,23,22,21,20,
6,35,34,39,38,39,38,19,51,17,35,33,1,51,9,1,51,1,
5,103,56,38,34,50,8,2,56,38,33,26,25,8,2,19,151,151,
254,200,56,38,34,26,19,13,2,56,38,34,25,28,5,2,19,151,
151,253,105,254,148,160,1,24,1,31,158,254,143,5,53,38,56,42,
33,8,11,38,56,21,21,33,16,254,255,251,207,5,53,38,56,21,
15,39,8,11,38,56,21,22,32,16,254,255,251,207,4,49,252,146,
3,110,251,207,0,0,0,3,0,121,0,0,4,226,5,147,0,11,
0,29,0,33,0,0,33,35,11,1,35,9,1,51,27,1,51,9,
1,52,54,51,50,23,22,23,22,21,20,6,35,34,39,38,39,38,
19,51,17,35,4,226,170,241,230,176,1,58,254,200,170,234,233,170,
254,201,252,214,56,38,33,26,25,8,2,56,38,33,26,25,8,2,
19,151,151,1,184,254,72,2,27,2,22,254,78,1,178,253,238,3,
22,38,56,21,21,33,8,11,38,56,21,21,33,16,254,255,251,207,
0,1,0,53,0,0,3,102,4,49,0,11,0,0,33,35,11,1,
35,9,1,51,27,1,51,1,3,102,170,241,230,176,1,58,254,200,
170,234,233,170,254,201,1,184,254,72,2,27,2,22,254,78,1,178,
253,238,0,3,0,53,0,0,4,157,5,147,0,17,0,21,0,33,
0,0,1,52,54,51,50,23,22,23,22,21,20,6,35,34,39,38,
39,38,19,51,17,43,2,11,1,35,9,1,51,27,1,51,1,3,
225,56,38,33,26,25,8,2,56,38,33,26,25,8,2,19,151,151,
142,170,241,230,176,1,58,254,200,170,234,233,170,254,201,5,53,38,
56,21,21,33,8,11,38,56,21,21,33,16,254,255,251,207,1,184,
254,72,2,27,2,22,254,78,1,178,253,238,0,0,0,5,0,53,
0,0,5,194,5,147,0,16,0,20,0,38,0,42,0,54,0,0,
1,52,54,51,50,23,22,23,22,21,20,6,35,34,38,39,38,19,
51,17,35,1,52,54,51,50,23,22,23,22,21,20,6,35,34,39,
38,39,38,19,51,17,43,2,11,1,35,9,1,51,27,1,51,1,
5,6,56,38,34,26,24,8,2,56,38,34,50,8,2,19,151,151,
254,200,56,38,33,26,25,8,2,56,38,33,26,25,8,2,19,151,
151,142,170,241,230,176,1,58,254,200,170,234,233,170,254,201,5,53,
38,56,21,20,34,8,11,38,56,42,33,16,254,255,251,207,5,53,
38,56,21,21,33,8,11,38,56,21,21,33,16,254,255,251,207,1,
184,254,72,2,27,2,22,254,78,1,178,253,238,0,0,1,0,126,
255,227,1,140,5,174,0,12,0,0,37,20,23,22,51,21,34,38,
39,38,53,17,51,1,21,3,16,100,113,130,20,7,151,207,17,13,
75,131,74,89,35,34,4,227,0,1,0,101,255,227,3,133,4,70,
0,47,0,0,1,38,39,38,35,34,6,21,20,22,51,50,55,54,
55,54,55,54,55,23,6,7,6,7,6,7,6,35,34,39,38,39,
38,53,52,55,54,55,54,55,54,55,54,51,50,23,22,23,3,2,
18,60,61,69,128,180,176,130,43,39,43,24,25,18,16,11,122,24,
32,25,50,41,55,53,61,132,104,106,58,59,20,20,40,41,54,56,
72,74,84,115,85,86,53,3,41,49,50,50,240,181,195,236,18,20,
24,25,26,24,21,77,40,37,29,39,32,20,19,76,77,128,130,155,
84,83,82,70,72,52,55,29,30,61,62,96,0,2,0,128,255,227,
3,206,5,174,0,35,0,50,0,0,1,51,17,35,53,6,7,6,
7,6,7,6,35,34,39,38,39,46,1,39,38,53,52,55,62,2,
51,50,23,22,23,22,23,22,23,1,20,23,22,51,50,55,54,53,
52,39,38,34,7,6,3,54,152,152,18,25,23,34,35,50,47,66,
80,69,66,46,44,64,13,14,23,22,94,154,102,63,49,53,32,38,
21,24,19,253,228,77,76,116,117,79,80,80,79,234,76,76,5,174,
250,82,184,42,38,34,32,32,18,17,32,31,55,53,148,80,84,85,
110,101,96,164,92,18,19,31,36,32,36,44,254,165,199,118,116,116,
118,197,198,116,115,114,113,0,0,0,0,1,0,129,0,0,5,147,
4,78,0,53,0,0,33,35,17,52,39,38,39,46,2,35,34,25,
1,35,17,51,21,62,1,55,54,55,54,55,54,55,54,51,50,23,
22,23,62,1,51,50,22,21,17,35,17,52,39,38,39,38,39,46,
2,35,34,17,3,86,152,4,5,12,13,44,72,53,218,152,152,7,
22,2,13,23,25,23,22,40,36,48,116,74,75,27,26,150,109,158,
150,151,3,3,7,8,13,15,42,66,43,222,2,35,78,49,61,51,
55,78,46,254,97,253,218,4,49,182,15,42,4,25,31,33,17,17,
14,13,68,69,105,104,138,240,209,253,115,2,31,59,47,54,43,56,
30,36,60,30,254,103,0,0,0,3,0,62,255,227,7,202,5,215,
0,46,0,69,0,95,0,0,1,20,7,14,1,7,6,35,33,53,
6,7,6,35,34,38,39,38,39,38,39,38,53,52,55,54,55,54,
55,54,55,54,51,50,23,22,23,22,23,53,33,50,23,30,1,23,
22,1,17,51,50,55,54,55,54,55,54,53,52,39,38,39,38,39,
38,39,38,39,38,35,1,17,38,39,38,43,1,34,7,6,7,6,
7,6,21,20,23,22,23,22,23,22,51,50,55,54,7,202,40,39,
146,113,114,136,254,68,54,70,80,96,116,204,68,71,47,49,22,23,
24,22,49,47,72,70,100,99,119,73,71,66,50,26,12,1,188,138,
112,113,146,39,40,252,150,244,128,91,91,53,53,24,24,10,10,22,
21,37,42,44,51,70,73,84,254,110,32,77,83,106,2,104,84,85,
52,53,28,28,30,29,56,53,84,82,100,108,90,68,2,215,151,135,
133,196,56,56,63,42,23,27,82,71,74,94,97,109,112,115,111,118,
109,101,97,75,73,43,43,19,18,30,16,9,53,61,62,202,131,134,
1,193,251,106,42,42,80,81,102,103,136,69,61,63,70,68,56,64,
40,46,25,26,251,252,3,112,81,51,55,54,55,89,90,111,109,121,
120,111,107,89,84,52,51,65,48,0,0,0,0,2,0,121,0,0,
4,129,5,176,0,22,0,41,0,0,1,52,39,38,39,38,39,38,
39,38,39,38,43,1,17,51,50,55,54,55,54,55,54,55,20,7,
6,7,6,7,6,35,33,17,33,50,23,22,23,22,23,22,3,219,
10,11,20,21,37,42,44,50,72,73,83,245,245,126,92,91,53,53,
24,24,166,39,39,74,73,112,114,137,254,68,1,188,138,112,113,73,
75,38,39,2,215,69,61,70,63,68,56,64,40,46,25,26,251,106,
42,42,80,81,102,104,135,154,132,131,100,99,55,56,5,176,61,62,
101,104,128,130,0,4,0,38,0,0,8,212,5,176,0,22,0,39,
0,62,0,79,0,0,1,52,39,38,39,38,39,38,39,38,39,38,
43,1,17,51,50,55,54,55,54,55,54,55,20,7,14,1,7,6,
35,33,17,33,50,23,30,1,23,22,5,20,23,22,23,22,23,22,
59,1,17,35,34,7,6,7,6,7,6,7,6,7,6,7,52,55,
62,1,55,54,51,33,17,33,34,39,46,1,39,38,8,46,10,11,
20,21,37,41,46,51,69,73,84,245,245,127,92,91,53,52,24,24,
166,40,39,146,113,114,136,254,68,1,188,138,112,113,146,39,40,247,
248,24,24,53,53,91,91,128,244,244,84,73,70,51,44,42,37,21,
22,10,10,166,40,39,146,113,112,138,1,188,254,68,136,114,113,146,
39,40,2,215,69,61,70,63,68,56,62,42,47,24,26,251,106,42,
42,80,78,105,103,136,151,135,133,196,56,56,5,176,61,62,202,131,
134,139,135,104,102,81,80,42,42,4,150,26,25,46,40,64,56,68,
70,63,61,69,139,134,131,202,62,61,250,80,56,56,196,133,135,0,
0,1,0,100,255,227,4,143,5,215,0,60,0,0,19,55,22,23,
22,51,50,55,54,55,54,55,54,53,52,39,38,39,38,39,38,43,
1,34,7,6,7,39,54,55,54,55,54,55,54,55,54,51,50,23,
30,1,23,22,23,22,21,20,14,1,7,14,1,35,34,39,38,39,
38,39,38,100,147,32,91,90,107,99,83,84,53,56,29,30,28,29,
52,53,83,84,105,2,106,83,85,28,149,13,27,26,37,39,49,49,
68,71,72,120,99,100,140,48,51,21,23,46,94,71,68,204,117,95,
80,83,53,58,36,38,1,37,41,92,66,65,51,52,84,89,107,111,
120,121,109,111,90,91,53,54,55,56,90,41,36,46,43,39,40,30,
30,18,19,43,43,146,99,104,106,113,116,115,224,188,74,71,82,27,
28,46,50,52,55,0,0,0,0,1,0,101,255,227,3,133,4,70,
0,47,0,0,19,39,54,55,54,51,50,23,22,23,22,23,22,23,
22,21,20,7,6,7,6,35,34,39,38,39,38,39,38,39,55,22,
23,22,23,22,23,22,51,50,54,53,52,38,35,34,7,6,232,131,
53,86,85,115,84,74,72,56,54,41,40,20,20,59,58,106,104,132,
61,53,55,41,50,25,32,24,122,11,16,18,25,24,43,39,43,130,
176,180,128,69,61,60,3,41,66,96,62,61,30,29,55,52,72,70,
82,83,84,155,130,128,77,76,19,20,32,39,29,37,40,77,21,24,
26,25,24,20,18,236,195,181,240,50,50,0,0,1,0,100,255,227,
4,143,5,215,0,64,0,0,1,6,7,6,7,6,7,6,35,34,
39,38,39,38,39,38,39,38,53,52,55,54,55,54,55,54,55,54,
51,50,23,22,23,22,23,22,23,22,23,7,38,39,38,43,1,34,
7,6,7,6,7,6,21,20,23,22,23,22,23,22,51,50,55,54,
55,4,143,24,38,36,58,53,83,79,96,117,102,100,69,71,47,50,
22,22,23,22,49,47,72,70,100,99,120,73,71,66,50,49,39,40,
24,24,15,149,28,86,83,105,2,104,84,86,52,51,29,28,30,30,
54,53,85,82,100,107,90,91,32,1,37,64,55,52,50,46,28,27,
41,40,72,74,94,101,105,107,120,116,113,109,101,97,75,73,43,43,
19,18,30,30,40,42,40,41,41,41,89,57,55,54,56,88,87,114,
109,121,120,111,110,86,83,53,51,65,66,92,0,0,0,1,0,66,
0,0,4,150,6,65,0,8,0,0,1,3,23,17,1,23,9,1,
55,2,37,1,146,1,123,101,253,214,253,214,103,1,21,5,44,1,
250,213,1,123,102,253,214,2,42,104,0,0,0,2,0,121,0,0,
4,129,5,176,0,22,0,41,0,0,1,52,39,38,39,38,39,38,
39,38,39,38,43,1,17,51,50,55,54,55,54,55,54,55,20,7,
6,7,6,7,6,35,33,17,33,50,23,22,23,22,23,22,3,219,
10,11,20,21,37,42,44,50,72,73,83,245,245,126,92,91,53,53,
24,24,166,39,39,74,73,112,114,137,254,68,1,188,138,112,113,73,
75,38,39,2,215,69,61,70,63,68,56,64,40,46,25,26,251,106,
42,42,80,81,102,104,135,154,132,131,100,99,55,56,5,176,61,62,
101,104,128,130,0,4,0,38,0,0,8,212,5,176,0,22,0,39,
0,62,0,79,0,0,1,52,39,38,39,38,39,38,39,38,39,38,
43,1,17,51,50,55,54,55,54,55,54,55,20,7,14,1,7,6,
35,33,17,33,50,23,30,1,23,22,5,20,23,22,23,22,23,22,
59,1,17,35,34,7,6,7,6,7,6,7,6,7,6,7,52,55,
62,1,55,54,51,33,17,33,34,39,46,1,39,38,8,46,10,11,
20,21,37,41,46,51,69,73,84,245,245,127,92,91,53,52,24,24,
166,40,39,146,113,114,136,254,68,1,188,138,112,113,146,39,40,247,
248,24,24,53,53,91,91,128,244,244,84,73,70,51,44,42,37,21,
22,10,10,166,40,39,146,113,112,138,1,188,254,68,136,114,113,146,
39,40,2,215,69,61,70,63,68,56,62,42,47,24,26,251,106,42,
42,80,78,105,103,136,151,135,133,196,56,56,5,176,61,62,202,131,
134,139,135,104,102,81,80,42,42,4,150,26,25,46,40,64,56,68,
70,63,61,69,139,134,131,202,62,61,250,80,56,56,196,133,135,0,
0,4,0,48,254,185,5,19,6,236,0,22,0,49,0,112,0,116,
0,0,19,54,55,62,1,51,50,22,23,22,21,20,7,14,1,35,
34,39,38,39,38,53,52,23,20,23,22,23,22,51,50,54,55,54,
55,54,53,52,39,38,39,38,35,34,7,6,7,6,7,6,1,55,
23,30,1,51,50,55,54,53,52,39,38,39,38,39,38,43,1,53,
51,50,55,54,53,52,38,43,1,34,7,6,15,1,39,55,54,55,
54,51,50,23,22,23,22,21,20,7,6,7,22,23,22,23,22,21,
20,7,6,35,34,38,39,1,35,1,51,66,18,33,33,108,66,100,
128,26,15,29,30,126,88,99,67,65,26,15,149,13,15,29,28,38,
26,48,16,16,9,9,13,14,29,27,37,25,25,24,17,18,8,10,
2,46,144,13,16,60,32,56,38,37,11,9,20,19,22,24,24,74,
84,34,25,26,52,34,3,30,21,20,13,15,134,17,32,57,58,72,
56,56,53,35,35,19,18,26,23,21,23,15,14,81,82,116,72,146,
31,254,165,150,2,209,144,5,229,73,59,59,72,150,119,72,77,113,
88,92,120,76,74,119,70,74,82,82,58,62,73,40,39,42,40,39,
50,49,52,68,61,69,41,39,22,21,42,43,48,57,250,8,43,27,
33,40,33,33,54,28,24,19,17,16,7,8,132,27,28,40,36,50,
15,15,28,32,62,32,62,37,37,28,26,54,53,65,49,41,39,26,
18,26,28,38,36,45,114,73,74,88,74,1,46,4,158,0,0,1,
0,120,0,224,6,18,2,224,0,6,0,0,37,9,1,7,33,21,
33,1,120,255,0,1,0,64,4,218,251,38,224,1,0,1,0,192,
128,0,0,1,0,250,0,0,2,250,5,154,0,6,0,0,19,9,
1,39,17,35,17,250,1,0,1,0,192,128,4,154,1,0,255,0,
64,251,38,4,218,0,0,1,0,120,0,224,6,18,2,224,0,6,
0,0,1,33,53,33,39,9,1,5,82,251,38,4,218,64,1,0,
255,0,1,160,128,192,255,0,255,0,0,1,0,250,0,0,2,250,
5,154,0,6,0,0,37,17,51,17,55,9,1,1,186,128,192,255,
0,255,0,194,4,216,251,40,64,254,254,1,2,0,0,1,0,120,
0,224,6,18,2,224,0,9,0,0,1,23,9,1,7,33,39,9,
1,55,1,56,64,255,0,1,0,64,4,26,64,1,0,255,0,64,
1,160,192,1,0,1,0,192,192,255,0,255,0,192,0,0,0,1,
0,250,0,0,2,250,5,154,0,9,0,0,37,55,9,1,23,17,
7,9,1,39,2,58,192,255,0,255,0,192,192,1,0,1,0,192,
194,64,254,254,1,2,64,4,24,64,1,0,255,0,64,0,0,0,
0,1,1,52,0,188,5,88,4,224,0,6,0,0,1,17,5,7,
1,7,1,1,52,1,106,180,3,110,92,252,146,3,116,1,108,2,
90,252,146,90,3,110,0,0,0,1,1,52,0,188,5,88,4,224,
0,6,0,0,1,37,3,39,1,39,1,3,236,1,108,2,90,252,
146,90,3,110,4,222,2,254,148,182,252,146,90,3,110,0,0,1,
1,52,0,188,5,88,4,224,0,6,0,0,9,1,55,1,55,19,
33,4,162,252,146,90,3,110,90,2,254,148,1,22,3,110,92,252,
146,180,254,150,0,0,0,1,1,52,0,188,5,88,4,224,0,6,
0,0,9,1,23,1,23,33,17,1,142,3,110,92,252,146,180,254,
150,1,114,3,110,92,252,146,90,1,106,0,0,0,0,1,0,120,
0,88,6,18,3,104,0,14,0,0,1,33,23,9,1,7,33,19,
51,3,33,21,33,3,35,2,240,254,72,64,255,0,1,0,64,1,
226,108,128,108,2,120,253,94,106,128,1,160,192,1,0,1,0,192,
1,72,254,184,128,254,184,0,0,0,0,1,0,120,0,88,6,18,
3,104,0,14,0,0,1,33,39,9,1,55,33,3,35,19,33,53,
33,19,51,3,154,1,184,64,1,0,255,0,64,254,30,106,128,106,
253,136,2,162,108,128,2,32,192,255,0,255,0,192,254,184,1,72,
128,1,72,0,0,0,0,1,0,206,1,2,5,190,2,190,0,23,
0,0,1,3,37,7,23,22,51,50,55,54,51,50,31,1,7,39,
38,35,34,4,35,38,47,1,1,44,94,1,94,152,134,80,77,102,
97,169,169,71,55,112,64,74,44,96,94,254,248,138,128,94,134,1,
2,1,94,94,136,76,44,79,137,26,66,112,44,26,210,10,50,78,
0,1,0,206,1,2,5,190,2,190,0,23,0,0,1,7,6,7,
34,36,35,34,15,1,39,55,54,51,50,23,22,51,50,63,1,39,
5,3,5,56,136,91,129,138,254,248,96,93,47,72,64,112,54,72,
169,169,97,102,75,80,136,152,1,94,94,1,200,78,49,11,210,26,
44,112,66,26,137,79,44,76,136,94,254,162,0,1,0,120,0,224,
6,18,2,224,0,12,0,0,1,51,55,7,33,21,33,23,39,35,
23,9,1,1,56,34,192,64,4,56,251,200,64,192,34,64,255,0,
1,0,2,32,192,192,128,192,192,192,1,0,1,0,0,1,0,250,
0,0,2,250,5,154,0,12,0,0,1,21,23,39,17,35,17,7,
55,53,7,9,1,2,58,192,192,128,192,192,192,1,0,1,0,4,
218,34,192,64,251,200,4,56,64,192,34,64,1,0,255,0,0,1,
0,120,0,224,6,18,2,224,0,12,0,0,1,35,7,55,33,53,
33,39,23,51,39,9,1,5,82,34,192,64,251,200,4,56,64,192,
34,64,1,0,255,0,1,160,192,192,128,192,192,192,255,0,255,0,
0,1,0,250,0,0,2,250,5,154,0,12,0,0,37,53,39,23,
17,51,17,55,7,21,55,9,1,1,186,192,192,128,192,192,192,255,
0,255,0,192,34,192,64,4,56,251,200,64,192,34,64,255,0,1,
0,0,0,1,0,120,0,224,6,60,2,224,0,11,0,0,1,33,
23,9,1,7,33,55,51,7,19,35,5,36,252,20,64,255,0,1,
0,64,3,236,152,128,200,200,128,1,160,192,1,0,1,0,192,192,
254,254,254,0,0,1,0,120,0,224,6,60,2,224,0,11,0,0,
55,35,19,39,51,23,33,39,9,1,55,33,248,128,200,200,128,152,
3,236,64,1,0,255,0,64,252,20,224,1,2,254,192,192,255,0,
255,0,192,0,0,0,0,1,0,120,0,224,6,18,2,224,0,10,
0,0,1,53,51,17,35,53,33,23,9,1,7,5,210,64,64,251,
102,64,255,0,1,0,64,2,32,128,254,128,128,192,1,0,1,0,
192,0,0,0,0,1,0,248,0,0,2,248,5,154,0,10,0,0,
37,51,21,33,53,51,17,7,9,1,39,2,56,128,254,128,128,192,
1,0,1,0,192,64,64,64,4,154,64,1,0,255,0,64,0,1,
0,120,0,224,6,18,2,224,0,10,0,0,1,53,51,17,35,53,
33,23,9,1,7,5,210,64,64,251,102,64,255,0,1,0,64,2,
32,128,254,128,128,192,1,0,1,0,192,0,0,0,0,1,0,250,
0,0,2,250,5,154,0,10,0,0,1,35,53,33,21,35,17,55,
9,1,23,1,186,128,1,128,128,192,255,0,255,0,192,5,90,64,
64,251,102,64,255,0,1,0,64,0,0,0,0,2,0,120,0,0,
3,116,5,154,0,3,0,13,0,0,55,33,21,33,1,55,9,1,
23,17,7,9,1,39,120,2,252,253,4,1,194,192,255,0,255,0,
192,192,1,0,1,0,192,100,100,1,100,64,254,254,1,2,64,3,
118,64,1,0,255,0,64,0,0,1,0,120,0,0,3,94,5,152,
0,8,0,0,1,33,23,9,1,7,37,17,35,2,222,254,90,64,
255,0,1,0,64,2,38,128,4,88,192,1,0,1,0,192,2,251,
38,0,0,1,0,150,0,0,3,124,5,152,0,8,0,0,33,35,
17,5,39,9,1,55,33,1,22,128,2,38,64,1,0,255,0,64,
254,90,4,218,2,192,255,0,255,0,192,0,0,0,0,1,0,120,
0,0,3,94,5,152,0,8,0,0,1,51,17,33,23,9,1,7,
33,2,222,128,253,218,64,255,0,1,0,64,1,166,5,152,251,40,
192,1,0,1,0,192,0,0,0,1,0,150,0,0,3,124,5,152,
0,8,0,0,1,33,39,9,1,55,33,17,51,1,22,1,166,64,
1,0,255,0,64,253,218,128,1,64,192,255,0,255,0,192,4,216,
0,0,0,1,0,120,0,4,3,138,5,154,0,8,0,0,19,53,
33,3,55,9,1,23,17,120,2,84,2,192,255,0,255,0,192,5,
26,128,251,42,64,255,0,1,0,64,4,86,0,0,0,1,0,120,
0,0,5,136,5,152,0,8,0,0,1,51,17,33,23,9,1,7,
33,5,8,128,251,176,64,255,0,1,0,64,3,208,5,152,251,40,
192,1,0,1,0,192,0,0,0,1,0,72,2,204,6,66,5,174,
0,32,0,0,1,38,39,38,39,38,39,48,35,34,7,6,7,6,
7,55,7,3,23,54,55,54,55,54,51,48,51,22,23,22,23,22,
23,5,190,5,71,74,139,141,168,9,161,132,137,85,43,23,100,216,
94,82,26,52,108,168,165,198,9,203,169,168,90,87,5,2,206,161,
131,135,88,90,1,72,77,141,73,79,6,172,1,6,58,92,84,173,
95,90,1,109,108,162,159,197,0,1,0,72,2,204,6,66,5,174,
0,32,0,0,19,54,55,54,55,54,55,48,51,50,23,22,23,22,
23,55,3,39,23,38,39,38,39,38,35,48,35,6,7,6,7,6,
7,72,5,87,90,168,169,203,9,198,165,168,108,52,26,82,94,216,
100,23,43,85,137,132,161,9,168,141,139,74,73,1,2,206,197,159,
162,108,109,1,90,95,173,84,92,58,254,250,172,6,79,73,141,77,
72,1,90,88,135,133,159,0,0,2,1,52,0,0,5,88,5,154,
0,6,0,10,0,0,1,17,33,7,1,7,1,3,33,21,33,1,
52,1,106,180,3,110,92,252,146,90,4,36,251,220,2,186,1,106,
90,252,146,92,3,110,2,44,128,0,0,4,0,120,0,0,6,18,
3,252,0,6,0,10,0,17,0,21,0,0,9,2,7,33,21,33,
5,17,51,17,1,33,53,33,39,9,1,5,17,51,17,2,14,255,
0,1,0,64,4,68,251,188,254,170,100,3,226,251,186,4,70,64,
1,0,255,0,1,48,100,1,252,1,0,1,0,192,128,194,2,0,
254,0,254,200,128,192,255,0,255,0,2,2,0,254,0,0,0,1,
0,90,255,237,6,27,5,96,0,47,0,0,19,20,23,22,23,22,
23,22,51,50,55,54,55,54,55,54,53,52,39,38,39,38,39,7,
3,33,7,22,23,22,23,22,21,20,7,6,7,6,7,6,35,34,
39,38,2,39,38,53,218,8,25,103,104,157,107,108,51,43,151,130,
131,58,41,7,25,105,53,67,30,88,1,22,82,79,61,128,30,9,
49,71,157,158,184,58,59,130,126,189,252,30,10,2,206,47,51,152,
132,132,54,37,7,26,100,100,158,114,107,47,42,152,132,65,47,96,
1,6,60,55,77,162,188,57,56,133,134,193,121,122,28,9,44,65,
1,64,188,57,63,0,0,1,0,111,255,237,6,48,5,96,0,47,
0,0,1,20,7,6,2,7,6,35,34,39,38,39,38,39,38,53,
52,55,54,55,54,55,39,33,3,39,6,7,6,7,6,21,20,23,
22,23,22,23,22,51,50,55,54,55,54,55,54,53,6,48,10,30,
252,189,126,130,59,58,184,158,157,71,49,9,30,128,61,79,82,1,
22,88,30,67,53,105,25,7,41,58,131,130,151,43,51,108,107,157,
104,103,25,8,2,206,63,57,188,254,192,65,44,9,28,122,121,193,
134,133,56,57,188,162,77,55,60,254,250,96,47,65,132,152,42,47,
107,114,158,100,100,26,7,37,54,132,132,152,51,47,0,1,0,120,
2,32,6,18,3,96,0,4,0,0,19,1,7,33,21,120,1,64,
64,4,154,2,32,1,64,192,128,0,0,1,0,120,0,224,6,18,
2,32,0,4,0,0,1,21,33,23,1,6,18,251,102,64,254,192,
2,32,128,192,1,64,0,1,1,192,0,0,3,0,5,154,0,4,
0,0,9,1,39,17,35,1,192,1,64,192,128,5,154,254,192,64,
251,102,0,1,1,0,0,0,2,64,5,154,0,4,0,0,9,1,
17,35,17,1,0,1,64,128,4,90,1,64,250,102,4,154,0,1,
0,120,2,30,6,18,3,94,0,4,0,0,19,53,33,39,1,120,
4,154,64,1,64,2,30,128,192,254,192,0,0,1,0,120,0,224,
6,18,2,32,0,4,0,0,1,33,53,33,1,5,18,251,102,5,
154,254,192,1,160,128,254,192,0,1,1,192,0,0,3,0,5,154,
0,4,0,0,1,51,17,55,1,1,192,128,192,254,192,5,154,251,
104,64,254,190,0,1,1,0,0,0,2,64,5,154,0,4,0,0,
1,17,51,17,1,1,192,128,254,192,1,2,4,152,250,102,1,66,
0,2,0,120,255,246,6,18,3,192,0,6,0,13,0,0,5,9,
1,7,33,21,33,1,33,53,33,39,9,1,1,120,255,0,1,0,
64,4,218,251,38,4,26,251,38,4,218,64,1,0,255,0,10,1,
0,1,0,192,128,1,202,128,192,255,0,255,0,0,0,2,1,74,
0,0,5,64,5,156,0,6,0,13,0,0,9,2,39,17,35,17,
1,17,51,17,55,9,1,1,74,1,0,1,0,192,128,1,246,128,
192,255,0,255,0,4,154,1,0,255,0,64,251,38,4,218,251,232,
4,218,251,38,64,255,0,1,0,0,0,2,0,120,255,246,6,18,
3,192,0,6,0,13,0,0,37,33,53,33,39,9,4,7,33,21,
33,5,82,251,38,4,218,64,1,0,255,0,252,102,255,0,1,0,
64,4,218,251,38,182,128,192,255,0,255,0,1,202,1,0,1,0,
192,128,0,2,0,120,0,54,6,18,3,128,0,6,0,13,0,0,
1,33,21,33,23,45,1,3,33,21,33,23,45,1,1,62,4,212,
251,44,58,255,0,1,0,56,4,210,251,46,56,255,0,1,0,3,
0,128,128,192,192,253,182,128,128,192,192,0,0,2,1,160,0,0,
4,234,5,154,0,6,0,13,0,0,1,17,35,17,7,27,1,37,
17,35,17,7,27,1,4,106,128,128,192,192,253,182,128,128,192,192,
4,212,251,44,4,212,58,1,0,255,0,56,251,46,4,210,56,1,
0,255,0,0,0,2,0,120,0,54,6,18,3,128,0,6,0,13,
0,0,1,13,1,55,33,53,33,3,13,1,55,33,53,33,5,18,
1,0,255,0,58,251,44,4,212,58,1,0,255,0,56,251,46,4,
210,3,128,192,192,128,128,254,182,192,192,128,128,0,0,2,1,160,
0,0,4,234,5,154,0,6,0,13,0,0,1,11,1,23,17,51,
17,37,11,1,23,17,51,17,4,234,192,192,128,128,254,182,192,192,
128,128,1,0,255,0,1,0,58,4,212,251,44,58,255,0,1,0,
56,4,210,251,46,0,0,2,0,120,0,160,6,18,3,160,0,4,
0,9,0,0,9,1,55,33,61,1,1,7,33,21,6,18,254,192,
64,251,102,1,64,64,4,154,1,224,254,192,192,128,128,1,64,192,
128,0,0,0,0,2,0,120,0,160,6,18,3,160,0,4,0,9,
0,0,1,21,33,23,1,61,1,33,39,1,6,18,251,102,64,254,
192,4,154,64,1,64,1,224,128,192,1,64,128,128,192,254,192,0,
0,0,0,3,0,10,1,20,3,98,3,214,0,5,0,9,0,13,
0,0,9,2,21,5,1,39,33,21,33,17,33,21,33,1,235,254,
31,1,233,254,148,1,101,104,1,222,254,34,1,222,254,34,1,20,
1,110,1,84,90,251,254,249,192,72,1,30,72,0,0,0,0,3,
0,85,0,201,3,23,4,33,0,5,0,9,0,13,0,0,19,9,
1,35,3,1,55,17,35,17,33,17,35,17,85,1,110,1,84,90,
251,254,249,192,72,1,30,72,2,64,1,225,254,23,1,108,254,155,
104,254,34,1,222,254,34,1,222,0,0,0,0,3,0,10,1,20,
3,98,3,214,0,5,0,9,0,13,0,0,1,39,1,37,53,1,
5,21,33,53,37,21,33,53,1,129,1,1,101,254,148,1,233,254,
134,254,34,1,222,254,34,1,20,102,1,7,251,90,254,172,72,72,
72,214,72,72,0,3,0,85,0,201,3,23,4,33,0,5,0,9,
0,13,0,0,9,2,51,19,1,7,17,51,17,33,17,51,17,3,
23,254,146,254,172,90,251,1,7,192,72,254,226,72,2,170,254,31,
1,233,254,148,1,101,104,1,222,254,34,1,222,254,34,0,0,0,
0,4,0,10,1,20,4,220,3,214,0,5,0,11,0,15,0,19,
0,0,1,39,1,37,53,9,3,21,5,1,39,33,21,33,17,33,
21,33,2,251,1,1,101,254,148,1,233,253,15,254,31,1,233,254,
148,1,101,104,1,222,254,34,1,222,254,34,1,20,102,1,7,251,
90,254,172,254,146,1,110,1,84,90,251,254,249,192,72,1,30,72,
0,0,0,2,0,72,0,0,4,223,5,176,0,2,0,10,0,0,
37,19,33,39,33,19,51,1,35,1,51,2,148,204,254,97,37,1,
241,162,176,253,244,127,253,244,180,242,2,81,136,1,229,250,80,5,
176,0,0,0,0,2,0,82,255,227,3,160,5,176,0,20,0,75,
0,0,19,20,23,22,23,22,51,50,55,54,53,52,39,38,39,38,
35,34,7,14,1,1,22,23,22,23,22,23,22,23,22,29,1,20,
7,6,35,34,38,39,38,53,52,55,54,51,50,23,22,23,22,23,
22,23,22,23,30,2,23,52,39,38,39,38,47,1,38,35,34,7,
39,54,51,50,23,233,10,26,75,76,72,112,86,86,7,24,95,93,
104,58,53,51,58,1,195,62,70,66,24,8,1,4,5,4,124,123,
179,171,202,32,15,110,111,160,43,34,40,18,25,25,21,17,13,25,
6,16,11,3,9,19,53,52,56,116,69,91,37,78,14,36,46,193,
134,1,199,49,47,117,68,68,108,109,132,39,27,114,79,77,53,51,
158,2,249,70,123,115,112,36,33,53,72,61,75,38,227,153,151,184,
152,72,80,196,135,136,7,8,7,9,18,15,15,11,24,6,15,10,
3,33,40,94,105,104,50,86,25,8,147,2,70,0,0,0,0,1,
0,121,0,0,4,18,5,176,0,11,0,0,41,1,53,33,17,33,
53,33,17,33,53,33,4,18,252,103,2,251,253,48,2,208,253,5,
3,153,141,1,242,141,2,23,141,0,0,3,0,94,0,136,4,88,
5,38,0,36,0,55,0,72,0,0,19,52,55,62,1,55,54,55,
54,51,50,23,55,51,7,23,22,23,22,21,20,7,6,7,6,35,
34,47,1,7,35,55,38,39,38,39,38,55,20,23,22,23,22,23,
1,38,39,38,35,34,7,6,7,6,7,6,37,1,22,23,22,51,
50,54,55,62,1,53,52,39,38,39,38,94,32,32,100,69,67,70,
67,71,109,89,59,144,95,15,141,37,11,74,75,116,114,131,108,100,
13,93,150,136,39,23,80,26,12,117,9,17,39,24,34,1,146,12,
10,57,55,66,70,66,60,57,37,35,2,122,254,109,21,21,58,60,
70,132,61,58,72,9,17,42,36,2,238,101,87,86,116,41,40,20,
19,38,96,158,12,112,175,60,51,147,117,119,63,62,42,6,154,222,
34,26,89,125,56,62,50,44,76,56,35,31,2,146,5,3,19,25,
24,47,46,79,76,211,253,102,9,6,18,52,50,48,152,90,46,40,
76,60,52,0,0,2,0,120,0,0,5,182,5,160,0,3,0,6,
0,0,51,1,51,1,37,33,1,120,2,70,179,2,69,251,212,3,
35,254,110,5,160,250,96,157,4,66,0,0,0,2,0,120,0,0,
5,182,5,160,0,3,0,6,0,0,19,33,1,35,9,2,120,5,
62,253,187,179,254,204,1,145,1,146,5,160,250,96,5,3,251,190,
4,66,0,1,0,137,0,0,4,18,5,176,0,34,0,0,1,20,
23,22,23,22,59,1,21,35,34,39,38,39,38,17,53,16,55,54,
55,54,59,1,21,35,34,7,6,7,6,21,33,21,33,1,23,83,
82,167,86,114,231,231,130,101,213,115,115,115,115,213,101,130,231,231,
117,83,168,81,83,2,250,253,6,2,127,238,103,102,36,19,141,22,
45,129,128,1,59,178,1,59,128,129,45,22,141,19,38,100,103,238,
141,0,0,3,0,109,255,226,4,18,6,60,0,33,0,38,0,46,
0,0,5,35,19,38,17,53,16,55,54,55,54,63,1,51,7,51,
21,35,3,33,21,33,3,22,23,22,59,1,21,35,34,39,38,39,
19,35,21,20,23,27,1,6,7,6,7,6,21,1,11,158,120,92,
115,115,213,96,125,65,158,65,83,149,232,1,124,254,67,195,79,131,
86,114,231,231,130,101,143,99,100,159,30,194,231,64,59,168,81,83,
30,1,1,134,1,22,178,1,59,128,129,45,20,2,140,140,141,254,
14,141,254,93,69,28,19,141,22,30,69,2,43,37,144,95,1,161,
1,240,4,13,38,100,103,238,0,0,0,1,0,58,0,94,5,66,
4,113,0,32,0,0,19,53,33,32,23,22,21,20,7,6,7,6,
35,33,53,33,50,55,54,55,54,55,33,53,33,38,39,38,39,38,
39,38,35,58,2,102,1,63,177,178,115,115,212,101,131,253,154,2,
102,118,82,167,83,65,14,251,138,4,107,8,9,31,64,62,104,102,
138,3,208,161,137,138,246,198,128,129,45,22,162,18,36,92,73,95,
142,24,18,63,52,50,29,28,0,0,0,1,0,110,0,0,4,64,
5,176,0,7,0,0,19,33,17,35,17,33,17,35,110,3,210,158,
253,106,158,5,176,250,80,5,25,250,231,0,0,0,0,1,0,110,
0,0,4,64,5,176,0,7,0,0,51,17,51,17,33,17,51,17,
110,158,2,150,158,5,176,250,231,5,25,250,80,0,0,1,0,64,
0,58,4,24,5,121,0,11,0,0,37,5,53,9,1,53,37,21,
5,9,1,37,4,24,252,40,1,148,254,108,3,216,252,204,1,180,
254,80,3,48,60,2,214,1,204,1,204,207,2,153,2,253,254,253,
247,2,0,1,0,68,2,58,2,136,2,200,0,3,0,0,19,33,
21,33,68,2,68,253,188,2,200,142,0,0,0,1,0,73,0,208,
3,72,4,40,0,59,0,0,1,23,30,1,20,7,6,35,34,47,
1,23,20,7,6,35,34,38,53,55,7,6,35,34,39,38,53,52,
63,1,39,38,53,52,55,54,51,50,31,1,39,52,54,51,50,23,
22,21,7,55,54,51,50,23,22,21,20,7,6,7,2,64,224,16,
24,12,23,39,22,19,207,14,17,18,41,32,42,14,208,21,21,39,
22,12,40,219,217,40,12,22,39,21,21,206,14,42,32,41,18,17,
14,205,19,22,39,23,12,12,13,15,2,125,113,7,34,42,21,38,
12,135,245,29,23,24,42,34,248,136,12,40,20,20,43,19,111,109,
19,43,21,19,40,12,135,247,34,42,24,23,29,244,134,12,38,21,
21,20,17,18,7,0,0,0,0,1,0,0,0,0,5,1,6,234,
0,8,0,0,1,51,1,35,3,33,53,33,19,4,93,164,253,232,
219,175,254,161,1,218,161,6,234,249,22,2,51,142,253,231,255,255,
0,0,0,0,5,1,6,245,16,39,0,117,0,172,0,7,16,6,
5,67,0,0,255,255,0,0,0,0,5,1,6,234,16,38,4,126,
68,0,16,6,5,67,0,0,0,0,0,2,0,22,0,0,3,169,
2,221,0,27,0,67,0,0,19,20,23,22,23,22,23,22,51,50,
55,54,55,54,55,54,53,52,39,38,39,38,35,34,7,6,7,6,
1,38,39,48,39,53,6,7,6,35,34,46,1,53,52,55,54,55,
54,55,54,51,50,23,22,23,54,55,54,51,21,34,7,6,7,21,
22,23,22,51,156,14,14,28,29,48,47,66,65,47,48,29,28,14,
14,24,25,55,58,83,84,58,55,25,24,3,10,154,65,4,40,60,
88,121,120,176,84,25,26,45,47,73,76,88,121,86,61,39,6,31,
54,137,66,52,35,2,6,45,44,57,1,113,57,51,50,39,39,23,
22,22,23,39,39,50,51,57,79,60,62,36,38,38,36,62,60,254,
76,1,108,6,9,52,34,50,100,166,103,79,65,67,48,50,27,28,
49,34,50,9,31,80,90,64,43,84,149,96,47,46,0,0,0,3,
0,6,0,206,5,104,4,3,0,16,0,47,0,64,0,0,1,50,
54,53,52,38,39,38,35,34,7,6,21,20,22,23,22,1,54,51,
50,23,30,1,21,20,7,6,43,1,34,39,38,39,6,7,6,35,
34,39,38,53,52,54,55,54,51,50,3,50,55,62,1,53,52,39,
38,35,34,7,14,1,21,20,22,3,243,100,132,98,80,25,29,114,
64,65,98,86,29,254,225,110,207,43,34,132,164,107,107,203,13,14,
16,152,78,81,147,39,48,160,106,107,164,132,34,43,210,210,31,28,
86,98,65,64,114,29,25,80,98,132,1,108,132,120,100,132,16,6,
70,71,111,96,134,18,6,1,219,188,8,29,220,154,175,118,117,9,
44,133,147,30,9,117,118,175,154,220,29,8,253,105,6,18,134,96,
111,71,70,6,16,132,100,120,132,0,0,1,0,54,0,0,3,51,
3,104,0,5,0,0,37,33,21,33,1,23,1,33,2,18,253,3,
2,18,109,142,142,3,104,56,0,0,0,1,0,79,0,0,3,141,
5,176,0,6,0,0,33,9,1,35,1,51,1,3,18,254,222,254,
223,128,1,79,164,1,75,5,8,250,248,5,176,250,80,0,0,0,
0,1,0,79,0,0,3,141,5,176,0,6,0,0,1,51,1,35,
1,51,1,3,18,123,254,181,164,254,177,128,1,33,5,176,250,80,
5,176,250,248,0,1,0,121,255,227,4,141,4,236,0,28,0,0,
5,17,52,39,38,39,38,39,38,35,34,7,6,7,6,21,17,35,
17,52,55,54,55,54,51,50,0,25,1,3,236,28,28,52,51,63,
66,73,122,92,93,34,19,162,22,45,130,130,195,246,1,20,29,2,
103,137,102,103,64,63,31,32,83,84,165,83,117,253,153,2,103,130,
101,210,117,116,254,156,254,194,253,153,0,1,0,121,255,227,4,141,
4,236,0,29,0,0,1,51,17,16,7,6,35,34,39,38,39,38,
53,17,51,17,20,23,22,23,22,51,50,55,54,55,54,55,54,53,
3,236,161,138,138,246,197,128,130,45,22,162,19,34,93,92,122,76,
63,61,53,52,28,28,4,236,253,153,254,195,178,179,115,116,212,101,
130,2,103,253,153,117,83,165,84,83,31,30,65,64,103,102,137,0,
0,0,0,1,0,23,254,84,2,225,7,10,0,41,0,0,37,17,
53,52,55,54,55,54,55,54,55,48,51,50,31,1,38,39,7,14,
1,29,1,3,20,7,6,7,6,7,6,7,35,34,47,1,22,23,
55,62,1,53,1,52,18,18,35,31,59,68,66,7,38,40,49,31,
54,93,38,68,1,18,18,35,31,59,68,66,7,38,40,49,28,57,
93,38,68,234,3,230,143,65,79,80,70,61,32,36,4,24,145,15,
6,13,14,106,49,188,250,251,65,79,80,70,61,32,36,4,24,144,
14,6,13,14,106,49,0,0,0,3,0,92,0,0,3,131,2,212,
0,27,0,45,0,63,0,0,1,6,7,6,35,34,39,38,39,38,
53,52,55,54,55,54,55,54,51,50,23,22,23,22,21,20,7,6,
1,34,38,53,52,55,54,55,54,51,50,22,21,20,7,6,7,6,
33,34,38,53,52,55,54,55,54,51,50,22,21,20,7,6,7,6,
2,80,22,44,13,16,27,26,33,14,6,5,7,2,22,43,13,16,
29,24,33,14,6,5,4,254,116,44,64,24,25,36,10,13,45,62,
24,21,40,10,2,68,44,64,25,24,37,10,12,45,62,23,21,41,
7,2,51,38,12,4,15,19,36,16,22,15,18,17,4,37,12,4,
14,19,36,17,19,13,22,14,253,198,64,44,40,28,29,8,2,62,
45,40,28,25,12,3,64,44,38,30,28,8,2,62,44,41,27,26,
12,2,0,1,0,63,2,51,3,90,3,92,0,38,0,0,19,54,
55,54,55,54,51,50,23,22,31,3,50,55,54,63,1,21,6,7,
6,7,6,35,34,39,38,47,3,34,7,6,7,6,7,63,19,44,
30,46,44,45,32,37,34,31,60,66,72,41,42,33,43,76,66,8,
30,46,42,43,40,39,37,35,62,62,59,45,41,44,28,41,27,2,
252,11,31,21,17,16,16,15,23,44,38,15,15,12,26,45,145,42,
5,21,16,15,15,14,24,46,38,15,15,16,20,29,17,0,0,0,
0,3,0,66,1,31,3,98,4,62,0,38,0,42,0,46,0,0,
19,54,55,62,1,51,50,23,22,31,3,50,55,54,63,1,21,14,
1,7,6,7,6,35,34,39,38,47,3,34,7,6,7,6,7,3,
33,21,33,17,33,21,33,69,19,44,31,88,46,32,37,34,31,59,
67,72,40,42,35,42,76,5,57,13,31,44,42,43,40,39,37,35,
62,62,59,46,41,42,29,41,27,3,3,32,252,224,3,32,252,224,
3,222,11,31,22,32,16,15,23,44,38,15,15,13,25,45,145,3,
35,9,21,16,15,15,14,24,46,38,15,15,15,21,29,17,254,97,
142,1,169,141,0,2,0,63,0,220,2,188,3,92,0,47,0,91,
0,0,19,54,55,54,55,54,51,50,23,22,23,48,23,22,23,22,
51,50,55,54,55,54,55,21,6,7,6,7,6,35,34,39,38,39,
46,2,39,38,39,38,35,34,7,6,7,6,7,17,54,55,62,1,
51,50,23,22,23,30,1,23,30,1,51,50,55,54,55,54,55,21,
6,7,6,7,6,35,34,39,38,39,38,39,38,39,38,35,34,6,
7,6,7,63,33,18,25,35,37,35,26,29,26,26,48,22,31,30,
28,29,37,36,26,47,13,49,11,27,33,34,34,30,34,30,27,6,
20,17,7,26,23,27,21,36,33,31,26,13,42,24,27,25,70,37,
25,30,26,26,8,32,8,25,56,30,32,34,30,32,27,33,49,11,
27,33,34,34,32,32,30,27,16,34,26,23,26,22,36,66,24,27,
28,1,165,25,16,22,16,17,15,14,24,45,21,16,16,16,15,21,
36,10,145,38,9,23,14,15,16,14,24,5,18,14,7,25,13,16,
15,14,23,12,33,1,233,18,24,22,32,16,14,24,7,29,8,23,
30,15,13,25,21,24,145,38,9,23,14,15,15,14,24,14,32,25,
13,15,30,21,23,23,0,1,0,15,0,24,3,112,4,182,0,19,
0,0,55,35,19,35,53,51,55,33,53,33,19,51,3,51,21,33,
7,33,21,33,165,150,204,153,239,138,254,135,1,207,207,144,206,192,
254,235,136,1,157,254,13,24,1,78,142,225,141,1,84,254,172,141,
225,142,0,3,0,66,1,30,3,98,3,225,0,3,0,7,0,11,
0,0,19,33,21,33,17,33,21,33,17,33,21,33,66,3,32,252,
224,3,32,252,224,3,32,252,224,3,225,141,254,88,142,1,169,141,
0,2,0,109,1,62,3,18,4,171,0,6,0,10,0,0,9,1,
53,1,21,13,2,33,21,33,3,6,253,104,2,160,254,90,1,158,
253,103,2,165,253,91,1,233,1,47,117,1,30,153,193,209,180,142,
0,0,0,2,0,109,1,62,3,18,4,171,0,6,0,10,0,0,
19,53,45,1,53,1,21,19,21,33,53,121,1,158,254,90,2,160,
1,253,91,1,233,151,209,193,153,254,226,117,254,180,142,142,0,0,
0,1,0,58,0,94,5,66,4,113,0,28,0,0,1,33,34,7,
6,7,14,1,21,20,23,22,23,22,51,33,21,33,34,39,38,39,
38,53,52,55,54,41,1,5,66,253,154,138,102,104,62,64,62,82,
84,166,79,121,2,102,253,154,131,101,212,115,115,178,177,1,63,2,
102,3,208,28,29,50,52,126,75,123,91,94,34,18,162,22,45,129,
128,198,246,138,137,0,0,1,0,58,0,94,5,66,4,113,0,28,
0,0,19,53,33,32,23,22,21,20,7,6,7,6,35,33,53,33,
50,55,54,55,54,53,52,38,39,38,39,38,35,58,2,102,1,63,
177,178,115,115,212,101,131,253,154,2,102,121,79,166,84,82,62,64,
62,104,102,138,3,208,161,137,138,246,198,128,129,45,22,162,18,34,
94,91,123,75,126,52,50,29,28,0,0,0,0,2,0,95,0,210,
4,20,5,239,0,26,0,37,0,0,1,33,48,35,3,22,51,33,
21,33,34,39,7,35,55,38,39,38,53,52,55,54,55,19,23,3,
51,5,6,7,6,7,6,21,20,23,22,23,4,20,254,237,22,145,
71,96,1,19,254,237,116,96,65,136,74,135,85,115,179,145,243,79,
127,75,251,254,82,35,49,105,55,111,72,53,92,4,70,254,10,10,
162,15,225,252,39,76,103,158,196,111,90,17,1,11,5,254,253,168,
4,9,20,37,75,104,98,57,41,25,0,2,0,100,0,0,4,25,
4,21,0,3,0,31,0,0,37,21,33,53,1,33,34,7,6,7,
6,21,20,23,22,23,22,51,33,21,33,34,39,38,39,38,53,52,
55,54,41,1,4,25,252,75,3,181,254,237,133,106,105,55,111,72,
73,165,86,114,1,19,254,237,128,103,212,115,116,178,177,1,63,1,
19,142,142,142,2,230,20,20,37,75,104,98,57,58,28,15,162,18,
36,103,104,157,196,111,110,0,0,0,0,2,0,100,0,0,4,25,
4,21,0,3,0,30,0,0,55,33,21,33,17,53,33,32,23,22,
21,20,6,7,6,35,33,53,33,50,55,54,55,54,53,52,39,38,
39,38,35,100,3,181,252,75,1,19,1,62,177,179,230,213,104,127,
254,237,1,19,115,85,165,73,72,111,55,105,106,133,142,142,3,116,
161,110,111,196,158,206,36,18,162,15,28,58,57,98,104,75,37,20,
20,0,0,5,0,94,0,242,4,88,4,236,0,27,0,39,0,49,
0,62,0,72,0,0,19,52,55,62,1,55,54,55,54,51,50,4,
23,22,21,20,7,6,7,6,35,34,39,38,39,38,39,38,23,22,
23,22,23,22,23,22,23,22,23,17,19,54,55,54,55,54,55,54,
55,33,37,52,38,53,38,39,38,39,38,39,38,39,17,3,6,7,
6,7,6,7,6,7,33,94,32,32,100,69,67,70,67,71,180,1,
26,37,11,74,75,116,114,131,108,100,101,81,80,26,12,121,1,4,
17,39,39,56,54,59,16,22,141,37,38,66,61,58,36,22,9,254,
185,1,69,2,17,42,43,56,54,60,21,30,141,23,33,66,60,57,
37,19,10,1,49,2,238,101,87,86,116,41,40,20,19,224,175,60,
51,147,117,119,63,62,42,42,92,89,125,56,4,10,18,76,56,57,
37,36,18,5,5,1,62,254,191,6,15,26,50,48,76,47,53,142,
1,7,2,76,60,61,36,35,20,7,6,254,201,1,53,5,12,24,
47,46,79,42,54,0,0,0,0,5,0,94,0,242,4,88,4,236,
0,27,0,37,0,48,0,59,0,69,0,0,19,52,55,62,1,55,
54,55,54,51,50,4,23,22,21,20,7,6,7,6,35,34,39,38,
39,38,39,38,55,20,23,22,23,55,39,6,7,6,19,23,22,23,
22,51,50,55,54,55,39,5,54,55,54,53,52,39,38,47,1,7,
19,38,39,38,35,34,7,6,7,23,94,32,32,100,69,67,70,67,
71,180,1,26,37,11,74,75,116,114,131,108,100,101,81,80,26,12,
117,9,15,35,217,216,15,10,35,157,3,54,59,58,60,70,66,44,
34,228,1,76,22,17,36,9,17,42,8,232,127,48,52,57,55,66,
70,54,43,218,2,238,101,87,86,116,41,40,20,19,224,175,60,51,
147,117,119,63,62,42,42,92,89,125,56,62,50,44,67,55,218,216,
24,22,76,254,97,1,36,18,18,26,16,23,228,133,30,36,76,90,
46,40,76,60,11,232,1,71,29,17,19,25,19,30,218,0,0,1,
0,34,0,0,3,94,5,176,0,7,0,0,37,33,21,33,53,33,
17,51,2,15,1,79,252,196,1,80,157,142,142,142,5,34,0,1,
0,82,2,196,1,84,3,198,0,17,0,0,19,52,54,51,50,23,
22,23,22,21,20,6,35,34,39,38,39,38,82,76,53,49,33,35,
9,3,76,53,46,35,36,9,3,3,69,55,74,29,31,42,9,18,
53,76,29,30,43,12,0,0,0,1,0,82,3,68,1,84,4,70,
0,18,0,0,19,52,55,54,51,50,23,22,23,22,21,20,6,35,
34,39,38,39,38,82,38,40,51,49,33,35,9,3,76,53,46,35,
36,9,3,3,196,55,37,38,29,31,42,9,19,52,76,29,30,43,
12,0,0,0,0,1,1,102,255,255,2,168,7,10,0,24,0,0,
33,3,53,52,55,54,55,54,55,54,55,48,51,50,31,1,38,39,
7,6,7,6,29,1,3,1,103,1,14,13,27,24,43,50,51,5,
29,30,36,24,39,70,29,25,26,1,4,208,143,60,84,77,73,62,
31,35,5,24,145,15,6,13,14,53,57,45,188,250,251,0,0,1,
0,145,255,255,1,211,7,10,0,24,0,0,1,19,21,20,7,6,
7,6,7,6,7,48,35,34,47,1,22,23,55,54,55,54,61,1,
19,1,210,1,14,13,27,24,43,50,50,6,28,30,37,22,41,70,
28,26,26,1,7,9,251,48,144,60,84,75,74,62,31,35,5,24,
144,14,6,12,13,55,57,45,187,5,6,0,0,0,0,1,0,57,
0,20,1,182,4,211,0,5,0,0,37,9,1,51,9,1,1,85,
254,228,1,28,97,254,226,1,30,20,2,103,2,88,253,166,253,155,
0,1,0,57,0,20,1,182,4,211,0,5,0,0,55,35,9,1,
51,1,154,97,1,30,254,226,97,1,28,20,2,101,2,90,253,168,
0,2,0,131,0,0,3,25,5,178,0,5,0,9,0,0,1,3,
35,3,19,51,7,3,27,1,3,25,219,219,224,224,219,111,168,168,
168,2,216,253,40,2,216,2,218,169,253,207,253,208,2,48,0,1,
0,126,0,0,5,83,5,176,0,9,0,0,19,51,17,5,17,33,
21,33,17,37,126,158,1,58,2,253,252,101,254,198,5,176,253,185,
3,253,39,141,2,217,1,0,0,0,0,1,0,129,255,227,2,157,
5,174,0,26,0,0,37,20,23,22,51,21,34,39,38,39,38,53,
17,34,39,38,39,38,53,17,51,17,20,23,22,59,1,2,38,3,
17,99,114,65,68,16,7,114,65,68,16,7,151,3,17,99,151,207,
17,13,75,131,37,39,87,35,34,1,253,37,39,87,35,34,1,254,
254,6,16,14,75,0,0,0,0,1,0,121,255,227,4,8,5,176,
0,25,0,0,19,33,21,33,17,33,17,51,17,51,21,35,17,20,
59,1,21,35,34,39,38,53,17,33,17,35,121,3,143,253,15,1,
158,151,188,188,117,70,70,149,59,60,254,98,158,5,176,141,254,14,
1,94,254,162,141,254,51,117,127,55,56,129,1,209,253,92,0,1,
1,216,4,108,3,71,5,64,0,11,0,0,1,22,59,1,50,55,
21,6,43,1,34,39,1,216,115,68,1,68,115,110,73,1,73,110,
5,64,85,85,126,86,86,0,0,0,0,2,0,115,254,63,7,162,
4,78,0,15,0,131,0,0,1,20,23,22,51,50,55,54,53,52,
39,38,35,34,7,6,1,20,7,6,7,6,7,6,35,34,39,38,
39,38,39,38,39,51,30,1,51,50,54,61,2,6,7,6,7,6,
7,6,35,34,39,38,39,46,1,39,38,53,52,55,62,2,51,50,
23,22,59,1,5,17,20,23,22,23,30,1,51,50,55,54,55,54,
55,54,53,17,51,17,20,7,6,7,6,7,6,35,34,39,55,22,
51,50,55,54,55,54,55,54,61,1,6,7,6,35,34,39,38,39,
38,39,38,53,17,35,22,23,22,29,1,17,1,13,77,76,116,117,
79,80,80,79,117,116,76,77,2,180,35,34,58,56,74,70,79,91,
78,80,50,49,31,29,8,143,13,160,91,105,158,18,25,22,35,35,
50,47,65,81,69,66,46,44,64,13,14,23,22,94,154,102,25,87,
53,58,23,2,10,14,15,30,30,102,68,69,50,54,30,31,15,16,
152,38,35,65,62,74,72,81,213,150,106,104,153,52,44,51,37,41,
25,25,29,81,82,113,83,66,67,49,52,26,27,231,24,20,21,2,
27,199,118,116,116,118,197,198,116,115,114,115,253,13,98,84,81,55,
53,31,29,33,34,50,49,60,57,57,86,118,146,134,33,184,42,38,
34,32,32,18,17,32,31,55,53,148,80,84,85,110,101,96,164,92,
18,10,1,253,227,95,70,76,58,59,66,34,36,58,59,75,80,83,
2,28,251,189,97,85,79,57,54,30,29,174,85,123,17,20,30,33,
55,54,71,214,89,60,61,33,34,66,70,106,108,144,1,143,38,55,
60,41,5,253,36,0,0,0,0,1,0,102,254,64,5,199,5,43,
0,72,0,0,19,35,53,51,53,51,21,37,17,20,23,22,23,30,
1,51,50,55,54,55,54,55,54,53,17,51,17,20,7,6,7,6,
7,6,35,34,39,55,22,51,50,55,54,55,54,55,54,61,1,6,
7,6,35,34,39,38,39,38,39,38,53,17,37,17,20,59,1,21,
35,34,39,38,53,244,142,142,151,1,152,15,16,28,30,102,68,70,
50,51,31,34,14,15,152,38,37,62,56,82,75,77,213,150,106,103,
154,50,46,51,37,41,25,25,29,80,81,115,82,66,69,48,50,27,
28,254,255,117,70,70,149,59,60,3,170,135,250,250,1,253,227,90,
75,79,55,59,66,34,35,58,65,70,75,88,2,28,251,189,96,85,
84,54,49,33,30,174,85,123,18,20,30,33,55,54,70,214,91,59,
60,33,34,66,69,106,112,141,1,143,6,253,45,117,127,55,56,129,
0,1,0,101,255,227,5,115,5,206,0,92,0,0,1,38,39,38,
35,34,7,6,21,20,22,51,50,55,54,55,54,55,54,55,23,6,
7,6,7,6,7,6,35,34,39,38,39,38,53,52,55,54,55,54,
55,54,55,54,51,50,23,39,38,53,52,55,54,55,54,55,54,51,
50,23,22,23,22,21,51,21,35,17,20,59,1,21,35,34,39,38,
53,17,35,53,51,53,52,39,38,39,34,7,6,21,20,23,19,3,
2,18,60,61,69,126,92,90,176,130,43,39,43,24,25,18,16,11,
122,24,32,25,50,41,55,53,61,132,104,106,58,59,20,20,40,41,
54,56,72,74,84,89,71,33,3,24,25,53,64,75,30,25,32,33,
143,5,3,197,197,117,70,70,149,59,60,66,66,21,26,34,51,32,
42,2,58,3,41,49,50,50,120,118,183,195,236,18,20,24,25,26,
24,21,77,40,37,29,39,32,20,19,76,77,128,130,155,84,83,82,
70,72,52,55,29,30,37,162,15,14,42,42,46,42,52,9,5,6,
24,188,106,89,135,253,45,117,127,55,56,129,2,215,135,201,42,29,
31,4,22,24,52,6,16,254,127,0,0,0,0,3,0,125,0,0,
5,36,6,120,0,3,0,36,0,43,0,0,1,51,17,35,1,17,
35,17,35,53,51,17,52,55,54,55,54,55,54,51,50,23,22,23,
7,38,39,38,39,38,35,34,6,21,17,51,21,37,35,39,7,35,
1,51,3,127,152,152,254,33,152,139,138,29,30,44,40,52,49,38,
60,37,34,47,109,12,11,10,19,21,27,39,58,195,2,192,188,156,
158,186,1,21,131,4,49,251,207,3,170,252,86,3,170,135,1,54,
62,51,52,35,32,21,20,20,18,44,105,16,11,10,7,8,52,45,
254,161,135,234,213,211,1,86,0,2,0,125,0,0,4,2,6,120,
0,17,0,69,0,0,1,52,54,51,50,23,22,23,22,21,20,6,
35,34,39,38,39,38,1,35,53,51,17,52,55,54,55,54,55,54,
51,50,23,22,23,22,23,22,23,22,21,20,6,35,34,39,38,39,
38,53,54,53,52,39,52,39,38,39,38,7,6,21,17,33,17,35,
17,33,17,35,3,70,56,38,34,25,23,10,2,56,38,32,27,27,
6,2,253,193,138,138,29,30,44,40,52,49,38,31,17,13,3,47,
41,39,8,2,56,38,32,27,21,12,2,3,1,15,11,37,27,24,
29,1,196,151,254,210,152,5,75,38,56,21,20,34,10,9,39,56,
22,22,32,16,254,98,135,1,54,62,51,52,35,32,21,20,17,5,
2,24,84,81,71,10,9,39,56,22,16,38,8,11,7,23,21,14,
4,50,36,6,5,24,26,45,254,161,251,207,3,170,252,86,0,0,
0,1,0,125,255,253,3,99,6,122,0,48,0,0,1,35,53,51,
53,17,52,55,54,55,54,55,54,51,50,23,22,23,48,23,19,22,
23,22,21,20,7,6,7,6,39,3,38,39,38,39,38,35,34,6,
21,17,5,17,35,17,33,17,35,1,8,139,138,29,30,44,40,52,
49,38,60,37,33,46,2,128,11,3,2,13,12,20,31,9,168,12,
11,10,19,21,27,39,58,1,194,151,254,212,152,3,170,135,2,1,
54,62,51,52,35,32,21,20,20,17,43,2,254,189,14,9,8,6,
17,18,15,5,9,16,1,47,16,11,10,7,8,52,45,254,161,3,
251,205,3,173,252,86,0,0,0,2,0,100,0,0,3,252,6,120,
0,34,0,60,0,0,1,17,35,17,35,53,51,17,52,55,54,55,
54,55,54,51,50,22,23,7,38,39,38,39,38,35,34,7,6,21,
17,33,17,35,17,3,37,54,51,50,23,22,23,22,21,20,7,6,
7,5,6,35,34,39,38,39,38,53,52,55,54,1,135,152,139,138,
30,30,43,40,52,49,38,59,74,45,109,12,11,10,19,21,27,40,
29,28,1,194,151,75,1,25,22,26,12,6,24,16,17,3,6,21,
254,207,12,14,4,10,20,12,13,2,3,3,170,252,86,3,170,135,
1,54,61,52,53,34,32,21,20,40,42,105,16,11,10,7,8,26,
25,46,254,161,251,207,3,170,1,71,250,18,2,6,22,20,26,2,
15,23,18,219,9,2,5,15,18,17,6,8,12,0,0,0,0,4,
0,125,0,0,7,155,6,120,0,31,0,35,0,68,0,75,0,0,
1,48,35,34,7,6,7,6,7,6,29,1,51,21,35,17,35,17,
35,53,51,53,52,55,54,55,54,55,54,55,54,55,1,51,17,35,
1,17,35,17,33,53,33,17,52,55,54,55,54,55,54,51,50,22,
23,7,38,39,38,39,38,35,34,7,6,21,17,51,21,37,35,39,
7,35,1,51,2,208,19,46,39,44,47,50,29,29,195,196,152,139,
138,29,24,44,52,38,68,64,99,96,2,237,152,152,254,33,152,254,
229,1,26,30,30,43,40,52,49,38,59,74,45,109,12,11,10,19,
21,27,40,29,28,195,2,192,188,156,158,186,1,21,131,5,154,10,
11,27,28,38,37,34,176,135,252,86,3,170,135,135,46,67,52,46,
54,21,36,18,28,5,254,4,251,207,3,170,252,86,3,170,135,1,
54,61,52,53,34,32,21,20,40,42,105,16,11,10,7,8,26,25,
46,254,161,135,234,213,211,1,86,0,0,3,0,125,0,3,5,200,
6,119,0,57,0,75,0,87,0,0,1,17,35,17,33,17,35,17,
35,53,51,53,52,55,54,55,54,55,54,55,54,55,54,51,50,23,
22,23,22,23,22,21,20,6,35,34,39,38,39,38,53,54,53,52,
39,52,39,38,39,38,7,6,21,17,33,17,35,17,19,52,54,51,
50,23,22,23,22,21,20,6,35,34,39,38,39,38,37,6,7,6,
7,6,29,1,33,17,52,55,3,102,152,254,210,152,139,138,29,24,
44,69,21,9,123,143,213,22,23,38,42,47,41,39,8,2,56,38,
34,25,21,12,2,3,1,15,11,37,27,24,29,1,196,151,120,56,
38,32,27,23,10,2,56,38,34,25,27,6,2,253,92,39,52,50,
29,29,1,44,6,3,174,252,85,3,170,252,86,3,170,135,135,46,
67,52,46,70,5,1,53,61,37,6,20,24,84,81,71,10,9,39,
56,21,16,39,8,11,8,22,21,14,5,49,36,6,5,24,26,45,
254,161,251,207,3,170,1,161,38,56,22,20,33,10,9,39,56,21,
22,33,16,72,10,28,28,38,37,34,176,1,54,48,26,0,0,0,
0,2,0,125,0,0,5,41,6,136,0,10,0,50,0,0,1,6,
7,6,7,6,29,1,33,16,55,19,17,35,17,33,17,35,17,35,
53,51,53,52,55,54,55,54,55,54,55,37,22,23,5,22,23,22,
21,20,7,6,7,6,39,1,3,5,17,35,17,2,104,39,52,50,
29,29,1,44,1,152,152,254,210,152,139,138,29,24,44,40,50,79,
55,1,0,84,100,1,25,11,3,2,13,12,20,23,17,254,148,1,
1,194,151,5,147,10,28,28,38,37,34,176,1,125,3,253,250,252,
85,3,170,252,86,3,170,135,135,46,67,52,46,42,33,54,21,100,
83,83,250,9,14,8,6,17,18,15,5,6,13,1,9,254,152,1,
251,205,3,174,0,0,0,3,0,125,0,0,5,215,6,120,0,11,
0,58,0,84,0,0,1,6,7,6,7,6,29,1,33,17,52,55,
19,17,35,17,33,17,35,17,35,53,51,53,52,55,54,55,54,55,
54,55,54,55,54,51,50,23,22,23,7,38,39,38,39,38,35,34,
7,6,15,1,48,21,17,33,17,35,17,3,37,54,51,50,23,22,
23,22,21,20,7,6,7,5,6,35,34,39,38,39,38,53,52,55,
54,2,104,39,52,50,29,29,1,44,6,147,152,254,210,152,139,138,
29,24,44,69,21,9,123,143,213,31,30,60,37,34,47,109,12,11,
9,20,21,27,39,29,10,4,15,1,194,151,79,1,25,22,26,12,
6,24,16,17,3,6,21,254,207,12,14,4,10,20,12,13,2,3,
5,144,10,28,28,38,37,34,176,1,54,49,26,253,248,252,86,3,
170,252,86,3,170,135,135,46,67,52,46,71,4,2,52,61,37,10,
20,18,44,105,16,11,10,7,8,26,10,5,49,7,254,161,251,207,
3,170,1,71,250,18,2,6,22,20,26,2,15,23,18,219,9,2,
5,15,18,17,6,8,12,0,0,0,0,2,0,225,0,0,3,143,
4,52,0,24,0,51,0,0,19,54,55,54,55,54,51,50,23,22,
23,22,21,20,7,14,1,35,34,39,38,39,38,53,52,23,20,23,
30,1,51,50,55,54,55,54,55,54,53,52,39,38,39,38,35,34,
7,6,7,6,7,6,248,21,46,45,65,67,81,120,83,80,34,21,
39,39,158,108,124,82,83,33,20,146,18,23,90,65,48,38,39,24,
24,12,13,19,22,44,43,64,48,38,41,23,25,13,14,2,227,92,
79,78,43,45,95,92,157,103,95,143,120,119,152,95,97,152,94,96,
105,105,88,81,106,124,34,35,59,61,68,76,66,89,93,102,62,61,
35,37,59,62,70,75,0,0,0,1,1,76,0,0,3,37,4,49,
0,11,0,0,33,53,51,17,35,53,33,21,35,17,51,21,1,76,
158,158,1,217,158,158,142,3,21,142,142,252,235,142,0,0,0,1,
0,226,0,0,3,142,4,77,0,70,0,0,1,39,55,54,55,54,
51,50,23,22,23,22,23,22,23,22,21,20,6,7,6,7,6,7,
6,7,6,15,2,6,7,6,7,6,7,6,7,33,21,33,53,52,
55,54,55,54,55,54,55,54,63,1,62,2,55,54,63,5,52,38,
35,34,7,6,7,1,111,135,5,30,95,96,115,49,45,46,40,45,
27,30,18,18,20,17,20,19,16,29,22,28,35,11,42,32,22,39,
40,28,30,20,17,5,1,255,253,84,19,21,28,28,46,40,44,43,
49,31,8,16,8,2,11,21,33,26,23,13,6,102,67,64,56,54,
25,3,14,53,18,105,71,72,12,12,27,30,35,39,56,55,67,40,
72,31,36,24,20,29,21,23,28,7,28,21,15,37,39,31,34,37,
31,24,140,20,71,63,68,47,46,51,44,36,35,35,21,5,11,6,
1,9,16,29,31,36,40,48,90,102,41,40,78,0,0,0,0,1,
0,106,254,120,4,5,4,50,0,63,0,0,23,55,22,23,22,51,
50,55,54,53,52,39,46,1,39,38,43,1,53,51,50,55,54,53,
52,39,38,43,1,34,6,7,39,54,55,54,51,50,23,22,23,22,
21,20,7,6,7,6,7,22,23,22,23,22,23,22,21,20,7,6,
35,34,39,38,106,156,37,79,82,80,139,97,96,28,29,94,58,56,
63,78,98,96,73,71,73,75,94,6,79,122,31,138,53,101,100,122,
100,92,91,59,58,32,33,39,37,41,37,43,37,43,38,26,25,141,
142,206,124,128,126,122,45,79,49,51,82,81,136,72,56,58,70,20,
19,120,71,70,109,97,67,69,82,70,61,101,62,61,45,45,86,85,
105,82,65,67,38,35,21,10,31,27,49,44,64,62,70,188,123,124,
74,73,0,2,0,86,254,127,4,26,4,47,0,11,0,14,0,0,
1,17,51,21,35,17,35,17,33,1,59,1,7,1,33,3,93,189,
189,157,253,150,2,94,12,157,153,254,126,1,130,4,36,252,116,140,
254,115,1,141,4,35,235,253,86,0,0,0,0,1,0,111,254,101,
4,1,4,50,0,51,0,0,1,34,7,6,7,6,7,6,7,14,
1,7,6,7,14,2,15,1,39,19,33,21,33,3,54,51,50,23,
22,23,22,21,20,14,1,35,34,38,39,55,22,51,50,55,54,53,
52,39,38,39,38,2,68,32,30,23,31,32,12,20,16,7,17,2,
12,10,3,6,4,1,2,145,94,2,160,253,227,66,91,155,164,116,
118,34,13,106,210,135,171,246,46,156,84,223,132,82,81,9,24,80,
80,1,169,3,2,10,10,5,8,11,4,11,2,8,9,3,5,3,
1,1,75,2,158,141,254,84,55,97,98,163,61,64,132,218,138,198,
161,28,245,97,96,155,44,39,112,76,75,0,0,0,0,2,0,118,
255,227,3,249,5,174,0,19,0,53,0,0,1,52,39,38,39,38,
35,34,7,6,21,20,23,22,23,22,51,50,55,54,1,54,51,50,
23,22,23,22,21,20,7,6,7,6,7,6,35,34,38,39,38,53,
52,55,54,55,54,55,54,55,54,55,1,51,3,100,6,23,81,82,
114,128,82,84,6,22,82,81,105,134,85,85,254,70,72,64,164,124,
125,33,9,33,32,58,56,89,87,102,165,236,31,10,12,13,22,15,
26,18,28,26,8,1,78,156,1,152,33,30,104,67,67,90,92,115,
33,30,102,63,63,87,86,2,21,31,100,101,155,37,57,78,78,76,
64,62,40,39,206,146,47,40,59,57,61,51,34,55,38,46,42,17,
2,72,0,1,0,84,254,130,4,28,4,50,0,5,0,0,9,1,
35,1,33,53,4,28,253,213,182,2,4,253,21,4,50,250,80,5,
27,149,0,3,0,84,255,227,4,28,5,217,0,17,0,37,0,76,
0,0,37,50,55,54,53,52,39,38,39,38,35,34,6,21,20,23,
30,1,3,20,23,22,23,22,51,50,55,54,53,52,39,38,39,38,
35,34,7,6,19,50,22,23,22,21,20,7,22,23,22,23,22,21,
20,7,6,7,6,35,34,36,39,38,53,52,55,54,55,54,55,54,
55,38,39,38,53,52,54,2,50,136,98,98,6,22,93,90,117,140,
184,8,24,176,138,6,18,68,67,95,111,71,70,6,17,65,65,101,
119,66,67,252,152,224,28,7,187,83,75,76,22,8,68,67,113,111,
131,170,254,248,34,10,26,25,42,44,38,41,40,146,30,10,236,113,
93,93,133,34,32,109,67,65,166,141,28,40,111,140,3,243,30,29,
85,50,49,65,64,114,28,26,81,49,48,66,67,1,18,166,130,29,
48,208,109,38,75,76,106,43,37,129,107,106,60,59,206,159,50,46,
76,69,66,45,47,27,28,17,85,145,43,44,159,214,0,2,0,118,
254,101,3,249,4,50,0,17,0,53,0,0,1,20,23,30,1,51,
50,54,53,52,39,38,39,38,35,34,7,6,1,6,35,34,39,38,
39,38,53,52,55,54,55,62,1,55,54,51,50,23,22,23,22,21,
20,7,6,7,6,7,6,7,6,7,1,35,1,12,8,23,160,115,
130,164,6,22,82,80,106,133,85,86,1,186,72,64,163,125,128,30,
10,21,22,39,43,102,77,75,79,166,118,116,32,9,11,10,25,22,
17,14,34,32,2,254,192,168,2,124,34,30,103,134,178,119,39,23,
101,65,64,88,89,253,237,31,101,102,153,47,48,62,63,65,54,59,
82,27,26,103,101,149,43,44,55,60,55,59,53,35,29,56,52,7,
253,184,0,2,0,90,255,227,3,120,4,66,0,25,0,45,0,0,
55,38,47,1,48,53,52,55,54,51,50,23,53,51,17,35,53,6,
7,6,7,6,7,6,35,34,3,23,20,23,22,51,50,55,54,53,
3,38,39,38,35,34,7,6,7,6,200,107,2,1,110,133,169,144,
102,140,140,3,20,23,32,33,53,51,55,159,88,1,64,66,148,96,
72,70,2,2,61,63,118,70,51,54,33,61,89,113,207,252,3,201,
116,109,87,70,251,207,156,19,29,33,29,30,23,22,2,178,252,142,
79,82,70,69,96,1,58,145,76,78,19,20,33,76,0,0,255,255,
0,90,255,227,3,120,6,61,16,39,0,67,0,97,254,165,16,6,
5,126,0,0,255,255,0,90,255,227,3,120,6,59,16,39,0,118,
1,138,254,163,16,6,5,126,0,0,255,255,0,90,255,227,3,120,
5,156,16,39,1,174,255,98,254,110,16,6,5,126,0,0,255,255,
0,90,255,227,3,120,5,182,16,39,1,178,0,134,2,90,16,6,
5,126,0,0,255,255,0,90,255,227,3,120,5,234,16,39,1,171,
255,212,254,168,16,6,5,126,0,0,255,255,0,90,255,227,3,120,
5,173,16,39,0,106,0,98,254,186,16,6,5,126,0,0,255,255,
0,90,254,197,3,155,4,66,16,39,1,177,2,42,0,0,16,6,
5,126,0,0,255,255,0,90,255,227,3,120,6,60,16,39,1,176,
255,228,254,158,16,6,5,126,0,0,255,255,0,90,255,227,3,120,
5,41,16,38,0,113,0,0,16,6,5,126,0,0,0,0,0,1,
0,38,255,236,4,38,4,50,0,64,0,0,1,52,39,38,35,34,
7,6,7,39,54,55,54,51,50,31,1,54,55,54,51,50,23,22,
23,7,38,39,38,35,34,7,6,29,1,20,23,22,51,50,55,23,
6,7,6,35,34,39,38,53,34,7,6,35,34,39,38,39,55,22,
51,50,55,54,53,1,220,54,62,70,40,30,25,63,86,33,23,74,
114,155,63,41,17,26,86,134,110,76,31,25,86,61,29,28,38,74,
62,42,58,57,59,94,74,86,72,60,57,65,179,73,4,2,4,95,
157,63,61,60,72,86,76,94,64,50,68,2,124,105,87,98,12,10,
72,102,41,21,68,122,66,41,35,122,70,29,31,102,70,12,12,98,
68,126,228,150,70,70,108,100,90,28,26,166,8,2,10,176,26,25,
93,100,108,72,100,104,0,3,0,131,0,0,5,194,7,231,0,19,
0,42,0,55,0,0,1,52,55,54,51,50,23,22,23,22,21,20,
7,6,35,34,39,38,39,38,7,22,23,30,1,51,50,55,54,55,
51,6,7,6,7,6,35,34,39,38,39,38,39,1,17,51,9,1,
51,17,35,17,1,35,1,17,2,199,58,18,19,62,24,5,1,2,
57,18,19,62,24,6,1,2,117,11,20,37,94,54,117,71,11,20,
156,27,45,53,77,78,95,88,76,77,57,52,34,254,217,215,1,204,
1,205,207,154,254,84,179,254,84,7,137,62,24,8,55,11,9,10,
9,62,24,8,55,14,7,10,37,30,25,55,60,110,18,40,82,62,
74,43,43,36,36,72,64,98,248,164,5,178,251,31,4,225,250,78,
4,181,251,91,4,165,251,75,0,0,0,3,0,139,0,0,5,159,
6,149,0,19,0,42,0,86,0,0,1,52,55,54,51,50,23,22,
23,22,21,20,7,6,35,34,39,38,39,38,7,22,23,30,1,51,
50,55,54,55,51,6,7,6,7,6,35,34,39,38,39,38,39,1,
35,17,52,39,38,35,34,7,6,7,14,1,21,17,35,17,51,21,
62,1,51,50,23,62,1,51,50,23,22,21,17,35,17,52,38,35,
34,7,6,7,14,1,21,2,183,57,18,19,62,24,6,1,2,58,
20,17,62,24,5,1,2,121,12,19,37,94,53,117,72,11,20,155,
28,43,53,78,76,97,87,77,76,57,52,34,1,203,152,42,42,75,
52,45,47,37,36,46,152,152,63,122,78,203,73,72,142,84,164,74,
73,152,86,73,52,45,47,37,36,46,6,55,62,24,8,55,14,7,
10,8,62,24,9,56,11,9,10,81,32,24,55,60,111,18,40,85,
59,75,43,42,36,36,72,64,98,250,35,2,146,148,77,76,23,24,
40,39,110,63,253,108,4,50,152,99,76,205,111,94,109,107,227,253,
114,2,142,153,152,23,24,40,39,110,63,0,0,0,0,2,0,131,
0,0,5,194,7,92,0,12,0,35,0,0,51,17,51,9,1,51,
17,35,17,1,35,1,17,1,22,23,30,1,51,50,55,54,55,51,
6,7,6,7,6,35,34,39,38,39,38,39,131,215,1,204,1,205,
207,154,254,84,179,254,84,1,53,11,20,37,94,54,117,71,11,20,
156,27,45,53,77,78,95,88,76,77,57,52,34,5,178,251,31,4,
225,250,78,4,181,251,91,4,165,251,75,7,92,30,25,55,60,110,
18,40,82,62,74,43,43,36,36,72,64,98,0,2,0,139,0,0,
5,159,5,221,0,43,0,66,0,0,33,35,17,52,39,38,35,34,
7,6,7,14,1,21,17,35,17,51,21,62,1,51,50,23,62,1,
51,50,23,22,21,17,35,17,52,38,35,34,7,6,7,14,1,21,
1,22,23,30,1,51,50,55,54,55,51,6,7,6,7,6,35,34,
39,38,39,38,39,3,97,152,42,42,75,52,45,47,37,36,46,152,
152,63,122,78,203,73,72,142,84,164,74,73,152,86,73,52,45,47,
37,36,46,254,221,12,19,37,94,53,117,72,11,20,155,28,43,53,
78,76,97,87,77,76,57,52,34,2,146,148,77,76,23,24,40,39,
110,63,253,108,4,50,152,99,76,205,111,94,109,107,227,253,114,2,
142,153,152,23,24,40,39,110,63,3,73,32,24,55,60,111,18,40,
85,59,75,43,42,36,36,72,64,98,0,2,0,131,0,0,4,159,
7,92,0,9,0,32,0,0,51,17,51,1,17,51,17,35,1,17,
19,22,23,22,23,22,51,50,55,54,55,51,6,7,6,7,6,35,
34,38,39,38,39,131,154,2,228,158,146,253,20,178,11,20,37,47,
46,55,117,71,11,20,156,27,45,53,77,78,95,87,154,57,52,34,
5,178,251,117,4,139,250,78,4,167,251,89,7,92,30,25,55,30,
30,110,18,40,82,62,74,43,43,72,72,64,98,0,0,2,0,139,
0,0,3,159,5,221,0,28,0,51,0,0,33,35,17,51,21,54,
51,50,31,1,22,23,22,23,17,35,17,52,39,38,39,34,7,6,
7,6,7,6,21,19,22,23,22,23,22,51,50,55,54,55,51,6,
7,14,1,35,34,39,38,39,38,39,1,35,152,152,125,168,230,80,
18,10,2,2,1,152,55,55,81,50,53,50,45,40,28,27,27,12,
18,36,49,47,53,117,72,6,24,156,27,45,54,152,97,87,77,76,
57,52,34,4,50,162,185,228,65,34,37,36,39,253,110,2,146,146,
74,75,6,24,23,43,38,57,54,60,3,73,34,22,53,32,30,111,
9,49,83,61,76,84,36,36,72,64,98,0,0,3,0,131,0,0,
4,91,7,92,0,8,0,28,0,52,0,0,1,51,32,17,52,39,
38,43,1,9,1,35,17,35,17,33,50,23,22,23,22,23,22,21,
20,7,6,7,9,1,22,23,22,23,22,51,50,55,54,55,51,6,
7,6,7,6,35,34,39,38,39,38,39,1,33,207,1,130,98,99,
189,207,2,132,254,83,215,158,1,109,118,101,103,72,74,40,42,97,
96,172,1,178,252,251,11,20,37,47,46,55,117,71,11,20,156,27,
45,53,77,78,95,88,76,77,57,52,34,3,7,1,17,135,66,67,
250,220,2,119,253,137,5,178,27,28,51,53,75,79,97,148,109,108,
33,253,118,7,92,30,25,55,30,30,110,18,40,82,62,74,43,43,
36,36,72,64,98,0,0,0,0,2,0,4,0,0,2,251,5,221,
0,25,0,48,0,0,1,38,35,34,7,6,7,6,7,6,21,17,
35,17,51,21,54,55,54,55,54,55,54,51,50,23,1,22,23,30,
1,51,50,55,54,55,51,6,7,6,7,6,35,34,39,38,39,38,
39,2,158,68,71,47,43,43,33,31,22,21,152,152,18,25,30,30,
34,33,37,33,116,89,253,204,12,19,37,94,53,117,72,11,20,156,
27,45,54,76,77,97,87,77,76,57,52,34,3,154,42,24,24,42,
40,60,58,72,253,124,4,50,152,38,29,35,22,25,14,16,55,1,
199,32,24,55,60,111,18,40,83,61,76,42,42,36,36,72,64,98,
0,0,0,3,0,98,254,159,4,167,5,178,0,7,0,25,0,43,
0,0,19,33,21,33,17,35,17,33,1,52,55,54,51,50,31,1,
22,21,20,7,6,35,34,47,1,38,37,52,55,54,51,50,31,1,
22,21,20,7,6,35,34,47,1,38,98,4,69,254,55,158,254,34,
2,185,58,16,21,62,24,6,2,57,18,19,62,24,7,2,254,41,
57,16,21,62,24,6,2,57,18,19,62,24,6,2,5,178,142,250,
220,5,36,249,220,62,24,8,55,21,8,10,62,24,9,56,20,8,
9,62,24,8,55,21,8,10,62,24,9,56,20,8,0,0,0,3,
0,62,254,159,2,210,5,44,0,18,0,36,0,54,0,0,19,35,
53,51,53,51,21,51,21,35,17,20,59,1,21,35,34,38,53,1,
52,55,54,51,50,31,1,22,21,20,7,6,35,34,47,1,38,37,
52,55,54,51,50,31,1,22,21,20,7,6,35,34,47,1,38,254,
141,141,152,197,197,117,69,69,151,118,1,23,57,16,21,62,24,7,
2,58,18,19,62,24,6,2,254,41,57,16,21,62,24,6,2,57,
18,19,62,24,6,2,3,171,135,250,250,135,253,44,117,127,122,118,
254,45,62,24,8,55,21,8,10,62,24,9,56,20,8,9,62,24,
8,55,21,8,10,62,24,9,56,20,8,0,0,0,0,3,0,76,
254,159,4,62,5,216,0,63,0,81,0,99,0,0,19,55,22,23,
22,51,50,55,62,1,55,54,53,52,39,38,47,1,36,17,52,55,
54,55,54,55,54,51,32,31,1,7,38,39,38,35,34,7,6,7,
14,1,21,20,31,1,22,23,22,23,22,23,22,21,20,7,6,7,
6,7,6,7,38,36,1,52,55,54,51,50,31,1,22,21,20,7,
6,35,34,47,1,38,37,52,55,54,51,50,31,1,22,21,20,7,
6,35,34,47,1,38,76,135,90,90,89,110,70,60,61,90,27,27,
94,90,181,23,254,110,35,34,62,63,82,83,96,1,10,157,37,125,
50,87,86,112,60,54,52,42,39,46,207,144,134,78,88,47,50,21,
20,37,38,66,65,92,92,106,158,254,250,2,52,57,16,21,62,24,
6,2,57,18,19,62,24,6,2,254,40,58,16,21,62,24,6,2,
57,18,19,62,24,7,2,1,31,80,141,58,57,22,22,82,53,54,
66,97,74,71,55,6,108,1,20,82,75,73,54,55,30,30,194,52,
79,87,49,48,18,17,36,33,96,58,139,83,51,52,37,42,44,47,
58,56,90,89,77,79,57,56,35,35,1,2,156,254,129,62,24,8,
55,21,8,10,62,24,9,56,20,8,9,62,24,8,55,21,8,10,
62,24,9,56,20,8,0,0,0,3,0,107,254,159,3,83,4,75,
0,68,0,86,0,104,0,0,1,38,39,38,39,38,39,38,53,52,
55,54,55,54,55,54,55,51,50,23,22,23,22,23,22,23,7,38,
35,34,7,6,7,6,7,6,21,20,31,1,22,23,22,23,22,23,
22,21,20,7,6,7,14,1,35,32,39,55,22,51,50,55,54,55,
54,55,54,53,52,3,52,55,54,51,50,31,1,22,21,20,7,6,
35,34,47,1,38,37,52,55,54,51,50,31,1,22,21,20,7,6,
35,34,47,1,38,1,224,107,62,70,37,39,17,17,25,23,47,44,
65,69,76,6,58,62,58,48,50,30,32,10,141,40,171,37,36,40,
24,29,15,16,154,43,100,75,68,46,42,19,19,28,26,51,50,132,
80,254,204,69,141,33,199,46,36,39,30,31,18,17,76,58,16,20,
63,24,6,2,58,18,19,62,24,6,2,254,41,57,16,21,62,24,
6,2,57,18,19,62,24,6,2,1,236,35,32,36,35,36,44,43,
47,58,56,52,42,40,24,26,1,16,15,30,31,40,42,54,28,121,
12,13,19,22,28,29,35,103,51,14,37,40,36,43,39,47,48,51,
63,62,58,45,44,54,246,27,137,14,15,24,25,34,33,45,123,253,
92,62,24,8,55,21,8,10,62,24,9,56,20,8,9,62,24,8,
55,21,8,10,62,24,9,56,20,8,0,3,0,131,254,159,4,85,
5,178,0,11,0,29,0,47,0,0,19,51,17,33,17,51,17,35,
17,33,17,35,1,52,55,54,51,50,31,1,22,21,20,7,6,35,
34,47,1,38,37,52,55,54,51,50,31,1,22,21,20,7,6,35,
34,47,1,38,131,158,2,150,158,158,253,106,158,2,118,57,16,21,
62,24,6,2,57,18,19,62,24,6,2,254,40,57,16,21,62,24,
7,2,58,18,19,62,24,6,2,5,178,253,126,2,130,250,78,2,
162,253,94,255,0,62,24,8,55,21,8,10,62,24,9,56,20,8,
9,62,24,8,55,21,8,10,62,24,9,56,20,8,0,3,0,139,
254,159,3,159,5,176,0,27,0,45,0,63,0,0,33,35,17,51,
17,54,55,54,55,62,1,51,50,22,21,17,35,17,16,35,34,7,
6,7,6,7,6,21,1,52,55,54,51,50,31,1,22,21,20,7,
6,35,34,47,1,38,37,52,55,54,51,50,31,1,22,21,20,7,
6,35,34,47,1,38,1,35,152,152,45,36,35,34,35,58,42,163,
188,152,199,53,51,50,42,40,24,25,1,132,57,16,21,62,24,6,
2,57,18,19,62,24,6,2,254,40,57,16,21,62,24,7,2,58,
18,19,62,24,6,2,5,176,253,234,56,34,33,19,19,14,218,221,
253,110,2,146,1,45,24,24,43,41,55,56,56,252,108,62,24,8,
55,21,8,10,62,24,9,56,20,8,9,62,24,8,55,21,8,10,
62,24,9,56,20,8,0,0,0,2,0,131,254,237,4,85,5,178,
0,11,0,15,0,0,19,51,17,33,17,51,17,35,17,33,17,35,
23,33,21,33,131,158,2,150,158,158,253,106,158,195,2,93,253,163,
5,178,253,126,2,130,250,78,2,162,253,94,139,136,0,3,0,131,
253,221,4,32,5,178,0,5,0,25,0,45,0,0,19,51,17,33,
21,33,1,20,23,22,23,22,51,50,55,54,53,52,39,38,39,38,
35,34,7,6,7,52,55,54,51,50,23,22,23,22,21,20,7,6,
35,34,39,38,39,38,131,158,2,255,252,99,1,11,4,18,76,26,
21,87,40,17,2,18,79,21,24,87,40,18,117,111,68,83,138,77,
32,10,6,111,68,84,138,77,31,10,6,5,178,250,219,141,254,227,
18,15,83,27,7,78,34,38,11,22,84,27,6,78,33,43,133,78,
47,110,46,49,27,26,133,78,47,110,44,51,27,0,0,3,0,23,
253,221,2,35,5,176,0,9,0,29,0,49,0,0,37,20,51,21,
34,39,38,53,17,51,3,20,23,22,23,22,51,50,55,54,53,52,
39,38,39,38,35,34,7,6,7,52,55,54,51,50,23,22,23,22,
21,20,7,6,35,34,39,38,39,38,1,56,118,137,67,66,152,173,
5,18,76,26,21,87,40,16,2,18,78,21,24,86,41,19,116,110,
68,84,138,77,31,10,6,110,68,84,138,77,31,10,6,207,105,131,
58,57,117,4,229,249,51,15,18,83,27,7,78,32,40,11,22,84,
27,6,78,35,41,134,77,47,110,44,51,27,26,134,77,47,110,44,
51,27,0,0,0,4,255,154,253,221,4,32,6,182,0,3,0,9,
0,29,0,49,0,0,3,33,21,33,23,51,17,33,21,33,1,20,
23,22,23,22,51,50,55,54,53,52,39,38,39,38,35,34,7,6,
7,52,55,54,51,50,23,22,23,22,21,20,7,6,35,34,39,38,
39,38,102,2,92,253,164,233,158,2,255,252,99,1,11,4,18,76,
26,21,87,40,17,2,18,79,21,24,87,40,18,117,111,68,83,138,
77,32,10,6,111,68,84,138,77,31,10,6,6,182,135,125,250,219,
141,254,227,18,15,83,27,7,78,34,38,11,22,84,27,6,78,33,
43,133,78,47,110,46,49,27,26,133,78,47,110,44,51,27,0,4,
255,190,253,221,2,35,6,184,0,3,0,13,0,33,0,53,0,0,
3,33,21,33,1,20,51,21,34,39,38,53,17,51,3,20,23,22,
23,22,51,50,55,54,53,52,39,38,39,38,35,34,7,6,7,52,
55,54,51,50,23,22,23,22,21,20,7,6,35,34,39,38,39,38,
66,2,93,253,163,1,122,118,137,67,66,152,173,5,18,76,26,21,
87,40,16,2,18,78,21,24,86,41,19,116,110,68,84,138,77,31,
10,6,110,68,84,138,77,31,10,6,6,184,135,250,158,105,131,58,
57,117,4,229,249,51,15,18,83,27,7,78,32,40,11,22,84,27,
6,78,35,41,134,77,47,110,44,51,27,26,134,77,47,110,44,51,
27,0,0,0,0,4,0,131,253,221,4,91,5,178,0,8,0,28,
0,48,0,68,0,0,1,51,32,17,52,39,38,43,1,9,1,35,
17,35,17,33,50,23,22,23,22,23,22,21,20,7,6,7,9,1,
20,23,22,23,22,51,50,55,54,53,48,39,38,39,38,35,34,7,
6,7,52,55,54,51,50,23,22,23,22,21,20,7,6,35,34,39,
38,39,38,1,33,207,1,130,98,99,189,207,2,132,254,83,215,158,
1,109,118,101,103,72,74,40,42,97,96,172,1,178,253,81,5,18,
76,26,21,86,41,17,3,18,78,21,24,86,41,19,116,110,68,84,
138,77,31,10,6,110,68,84,138,77,31,10,6,3,7,1,17,135,
66,67,250,220,2,119,253,137,5,178,27,28,51,53,75,79,97,148,
109,108,33,253,118,254,227,15,18,83,27,7,78,34,38,33,84,27,
6,78,35,41,134,77,47,110,44,51,27,26,134,77,47,110,44,51,
27,0,0,0,0,3,255,215,253,221,2,224,4,77,0,25,0,45,
0,65,0,0,1,38,35,34,7,6,7,6,7,6,21,17,35,17,
51,21,54,55,54,55,54,55,54,51,50,23,1,20,23,22,23,22,
51,50,55,54,53,52,39,38,39,38,35,34,7,6,7,52,55,54,
51,50,23,22,23,22,21,20,7,6,35,34,39,38,39,38,2,158,
68,71,47,43,43,33,31,22,21,152,152,18,25,30,30,34,33,37,
33,116,89,253,108,4,18,76,26,21,87,40,17,2,18,79,21,24,
86,41,18,117,111,68,83,139,77,31,10,6,111,68,84,138,77,31,
10,6,3,154,42,24,24,42,40,60,58,72,253,124,4,50,152,38,
29,35,22,25,14,16,55,250,205,18,15,83,27,7,78,34,38,11,
22,84,27,6,78,33,43,133,78,47,110,44,51,27,26,133,78,47,
110,44,51,27,0,0,0,5,0,131,253,221,4,91,6,182,0,3,
0,12,0,32,0,52,0,72,0,0,19,33,21,33,19,51,32,17,
52,39,38,43,1,9,1,35,17,35,17,33,50,23,22,23,22,23,
22,21,20,7,6,7,9,1,20,23,22,23,22,51,50,55,54,53,
48,39,38,39,38,35,34,7,6,7,52,55,54,51,50,23,22,23,
22,21,20,7,6,35,34,39,38,39,38,248,2,93,253,163,41,207,
1,130,98,99,189,207,2,132,254,83,215,158,1,109,118,101,103,72,
74,40,42,97,96,172,1,178,253,81,5,18,76,26,21,86,41,17,
3,18,78,21,24,86,41,19,116,110,68,84,138,77,31,10,6,110,
68,84,138,77,31,10,6,6,182,135,252,216,1,17,135,66,67,250,
220,2,119,253,137,5,178,27,28,51,53,75,79,97,148,109,108,33,
253,118,254,227,15,18,83,27,7,78,34,38,33,84,27,6,78,35,
41,134,77,47,110,44,51,27,26,134,77,47,110,44,51,27,0,0,
0,4,255,215,253,221,2,224,5,55,0,3,0,29,0,49,0,69,
0,0,19,33,21,33,1,38,35,34,7,6,7,6,7,6,21,17,
35,17,51,21,54,55,54,55,54,55,54,51,50,23,1,20,23,22,
23,22,51,50,55,54,53,52,39,38,39,38,35,34,7,6,7,52,
55,54,51,50,23,22,23,22,21,20,7,6,35,34,39,38,39,38,
82,2,93,253,163,2,76,68,71,47,43,43,33,31,22,21,152,152,
18,25,30,30,34,33,37,33,116,89,253,108,4,18,76,26,21,87,
40,17,2,18,79,21,24,86,41,18,117,111,68,83,139,77,31,10,
6,111,68,84,138,77,31,10,6,5,55,136,254,235,42,24,24,42,
40,60,58,72,253,124,4,50,152,38,29,35,22,25,14,16,55,250,
205,18,15,83,27,7,78,34,38,11,22,84,27,6,78,33,43,133,
78,47,110,44,51,27,26,133,78,47,110,44,51,27,0,1,255,137,
254,84,1,84,4,49,0,32,0,0,3,55,22,23,22,23,22,23,
30,1,51,50,61,1,17,51,17,21,20,7,6,7,6,7,6,7,
6,35,34,39,38,39,38,119,107,10,5,10,6,15,4,10,24,14,
102,152,23,22,35,40,34,40,34,29,28,42,36,35,17,8,254,166,
102,10,4,8,4,10,2,5,6,123,170,4,49,251,207,139,63,52,
50,32,36,18,21,9,8,15,15,12,6,0,0,0,0,4,0,27,
0,0,5,101,4,149,0,11,0,23,0,29,0,35,0,0,1,33,
21,35,21,51,21,35,21,51,21,41,1,35,39,7,35,55,39,51,
23,55,51,7,9,2,33,9,1,37,33,9,1,33,1,1,158,1,
19,212,195,195,212,254,237,2,127,68,96,92,71,126,125,68,94,93,
68,125,254,14,254,234,1,22,2,42,1,22,254,234,253,153,2,164,
1,83,254,173,253,92,254,173,3,165,56,200,56,214,56,176,176,216,
213,173,173,212,1,243,254,31,254,32,1,224,1,225,106,253,181,253,
182,2,74,0,0,0,0,2,0,119,0,136,3,69,4,54,0,2,
0,6,0,0,9,2,19,33,21,33,3,69,254,154,254,152,69,2,
68,253,188,4,54,253,50,2,206,252,224,142,0,0,0,3,0,94,
0,242,4,88,4,236,0,9,0,43,0,71,0,0,1,33,21,35,
21,51,21,35,21,35,3,20,23,22,23,22,23,22,23,22,51,50,
54,55,62,1,53,52,39,38,39,38,39,38,39,38,35,34,7,6,
7,6,7,6,7,52,55,62,1,55,54,55,54,51,50,4,23,22,
21,20,7,6,7,6,35,34,39,38,39,38,39,38,1,200,1,76,
251,235,235,81,245,9,17,39,39,56,54,59,58,60,70,132,61,58,
72,9,17,42,43,56,54,60,57,55,66,70,66,60,57,37,35,117,
32,32,100,69,67,70,67,71,180,1,26,37,11,74,75,116,114,131,
108,100,101,81,80,26,12,3,230,78,123,80,243,1,20,50,44,76,
56,57,37,36,18,18,52,50,48,152,90,46,40,76,60,61,36,35,
20,19,25,24,47,46,79,76,96,101,87,86,116,41,40,20,19,224,
175,60,51,147,117,119,63,62,42,42,92,91,123,56,0,1,0,170,
0,0,2,240,5,176,0,7,0,0,19,33,17,35,17,33,17,35,
170,2,70,158,254,246,158,5,176,250,80,5,25,250,231,0,0,0,
0,4,0,158,0,64,5,238,5,98,0,14,0,41,0,55,0,82,
0,0,1,34,6,21,20,23,22,51,50,55,54,53,52,39,38,1,
36,39,38,39,53,22,5,22,51,50,53,52,39,38,53,52,55,54,
51,50,22,16,7,6,7,6,1,50,54,53,52,39,38,35,34,6,
21,20,23,22,1,4,23,22,23,21,38,37,38,35,34,29,1,22,
21,20,7,6,32,39,38,53,52,55,54,55,54,4,144,94,132,66,
67,93,91,67,66,65,65,254,228,254,214,191,178,153,251,1,19,71,
72,122,1,130,101,101,146,148,204,104,72,121,123,253,178,94,130,65,
65,94,94,132,66,67,1,25,1,44,190,175,157,249,254,235,95,48,
121,130,102,102,254,220,102,102,102,72,122,125,2,178,132,94,94,65,
65,65,65,94,93,67,66,253,142,1,21,19,43,122,83,16,5,23,
1,2,106,166,145,103,102,204,254,220,102,77,37,38,2,176,130,94,
93,67,66,132,94,94,65,65,2,114,1,21,19,45,122,83,17,5,
22,3,108,164,146,103,103,103,103,146,144,102,76,38,39,0,0,0,
0,2,0,212,255,236,5,182,5,174,0,23,0,88,0,0,1,54,
55,54,53,52,39,38,39,38,35,34,7,6,7,6,21,20,23,22,
23,22,51,50,19,52,54,51,50,23,22,21,20,7,6,21,22,23,
50,55,23,6,35,34,38,53,52,0,53,52,38,35,34,7,6,21,
20,23,22,23,22,23,22,21,20,7,6,7,6,35,34,39,38,39,
38,53,52,55,54,55,54,51,50,23,50,53,52,39,38,2,70,76,
32,17,15,29,72,39,37,35,36,76,31,16,13,30,72,40,37,36,
45,222,178,170,108,108,144,144,4,134,70,98,64,124,110,98,144,1,
28,162,130,127,73,74,23,22,25,37,7,1,31,50,116,56,54,62,
57,113,46,22,28,49,117,54,56,75,71,8,30,46,1,114,30,72,
39,36,35,36,75,31,17,15,28,72,36,40,37,33,75,31,17,2,
229,158,198,109,110,171,184,248,247,177,122,4,86,70,118,120,110,197,
1,216,191,132,162,76,77,125,59,72,69,64,98,106,13,24,86,65,
114,44,21,25,48,118,53,55,61,59,112,44,22,40,13,24,72,108,
0,2,0,25,0,0,5,53,5,202,0,3,0,84,0,0,55,33,
21,33,1,38,39,38,39,38,53,52,55,54,55,54,55,54,55,54,
51,50,22,23,22,23,22,23,22,21,7,14,1,7,6,7,6,15,
1,33,21,33,53,54,55,54,55,54,55,54,53,52,39,38,39,38,
39,38,39,38,39,38,35,34,7,6,7,6,7,6,7,6,21,20,
23,22,23,22,23,22,23,51,21,33,55,26,5,26,250,230,1,6,
35,72,51,15,23,19,19,45,43,67,63,104,103,121,122,196,68,50,
60,60,6,24,2,2,10,6,5,59,44,73,4,1,20,253,253,75,
57,57,33,33,11,14,2,21,2,3,46,37,40,44,72,69,86,94,
73,74,46,28,49,33,6,15,22,15,33,30,56,57,69,1,253,252,
1,142,142,1,96,41,126,89,73,110,50,25,76,77,103,100,82,77,
51,50,92,80,59,113,112,38,144,3,15,15,73,41,30,135,100,76,
4,142,142,40,64,65,65,66,50,59,49,11,20,144,5,3,98,77,
50,56,34,33,40,41,62,39,109,74,19,77,39,57,104,77,54,50,
57,58,32,142,142,0,0,0,0,1,0,34,255,62,6,106,5,168,
0,61,0,0,1,20,22,59,1,53,51,23,7,39,53,35,34,39,
38,39,3,53,16,35,34,7,6,7,17,35,17,16,39,38,43,2,
34,7,6,7,17,35,17,52,39,51,22,23,54,55,54,51,50,23,
22,21,54,55,54,51,50,23,22,29,1,4,192,74,62,88,4,198,
198,4,88,148,54,55,7,20,46,57,64,67,60,148,15,15,32,2,
1,40,87,88,18,146,148,138,114,36,23,89,90,66,62,58,58,41,
95,96,74,60,40,40,1,4,108,122,114,168,170,4,114,95,95,114,
2,254,24,1,28,106,110,190,252,126,3,126,1,56,52,50,109,110,
209,252,144,4,32,185,185,78,170,90,91,91,96,95,125,116,100,100,
81,80,213,196,0,1,0,120,0,0,6,18,5,154,0,18,0,0,
1,33,53,33,29,1,17,35,17,7,17,35,17,1,39,1,33,53,
33,5,26,253,232,3,16,146,246,146,252,230,102,3,26,253,232,2,
168,5,10,144,100,2,253,86,2,26,248,253,86,2,26,252,228,104,
3,26,144,0,0,2,0,132,0,0,6,6,5,176,0,49,0,57,
0,0,1,50,19,18,51,54,51,50,23,22,21,20,7,6,35,34,
39,6,7,6,7,35,53,51,54,19,38,3,2,35,34,7,6,21,
48,21,7,52,39,38,39,53,50,23,22,19,54,55,62,1,1,22,
51,50,55,38,39,34,3,4,104,40,39,25,106,190,118,74,74,70,
71,137,150,118,44,61,61,134,164,150,118,102,48,31,31,56,36,77,
71,156,68,67,129,142,79,80,37,43,45,40,120,1,78,90,126,156,
10,8,154,148,5,176,254,91,254,95,216,93,94,99,143,82,83,130,
156,105,104,5,116,4,1,110,16,1,128,1,128,236,216,191,29,2,
244,243,241,6,96,109,110,254,245,193,89,88,146,252,64,140,192,153,
19,0,0,0,0,2,0,104,1,54,6,36,4,150,0,40,0,83,
0,0,19,0,51,50,23,22,50,54,51,50,23,22,50,55,54,51,
50,19,7,38,35,34,7,6,35,34,39,38,35,34,7,6,35,34,
39,38,34,7,6,35,39,17,0,51,50,23,22,50,54,51,50,23,
22,51,50,55,54,51,50,19,7,38,35,34,7,6,35,34,39,38,
35,34,7,6,35,34,39,38,35,34,7,6,35,39,104,1,66,114,
44,12,25,110,170,55,54,24,25,114,85,42,42,122,108,94,63,94,
51,58,83,57,56,24,27,59,55,83,85,55,56,24,24,108,86,170,
4,52,1,64,116,42,14,25,110,170,55,54,24,25,57,55,85,43,
41,124,108,94,63,93,49,61,85,55,57,25,26,58,54,84,85,55,
56,24,24,55,56,83,170,4,52,1,154,1,12,40,70,140,70,70,
70,36,254,198,50,184,52,76,74,78,68,70,72,70,71,141,98,1,
212,1,10,38,70,140,70,70,70,34,254,200,50,183,53,76,76,77,
67,70,70,71,70,141,96,0,0,0,0,1,0,250,0,0,5,144,
5,154,0,28,0,0,1,7,2,1,7,0,19,33,53,33,2,1,
23,0,19,51,18,1,55,0,3,33,21,33,18,1,39,0,3,3,
188,238,30,254,238,162,1,47,25,254,222,1,34,28,254,210,164,1,
18,30,240,30,1,18,162,254,209,25,1,34,254,220,29,1,45,162,
254,238,32,2,126,4,254,189,254,205,4,1,83,1,39,166,1,42,
1,80,2,254,205,254,187,1,69,1,51,2,254,175,254,215,166,254,
215,254,175,4,1,52,1,66,0,2,0,116,1,98,6,134,4,54,
0,2,0,5,0,0,9,3,17,1,6,134,253,50,2,206,249,238,
2,206,1,98,1,102,1,104,253,56,2,206,254,152,0,0,0,3,
0,72,0,0,4,121,5,79,0,20,0,70,0,80,0,0,1,38,
35,34,7,6,15,1,51,21,35,3,54,55,54,55,54,53,52,39,
38,1,19,38,39,38,39,7,38,39,38,39,38,53,52,55,54,55,
54,55,62,1,59,1,55,54,55,54,55,54,55,51,50,23,22,23,
22,21,20,7,6,7,6,7,6,7,6,35,34,39,11,1,22,23,
19,35,34,21,20,23,22,3,87,15,16,24,22,38,16,46,212,254,
129,120,126,169,58,29,36,56,253,4,152,43,40,36,31,1,30,9,
15,13,15,9,9,21,19,34,32,102,63,153,51,22,45,47,52,54,
50,9,68,72,65,41,55,3,14,81,80,138,71,84,81,80,40,19,
158,46,39,65,118,127,138,22,14,4,218,6,12,19,44,126,117,254,
160,3,72,98,134,65,62,66,55,87,251,112,1,161,19,31,28,38,
1,32,12,20,32,36,42,24,33,34,40,37,37,35,48,141,59,38,
40,16,16,3,54,45,59,79,113,24,27,131,114,113,80,41,25,24,
2,254,80,2,173,54,27,1,70,141,25,44,27,0,0,0,0,5,
0,94,0,0,4,88,4,236,0,3,0,18,0,38,0,72,0,100,
0,0,55,33,21,33,1,51,50,53,52,39,38,39,38,39,38,39,
38,43,1,39,59,1,50,23,22,23,22,21,20,7,6,7,6,7,
6,43,1,21,35,3,20,23,22,23,22,23,22,23,22,51,50,54,
55,62,1,53,52,39,38,39,38,39,38,39,38,35,34,7,6,7,
6,7,6,7,52,55,62,1,55,54,55,54,51,50,4,23,22,21,
20,7,6,7,6,35,34,39,38,39,38,39,38,95,3,248,252,8,
1,183,78,147,3,3,8,9,16,19,24,32,33,78,87,87,78,86,
54,56,9,4,13,10,28,25,40,41,52,78,87,236,9,17,39,39,
56,54,59,58,60,70,132,61,58,72,9,17,42,43,56,54,60,57,
55,66,70,66,60,57,37,35,117,32,32,100,69,67,70,67,71,180,
1,26,37,11,74,75,116,114,131,108,100,101,81,80,26,12,142,142,
2,250,104,14,9,16,12,13,12,14,5,7,54,34,35,55,22,10,
30,31,24,26,23,12,12,240,1,26,50,44,76,56,57,37,36,18,
18,52,50,48,152,90,46,40,76,60,61,36,35,20,19,25,24,47,
46,79,76,96,101,87,86,116,41,40,20,19,224,175,60,51,147,117,
119,63,62,42,42,92,91,123,56,0,0,1,1,61,254,62,1,188,
7,158,0,3,0,0,1,17,51,17,1,61,127,254,62,9,96,246,
160,0,0,1,1,61,254,62,1,188,7,158,0,3,0,0,1,17,
51,17,1,61,127,254,62,9,96,246,160,0,0,1,0,0,254,148,
1,188,7,158,0,12,0,0,26,1,17,48,21,17,35,17,2,39,
2,39,55,252,192,127,2,51,92,172,32,6,246,254,120,254,164,28,
250,158,5,98,1,36,144,0,255,219,26,0,0,0,0,1,0,82,
2,196,1,84,3,198,0,17,0,0,19,52,54,51,50,23,22,23,
22,21,20,6,35,34,39,38,39,38,82,76,53,49,33,35,9,3,
76,53,46,35,36,9,3,3,69,55,74,29,31,42,9,18,53,76,
29,30,43,12,0,0,0,1,0,0,254,148,1,188,7,158,0,12,
0,0,36,2,7,39,54,19,54,19,17,51,17,48,21,1,188,192,
220,32,172,92,51,2,127,196,254,120,168,26,219,0,255,144,1,36,
5,98,250,158,28,0,0,0,0,1,0,0,254,62,1,188,7,158,
0,5,0,0,1,17,35,17,33,53,1,188,127,254,195,7,158,246,
160,8,240,112,0,1,1,61,254,62,1,188,7,158,0,3,0,0,
1,17,51,17,1,61,127,254,62,9,96,246,160,0,0,1,0,0,
254,62,1,188,7,158,0,5,0,0,1,33,53,33,17,51,1,188,
254,68,1,61,127,254,62,112,8,240,0,1,0,145,255,255,1,211,
7,10,0,24,0,0,33,7,3,53,52,39,38,47,1,6,7,55,
54,51,48,51,22,23,22,23,22,23,22,29,1,1,210,107,1,26,
25,29,70,39,24,37,30,28,6,50,50,43,24,27,13,14,1,5,
5,188,45,57,53,14,13,6,15,145,24,5,35,31,62,73,77,84,
60,143,0,0,0,1,0,50,1,244,2,112,4,50,0,2,0,0,
9,2,2,112,254,226,254,224,4,50,253,194,2,62,0,1,0,50,
1,244,2,112,4,50,0,2,0,0,1,33,1,2,112,253,194,1,
32,1,244,2,62,0,0,2,0,99,255,227,3,238,5,234,0,40,
0,66,0,0,1,55,23,55,23,7,23,22,23,22,21,20,7,6,
7,6,35,34,39,38,39,38,53,52,55,54,55,50,54,50,22,59,
1,50,53,52,47,1,7,39,55,1,6,21,20,23,22,23,22,23,
48,51,50,55,54,55,54,53,52,39,38,39,38,35,34,7,6,2,
130,129,49,95,91,150,59,21,9,5,5,20,113,114,179,167,106,90,
27,30,114,109,152,16,65,34,68,18,3,115,7,47,130,91,186,254,
75,13,6,34,66,71,78,8,110,75,72,9,13,1,9,114,81,76,
103,37,87,5,202,32,208,80,109,125,249,105,96,53,45,44,58,229,
151,151,92,79,95,103,119,147,54,51,1,1,1,87,17,30,208,109,
109,155,253,32,32,35,23,24,125,60,65,3,99,96,44,72,47,18,
7,83,10,8,20,48,0,0,0,1,0,125,255,227,4,40,5,206,
0,51,0,0,1,3,35,17,35,53,51,53,52,55,54,55,54,55,
54,55,54,51,50,23,22,23,22,21,51,21,35,17,20,59,1,21,
35,34,39,38,53,17,35,53,51,53,52,39,38,35,34,7,34,7,
6,21,1,161,1,152,139,138,29,30,44,43,49,27,60,32,49,44,
46,142,6,3,197,197,117,70,70,149,59,60,96,96,24,20,60,18,
10,53,59,55,4,49,251,207,3,170,135,135,62,51,52,35,34,20,
11,8,5,6,24,188,106,89,135,253,45,117,127,55,56,129,2,215,
135,201,46,32,29,1,40,31,60,0,0,0,0,1,0,96,255,227,
5,35,5,206,0,115,0,0,1,39,38,53,52,55,54,55,54,55,
54,51,50,23,22,23,22,21,51,21,35,17,20,59,1,21,35,34,
39,38,53,17,35,53,51,53,52,39,38,39,34,7,6,21,20,23,
19,7,38,35,34,6,21,20,23,22,23,22,23,22,23,30,4,31,
9,20,7,6,35,34,39,38,39,55,22,23,22,51,50,55,54,53,
52,39,38,39,38,39,38,39,38,39,38,39,38,39,38,39,38,53,
52,55,54,51,50,2,144,47,3,24,25,53,64,75,30,25,32,33,
143,5,3,197,197,117,70,70,149,59,60,96,96,21,26,34,51,32,
42,2,58,144,54,152,81,116,14,15,23,26,22,16,36,10,33,4,
11,20,10,49,49,50,45,43,36,30,17,7,108,107,152,153,92,95,
37,147,30,52,53,91,101,58,58,19,21,34,39,27,30,47,38,63,
42,50,47,34,34,19,21,100,103,145,94,4,35,160,9,20,42,42,
46,42,52,9,5,6,24,188,106,89,135,253,45,117,127,55,56,129,
2,215,135,201,42,29,31,4,22,24,52,6,16,254,127,34,122,78,
72,38,28,29,19,21,12,9,14,4,11,2,3,7,4,18,19,23,
27,33,39,47,54,65,137,90,89,67,69,110,28,67,36,36,48,48,
85,41,31,34,21,25,11,13,14,12,24,17,28,26,36,35,46,49,
59,137,75,77,0,2,0,24,0,0,5,200,4,153,0,15,0,18,
0,0,37,21,35,53,1,53,1,53,51,21,37,21,5,17,5,21,
1,13,1,3,231,143,252,192,3,64,143,1,225,254,31,1,225,253,
144,253,178,2,78,173,173,225,1,43,127,1,43,227,175,173,180,159,
254,13,161,176,3,29,210,203,0,2,0,170,0,0,4,121,5,176,
0,2,0,10,0,0,1,13,1,19,17,33,53,33,3,1,53,3,
234,253,178,2,78,143,252,50,3,64,1,252,192,4,227,210,203,2,
106,250,80,142,2,25,1,43,127,0,0,1,0,11,0,0,4,11,
5,60,0,5,0,0,33,35,17,1,39,1,4,11,155,253,4,105,
4,0,4,23,254,51,138,2,104,0,0,2,0,20,0,0,5,182,
5,174,0,2,0,8,0,0,1,17,9,1,35,53,1,53,1,5,
23,251,190,4,225,158,250,252,5,160,1,130,3,35,254,110,252,237,
175,2,7,179,2,69,0,0,0,1,0,121,0,0,4,18,5,176,
0,13,0,0,1,17,35,53,5,53,37,17,5,53,37,17,5,53,
4,18,156,253,3,2,251,253,48,2,208,253,5,5,176,250,80,197,
61,141,74,1,125,74,141,74,1,186,74,141,0,0,0,1,0,66,
0,0,4,90,5,176,0,8,0,0,19,51,9,1,51,1,17,35,
17,66,168,1,100,1,100,168,254,66,158,5,176,253,168,2,88,253,
60,253,20,2,236,0,0,0,0,1,0,34,0,0,3,94,5,176,
0,11,0,0,1,21,33,17,33,21,33,53,33,17,33,53,3,94,
254,177,1,79,252,196,1,80,254,176,5,176,142,251,108,142,142,4,
148,142,0,3,0,66,0,0,3,219,5,176,0,9,0,13,0,17,
0,0,55,17,51,21,33,17,35,53,33,53,55,33,17,33,53,33,
17,33,66,143,3,10,143,253,11,122,2,123,253,133,2,123,253,133,
136,5,40,152,250,232,135,1,152,1,112,140,1,103,0,0,0,5,
0,20,0,0,5,60,5,40,0,7,0,12,0,17,0,22,0,28,
0,0,0,32,0,16,0,32,0,16,36,32,7,9,1,5,6,16,
23,9,3,54,16,9,1,22,51,50,55,1,150,2,36,1,130,254,
126,253,220,254,126,3,60,254,176,134,1,46,1,46,253,57,99,99,
1,46,2,4,254,210,1,46,99,254,4,254,210,133,169,168,134,5,
40,254,126,253,220,254,126,1,130,2,36,234,99,254,211,1,45,107,
134,254,176,133,1,45,1,46,254,210,254,211,133,1,80,254,237,254,
210,99,99,0,0,1,0,100,0,0,4,221,5,176,0,11,0,0,
19,33,1,33,21,33,1,33,53,33,1,33,129,4,80,252,160,3,
108,251,135,1,122,254,152,1,199,1,144,252,180,5,176,250,221,141,
2,58,142,2,91,0,0,1,0,26,0,0,5,46,5,54,0,10,
0,0,33,39,1,5,39,37,19,23,19,1,23,2,56,112,1,50,
253,164,132,2,226,4,157,2,1,31,112,112,1,49,2,140,1,3,
10,152,253,170,1,30,112,0,0,1,0,52,0,0,3,33,4,79,
0,5,0,0,1,23,1,33,21,33,2,151,133,254,26,1,235,253,
19,4,79,74,252,147,152,0,0,1,0,44,0,0,4,29,5,181,
0,24,0,0,1,27,3,23,22,21,48,21,2,1,39,18,19,54,
53,52,47,1,11,2,1,55,1,70,185,142,212,174,1,13,16,254,
251,128,209,46,1,11,70,199,132,166,254,230,135,4,53,1,128,254,
123,1,123,253,190,4,74,57,18,254,185,254,119,79,1,24,1,105,
5,14,31,69,230,254,155,1,108,254,168,2,74,65,0,1,0,34,
0,0,3,112,4,169,0,7,0,0,19,23,3,1,3,39,19,1,
125,151,56,2,148,64,151,48,253,89,4,169,20,254,91,1,41,251,
231,10,3,28,254,210,0,0,0,1,0,41,0,0,4,1,5,176,
0,27,0,0,1,51,17,33,21,33,21,33,21,33,21,33,21,33,
17,35,17,33,53,33,53,33,53,33,53,33,53,33,1,201,152,1,
160,254,96,1,160,254,96,1,160,254,96,152,254,96,1,160,254,96,
1,160,254,96,1,160,5,176,254,194,152,152,152,176,152,254,158,1,
98,152,176,152,152,152,0,2,0,34,0,0,5,46,5,12,0,7,
0,15,0,0,0,32,0,16,0,32,0,16,36,32,0,16,0,32,
0,16,1,156,2,24,1,122,254,134,253,232,254,134,3,82,254,104,
254,222,1,34,1,152,1,34,5,12,254,134,253,232,254,134,1,122,
2,24,226,254,222,254,104,254,222,1,34,1,152,0,0,1,0,38,
0,0,4,45,5,60,0,25,0,0,19,39,18,33,50,23,22,23,
22,21,20,7,6,15,1,39,54,55,54,53,52,33,34,7,6,7,
196,158,130,1,199,174,110,109,27,26,176,179,174,176,74,221,200,201,
254,219,151,107,104,31,3,183,53,1,80,83,82,73,69,56,219,243,
247,133,135,144,142,248,249,183,213,57,56,58,0,1,0,35,0,0,
4,83,4,171,0,11,0,0,19,23,37,19,37,23,5,3,7,19,
7,1,179,82,1,86,156,1,11,81,254,104,156,234,243,144,254,139,
4,171,250,197,254,213,167,129,255,1,50,135,253,18,47,4,123,0,
0,3,0,22,0,0,4,100,5,176,0,17,0,25,0,30,0,0,
33,17,38,39,38,53,52,0,51,50,23,22,21,20,7,6,7,25,
2,54,55,54,53,52,38,37,4,17,16,5,1,232,197,136,133,1,
66,229,228,161,162,139,139,206,144,93,95,190,254,218,254,198,1,58,
1,217,27,140,137,185,204,1,34,145,146,203,189,139,140,22,254,40,
5,19,253,94,21,95,97,124,126,190,18,59,254,237,254,236,59,0,
0,2,0,22,0,0,4,52,5,12,0,4,0,7,0,0,19,1,
17,35,25,1,13,1,22,4,30,152,253,254,2,2,3,11,2,1,
250,244,1,195,2,87,251,187,0,1,0,84,0,0,5,236,5,176,
0,12,0,0,19,51,19,1,51,1,19,51,3,35,9,1,35,84,
160,184,1,18,195,1,18,185,160,230,219,254,246,254,246,224,5,176,
251,6,4,213,251,43,4,250,250,80,4,205,251,51,0,1,0,74,
0,0,4,137,5,176,0,11,0,0,19,51,9,1,51,9,1,35,
9,1,35,1,74,182,1,106,1,99,182,254,59,1,203,190,254,159,
254,152,178,1,199,5,176,253,162,2,94,253,41,253,39,2,74,253,
182,2,217,0,0,0,0,1,0,154,0,0,1,55,5,176,0,3,
0,0,51,17,51,17,154,157,5,176,250,80,0,1,0,120,4,34,
3,176,5,176,0,5,0,0,19,33,17,35,17,33,120,3,56,143,
253,87,5,176,254,114,1,0,0,1,0,27,1,255,2,194,5,176,
0,12,0,0,19,55,37,53,37,47,1,5,21,13,1,21,5,224,
232,254,83,1,173,226,6,1,226,254,36,1,220,254,33,2,133,54,
209,151,209,53,135,129,122,222,227,117,128,0,0,0,0,1,0,19,
2,89,4,208,5,187,0,9,0,0,19,39,1,23,55,23,7,1,
7,1,115,96,1,197,168,168,98,168,1,238,107,253,105,3,150,96,
1,197,168,168,98,168,254,19,107,2,150,0,0,2,0,154,0,0,
2,88,5,176,0,3,0,7,0,0,33,17,51,17,33,17,51,17,
1,187,157,254,66,157,5,176,250,80,5,176,250,80,0,0,0,3,
0,154,0,0,3,120,5,176,0,3,0,7,0,11,0,0,33,17,
51,17,33,17,51,17,33,17,51,17,2,219,157,254,67,157,254,66,
157,5,176,250,80,5,176,250,80,5,176,250,80,0,0,1,0,95,
2,34,1,54,2,249,0,17,0,0,19,52,55,54,51,50,22,23,
22,21,20,6,35,34,39,38,39,38,95,32,31,45,38,60,7,2,
64,43,39,29,30,7,3,2,141,45,32,31,50,35,10,13,43,64,
24,25,36,11,0,0,0,1,0,95,2,34,1,54,2,249,0,17,
0,0,19,52,55,54,51,50,22,23,22,21,20,6,35,34,39,38,
39,38,95,32,31,45,38,60,7,2,64,43,39,29,30,7,3,2,
141,45,32,31,50,35,10,13,43,64,24,25,36,11,0,0,0,1,
0,95,2,34,1,54,2,249,0,17,0,0,19,52,55,54,51,50,
22,23,22,21,20,6,35,34,39,38,39,38,95,32,31,45,38,60,
7,2,64,43,39,29,30,7,3,2,141,45,32,31,50,35,10,13,
43,64,24,25,36,11,0,0,0,1,0,95,2,34,1,54,2,249,
0,17,0,0,19,52,55,54,51,50,22,23,22,21,20,6,35,34,
39,38,39,38,95,32,31,45,38,60,7,2,64,43,39,29,30,7,
3,2,141,45,32,31,50,35,10,13,43,64,24,25,36,11,0,0,
0,0,0,1,0,0,2,132,0,1,0,105,1,128,0,6,0,246,
0,6,0,7,255,201,0,18,0,18,255,113,0,36,0,38,255,176,
0,36,0,55,255,158,0,36,0,57,255,43,0,36,0,89,255,92,
0,36,0,90,255,162,0,36,1,15,255,156,0,36,1,16,255,156,
0,36,1,17,255,156,0,36,1,19,255,156,0,40,0,53,0,41,
0,42,0,55,255,188,0,46,0,50,255,147,0,50,0,36,255,158,
0,50,0,55,255,143,0,51,0,36,255,119,0,55,0,36,255,145,
0,55,0,88,255,121,0,57,0,36,255,12,0,57,0,40,255,186,
0,57,0,72,255,190,0,58,0,36,255,160,0,58,0,72,255,229,
0,60,0,36,255,66,0,60,0,68,255,129,0,63,0,63,255,113,
0,68,0,89,255,133,0,72,0,87,255,203,0,73,0,68,255,176,
0,73,0,81,255,188,0,73,0,82,255,215,0,73,0,87,255,186,
0,73,0,88,255,174,0,73,0,92,255,215,0,74,0,77,0,117,
0,77,0,77,0,80,0,82,0,91,255,203,0,84,0,77,1,18,
0,85,0,72,255,215,0,92,0,77,0,117,0,130,1,15,255,156,
0,130,1,16,255,156,0,130,1,17,255,156,0,130,1,19,255,156,
0,131,1,15,255,156,0,131,1,16,255,156,0,131,1,17,255,156,
0,131,1,19,255,156,0,132,1,15,255,156,0,132,1,16,255,156,
0,132,1,17,255,156,0,132,1,19,255,156,0,133,1,15,255,156,
0,133,1,16,255,156,0,133,1,17,255,156,0,133,1,19,255,156,
0,134,1,15,255,156,0,134,1,16,255,156,0,134,1,17,255,156,
0,134,1,19,255,156,0,135,1,15,255,156,0,135,1,16,255,156,
0,135,1,17,255,156,0,135,1,19,255,156,0,194,0,50,255,156,
0,194,0,82,255,156,0,194,0,89,255,24,0,194,0,149,255,156,
0,194,0,181,255,156,0,194,0,182,255,156,0,194,0,183,255,156,
0,194,0,184,255,156,0,194,1,15,255,156,0,194,1,16,255,156,
0,194,1,17,255,156,0,194,1,19,255,156,0,196,0,50,255,156,
0,196,0,57,255,24,0,196,0,82,255,156,0,196,0,89,255,24,
0,196,0,149,255,156,0,196,0,181,255,156,0,196,0,182,255,156,
0,196,0,183,255,156,0,196,0,184,255,156,0,196,1,15,255,156,
0,196,1,16,255,156,0,196,1,17,255,156,0,196,1,19,255,156,
0,198,0,50,255,156,0,198,0,57,255,24,0,198,0,82,255,156,
0,198,0,89,255,24,0,198,0,149,255,156,0,198,0,181,255,156,
0,198,0,182,255,156,0,198,0,183,255,156,0,198,0,184,255,156,
0,198,1,15,255,156,0,198,1,16,255,156,0,198,1,17,255,156,
0,198,1,19,255,156,5,108,0,176,255,32,5,108,5,109,0,51,
0,0,0,55,2,154,0,1,0,0,0,0,0,0,1,2,2,6,
0,1,0,0,0,0,0,1,0,5,3,21,0,1,0,0,0,0,
0,2,0,7,3,43,0,1,0,0,0,0,0,3,0,37,3,127,
0,1,0,0,0,0,0,4,0,13,3,193,0,1,0,0,0,0,
0,5,0,16,3,241,0,1,0,0,0,0,0,6,0,5,4,14,
0,1,0,0,0,0,0,9,0,49,4,120,0,1,0,0,0,0,
0,11,0,19,4,210,0,1,0,0,0,0,0,12,0,19,5,14,
0,1,0,0,0,0,0,13,0,14,5,64,0,1,0,0,0,0,
1,0,0,24,5,79,0,1,0,0,0,0,1,1,0,9,5,214,
0,1,0,0,0,0,1,2,0,9,6,7,0,1,0,0,0,0,
1,3,0,17,6,35,0,1,0,0,0,0,1,4,0,16,6,146,
0,1,0,0,0,0,1,5,0,12,6,249,0,1,0,0,0,0,
1,6,0,18,7,65,0,1,0,0,0,1,1,0,0,24,5,104,
0,1,0,0,0,1,1,1,0,9,5,224,0,1,0,0,0,1,
1,2,0,9,6,17,0,1,0,0,0,1,1,3,0,31,6,53,
0,1,0,0,0,1,1,4,0,18,6,163,0,1,0,0,0,1,
1,5,0,16,7,6,0,1,0,0,0,1,1,6,0,22,7,84,
0,1,0,0,0,2,1,0,0,33,5,129,0,1,0,0,0,2,
1,1,0,9,5,234,0,1,0,0,0,2,1,3,0,23,6,85,
0,1,0,0,0,2,1,4,0,17,6,182,0,1,0,0,0,2,
1,5,0,11,7,23,0,1,0,0,0,2,1,6,0,16,7,107,
0,1,0,0,0,3,1,0,0,21,5,163,0,1,0,0,0,3,
1,1,0,8,5,244,0,1,0,0,0,3,1,3,0,17,6,109,
0,1,0,0,0,3,1,4,0,19,6,200,0,1,0,0,0,3,
1,5,0,16,7,35,0,1,0,0,0,3,1,6,0,18,7,124,
0,1,0,0,0,4,1,0,0,28,5,185,0,1,0,0,0,4,
1,1,0,9,5,253,0,1,0,0,0,4,1,2,0,7,6,27,
0,1,0,0,0,4,1,3,0,18,6,127,0,1,0,0,0,4,
1,4,0,28,6,220,0,1,0,0,0,4,1,5,0,12,7,52,
0,1,0,0,0,4,1,6,0,17,7,143,0,3,0,1,4,9,
0,0,2,4,0,0,0,3,0,1,4,9,0,1,0,10,3,9,
0,3,0,1,4,9,0,2,0,14,3,27,0,3,0,1,4,9,
0,3,0,74,3,51,0,3,0,1,4,9,0,4,0,26,3,165,
0,3,0,1,4,9,0,5,0,32,3,207,0,3,0,1,4,9,
0,6,0,10,4,2,0,3,0,1,4,9,0,9,0,98,4,20,
0,3,0,1,4,9,0,11,0,38,4,170,0,3,0,1,4,9,
0,12,0,38,4,230,0,3,0,1,4,9,0,13,0,28,5,34,
0,67,0,114,0,101,0,97,0,116,0,101,0,100,0,32,0,98,
0,121,0,32,0,84,0,104,0,97,0,116,0,99,0,104,0,101,
0,114,0,32,0,85,0,108,0,114,0,105,0,99,0,104,0,32,
0,40,0,104,0,116,0,116,0,112,0,58,0,47,0,47,0,116,
0,117,0,108,0,114,0,105,0,99,0,104,0,46,0,99,0,111,
0,109,0,41,0,44,0,32,0,75,0,97,0,114,0,111,0,108,
0,121,0,32,0,66,0,97,0,114,0,116,0,97,0,32,0,40,
0,98,0,97,0,114,0,116,0,97,0,107,0,97,0,114,0,99,
0,115,0,105,0,64,0,103,0,109,0,97,0,105,0,108,0,46,
0,99,0,111,0,109,0,41,0,32,0,97,0,110,0,100,0,32,
0,77,0,105,0,99,0,104,0,97,0,101,0,108,0,32,0,69,
0,118,0,101,0,114,0,115,0,111,0,110,0,32,0,119,0,105,
0,116,0,104,0,32,0,70,0,111,0,110,0,116,0,70,0,111,
0,114,0,103,0,101,0,32,0,40,0,104,0,116,0,116,0,112,
0,58,0,47,0,47,0,102,0,111,0,110,0,116,0,102,0,111,
0,114,0,103,0,101,0,46,0,115,0,102,0,46,0,110,0,101,
0,116,0,41,0,10,0,10,0,84,0,104,0,105,0,115,0,32,
0,102,0,111,0,110,0,116,0,44,0,32,0,105,0,110,0,99,
0,108,0,117,0,100,0,105,0,110,0,103,0,32,0,104,0,105,
0,110,0,116,0,32,0,105,0,110,0,115,0,116,0,114,0,117,
0,99,0,116,0,105,0,111,0,110,0,115,0,44,0,32,0,104,
0,97,0,115,0,32,0,98,0,101,0,101,0,110,0,32,0,100,
0,111,0,110,0,97,0,116,0,101,0,100,0,32,0,116,0,111,
0,32,0,116,0,104,0,101,0,32,0,80,0,117,0,98,0,108,
0,105,0,99,0,32,0,68,0,111,0,109,0,97,0,105,0,110,
0,46,0,32,0,32,0,68,0,111,0,32,0,119,0,104,0,97,
0,116,0,101,0,118,0,101,0,114,0,32,0,121,0,111,0,117,
0,32,0,119,0,97,0,110,0,116,0,32,0,119,0,105,0,116,
0,104,0,32,0,105,0,116,0,46,0,10,0,0,67,114,101,97,
116,101,100,32,98,121,32,84,104,97,116,99,104,101,114,32,85,108,
114,105,99,104,32,40,104,116,116,112,58,47,47,116,117,108,114,105,
99,104,46,99,111,109,41,44,32,75,97,114,111,108,121,32,66,97,
114,116,97,32,40,98,97,114,116,97,107,97,114,99,115,105,64,103,
109,97,105,108,46,99,111,109,41,32,97,110,100,32,77,105,99,104,
97,101,108,32,69,118,101,114,115,111,110,32,119,105,116,104,32,70,
111,110,116,70,111,114,103,101,32,40,104,116,116,112,58,47,47,102,
111,110,116,102,111,114,103,101,46,115,102,46,110,101,116,41,10,10,
84,104,105,115,32,102,111,110,116,44,32,105,110,99,108,117,100,105,
110,103,32,104,105,110,116,32,105,110,115,116,114,117,99,116,105,111,
110,115,44,32,104,97,115,32,98,101,101,110,32,100,111,110,97,116,
101,100,32,116,111,32,116,104,101,32,80,117,98,108,105,99,32,68,
111,109,97,105,110,46,32,32,68,111,32,119,104,97,116,101,118,101,
114,32,121,111,117,32,119,97,110,116,32,119,105,116,104,32,105,116,
46,10,0,0,84,0,117,0,102,0,102,0,121,0,0,84,117,102,
102,121,0,0,82,0,101,0,103,0,117,0,108,0,97,0,114,0,
0,82,101,103,117,108,97,114,0,0,70,0,111,0,110,0,116,0,
70,0,111,0,114,0,103,0,101,0,32,0,58,0,32,0,84,0,
117,0,102,0,102,0,121,0,32,0,82,0,101,0,103,0,117,0,
108,0,97,0,114,0,32,0,58,0,32,0,49,0,52,0,45,0,
54,0,45,0,50,0,48,0,49,0,50,0,0,70,111,110,116,70,
111,114,103,101,32,58,32,84,117,102,102,121,32,82,101,103,117,108,
97,114,32,58,32,49,52,45,54,45,50,48,49,50,0,0,84,0,
117,0,102,0,102,0,121,0,32,0,82,0,101,0,103,0,117,0,
108,0,97,0,114,0,0,84,117,102,102,121,32,82,101,103,117,108,
97,114,0,0,86,0,101,0,114,0,115,0,105,0,111,0,110,0,
32,0,48,0,48,0,49,0,46,0,50,0,56,0,48,0,32,0,
0,86,101,114,115,105,111,110,32,48,48,49,46,50,56,48,32,0,
0,84,0,117,0,102,0,102,0,121,0,0,84,117,102,102,121,0,
0,84,0,104,0,97,0,116,0,99,0,104,0,101,0,114,0,32,
0,85,0,108,0,114,0,105,0,99,0,104,0,44,0,32,0,75,
0,97,0,114,0,111,0,108,0,121,0,32,0,66,0,97,0,114,
0,116,0,97,0,32,0,97,0,110,0,100,0,32,0,77,0,105,
0,99,0,104,0,97,0,101,0,108,0,32,0,69,0,118,0,101,
0,114,0,115,0,111,0,110,0,0,84,104,97,116,99,104,101,114,
32,85,108,114,105,99,104,44,32,75,97,114,111,108,121,32,66,97,
114,116,97,32,97,110,100,32,77,105,99,104,97,101,108,32,69,118,
101,114,115,111,110,0,0,104,0,116,0,116,0,112,0,58,0,47,
0,47,0,116,0,117,0,108,0,114,0,105,0,99,0,104,0,46,
0,99,0,111,0,109,0,10,0,0,104,116,116,112,58,47,47,116,
117,108,114,105,99,104,46,99,111,109,10,0,0,104,0,116,0,116,
0,112,0,58,0,47,0,47,0,116,0,117,0,108,0,114,0,105,
0,99,0,104,0,46,0,99,0,111,0,109,0,10,0,0,104,116,
116,112,58,47,47,116,117,108,114,105,99,104,46,99,111,109,10,0,
0,80,0,117,0,98,0,108,0,105,0,99,0,32,0,68,0,111,
0,109,0,97,0,105,0,110,0,10,0,0,80,117,98,108,105,99,
32,68,111,109,97,105,110,10,0,65,108,108,32,84,121,112,111,103,
114,97,112,104,105,99,32,70,101,97,116,117,114,101,115,0,70,111,
110,99,116,105,111,110,115,32,116,121,112,111,103,114,97,112,104,105,
113,117,101,115,0,65,108,108,101,32,116,121,112,111,103,114,97,102,
105,115,99,104,101,110,32,77,154,103,108,105,99,104,107,101,105,116,
101,110,0,70,117,110,122,105,111,110,105,32,84,105,112,111,103,114,
97,102,105,99,104,101,0,65,108,108,101,32,116,121,112,111,103,114,
97,102,105,115,99,104,101,32,107,101,110,109,101,114,107,101,110,0,
76,105,103,97,116,117,114,101,115,0,76,105,103,97,116,117,114,101,
115,0,76,105,103,97,116,117,114,101,110,0,76,101,103,97,116,117,
114,101,0,76,105,103,97,116,117,114,101,110,0,70,114,97,99,116,
105,111,110,115,0,70,114,97,99,116,105,111,110,115,0,66,114,101,
117,107,101,110,0,65,108,108,32,84,121,112,101,32,70,101,97,116,
117,114,101,115,0,84,111,117,116,101,115,32,102,111,110,99,116,105,
111,110,115,32,116,121,112,111,103,114,97,112,104,105,113,117,101,115,
0,65,108,108,101,32,65,117,115,122,101,105,99,104,110,117,110,103,
115,97,114,116,101,110,0,84,117,116,116,101,32,108,101,32,70,117,
110,122,105,111,110,105,0,65,108,108,101,32,116,121,112,101,107,101,
110,109,101,114,107,101,110,0,67,111,109,109,111,110,32,76,105,103,
97,116,117,114,101,115,0,76,105,103,97,116,117,114,101,115,32,85,
115,117,101,108,108,101,115,0,78,111,114,109,97,108,101,32,76,105,
103,97,116,117,114,101,110,0,76,101,103,97,116,117,114,101,32,112,
105,157,32,67,111,109,117,110,105,0,71,101,109,101,101,110,115,99,
104,97,112,112,101,108,105,106,107,101,32,76,105,103,97,116,117,114,
101,110,0,78,111,32,70,114,97,99,116,105,111,110,115,0,80,97,
115,32,100,101,32,70,114,97,99,116,105,111,110,115,0,75,101,105,
110,32,66,114,117,99,104,101,0,78,101,115,115,117,110,97,32,70,
114,97,122,105,111,110,101,0,71,101,101,110,32,98,114,101,117,107,
101,110,0,68,105,97,103,111,110,97,108,32,70,114,97,99,116,105,
111,110,115,0,70,114,97,99,116,105,111,110,115,32,101,110,32,68,
105,97,103,111,110,97,108,101,0,68,105,97,103,111,110,97,108,101,
114,32,66,114,117,99,104,0,70,114,97,122,105,111,110,105,32,68,
105,97,103,111,110,97,108,105,0,68,105,97,103,111,110,97,108,101,
32,98,114,101,117,107,101,110,0,0,0,2,0,0,0,0,0,0,
255,131,0,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,5,222,0,0,0,1,0,2,0,3,0,4,
0,5,0,6,0,7,0,8,0,9,0,10,0,11,0,12,0,13,
0,14,0,15,0,16,0,17,0,18,0,19,0,20,0,21,0,22,
0,23,0,24,0,25,0,26,0,27,0,28,0,29,0,30,0,31,
0,32,0,33,0,34,0,35,0,36,0,37,0,38,0,39,0,40,
0,41,0,42,0,43,0,44,0,45,0,46,0,47,0,48,0,49,
0,50,0,51,0,52,0,53,0,54,0,55,0,56,0,57,0,58,
0,59,0,60,0,61,0,62,0,63,0,64,0,65,0,66,0,67,
0,68,0,69,0,70,0,71,0,72,0,73,0,74,0,75,0,76,
0,77,0,78,0,79,0,80,0,81,0,82,0,83,0,84,0,85,
0,86,0,87,0,88,0,89,0,90,0,91,0,92,0,93,0,94,
0,95,0,96,0,97,1,2,0,163,0,132,0,133,0,189,0,150,
0,232,0,134,0,142,0,139,0,157,0,169,0,164,1,3,0,138,
0,218,0,131,0,147,0,242,0,243,0,141,1,4,0,136,0,195,
0,222,0,241,0,158,0,170,0,245,0,244,0,246,0,162,0,173,
0,201,0,199,0,174,0,98,0,99,0,144,0,100,0,203,0,101,
0,200,0,202,0,207,0,204,0,205,0,206,0,233,0,102,0,211,
0,208,0,209,0,175,0,103,0,240,0,145,0,214,0,212,0,213,
0,104,0,235,0,237,0,137,0,106,0,105,0,107,0,109,0,108,
0,110,0,160,0,111,0,113,0,112,0,114,0,115,0,117,0,116,
0,118,0,119,0,234,0,120,0,122,0,121,0,123,0,125,0,124,
0,184,0,161,0,127,0,126,0,128,0,129,0,236,0,238,0,186,
1,5,1,6,1,7,1,8,1,9,1,10,0,253,0,254,1,11,
1,12,1,13,1,14,0,255,1,0,1,15,1,16,1,17,1,1,
1,18,1,19,1,20,1,21,1,22,1,23,1,24,1,25,1,26,
1,27,1,28,1,29,0,248,0,249,1,30,1,31,1,32,1,33,
1,34,1,35,1,36,1,37,1,38,1,39,1,40,1,41,1,42,
1,43,1,44,1,45,0,250,0,215,1,46,1,47,1,48,1,49,
1,50,1,51,1,52,1,53,1,54,1,55,1,56,1,57,1,58,
1,59,1,60,0,226,0,227,1,61,1,62,1,63,1,64,1,65,
1,66,1,67,1,68,1,69,1,70,1,71,1,72,1,73,1,74,
1,75,0,176,0,177,1,76,1,77,1,78,1,79,1,80,1,81,
1,82,1,83,1,84,1,85,0,251,0,252,0,228,0,229,1,86,
1,87,1,88,1,89,1,90,1,91,1,92,1,93,1,94,1,95,
1,96,1,97,1,98,1,99,1,100,1,101,1,102,1,103,1,104,
1,105,1,106,1,107,0,187,1,108,1,109,1,110,1,111,0,230,
0,231,1,112,0,166,1,113,1,114,1,115,1,116,1,117,1,118,
1,119,1,120,1,121,1,122,1,123,1,124,1,125,1,126,1,127,
1,128,1,129,1,130,1,131,1,132,1,133,1,134,1,135,1,136,
1,137,1,138,1,139,1,140,1,141,1,142,1,143,1,144,1,145,
1,146,1,147,1,148,1,149,1,150,1,151,1,152,1,153,1,154,
1,155,1,156,1,157,1,158,1,159,1,160,1,161,1,162,1,163,
1,164,1,165,1,166,1,167,1,168,1,169,1,170,1,171,1,172,
1,173,1,174,1,175,1,176,1,177,1,178,1,179,1,180,1,181,
1,182,1,183,1,184,1,185,1,186,1,187,1,188,1,189,1,190,
1,191,1,192,1,193,1,194,1,195,1,196,1,197,1,198,1,199,
1,200,1,201,1,202,1,203,1,204,1,205,1,206,1,207,1,208,
1,209,1,210,1,211,1,212,1,213,1,214,1,215,1,216,0,216,
0,225,1,217,0,219,0,220,0,221,0,224,0,217,0,223,1,218,
1,219,1,220,1,221,1,222,1,223,1,224,1,225,1,226,1,227,
1,228,1,229,1,230,1,231,1,232,1,233,1,234,1,235,1,236,
1,237,1,238,1,239,1,240,1,241,1,242,1,243,1,244,1,245,
1,246,1,247,1,248,1,249,1,250,1,251,1,252,1,253,1,254,
1,255,2,0,2,1,2,2,0,168,2,3,2,4,2,5,2,6,
2,7,2,8,2,9,2,10,2,11,2,12,2,13,2,14,2,15,
2,16,2,17,2,18,2,19,2,20,2,21,0,159,2,22,2,23,
2,24,2,25,2,26,2,27,2,28,2,29,2,30,2,31,2,32,
2,33,2,34,2,35,2,36,2,37,2,38,2,39,0,151,2,40,
2,41,2,42,0,155,2,43,2,44,2,45,2,46,2,47,2,48,
2,49,2,50,2,51,2,52,2,53,2,54,2,55,2,56,2,57,
2,58,2,59,2,60,2,61,2,62,2,63,2,64,2,65,2,66,
2,67,2,68,2,69,2,70,2,71,2,72,2,73,2,74,2,75,
2,76,2,77,2,78,2,79,2,80,2,81,2,82,2,83,2,84,
2,85,2,86,2,87,2,88,2,89,2,90,2,91,2,92,2,93,
2,94,2,95,2,96,2,97,2,98,2,99,2,100,2,101,2,102,
2,103,2,104,2,105,2,106,2,107,2,108,2,109,2,110,2,111,
2,112,2,113,2,114,2,115,2,116,2,117,2,118,2,119,2,120,
2,121,2,122,2,123,2,124,2,125,2,126,2,127,2,128,2,129,
2,130,2,131,2,132,2,133,2,134,2,135,2,136,2,137,2,138,
2,139,2,140,2,141,2,142,2,143,2,144,2,145,2,146,2,147,
2,148,2,149,2,150,2,151,2,152,2,153,2,154,2,155,2,156,
2,157,2,158,2,159,2,160,2,161,2,162,2,163,2,164,2,165,
2,166,2,167,2,168,2,169,2,170,2,171,2,172,2,173,2,174,
2,175,2,176,2,177,2,178,2,179,2,180,2,181,2,182,2,183,
2,184,2,185,2,186,2,187,2,188,2,189,2,190,2,191,2,192,
2,193,2,194,2,195,2,196,2,197,2,198,2,199,2,200,2,201,
2,202,2,203,2,204,2,205,2,206,2,207,2,208,2,209,2,210,
2,211,2,212,2,213,2,214,2,215,2,216,2,217,2,218,2,219,
2,220,2,221,2,222,2,223,2,224,2,225,2,226,2,227,2,228,
2,229,2,230,2,231,2,232,2,233,2,234,2,235,2,236,2,237,
2,238,2,239,2,240,2,241,2,242,2,243,2,244,2,245,2,246,
2,247,2,248,2,249,2,250,2,251,2,252,2,253,2,254,2,255,
3,0,3,1,3,2,3,3,3,4,3,5,3,6,3,7,3,8,
3,9,3,10,3,11,3,12,3,13,3,14,3,15,3,16,3,17,
3,18,3,19,3,20,3,21,3,22,3,23,3,24,3,25,3,26,
3,27,3,28,3,29,3,30,3,31,3,32,3,33,3,34,3,35,
3,36,3,37,3,38,3,39,3,40,3,41,3,42,3,43,3,44,
3,45,3,46,3,47,3,48,3,49,3,50,3,51,3,52,3,53,
3,54,3,55,3,56,3,57,3,58,3,59,3,60,3,61,3,62,
3,63,3,64,3,65,3,66,3,67,3,68,3,69,3,70,3,71,
3,72,3,73,3,74,3,75,3,76,3,77,3,78,3,79,3,80,
3,81,3,82,3,83,3,84,3,85,3,86,3,87,3,88,3,89,
3,90,3,91,3,92,3,93,3,94,3,95,3,96,3,97,3,98,
3,99,3,100,3,101,3,102,3,103,3,104,3,105,3,106,3,107,
3,108,3,109,3,110,3,111,3,112,3,113,3,114,3,115,3,116,
3,117,3,118,3,119,3,120,3,121,3,122,3,123,3,124,3,125,
3,126,3,127,3,128,3,129,3,130,3,131,3,132,3,133,3,134,
3,135,3,136,3,137,3,138,3,139,3,140,3,141,3,142,3,143,
3,144,3,145,3,146,3,147,3,148,3,149,3,150,3,151,3,152,
3,153,3,154,3,155,3,156,3,157,3,158,3,159,3,160,3,161,
3,162,3,163,3,164,3,165,3,166,3,167,3,168,3,169,3,170,
3,171,3,172,3,173,3,174,3,175,3,176,3,177,3,178,3,179,
3,180,3,181,3,182,3,183,3,184,3,185,3,186,3,187,3,188,
3,189,3,190,3,191,3,192,3,193,3,194,3,195,3,196,3,197,
3,198,3,199,3,200,3,201,3,202,3,203,3,204,3,205,3,206,
3,207,3,208,3,209,3,210,3,211,3,212,3,213,3,214,3,215,
3,216,3,217,3,218,3,219,3,220,3,221,3,222,3,223,3,224,
3,225,3,226,3,227,3,228,3,229,3,230,3,231,3,232,3,233,
3,234,3,235,3,236,3,237,3,238,3,239,3,240,3,241,3,242,
3,243,3,244,3,245,3,246,3,247,3,248,3,249,3,250,3,251,
3,252,3,253,3,254,3,255,4,0,4,1,4,2,4,3,4,4,
4,5,4,6,4,7,4,8,4,9,4,10,4,11,4,12,4,13,
4,14,4,15,4,16,4,17,4,18,4,19,4,20,4,21,4,22,
4,23,4,24,4,25,4,26,4,27,4,28,4,29,4,30,4,31,
4,32,4,33,4,34,4,35,4,36,4,37,4,38,4,39,4,40,
4,41,4,42,4,43,4,44,4,45,4,46,4,47,4,48,4,49,
4,50,4,51,4,52,4,53,4,54,4,55,4,56,4,57,4,58,
4,59,4,60,4,61,4,62,4,63,4,64,4,65,4,66,4,67,
4,68,4,69,4,70,4,71,4,72,4,73,4,74,4,75,4,76,
4,77,4,78,4,79,4,80,4,81,4,82,4,83,4,84,4,85,
4,86,4,87,4,88,4,89,4,90,4,91,4,92,4,93,4,94,
4,95,4,96,4,97,4,98,4,99,4,100,4,101,4,102,4,103,
4,104,4,105,4,106,0,178,0,179,4,107,4,108,0,182,0,183,
0,196,4,109,0,180,0,181,0,197,4,110,0,130,0,194,0,135,
4,111,4,112,4,113,0,171,4,114,0,198,4,115,4,116,4,117,
0,190,0,191,4,118,4,119,4,120,4,121,4,122,0,188,4,123,
4,124,4,125,4,126,4,127,4,128,4,129,4,130,4,131,4,132,
4,133,4,134,4,135,4,136,4,137,4,138,4,139,4,140,4,141,
4,142,4,143,4,144,4,145,4,146,4,147,4,148,4,149,4,150,
4,151,4,152,4,153,4,154,4,155,4,156,4,157,4,158,4,159,
4,160,4,161,4,162,4,163,4,164,4,165,4,166,4,167,4,168,
4,169,4,170,4,171,4,172,4,173,4,174,4,175,4,176,4,177,
4,178,4,179,4,180,0,247,4,181,4,182,4,183,4,184,4,185,
4,186,4,187,4,188,4,189,4,190,4,191,4,192,4,193,4,194,
4,195,4,196,4,197,4,198,4,199,4,200,4,201,4,202,4,203,
4,204,4,205,4,206,4,207,0,140,4,208,4,209,4,210,4,211,
4,212,4,213,4,214,4,215,4,216,4,217,4,218,4,219,4,220,
4,221,4,222,4,223,4,224,4,225,4,226,4,227,4,228,4,229,
4,230,4,231,4,232,4,233,4,234,4,235,4,236,4,237,4,238,
4,239,4,240,4,241,4,242,4,243,4,244,4,245,4,246,4,247,
4,248,4,249,4,250,4,251,4,252,4,253,4,254,4,255,5,0,
5,1,5,2,5,3,5,4,5,5,5,6,5,7,5,8,5,9,
5,10,5,11,5,12,5,13,5,14,5,15,5,16,5,17,5,18,
5,19,5,20,5,21,5,22,5,23,5,24,5,25,5,26,5,27,
5,28,5,29,5,30,5,31,5,32,5,33,5,34,5,35,5,36,
5,37,5,38,5,39,5,40,5,41,5,42,5,43,5,44,5,45,
5,46,5,47,5,48,5,49,5,50,5,51,5,52,5,53,5,54,
5,55,5,56,5,57,5,58,5,59,5,60,5,61,5,62,5,63,
5,64,5,65,5,66,5,67,5,68,5,69,0,152,5,70,5,71,
5,72,5,73,5,74,5,75,5,76,0,154,5,77,0,153,0,239,
5,78,0,165,5,79,5,80,5,81,0,146,5,82,5,83,5,84,
5,85,5,86,0,156,5,87,5,88,5,89,0,167,0,143,5,90,
0,148,0,149,5,91,5,92,5,93,5,94,5,95,5,96,5,97,
5,98,5,99,5,100,5,101,5,102,5,103,5,104,0,185,5,105,
5,106,5,107,5,108,5,109,5,110,5,111,5,112,5,113,5,114,
5,115,5,116,5,117,5,118,5,119,5,120,5,121,5,122,5,123,
5,124,5,125,5,126,5,127,5,128,5,129,5,130,5,131,5,132,
5,133,5,134,5,135,5,136,5,137,5,138,5,139,5,140,5,141,
5,142,5,143,5,144,5,145,5,146,5,147,5,148,5,149,5,150,
5,151,5,152,5,153,5,154,5,155,5,156,5,157,5,158,5,159,
5,160,5,161,5,162,5,163,5,164,5,165,5,166,5,167,5,168,
5,169,5,170,5,171,5,172,5,173,5,174,5,175,5,176,5,177,
5,178,5,179,5,180,5,181,5,182,5,183,5,184,5,185,5,186,
5,187,5,188,5,189,5,190,5,191,5,192,5,193,5,194,5,195,
5,196,5,197,5,198,5,199,5,200,5,201,5,202,5,203,5,204,
5,205,5,206,5,207,5,208,5,209,5,210,5,211,5,212,5,213,
5,214,5,215,5,216,5,217,5,218,5,219,5,220,5,221,5,222,
5,223,5,224,5,225,7,117,110,105,48,48,55,70,10,115,111,102,
116,104,121,112,104,101,110,7,117,110,105,48,48,66,53,7,65,109,
97,99,114,111,110,7,97,109,97,99,114,111,110,6,65,98,114,101,
118,101,6,97,98,114,101,118,101,7,65,111,103,111,110,101,107,7,
97,111,103,111,110,101,107,11,67,99,105,114,99,117,109,102,108,101,
120,11,99,99,105,114,99,117,109,102,108,101,120,10,67,100,111,116,
97,99,99,101,110,116,10,99,100,111,116,97,99,99,101,110,116,6,
68,99,97,114,111,110,6,100,99,97,114,111,110,6,68,99,114,111,
97,116,7,69,109,97,99,114,111,110,7,101,109,97,99,114,111,110,
6,69,98,114,101,118,101,6,101,98,114,101,118,101,10,69,100,111,
116,97,99,99,101,110,116,10,101,100,111,116,97,99,99,101,110,116,
7,69,111,103,111,110,101,107,7,101,111,103,111,110,101,107,6,69,
99,97,114,111,110,6,101,99,97,114,111,110,11,71,99,105,114,99,
117,109,102,108,101,120,11,103,99,105,114,99,117,109,102,108,101,120,
10,71,100,111,116,97,99,99,101,110,116,10,103,100,111,116,97,99,
99,101,110,116,12,71,99,111,109,109,97,97,99,99,101,110,116,12,
103,99,111,109,109,97,97,99,99,101,110,116,11,72,99,105,114,99,
117,109,102,108,101,120,11,104,99,105,114,99,117,109,102,108,101,120,
4,72,98,97,114,4,104,98,97,114,6,73,116,105,108,100,101,6,
105,116,105,108,100,101,7,73,109,97,99,114,111,110,7,105,109,97,
99,114,111,110,6,73,98,114,101,118,101,6,105,98,114,101,118,101,
7,73,111,103,111,110,101,107,7,105,111,103,111,110,101,107,2,73,
74,2,105,106,11,74,99,105,114,99,117,109,102,108,101,120,11,106,
99,105,114,99,117,109,102,108,101,120,12,75,99,111,109,109,97,97,
99,99,101,110,116,12,107,99,111,109,109,97,97,99,99,101,110,116,
12,107,103,114,101,101,110,108,97,110,100,105,99,6,76,97,99,117,
116,101,6,108,97,99,117,116,101,12,76,99,111,109,109,97,97,99,
99,101,110,116,12,108,99,111,109,109,97,97,99,99,101,110,116,6,
76,99,97,114,111,110,6,108,99,97,114,111,110,4,76,100,111,116,
4,108,100,111,116,6,78,97,99,117,116,101,6,110,97,99,117,116,
101,12,78,99,111,109,109,97,97,99,99,101,110,116,12,110,99,111,
109,109,97,97,99,99,101,110,116,6,78,99,97,114,111,110,6,110,
99,97,114,111,110,11,110,97,112,111,115,116,114,111,112,104,101,3,
69,110,103,3,101,110,103,7,79,109,97,99,114,111,110,7,111,109,
97,99,114,111,110,6,79,98,114,101,118,101,6,111,98,114,101,118,
101,13,79,104,117,110,103,97,114,117,109,108,97,117,116,13,111,104,
117,110,103,97,114,117,109,108,97,117,116,6,82,97,99,117,116,101,
6,114,97,99,117,116,101,12,82,99,111,109,109,97,97,99,99,101,
110,116,12,114,99,111,109,109,97,97,99,99,101,110,116,6,82,99,
97,114,111,110,6,114,99,97,114,111,110,6,83,97,99,117,116,101,
6,115,97,99,117,116,101,11,83,99,105,114,99,117,109,102,108,101,
120,11,115,99,105,114,99,117,109,102,108,101,120,12,84,99,111,109,
109,97,97,99,99,101,110,116,12,116,99,111,109,109,97,97,99,99,
101,110,116,6,84,99,97,114,111,110,6,116,99,97,114,111,110,4,
84,98,97,114,4,116,98,97,114,6,85,116,105,108,100,101,6,117,
116,105,108,100,101,7,85,109,97,99,114,111,110,7,117,109,97,99,
114,111,110,6,85,98,114,101,118,101,6,117,98,114,101,118,101,5,
85,114,105,110,103,5,117,114,105,110,103,13,85,104,117,110,103,97,
114,117,109,108,97,117,116,13,117,104,117,110,103,97,114,117,109,108,
97,117,116,7,85,111,103,111,110,101,107,7,117,111,103,111,110,101,
107,11,87,99,105,114,99,117,109,102,108,101,120,11,119,99,105,114,
99,117,109,102,108,101,120,11,89,99,105,114,99,117,109,102,108,101,
120,11,121,99,105,114,99,117,109,102,108,101,120,6,90,97,99,117,
116,101,6,122,97,99,117,116,101,10,90,100,111,116,97,99,99,101,
110,116,10,122,100,111,116,97,99,99,101,110,116,5,108,111,110,103,
115,7,117,110,105,48,49,69,50,7,117,110,105,48,49,69,51,12,
83,99,111,109,109,97,97,99,99,101,110,116,12,115,99,111,109,109,
97,97,99,99,101,110,116,7,117,110,105,48,50,49,65,7,117,110,
105,48,50,49,66,7,117,110,105,48,50,49,67,7,117,110,105,48,
50,49,68,7,117,110,105,48,50,53,48,7,117,110,105,48,50,53,
49,7,117,110,105,48,50,53,50,7,117,110,105,48,50,53,51,7,
117,110,105,48,50,53,52,7,117,110,105,48,50,53,53,7,117,110,
105,48,50,53,54,7,117,110,105,48,50,53,55,7,117,110,105,48,
50,53,56,7,117,110,105,48,50,53,57,7,117,110,105,48,50,53,
65,7,117,110,105,48,50,53,66,7,117,110,105,48,50,53,67,7,
117,110,105,48,50,53,68,7,117,110,105,48,50,53,69,7,117,110,
105,48,50,53,70,7,117,110,105,48,50,54,48,7,117,110,105,48,
50,54,49,7,117,110,105,48,50,54,50,7,117,110,105,48,50,54,
51,7,117,110,105,48,50,54,52,7,117,110,105,48,50,54,53,7,
117,110,105,48,50,54,54,7,117,110,105,48,50,54,55,7,117,110,
105,48,50,54,56,7,117,110,105,48,50,54,57,7,117,110,105,48,
50,54,65,7,117,110,105,48,50,54,66,7,117,110,105,48,50,54,
67,7,117,110,105,48,50,54,68,7,117,110,105,48,50,54,69,7,
117,110,105,48,50,54,70,7,117,110,105,48,50,55,48,7,117,110,
105,48,50,55,49,7,117,110,105,48,50,55,50,7,117,110,105,48,
50,55,51,7,117,110,105,48,50,55,52,7,117,110,105,48,50,55,
53,7,117,110,105,48,50,55,54,7,117,110,105,48,50,55,55,7,
117,110,105,48,50,55,56,7,117,110,105,48,50,55,57,7,117,110,
105,48,50,55,65,7,117,110,105,48,50,55,66,7,117,110,105,48,
50,55,67,7,117,110,105,48,50,55,68,7,117,110,105,48,50,55,
69,7,117,110,105,48,50,55,70,7,117,110,105,48,50,56,48,7,
117,110,105,48,50,56,49,7,117,110,105,48,50,56,50,7,117,110,
105,48,50,56,51,7,117,110,105,48,50,56,52,7,117,110,105,48,
50,56,53,7,117,110,105,48,50,56,54,7,117,110,105,48,50,56,
55,7,117,110,105,48,50,56,56,7,117,110,105,48,50,56,57,7,
117,110,105,48,50,56,65,7,117,110,105,48,50,56,66,7,117,110,
105,48,50,56,67,7,117,110,105,48,50,56,68,7,117,110,105,48,
50,56,69,7,117,110,105,48,50,56,70,7,117,110,105,48,50,57,
48,7,117,110,105,48,50,57,49,7,117,110,105,48,50,57,50,7,
117,110,105,48,50,57,51,7,117,110,105,48,50,57,52,7,117,110,
105,48,50,57,53,7,117,110,105,48,50,57,54,7,117,110,105,48,
50,57,55,7,117,110,105,48,50,57,56,7,117,110,105,48,50,57,
57,7,117,110,105,48,50,57,65,7,117,110,105,48,50,57,66,7,
117,110,105,48,50,57,67,7,117,110,105,48,50,57,68,7,117,110,
105,48,50,57,69,7,117,110,105,48,50,57,70,7,117,110,105,48,
50,65,48,7,117,110,105,48,50,65,49,7,117,110,105,48,50,65,
50,7,117,110,105,48,50,65,51,7,117,110,105,48,50,65,52,7,
117,110,105,48,50,65,53,7,117,110,105,48,50,65,54,7,117,110,
105,48,50,65,55,7,117,110,105,48,50,65,56,7,117,110,105,48,
50,65,57,7,117,110,105,48,50,65,65,7,117,110,105,48,50,65,
66,7,117,110,105,48,50,65,67,7,117,110,105,48,50,65,68,7,
117,110,105,48,50,65,69,7,117,110,105,48,50,65,70,9,109,97,
99,114,111,110,115,117,98,9,103,114,97,118,101,99,111,109,98,9,
97,99,117,116,101,99,111,109,98,7,117,110,105,48,51,48,50,9,
116,105,108,100,101,99,111,109,98,7,117,110,105,48,51,48,52,7,
117,110,105,48,51,48,54,7,117,110,105,48,51,48,55,7,117,110,
105,48,51,48,56,7,117,110,105,48,51,48,65,7,117,110,105,48,
51,48,66,7,117,110,105,48,51,48,67,7,117,110,105,48,51,49,
48,12,100,111,116,98,101,108,111,119,99,111,109,98,7,117,110,105,
48,51,50,52,7,117,110,105,48,51,50,53,7,117,110,105,48,51,
50,55,7,117,110,105,48,51,50,56,12,98,114,101,118,101,115,117,
98,110,111,115,112,7,117,110,105,48,51,51,49,7,117,110,105,48,
51,55,48,7,117,110,105,48,51,55,49,7,117,110,105,48,51,55,
54,7,117,110,105,48,51,55,65,7,117,110,105,48,51,55,66,7,
117,110,105,48,51,55,67,7,117,110,105,48,51,55,68,7,117,110,
105,48,51,55,69,5,116,111,110,111,115,13,100,105,101,114,101,115,
105,115,116,111,110,111,115,10,65,108,112,104,97,116,111,110,111,115,
9,97,110,111,116,101,108,101,105,97,12,69,112,115,105,108,111,110,
116,111,110,111,115,8,69,116,97,116,111,110,111,115,9,73,111,116,
97,116,111,110,111,115,12,79,109,105,99,114,111,110,116,111,110,111,
115,12,85,112,115,105,108,111,110,116,111,110,111,115,10,79,109,101,
103,97,116,111,110,111,115,17,105,111,116,97,100,105,101,114,101,115,
105,115,116,111,110,111,115,5,65,108,112,104,97,4,66,101,116,97,
5,71,97,109,109,97,7,69,112,115,105,108,111,110,4,90,101,116,
97,3,69,116,97,5,84,104,101,116,97,4,73,111,116,97,5,75,
97,112,112,97,6,76,97,109,98,100,97,2,77,117,2,78,117,2,
88,105,7,79,109,105,99,114,111,110,2,80,105,3,82,104,111,5,
83,105,103,109,97,3,84,97,117,7,85,112,115,105,108,111,110,3,
80,104,105,3,67,104,105,3,80,115,105,12,73,111,116,97,100,105,
101,114,101,115,105,115,15,85,112,115,105,108,111,110,100,105,101,114,
101,115,105,115,10,97,108,112,104,97,116,111,110,111,115,12,101,112,
115,105,108,111,110,116,111,110,111,115,8,101,116,97,116,111,110,111,
115,9,105,111,116,97,116,111,110,111,115,20,117,112,115,105,108,111,
110,100,105,101,114,101,115,105,115,116,111,110,111,115,5,97,108,112,
104,97,4,98,101,116,97,5,103,97,109,109,97,5,100,101,108,116,
97,7,101,112,115,105,108,111,110,4,122,101,116,97,3,101,116,97,
5,116,104,101,116,97,4,105,111,116,97,5,107,97,112,112,97,6,
108,97,109,98,100,97,2,110,117,2,120,105,7,111,109,105,99,114,
111,110,3,114,104,111,6,115,105,103,109,97,49,5,115,105,103,109,
97,3,116,97,117,7,117,112,115,105,108,111,110,3,112,104,105,3,
99,104,105,3,112,115,105,5,111,109,101,103,97,12,105,111,116,97,
100,105,101,114,101,115,105,115,15,117,112,115,105,108,111,110,100,105,
101,114,101,115,105,115,12,111,109,105,99,114,111,110,116,111,110,111,
115,12,117,112,115,105,108,111,110,116,111,110,111,115,10,111,109,101,
103,97,116,111,110,111,115,7,117,110,105,48,51,67,70,7,117,110,
105,48,51,68,48,6,116,104,101,116,97,49,8,85,112,115,105,108,
111,110,49,16,85,112,115,105,108,111,110,104,111,111,107,116,111,110,
111,115,7,117,110,105,48,51,68,52,4,112,104,105,49,6,111,109,
101,103,97,49,7,117,110,105,48,51,68,55,7,117,110,105,48,51,
68,56,7,117,110,105,48,51,68,57,7,117,110,105,48,51,68,65,
7,117,110,105,48,51,68,66,7,117,110,105,48,51,68,67,7,117,
110,105,48,51,68,68,7,117,110,105,48,51,68,69,7,117,110,105,
48,51,68,70,7,117,110,105,48,51,69,48,7,117,110,105,48,51,
69,49,7,117,110,105,48,51,69,50,7,117,110,105,48,51,69,51,
7,117,110,105,48,51,69,52,7,117,110,105,48,51,69,53,7,117,
110,105,48,51,69,54,7,117,110,105,48,51,69,55,7,117,110,105,
48,51,69,56,7,117,110,105,48,51,69,57,7,117,110,105,48,51,
69,65,7,117,110,105,48,51,69,66,7,117,110,105,48,51,69,67,
7,117,110,105,48,51,69,68,7,117,110,105,48,51,69,69,7,117,
110,105,48,51,69,70,11,107,97,112,112,97,115,99,114,105,112,116,
7,117,110,105,48,51,70,49,7,117,110,105,48,51,70,50,7,117,
110,105,48,51,70,51,7,117,110,105,48,51,70,52,7,117,110,105,
48,51,70,53,7,117,110,105,48,51,70,54,7,117,110,105,48,51,
70,55,7,117,110,105,48,51,70,56,7,117,110,105,48,51,70,57,
7,117,110,105,48,51,70,65,7,117,110,105,48,51,70,66,7,117,
110,105,48,51,70,67,7,117,110,105,48,51,70,68,7,117,110,105,
48,51,70,69,7,117,110,105,48,51,70,70,7,117,110,105,48,52,
48,48,9,97,102,105,105,49,48,48,50,51,9,97,102,105,105,49,
48,48,53,49,9,97,102,105,105,49,48,48,53,50,9,97,102,105,
105,49,48,48,53,51,9,97,102,105,105,49,48,48,53,52,9,97,
102,105,105,49,48,48,53,53,9,97,102,105,105,49,48,48,53,54,
9,97,102,105,105,49,48,48,53,55,9,97,102,105,105,49,48,48,
53,56,9,97,102,105,105,49,48,48,53,57,9,97,102,105,105,49,
48,48,54,48,9,97,102,105,105,49,48,48,54,49,7,117,110,105,
48,52,48,68,9,97,102,105,105,49,48,48,54,50,9,97,102,105,
105,49,48,49,52,53,9,97,102,105,105,49,48,48,49,55,9,97,
102,105,105,49,48,48,49,56,9,97,102,105,105,49,48,48,49,57,
9,97,102,105,105,49,48,48,50,48,9,97,102,105,105,49,48,48,
50,49,9,97,102,105,105,49,48,48,50,50,9,97,102,105,105,49,
48,48,50,52,9,97,102,105,105,49,48,48,50,53,9,97,102,105,
105,49,48,48,50,54,9,97,102,105,105,49,48,48,50,55,9,97,
102,105,105,49,48,48,50,56,9,97,102,105,105,49,48,48,50,57,
9,97,102,105,105,49,48,48,51,48,9,97,102,105,105,49,48,48,
51,49,9,97,102,105,105,49,48,48,51,50,9,97,102,105,105,49,
48,48,51,51,9,97,102,105,105,49,48,48,51,52,9,97,102,105,
105,49,48,48,51,53,9,97,102,105,105,49,48,48,51,54,9,97,
102,105,105,49,48,48,51,55,9,97,102,105,105,49,48,48,51,56,
9,97,102,105,105,49,48,48,51,57,9,97,102,105,105,49,48,48,
52,48,9,97,102,105,105,49,48,48,52,49,9,97,102,105,105,49,
48,48,52,50,9,97,102,105,105,49,48,48,52,51,9,97,102,105,
105,49,48,48,52,52,9,97,102,105,105,49,48,48,52,53,9,97,
102,105,105,49,48,48,52,54,9,97,102,105,105,49,48,48,52,55,
9,97,102,105,105,49,48,48,52,56,9,97,102,105,105,49,48,48,
52,57,9,97,102,105,105,49,48,48,54,53,9,97,102,105,105,49,
48,48,54,54,9,97,102,105,105,49,48,48,54,55,9,97,102,105,
105,49,48,48,54,56,9,97,102,105,105,49,48,48,54,57,9,97,
102,105,105,49,48,48,55,48,9,97,102,105,105,49,48,48,55,50,
9,97,102,105,105,49,48,48,55,51,9,97,102,105,105,49,48,48,
55,52,9,97,102,105,105,49,48,48,55,53,9,97,102,105,105,49,
48,48,55,54,9,97,102,105,105,49,48,48,55,55,9,97,102,105,
105,49,48,48,55,56,9,97,102,105,105,49,48,48,55,57,9,97,
102,105,105,49,48,48,56,48,9,97,102,105,105,49,48,48,56,49,
9,97,102,105,105,49,48,48,56,50,9,97,102,105,105,49,48,48,
56,51,9,97,102,105,105,49,48,48,56,52,9,97,102,105,105,49,
48,48,56,53,9,97,102,105,105,49,48,48,56,54,9,97,102,105,
105,49,48,48,56,55,9,97,102,105,105,49,48,48,56,56,9,97,
102,105,105,49,48,48,56,57,9,97,102,105,105,49,48,48,57,48,
9,97,102,105,105,49,48,48,57,49,9,97,102,105,105,49,48,48,
57,50,9,97,102,105,105,49,48,48,57,51,9,97,102,105,105,49,
48,48,57,52,9,97,102,105,105,49,48,48,57,53,9,97,102,105,
105,49,48,48,57,54,9,97,102,105,105,49,48,48,57,55,7,117,
110,105,48,52,53,48,9,97,102,105,105,49,48,48,55,49,9,97,
102,105,105,49,48,48,57,57,9,97,102,105,105,49,48,49,48,48,
9,97,102,105,105,49,48,49,48,49,9,97,102,105,105,49,48,49,
48,50,9,97,102,105,105,49,48,49,48,51,9,97,102,105,105,49,
48,49,48,52,9,97,102,105,105,49,48,49,48,53,9,97,102,105,
105,49,48,49,48,54,9,97,102,105,105,49,48,49,48,55,9,97,
102,105,105,49,48,49,48,56,9,97,102,105,105,49,48,49,48,57,
7,117,110,105,48,52,53,68,9,97,102,105,105,49,48,49,49,48,
9,97,102,105,105,49,48,49,57,51,7,117,110,105,48,52,56,65,
7,117,110,105,48,52,56,66,7,117,110,105,48,52,56,67,7,117,
110,105,48,52,56,68,7,117,110,105,48,52,56,69,7,117,110,105,
48,52,56,70,17,71,104,101,117,112,116,117,114,110,99,121,114,105,
108,108,105,99,17,103,104,101,117,112,116,117,114,110,99,121,114,105,
108,108,105,99,17,71,104,101,115,116,114,111,107,101,99,121,114,105,
108,108,105,99,17,103,104,101,115,116,114,111,107,101,99,121,114,105,
108,108,105,99,21,71,104,101,109,105,100,100,108,101,104,111,111,107,
99,121,114,105,108,108,105,99,21,103,104,101,109,105,100,100,108,101,
104,111,111,107,99,121,114,105,108,108,105,99,20,90,104,101,100,101,
115,99,101,110,100,101,114,99,121,114,105,108,108,105,99,20,122,104,
101,100,101,115,99,101,110,100,101,114,99,121,114,105,108,108,105,99,
19,90,101,100,101,115,99,101,110,100,101,114,99,121,114,105,108,108,
105,99,19,122,101,100,101,115,99,101,110,100,101,114,99,121,114,105,
108,108,105,99,19,75,97,100,101,115,99,101,110,100,101,114,99,121,
114,105,108,108,105,99,19,107,97,100,101,115,99,101,110,100,101,114,
99,121,114,105,108,108,105,99,24,75,97,118,101,114,116,105,99,97,
108,115,116,114,111,107,101,99,121,114,105,108,108,105,99,24,107,97,
118,101,114,116,105,99,97,108,115,116,114,111,107,101,99,121,114,105,
108,108,105,99,16,75,97,115,116,114,111,107,101,99,121,114,105,108,
108,105,99,16,107,97,115,116,114,111,107,101,99,121,114,105,108,108,
105,99,17,75,97,98,97,115,104,107,105,114,99,121,114,105,108,108,
105,99,17,107,97,98,97,115,104,107,105,114,99,121,114,105,108,108,
105,99,19,69,110,100,101,115,99,101,110,100,101,114,99,121,114,105,
108,108,105,99,19,101,110,100,101,115,99,101,110,100,101,114,99,121,
114,105,108,108,105,99,13,69,110,103,104,101,99,121,114,105,108,108,
105,99,13,101,110,103,104,101,99,121,114,105,108,108,105,99,20,80,
101,109,105,100,100,108,101,104,111,111,107,99,121,114,105,108,108,105,
99,20,112,101,109,105,100,100,108,101,104,111,111,107,99,121,114,105,
108,108,105,99,19,72,97,97,98,107,104,97,115,105,97,110,99,121,
114,105,108,108,105,99,19,104,97,97,98,107,104,97,115,105,97,110,
99,121,114,105,108,108,105,99,19,69,115,100,101,115,99,101,110,100,
101,114,99,121,114,105,108,108,105,99,19,101,115,100,101,115,99,101,
110,100,101,114,99,121,114,105,108,108,105,99,19,84,101,100,101,115,
99,101,110,100,101,114,99,121,114,105,108,108,105,99,19,116,101,100,
101,115,99,101,110,100,101,114,99,121,114,105,108,108,105,99,17,85,
115,116,114,97,105,103,104,116,99,121,114,105,108,108,105,99,17,117,
115,116,114,97,105,103,104,116,99,121,114,105,108,108,105,99,23,85,
115,116,114,97,105,103,104,116,115,116,114,111,107,101,99,121,114,105,
108,108,105,99,23,117,115,116,114,97,105,103,104,116,115,116,114,111,
107,101,99,121,114,105,108,108,105,99,19,72,97,100,101,115,99,101,
110,100,101,114,99,121,114,105,108,108,105,99,19,104,97,100,101,115,
99,101,110,100,101,114,99,121,114,105,108,108,105,99,13,84,101,116,
115,101,99,121,114,105,108,108,105,99,13,116,101,116,115,101,99,121,
114,105,108,108,105,99,20,67,104,101,100,101,115,99,101,110,100,101,
114,99,121,114,105,108,108,105,99,20,99,104,101,100,101,115,99,101,
110,100,101,114,99,121,114,105,108,108,105,99,25,67,104,101,118,101,
114,116,105,99,97,108,115,116,114,111,107,101,99,121,114,105,108,108,
105,99,25,99,104,101,118,101,114,116,105,99,97,108,115,116,114,111,
107,101,99,121,114,105,108,108,105,99,12,83,104,104,97,99,121,114,
105,108,108,105,99,12,115,104,104,97,99,121,114,105,108,108,105,99,
20,67,104,101,97,98,107,104,97,115,105,97,110,99,121,114,105,108,
108,105,99,20,99,104,101,97,98,107,104,97,115,105,97,110,99,121,
114,105,108,108,105,99,29,67,104,101,100,101,115,99,101,110,100,101,
114,97,98,107,104,97,115,105,97,110,99,121,114,105,108,108,105,99,
29,99,104,101,100,101,115,99,101,110,100,101,114,97,98,107,104,97,
115,105,97,110,99,121,114,105,108,108,105,99,16,112,97,108,111,99,
104,107,97,99,121,114,105,108,108,105,99,16,90,104,101,98,114,101,
118,101,99,121,114,105,108,108,105,99,16,122,104,101,98,114,101,118,
101,99,121,114,105,108,108,105,99,14,75,97,104,111,111,107,99,121,
114,105,108,108,105,99,14,107,97,104,111,111,107,99,121,114,105,108,
108,105,99,7,117,110,105,48,52,67,53,7,117,110,105,48,52,67,
54,14,69,110,104,111,111,107,99,121,114,105,108,108,105,99,14,101,
110,104,111,111,107,99,121,114,105,108,108,105,99,7,117,110,105,48,
52,67,57,7,117,110,105,48,52,67,65,21,67,104,101,107,104,97,
107,97,115,115,105,97,110,99,121,114,105,108,108,105,99,21,99,104,
101,107,104,97,107,97,115,115,105,97,110,99,121,114,105,108,108,105,
99,7,117,110,105,48,52,67,68,7,117,110,105,48,52,67,69,7,
117,110,105,48,52,67,70,14,65,98,114,101,118,101,99,121,114,105,
108,108,105,99,14,97,98,114,101,118,101,99,121,114,105,108,108,105,
99,17,65,100,105,101,114,101,115,105,115,99,121,114,105,108,108,105,
99,17,97,100,105,101,114,101,115,105,115,99,121,114,105,108,108,105,
99,11,65,105,101,99,121,114,105,108,108,105,99,11,97,105,101,99,
121,114,105,108,108,105,99,15,73,101,98,114,101,118,101,99,121,114,
105,108,108,105,99,15,105,101,98,114,101,118,101,99,121,114,105,108,
108,105,99,13,83,99,104,119,97,99,121,114,105,108,108,105,99,13,
115,99,104,119,97,99,121,114,105,108,108,105,99,21,83,99,104,119,
97,100,105,101,114,101,115,105,115,99,121,114,105,108,108,105,99,21,
115,99,104,119,97,100,105,101,114,101,115,105,115,99,121,114,105,108,
108,105,99,19,90,104,101,100,105,101,114,101,115,105,115,99,121,114,
105,108,108,105,99,19,122,104,101,100,105,101,114,101,115,105,115,99,
121,114,105,108,108,105,99,18,90,101,100,105,101,114,101,115,105,115,
99,121,114,105,108,108,105,99,18,122,101,100,105,101,114,101,115,105,
115,99,121,114,105,108,108,105,99,20,68,122,101,97,98,107,104,97,
115,105,97,110,99,121,114,105,108,108,105,99,20,100,122,101,97,98,
107,104,97,115,105,97,110,99,121,114,105,108,108,105,99,15,73,109,
97,99,114,111,110,99,121,114,105,108,108,105,99,15,105,109,97,99,
114,111,110,99,121,114,105,108,108,105,99,17,73,100,105,101,114,101,
115,105,115,99,121,114,105,108,108,105,99,17,105,100,105,101,114,101,
115,105,115,99,121,114,105,108,108,105,99,17,79,100,105,101,114,101,
115,105,115,99,121,114,105,108,108,105,99,17,111,100,105,101,114,101,
115,105,115,99,121,114,105,108,108,105,99,15,79,98,97,114,114,101,
100,99,121,114,105,108,108,105,99,15,111,98,97,114,114,101,100,99,
121,114,105,108,108,105,99,23,79,98,97,114,114,101,100,100,105,101,
114,101,115,105,115,99,121,114,105,108,108,105,99,23,111,98,97,114,
114,101,100,100,105,101,114,101,115,105,115,99,121,114,105,108,108,105,
99,7,117,110,105,48,52,69,67,7,117,110,105,48,52,69,68,15,
85,109,97,99,114,111,110,99,121,114,105,108,108,105,99,15,117,109,
97,99,114,111,110,99,121,114,105,108,108,105,99,17,85,100,105,101,
114,101,115,105,115,99,121,114,105,108,108,105,99,17,117,100,105,101,
114,101,115,105,115,99,121,114,105,108,108,105,99,21,85,104,117,110,
103,97,114,117,109,108,97,117,116,99,121,114,105,108,108,105,99,21,
117,104,117,110,103,97,114,117,109,108,97,117,116,99,121,114,105,108,
108,105,99,19,67,104,101,100,105,101,114,101,115,105,115,99,121,114,
105,108,108,105,99,19,99,104,101,100,105,101,114,101,115,105,115,99,
121,114,105,108,108,105,99,7,117,110,105,48,52,70,54,7,117,110,
105,48,52,70,55,20,89,101,114,117,100,105,101,114,101,115,105,115,
99,121,114,105,108,108,105,99,20,121,101,114,117,100,105,101,114,101,
115,105,115,99,121,114,105,108,108,105,99,10,66,100,111,116,97,99,
99,101,110,116,10,98,100,111,116,97,99,99,101,110,116,10,68,100,
111,116,97,99,99,101,110,116,10,100,100,111,116,97,99,99,101,110,
116,7,117,110,105,49,69,48,67,7,117,110,105,49,69,48,68,7,
117,110,105,49,69,48,69,7,117,110,105,49,69,48,70,10,70,100,
111,116,97,99,99,101,110,116,10,102,100,111,116,97,99,99,101,110,
116,7,117,110,105,49,69,50,52,7,117,110,105,49,69,50,53,7,
117,110,105,49,69,50,65,7,117,110,105,49,69,50,66,7,117,110,
105,49,69,51,52,7,117,110,105,49,69,51,53,7,117,110,105,49,
69,51,54,7,117,110,105,49,69,51,55,7,117,110,105,49,69,51,
56,7,117,110,105,49,69,51,57,7,117,110,105,49,69,51,65,7,
117,110,105,49,69,51,66,10,77,100,111,116,97,99,99,101,110,116,
10,109,100,111,116,97,99,99,101,110,116,7,117,110,105,49,69,52,
50,7,117,110,105,49,69,52,51,7,117,110,105,49,69,52,52,7,
117,110,105,49,69,52,53,7,117,110,105,49,69,52,54,7,117,110,
105,49,69,52,55,7,117,110,105,49,69,52,56,7,117,110,105,49,
69,52,57,10,80,100,111,116,97,99,99,101,110,116,10,112,100,111,
116,97,99,99,101,110,116,7,117,110,105,49,69,53,65,7,117,110,
105,49,69,53,66,7,117,110,105,49,69,53,67,7,117,110,105,49,
69,53,68,7,117,110,105,49,69,53,69,7,117,110,105,49,69,53,
70,10,83,100,111,116,97,99,99,101,110,116,10,115,100,111,116,97,
99,99,101,110,116,7,117,110,105,49,69,54,50,7,117,110,105,49,
69,54,51,10,84,100,111,116,97,99,99,101,110,116,10,116,100,111,
116,97,99,99,101,110,116,7,117,110,105,49,69,54,67,7,117,110,
105,49,69,54,68,7,117,110,105,49,69,54,69,7,117,110,105,49,
69,54,70,6,87,103,114,97,118,101,6,119,103,114,97,118,101,6,
87,97,99,117,116,101,6,119,97,99,117,116,101,9,87,100,105,101,
114,101,115,105,115,9,119,100,105,101,114,101,115,105,115,7,117,110,
105,49,69,56,69,7,117,110,105,49,69,56,70,7,117,110,105,49,
69,57,54,7,117,110,105,49,69,57,69,6,89,103,114,97,118,101,
6,121,103,114,97,118,101,7,117,110,105,49,69,70,65,7,117,110,
105,49,69,70,66,10,97,108,112,104,97,108,101,110,105,115,10,97,
108,112,104,97,97,115,112,101,114,15,97,108,112,104,97,108,101,110,
105,115,103,114,97,118,101,15,97,108,112,104,97,97,115,112,101,114,
103,114,97,118,101,15,97,108,112,104,97,108,101,110,105,115,97,99,
117,116,101,15,97,108,112,104,97,97,115,112,101,114,97,99,117,116,
101,15,97,108,112,104,97,108,101,110,105,115,116,105,108,100,101,15,
97,108,112,104,97,97,115,112,101,114,116,105,108,100,101,10,65,108,
112,104,97,108,101,110,105,115,10,65,108,112,104,97,97,115,112,101,
114,15,65,108,112,104,97,108,101,110,105,115,103,114,97,118,101,15,
65,108,112,104,97,97,115,112,101,114,103,114,97,118,101,15,65,108,
112,104,97,108,101,110,105,115,97,99,117,116,101,15,65,108,112,104,
97,97,115,112,101,114,97,99,117,116,101,15,65,108,112,104,97,108,
101,110,105,115,116,105,108,100,101,15,65,108,112,104,97,97,115,112,
101,114,116,105,108,100,101,12,101,112,115,105,108,111,110,108,101,110,
105,115,12,101,112,115,105,108,111,110,97,115,112,101,114,17,101,112,
115,105,108,111,110,108,101,110,105,115,103,114,97,118,101,17,101,112,
115,105,108,111,110,97,115,112,101,114,103,114,97,118,101,17,101,112,
115,105,108,111,110,108,101,110,105,115,97,99,117,116,101,17,101,112,
115,105,108,111,110,97,115,112,101,114,97,99,117,116,101,12,69,112,
115,105,108,111,110,108,101,110,105,115,12,69,112,115,105,108,111,110,
97,115,112,101,114,17,69,112,115,105,108,111,110,108,101,110,105,115,
103,114,97,118,101,17,69,112,115,105,108,111,110,97,115,112,101,114,
103,114,97,118,101,17,69,112,115,105,108,111,110,108,101,110,105,115,
97,99,117,116,101,17,69,112,115,105,108,111,110,97,115,112,101,114,
97,99,117,116,101,8,101,116,97,108,101,110,105,115,8,101,116,97,
97,115,112,101,114,13,101,116,97,108,101,110,105,115,103,114,97,118,
101,13,101,116,97,97,115,112,101,114,103,114,97,118,101,13,101,116,
97,108,101,110,105,115,97,99,117,116,101,13,101,116,97,97,115,112,
101,114,97,99,117,116,101,13,101,116,97,108,101,110,105,115,116,105,
108,100,101,13,101,116,97,97,115,112,101,114,116,105,108,100,101,8,
69,116,97,108,101,110,105,115,8,69,116,97,97,115,112,101,114,13,
69,116,97,108,101,110,105,115,103,114,97,118,101,13,69,116,97,97,
115,112,101,114,103,114,97,118,101,13,69,116,97,108,101,110,105,115,
97,99,117,116,101,13,69,116,97,97,115,112,101,114,97,99,117,116,
101,13,69,116,97,108,101,110,105,115,116,105,108,100,101,13,69,116,
97,97,115,112,101,114,116,105,108,100,101,9,105,111,116,97,108,101,
110,105,115,9,105,111,116,97,97,115,112,101,114,14,105,111,116,97,
108,101,110,105,115,103,114,97,118,101,14,105,111,116,97,97,115,112,
101,114,103,114,97,118,101,14,105,111,116,97,108,101,110,105,115,97,
99,117,116,101,14,105,111,116,97,97,115,112,101,114,97,99,117,116,
101,14,105,111,116,97,108,101,110,105,115,116,105,108,100,101,14,105,
111,116,97,97,115,112,101,114,116,105,108,100,101,9,73,111,116,97,
108,101,110,105,115,9,73,111,116,97,97,115,112,101,114,14,73,111,
116,97,108,101,110,105,115,103,114,97,118,101,14,73,111,116,97,97,
115,112,101,114,103,114,97,118,101,14,73,111,116,97,108,101,110,105,
115,97,99,117,116,101,14,73,111,116,97,97,115,112,101,114,97,99,
117,116,101,14,73,111,116,97,108,101,110,105,115,116,105,108,100,101,
14,73,111,116,97,97,115,112,101,114,116,105,108,100,101,12,111,109,
105,99,114,111,110,108,101,110,105,115,12,111,109,105,99,114,111,110,
97,115,112,101,114,17,111,109,105,99,114,111,110,108,101,110,105,115,
103,114,97,118,101,17,111,109,105,99,114,111,110,97,115,112,101,114,
103,114,97,118,101,17,111,109,105,99,114,111,110,108,101,110,105,115,
97,99,117,116,101,17,111,109,105,99,114,111,110,97,115,112,101,114,
97,99,117,116,101,12,79,109,105,99,114,111,110,108,101,110,105,115,
12,79,109,105,99,114,111,110,97,115,112,101,114,17,79,109,105,99,
114,111,110,108,101,110,105,115,103,114,97,118,101,17,79,109,105,99,
114,111,110,97,115,112,101,114,103,114,97,118,101,17,79,109,105,99,
114,111,110,108,101,110,105,115,97,99,117,116,101,17,79,109,105,99,
114,111,110,97,115,112,101,114,97,99,117,116,101,12,117,112,115,105,
108,111,110,108,101,110,105,115,12,117,112,115,105,108,111,110,97,115,
112,101,114,17,117,112,115,105,108,111,110,108,101,110,105,115,103,114,
97,118,101,17,117,112,115,105,108,111,110,97,115,112,101,114,103,114,
97,118,101,17,117,112,115,105,108,111,110,108,101,110,105,115,97,99,
117,116,101,17,117,112,115,105,108,111,110,97,115,112,101,114,97,99,
117,116,101,17,117,112,115,105,108,111,110,108,101,110,105,115,116,105,
108,100,101,17,117,112,115,105,108,111,110,97,115,112,101,114,116,105,
108,100,101,12,85,112,115,105,108,111,110,97,115,112,101,114,17,85,
112,115,105,108,111,110,97,115,112,101,114,103,114,97,118,101,17,85,
112,115,105,108,111,110,97,115,112,101,114,97,99,117,116,101,17,85,
112,115,105,108,111,110,97,115,112,101,114,116,105,108,100,101,10,111,
109,101,103,97,108,101,110,105,115,10,111,109,101,103,97,97,115,112,
101,114,15,111,109,101,103,97,108,101,110,105,115,103,114,97,118,101,
15,111,109,101,103,97,97,115,112,101,114,103,114,97,118,101,15,111,
109,101,103,97,108,101,110,105,115,97,99,117,116,101,15,111,109,101,
103,97,97,115,112,101,114,97,99,117,116,101,15,111,109,101,103,97,
108,101,110,105,115,116,105,108,100,101,15,111,109,101,103,97,97,115,
112,101,114,116,105,108,100,101,10,79,109,101,103,97,108,101,110,105,
115,10,79,109,101,103,97,97,115,112,101,114,15,79,109,101,103,97,
108,101,110,105,115,103,114,97,118,101,15,79,109,101,103,97,97,115,
112,101,114,103,114,97,118,101,15,79,109,101,103,97,108,101,110,105,
115,97,99,117,116,101,15,79,109,101,103,97,97,115,112,101,114,97,
99,117,116,101,15,79,109,101,103,97,108,101,110,105,115,116,105,108,
100,101,15,79,109,101,103,97,97,115,112,101,114,116,105,108,100,101,
10,97,108,112,104,97,103,114,97,118,101,10,97,108,112,104,97,97,
99,117,116,101,12,101,112,115,105,108,111,110,103,114,97,118,101,12,
101,112,115,105,108,111,110,97,99,117,116,101,8,101,116,97,103,114,
97,118,101,8,101,116,97,97,99,117,116,101,9,105,111,116,97,103,
114,97,118,101,9,105,111,116,97,97,99,117,116,101,12,111,109,105,
99,114,111,110,103,114,97,118,101,12,111,109,105,99,114,111,110,97,
99,117,116,101,12,117,112,115,105,108,111,110,103,114,97,118,101,12,
117,112,115,105,108,111,110,97,99,117,116,101,10,111,109,101,103,97,
103,114,97,118,101,10,111,109,101,103,97,97,99,117,116,101,17,97,
108,112,104,97,105,111,116,97,115,117,98,108,101,110,105,115,17,97,
108,112,104,97,105,111,116,97,115,117,98,97,115,112,101,114,22,97,
108,112,104,97,105,111,116,97,115,117,98,108,101,110,105,115,103,114,
97,118,101,22,97,108,112,104,97,105,111,116,97,115,117,98,97,115,
112,101,114,103,114,97,118,101,22,97,108,112,104,97,105,111,116,97,
115,117,98,108,101,110,105,115,97,99,117,116,101,22,97,108,112,104,
97,105,111,116,97,115,117,98,97,115,112,101,114,97,99,117,116,101,
22,97,108,112,104,97,105,111,116,97,115,117,98,108,101,110,105,115,
116,105,108,100,101,22,97,108,112,104,97,105,111,116,97,115,117,98,
97,115,112,101,114,116,105,108,100,101,17,65,108,112,104,97,105,111,
116,97,115,117,98,108,101,110,105,115,17,65,108,112,104,97,105,111,
116,97,115,117,98,97,115,112,101,114,22,65,108,112,104,97,105,111,
116,97,115,117,98,108,101,110,105,115,103,114,97,118,101,22,65,108,
112,104,97,105,111,116,97,115,117,98,97,115,112,101,114,103,114,97,
118,101,22,65,108,112,104,97,105,111,116,97,115,117,98,108,101,110,
105,115,97,99,117,116,101,22,65,108,112,104,97,105,111,116,97,115,
117,98,97,115,112,101,114,97,99,117,116,101,22,65,108,112,104,97,
105,111,116,97,115,117,98,108,101,110,105,115,116,105,108,100,101,22,
65,108,112,104,97,105,111,116,97,115,117,98,97,115,112,101,114,116,
105,108,100,101,15,101,116,97,105,111,116,97,115,117,98,108,101,110,
105,115,15,101,116,97,105,111,116,97,115,117,98,97,115,112,101,114,
20,101,116,97,105,111,116,97,115,117,98,108,101,110,105,115,103,114,
97,118,101,20,101,116,97,105,111,116,97,115,117,98,97,115,112,101,
114,103,114,97,118,101,20,101,116,97,105,111,116,97,115,117,98,108,
101,110,105,115,97,99,117,116,101,20,101,116,97,105,111,116,97,115,
117,98,97,115,112,101,114,97,99,117,116,101,20,101,116,97,105,111,
116,97,115,117,98,108,101,110,105,115,116,105,108,100,101,20,101,116,
97,105,111,116,97,115,117,98,97,115,112,101,114,116,105,108,100,101,
15,69,116,97,105,111,116,97,115,117,98,108,101,110,105,115,15,69,
116,97,105,111,116,97,115,117,98,97,115,112,101,114,20,69,116,97,
105,111,116,97,115,117,98,108,101,110,105,115,103,114,97,118,101,20,
69,116,97,105,111,116,97,115,117,98,97,115,112,101,114,103,114,97,
118,101,20,69,116,97,105,111,116,97,115,117,98,108,101,110,105,115,
97,99,117,116,101,20,69,116,97,105,111,116,97,115,117,98,97,115,
112,101,114,97,99,117,116,101,20,69,116,97,105,111,116,97,115,117,
98,108,101,110,105,115,116,105,108,100,101,20,69,116,97,105,111,116,
97,115,117,98,97,115,112,101,114,116,105,108,100,101,17,111,109,101,
103,97,105,111,116,97,115,117,98,108,101,110,105,115,17,111,109,101,
103,97,105,111,116,97,115,117,98,97,115,112,101,114,22,111,109,101,
103,97,105,111,116,97,115,117,98,108,101,110,105,115,103,114,97,118,
101,22,111,109,101,103,97,105,111,116,97,115,117,98,97,115,112,101,
114,103,114,97,118,101,22,111,109,101,103,97,105,111,116,97,115,117,
98,108,101,110,105,115,97,99,117,116,101,22,111,109,101,103,97,105,
111,116,97,115,117,98,97,115,112,101,114,97,99,117,116,101,22,111,
109,101,103,97,105,111,116,97,115,117,98,108,101,110,105,115,116,105,
108,100,101,22,111,109,101,103,97,105,111,116,97,115,117,98,97,115,
112,101,114,116,105,108,100,101,17,79,109,101,103,97,105,111,116,97,
115,117,98,108,101,110,105,115,17,79,109,101,103,97,105,111,116,97,
115,117,98,97,115,112,101,114,22,79,109,101,103,97,105,111,116,97,
115,117,98,108,101,110,105,115,103,114,97,118,101,22,79,109,101,103,
97,105,111,116,97,115,117,98,97,115,112,101,114,103,114,97,118,101,
22,79,109,101,103,97,105,111,116,97,115,117,98,108,101,110,105,115,
97,99,117,116,101,22,79,109,101,103,97,105,111,116,97,115,117,98,
97,115,112,101,114,97,99,117,116,101,22,79,109,101,103,97,105,111,
116,97,115,117,98,108,101,110,105,115,116,105,108,100,101,22,79,109,
101,103,97,105,111,116,97,115,117,98,97,115,112,101,114,116,105,108,
100,101,10,97,108,112,104,97,98,114,101,118,101,11,97,108,112,104,
97,109,97,99,114,111,110,17,97,108,112,104,97,105,111,116,97,115,
117,98,103,114,97,118,101,12,97,108,112,104,97,105,111,116,97,115,
117,98,17,97,108,112,104,97,105,111,116,97,115,117,98,97,99,117,
116,101,10,97,108,112,104,97,116,105,108,100,101,17,97,108,112,104,
97,105,111,116,97,115,117,98,116,105,108,100,101,10,65,108,112,104,
97,98,114,101,118,101,11,65,108,112,104,97,109,97,99,114,111,110,
10,65,108,112,104,97,103,114,97,118,101,10,65,108,112,104,97,97,
99,117,116,101,12,65,108,112,104,97,105,111,116,97,115,117,98,5,
108,101,110,105,115,13,105,111,116,97,115,117,98,115,99,114,105,112,
116,5,112,115,105,108,105,11,112,101,114,105,115,112,111,109,101,110,
105,21,100,105,97,108,121,116,105,107,97,95,112,101,114,105,115,112,
111,109,101,110,105,15,101,116,97,105,111,116,97,115,117,98,103,114,
97,118,101,10,101,116,97,105,111,116,97,115,117,98,15,101,116,97,
105,111,116,97,115,117,98,97,99,117,116,101,8,101,116,97,116,105,
108,100,101,15,101,116,97,105,111,116,97,115,117,98,116,105,108,100,
101,12,69,112,115,105,108,111,110,103,114,97,118,101,12,69,112,115,
105,108,111,110,97,99,117,116,101,8,69,116,97,103,114,97,118,101,
8,69,116,97,97,99,117,116,101,10,69,116,97,105,111,116,97,115,
117,98,11,112,115,105,108,105,95,118,97,114,105,97,10,112,115,105,
108,105,95,111,120,105,97,17,112,115,105,108,105,95,112,101,114,105,
115,112,111,109,101,110,105,9,105,111,116,97,98,114,101,118,101,10,
105,111,116,97,109,97,99,114,111,110,17,105,111,116,97,100,105,101,
114,101,115,105,115,103,114,97,118,101,17,105,111,116,97,100,105,101,
114,101,115,105,115,97,99,117,116,101,9,105,111,116,97,116,105,108,
100,101,17,105,111,116,97,100,105,101,114,101,115,105,115,116,105,108,
100,101,9,73,111,116,97,98,114,101,118,101,10,73,111,116,97,109,
97,99,114,111,110,9,73,111,116,97,103,114,97,118,101,9,73,111,
116,97,97,99,117,116,101,11,100,97,115,105,97,95,118,97,114,105,
97,10,100,97,115,105,97,95,111,120,105,97,17,100,97,115,105,97,
95,112,101,114,105,115,112,111,109,101,110,105,12,117,112,115,105,108,
111,110,98,114,101,118,101,13,117,112,115,105,108,111,110,109,97,99,
114,111,110,20,117,112,115,105,108,111,110,100,105,101,114,101,115,105,
115,103,114,97,118,101,20,117,112,115,105,108,111,110,100,105,101,114,
101,115,105,115,97,99,117,116,101,8,114,104,111,108,101,110,105,115,
8,114,104,111,97,115,112,101,114,12,117,112,115,105,108,111,110,116,
105,108,100,101,20,117,112,115,105,108,111,110,100,105,101,114,101,115,
105,115,116,105,108,100,101,12,85,112,115,105,108,111,110,98,114,101,
118,101,13,85,112,115,105,108,111,110,109,97,99,114,111,110,12,85,
112,115,105,108,111,110,103,114,97,118,101,12,85,112,115,105,108,111,
110,97,99,117,116,101,8,82,104,111,97,115,112,101,114,15,100,105,
97,108,121,116,105,107,97,95,118,97,114,105,97,14,100,105,97,108,
121,116,105,107,97,95,111,120,105,97,5,118,97,114,105,97,17,111,
109,101,103,97,105,111,116,97,115,117,98,103,114,97,118,101,12,111,
109,101,103,97,105,111,116,97,115,117,98,17,111,109,101,103,97,105,
111,116,97,115,117,98,97,99,117,116,101,10,111,109,101,103,97,116,
105,108,100,101,17,111,109,101,103,97,105,111,116,97,115,117,98,116,
105,108,100,101,12,79,109,105,99,114,111,110,103,114,97,118,101,12,
79,109,105,99,114,111,110,97,99,117,116,101,10,79,109,101,103,97,
103,114,97,118,101,10,79,109,101,103,97,97,99,117,116,101,12,79,
109,101,103,97,105,111,116,97,115,117,98,4,111,120,105,97,5,97,
115,112,101,114,7,101,109,115,112,97,99,101,15,116,104,114,101,101,
112,101,114,101,109,115,112,97,99,101,14,102,111,117,114,112,101,114,
101,109,115,112,97,99,101,9,116,104,105,110,115,112,97,99,101,9,
104,97,105,114,115,112,97,99,101,9,104,121,112,104,101,110,116,119,
111,13,104,121,112,104,101,110,110,111,98,114,101,97,107,10,102,105,
103,117,114,101,100,97,115,104,13,104,111,114,105,122,111,110,116,97,
108,98,97,114,7,117,110,105,50,48,49,54,13,113,117,111,116,101,
114,101,118,101,114,115,101,100,7,117,110,105,50,48,49,70,7,117,
110,105,50,48,50,51,14,111,110,101,100,111,116,101,110,108,101,97,
100,101,114,14,116,119,111,100,111,116,101,110,108,101,97,100,101,114,
7,117,110,105,50,48,50,55,7,117,110,105,50,48,51,49,6,109,
105,110,117,116,101,6,115,101,99,111,110,100,9,101,120,99,108,97,
109,100,98,108,7,117,110,105,50,48,51,68,7,117,110,105,50,48,
51,70,7,117,110,105,50,48,52,50,7,117,110,105,50,48,52,51,
7,117,110,105,50,48,52,55,7,117,110,105,50,48,52,56,7,117,
110,105,50,48,52,57,7,117,110,105,50,48,52,66,7,117,110,105,
50,48,52,67,7,117,110,105,50,48,52,68,7,117,110,105,50,48,
52,69,7,117,110,105,50,48,52,70,7,117,110,105,50,48,53,50,
7,117,110,105,50,48,53,51,7,117,110,105,50,48,53,54,7,117,
110,105,50,48,53,56,7,117,110,105,50,48,53,57,7,117,110,105,
50,48,53,65,7,117,110,105,50,48,53,66,7,117,110,105,50,48,
53,68,7,117,110,105,50,48,53,69,7,117,110,105,50,48,55,48,
7,117,110,105,50,48,55,49,7,117,110,105,50,48,55,50,7,117,
110,105,50,48,55,51,12,102,111,117,114,115,117,112,101,114,105,111,
114,7,117,110,105,50,48,55,53,7,117,110,105,50,48,55,54,7,
117,110,105,50,48,55,55,7,117,110,105,50,48,55,56,7,117,110,
105,50,48,55,57,7,117,110,105,50,48,55,65,7,117,110,105,50,
48,55,66,7,117,110,105,50,48,55,67,7,117,110,105,50,48,55,
68,7,117,110,105,50,48,55,69,7,117,110,105,50,48,55,70,7,
117,110,105,50,48,56,48,7,117,110,105,50,48,56,49,7,117,110,
105,50,48,56,50,7,117,110,105,50,48,56,51,7,117,110,105,50,
48,56,52,7,117,110,105,50,48,56,53,7,117,110,105,50,48,56,
54,7,117,110,105,50,48,56,55,7,117,110,105,50,48,56,56,7,
117,110,105,50,48,56,57,7,117,110,105,50,48,56,65,7,117,110,
105,50,48,56,66,7,117,110,105,50,48,56,67,7,117,110,105,50,
48,56,68,7,117,110,105,50,48,56,69,7,117,110,105,50,48,57,
48,7,117,110,105,50,48,57,49,7,117,110,105,50,48,57,50,7,
117,110,105,50,48,57,51,7,117,110,105,50,48,57,52,7,117,110,
105,50,48,57,56,7,117,110,105,50,48,57,57,7,117,110,105,50,
48,65,48,13,99,111,108,111,110,109,111,110,101,116,97,114,121,7,
117,110,105,50,48,65,50,4,108,105,114,97,7,117,110,105,50,48,
65,53,7,117,110,105,50,48,65,54,6,112,101,115,101,116,97,7,
117,110,105,50,48,65,56,7,117,110,105,50,48,65,57,9,97,102,
105,105,53,55,54,51,54,4,100,111,110,103,4,69,117,114,111,7,
117,110,105,50,48,65,68,7,117,110,105,50,48,65,69,7,117,110,
105,50,48,65,70,7,117,110,105,50,48,66,48,7,117,110,105,50,
48,66,49,7,117,110,105,50,48,66,50,7,117,110,105,50,48,66,
51,7,117,110,105,50,48,66,52,7,117,110,105,50,48,66,53,7,
117,110,105,50,48,66,54,7,117,110,105,50,48,66,55,7,117,110,
105,50,48,66,56,7,117,110,105,50,48,66,57,10,99,101,110,116,
105,103,114,97,100,101,8,73,102,114,97,107,116,117,114,9,97,102,
105,105,54,49,51,53,50,11,119,101,105,101,114,115,116,114,97,115,
115,8,82,102,114,97,107,116,117,114,7,117,110,105,50,49,50,54,
9,101,115,116,105,109,97,116,101,100,5,97,108,101,112,104,8,111,
110,101,116,104,105,114,100,9,116,119,111,116,104,105,114,100,115,7,
117,110,105,50,49,53,53,7,117,110,105,50,49,53,54,7,117,110,
105,50,49,53,55,7,117,110,105,50,49,53,56,7,117,110,105,50,
49,53,57,7,117,110,105,50,49,53,65,9,111,110,101,101,105,103,
104,116,104,12,116,104,114,101,101,101,105,103,104,116,104,115,11,102,
105,118,101,101,105,103,104,116,104,115,12,115,101,118,101,110,101,105,
103,104,116,104,115,7,117,110,105,50,49,53,70,7,117,110,105,50,
49,54,48,7,117,110,105,50,49,54,49,7,117,110,105,50,49,54,
50,7,117,110,105,50,49,54,51,7,117,110,105,50,49,54,52,7,
117,110,105,50,49,54,53,7,117,110,105,50,49,54,54,7,117,110,
105,50,49,54,55,7,117,110,105,50,49,54,56,7,117,110,105,50,
49,54,57,7,117,110,105,50,49,54,65,7,117,110,105,50,49,54,
66,7,117,110,105,50,49,54,67,7,117,110,105,50,49,54,68,7,
117,110,105,50,49,54,69,7,117,110,105,50,49,54,70,7,117,110,
105,50,49,55,48,7,117,110,105,50,49,55,49,7,117,110,105,50,
49,55,50,7,117,110,105,50,49,55,51,7,117,110,105,50,49,55,
52,7,117,110,105,50,49,55,53,7,117,110,105,50,49,55,54,7,
117,110,105,50,49,55,55,7,117,110,105,50,49,55,56,7,117,110,
105,50,49,55,57,7,117,110,105,50,49,55,65,7,117,110,105,50,
49,55,66,7,117,110,105,50,49,55,67,7,117,110,105,50,49,55,
68,7,117,110,105,50,49,55,69,7,117,110,105,50,49,55,70,7,
117,110,105,50,49,56,48,7,117,110,105,50,49,56,49,7,117,110,
105,50,49,56,50,7,117,110,105,50,49,56,51,7,117,110,105,50,
49,56,52,7,117,110,105,50,49,56,53,7,117,110,105,50,49,56,
54,7,117,110,105,50,49,56,55,7,117,110,105,50,49,56,56,7,
117,110,105,50,49,56,57,9,97,114,114,111,119,108,101,102,116,7,
97,114,114,111,119,117,112,10,97,114,114,111,119,114,105,103,104,116,
9,97,114,114,111,119,100,111,119,110,9,97,114,114,111,119,98,111,
116,104,9,97,114,114,111,119,117,112,100,110,7,117,110,105,50,49,
57,54,7,117,110,105,50,49,57,55,7,117,110,105,50,49,57,56,
7,117,110,105,50,49,57,57,7,117,110,105,50,49,57,65,7,117,
110,105,50,49,57,66,7,117,110,105,50,49,57,67,7,117,110,105,
50,49,57,68,7,117,110,105,50,49,57,69,7,117,110,105,50,49,
57,70,7,117,110,105,50,49,65,48,7,117,110,105,50,49,65,49,
7,117,110,105,50,49,65,50,7,117,110,105,50,49,65,51,7,117,
110,105,50,49,65,52,7,117,110,105,50,49,65,53,7,117,110,105,
50,49,65,54,7,117,110,105,50,49,65,55,12,97,114,114,111,119,
117,112,100,110,98,115,101,7,117,110,105,50,49,66,48,7,117,110,
105,50,49,66,49,7,117,110,105,50,49,66,50,7,117,110,105,50,
49,66,51,7,117,110,105,50,49,66,52,14,99,97,114,114,105,97,
103,101,114,101,116,117,114,110,7,117,110,105,50,49,66,54,7,117,
110,105,50,49,66,55,7,117,110,105,50,49,66,56,7,117,110,105,
50,49,66,57,7,117,110,105,50,49,66,65,7,117,110,105,50,49,
66,66,7,117,110,105,50,49,66,67,7,117,110,105,50,49,66,68,
7,117,110,105,50,49,66,69,7,117,110,105,50,49,66,70,7,117,
110,105,50,49,67,48,7,117,110,105,50,49,67,49,7,117,110,105,
50,49,67,50,7,117,110,105,50,49,67,51,7,117,110,105,50,49,
67,52,7,117,110,105,50,49,67,53,7,117,110,105,50,49,67,54,
7,117,110,105,50,49,67,55,7,117,110,105,50,49,67,56,7,117,
110,105,50,49,67,57,7,117,110,105,50,49,67,65,7,117,110,105,
50,49,67,66,7,117,110,105,50,49,67,67,12,97,114,114,111,119,
100,98,108,108,101,102,116,10,97,114,114,111,119,100,98,108,117,112,
13,97,114,114,111,119,100,98,108,114,105,103,104,116,12,97,114,114,
111,119,100,98,108,100,111,119,110,12,97,114,114,111,119,100,98,108,
98,111,116,104,9,117,110,105,118,101,114,115,97,108,11,101,120,105,
115,116,101,110,116,105,97,108,8,101,109,112,116,121,115,101,116,7,
117,110,105,50,50,48,54,8,103,114,97,100,105,101,110,116,7,101,
108,101,109,101,110,116,10,110,111,116,101,108,101,109,101,110,116,7,
117,110,105,50,50,48,68,7,117,110,105,50,50,49,48,12,97,115,
116,101,114,105,115,107,109,97,116,104,7,117,110,105,50,50,49,66,
7,117,110,105,50,50,49,67,12,112,114,111,112,111,114,116,105,111,
110,97,108,5,97,110,103,108,101,10,108,111,103,105,99,97,108,97,
110,100,9,108,111,103,105,99,97,108,111,114,12,105,110,116,101,114,
115,101,99,116,105,111,110,5,117,110,105,111,110,9,116,104,101,114,
101,102,111,114,101,7,115,105,109,105,108,97,114,9,99,111,110,103,
114,117,101,110,116,11,101,113,117,105,118,97,108,101,110,99,101,12,
112,114,111,112,101,114,115,117,98,115,101,116,14,112,114,111,112,101,
114,115,117,112,101,114,115,101,116,9,110,111,116,115,117,98,115,101,
116,12,114,101,102,108,101,120,115,117,98,115,101,116,14,114,101,102,
108,101,120,115,117,112,101,114,115,101,116,10,99,105,114,99,108,101,
112,108,117,115,14,99,105,114,99,108,101,109,117,108,116,105,112,108,
121,13,112,101,114,112,101,110,100,105,99,117,108,97,114,7,117,110,
105,50,50,67,52,7,100,111,116,109,97,116,104,10,105,110,116,101,
103,114,97,108,116,112,10,105,110,116,101,103,114,97,108,98,116,9,
97,110,103,108,101,108,101,102,116,10,97,110,103,108,101,114,105,103,
104,116,7,117,110,105,65,55,52,54,7,117,110,105,65,55,52,55,
6,102,111,114,105,110,116,8,98,114,101,118,101,97,108,116,3,103,
95,121,3,116,95,121,3,99,95,116,13,102,95,105,99,105,114,99,
117,109,102,108,101,120,11,102,95,105,100,105,101,114,101,115,105,115,
8,102,95,105,103,114,97,118,101,8,102,95,105,97,99,117,116,101,
15,102,95,102,95,105,99,105,114,99,117,109,102,108,101,120,13,102,
95,102,95,105,100,105,101,114,101,115,105,115,10,102,95,102,95,105,
103,114,97,118,101,10,102,95,102,95,105,97,99,117,116,101,7,117,
110,105,69,49,49,56,7,117,110,105,69,49,49,57,7,117,110,105,
69,49,49,65,7,117,110,105,69,49,49,66,7,117,110,105,69,49,
49,67,7,117,110,105,69,49,49,68,7,117,110,105,69,49,49,69,
7,117,110,105,69,49,49,70,7,117,110,105,69,49,50,48,7,117,
110,105,69,49,50,49,4,97,97,108,116,9,97,103,114,97,118,101,
97,108,116,9,97,97,99,117,116,101,97,108,116,9,97,98,114,101,
118,101,97,108,116,9,97,116,105,108,100,101,97,108,116,14,97,99,
105,114,99,117,109,102,108,101,120,97,108,116,12,97,100,105,101,114,
101,115,105,115,97,108,116,10,97,111,103,111,110,101,107,97,108,116,
8,97,114,105,110,103,97,108,116,10,97,109,97,99,114,111,110,97,
108,116,4,120,97,108,116,7,117,110,105,69,70,65,48,7,117,110,
105,69,70,65,49,7,117,110,105,69,70,65,50,7,117,110,105,69,
70,65,51,7,117,110,105,69,70,65,52,7,117,110,105,69,70,65,
53,7,117,110,105,69,70,65,54,7,117,110,105,69,70,65,55,7,
117,110,105,69,70,65,56,7,117,110,105,69,70,65,57,7,117,110,
105,69,70,65,65,7,117,110,105,69,70,65,66,7,117,110,105,69,
70,65,67,7,117,110,105,69,70,65,68,7,117,110,105,69,70,66,
48,7,117,110,105,69,70,66,49,7,117,110,105,69,70,66,50,7,
117,110,105,69,70,66,51,7,117,110,105,69,70,66,52,7,117,110,
105,69,70,66,53,7,117,110,105,69,70,66,54,7,117,110,105,69,
70,66,55,7,117,110,105,69,70,66,56,9,106,46,100,111,116,108,
101,115,115,7,117,110,105,70,56,69,53,7,117,110,105,70,56,69,
54,7,117,110,105,70,56,69,55,7,117,110,105,70,56,69,56,7,
117,110,105,70,56,69,57,7,117,110,105,70,56,69,65,7,117,110,
105,70,56,69,66,7,117,110,105,70,56,69,67,7,117,110,105,70,
56,69,68,7,117,110,105,70,56,69,69,7,117,110,105,70,56,69,
70,7,117,110,105,70,56,70,48,7,117,110,105,70,56,70,49,7,
117,110,105,70,56,70,50,7,117,110,105,70,56,70,51,7,117,110,
105,70,56,70,52,7,117,110,105,70,56,70,53,7,117,110,105,70,
56,70,54,7,117,110,105,70,56,70,55,7,117,110,105,70,56,70,
56,14,98,114,97,99,107,101,116,114,105,103,104,116,116,112,14,98,
114,97,99,107,101,116,114,105,103,104,116,101,120,14,98,114,97,99,
107,101,116,114,105,103,104,116,98,116,12,98,114,97,99,101,114,105,
103,104,116,116,112,7,117,110,105,70,56,70,68,7,117,110,105,70,
56,70,69,7,117,110,105,70,56,70,70,7,108,111,110,103,115,95,
116,3,115,95,116,6,117,49,48,57,48,48,6,117,49,48,57,48,
49,6,117,49,48,57,48,50,6,117,49,48,57,48,51,6,117,49,
48,57,48,52,6,117,49,48,57,48,53,6,117,49,48,57,48,54,
6,117,49,48,57,48,55,6,117,49,48,57,48,56,6,117,49,48,
57,48,57,6,117,49,48,57,48,65,6,117,49,48,57,48,66,6,
117,49,48,57,48,67,6,117,49,48,57,48,68,6,117,49,48,57,
48,69,6,117,49,48,57,48,70,6,117,49,48,57,49,48,6,117,
49,48,57,49,49,6,117,49,48,57,49,50,6,117,49,48,57,49,
51,6,117,49,48,57,49,52,6,117,49,48,57,49,53,6,117,49,
48,57,49,54,6,117,49,48,57,49,55,6,117,49,48,57,49,56,
6,117,49,48,57,49,57,6,117,49,48,57,49,65,6,117,49,48,
57,49,66,6,117,49,48,57,49,70,6,117,49,48,57,49,69,6,
117,49,48,57,49,68,6,117,49,48,57,49,67,0,0,0,0,1,
255,255,0,2,0,2,0,0,0,1,0,0,0,2,0,6,0,85,
1,128,0,6,0,126,0,3,0,3,0,10,0,5,0,4,0,11,
0,8,0,6,0,5,0,10,0,9,0,11,0,11,0,11,17,11,
0,12,0,12,31,11,0,13,0,13,0,11,0,14,0,14,0,4,
0,15,0,15,0,7,0,16,0,16,0,4,0,18,0,17,0,7,
0,28,0,19,0,3,0,29,0,29,0,7,0,30,0,30,0,11,
0,31,0,31,18,11,0,32,0,32,0,11,0,33,0,33,30,11,
0,35,0,34,0,11,0,62,0,62,18,11,0,63,0,63,0,11,
0,64,0,64,30,11,0,67,0,65,0,11,0,94,0,94,18,11,
0,95,0,95,0,11,0,96,0,96,30,11,0,99,0,97,0,11,
0,103,0,100,0,5,0,107,0,104,0,11,0,113,0,109,0,11,
0,115,0,114,0,5,0,117,0,116,0,3,0,118,0,118,0,11,
0,122,0,120,0,11,0,123,0,123,0,3,0,129,0,125,0,11,
0,153,0,153,0,11,0,185,0,185,0,11,1,179,1,171,0,11,
1,196,1,180,128,11,1,197,1,197,0,11,1,198,1,198,128,11,
1,208,1,206,0,11,1,210,1,210,0,11,2,62,2,62,0,11,
4,6,4,6,0,11,4,10,4,8,0,11,4,23,4,21,0,11,
4,36,4,34,0,11,4,52,4,50,0,11,4,64,4,63,0,11,
4,69,4,65,0,10,4,92,4,70,0,11,4,96,4,93,0,5,
4,97,4,97,17,11,4,98,4,98,31,11,4,103,4,99,0,11,
4,104,4,104,0,7,4,121,4,105,0,11,4,122,4,122,0,3,
4,125,4,124,0,11,4,131,4,126,0,3,4,133,4,132,0,4,
4,134,4,134,0,11,4,135,4,135,17,11,4,136,4,136,31,11,
4,147,4,138,0,3,4,149,4,148,0,4,4,150,4,150,0,11,
4,151,4,151,17,11,4,152,4,152,31,11,4,185,4,160,0,5,
4,186,4,186,0,11,4,189,4,188,0,11,4,191,4,191,0,11,
4,193,4,193,0,5,4,207,4,195,0,11,5,64,4,249,0,11,
5,65,5,65,0,4,5,97,5,66,0,11,5,98,5,98,17,11,
5,99,5,99,31,11,5,100,5,100,0,11,5,198,5,190,0,11,
5,201,5,201,0,4,5,221,5,202,0,11,255,255,255,255,0,0,
0,1,0,0,0,3,0,0,0,0,0,0,0,0,0,1,0,0,
0,48,0,0,1,0,0,1,0,1,0,0,0,52,0,0,1,1,
0,11,0,2,0,0,0,56,192,0,1,2,0,0,1,3,0,2,
1,4,0,0,1,5,0,2,1,6,0,2,0,0,0,0,0,1,
0,0,0,1,0,0,3,168,0,0,0,6,0,0,0,3,0,1,
0,2,0,0,0,1,255,255,255,255,0,1,0,3,0,0,0,0,
255,255,255,254,0,11,0,0,0,0,0,0,255,255,255,251,0,11,
0,2,0,0,0,4,255,255,255,255,0,0,0,0,255,255,255,255,
255,255,255,255,0,0,0,1,0,0,0,0,0,0,0,0,0,0,
0,196,0,0,0,2,0,0,0,1,0,0,0,7,0,0,0,28,
0,0,0,70,0,0,0,126,0,0,0,156,0,0,0,172,0,0,
0,180,0,4,0,6,0,3,0,12,0,1,0,6,0,74,0,74,
0,36,0,87,0,87,0,38,0,92,0,92,0,40,255,255,255,255,
0,0,0,4,0,5,0,6,0,0,0,0,0,0,0,0,0,1,
0,2,0,0,0,0,0,0,0,0,0,0,0,1,0,2,0,0,
0,0,0,0,0,0,0,0,0,1,0,2,0,3,0,0,0,0,
0,0,0,0,0,1,0,2,0,4,0,0,0,0,0,0,0,2,
128,0,0,0,0,3,128,0,0,0,0,0,160,0,0,0,0,0,
160,0,0,2,63,255,255,164,191,255,255,183,63,255,255,166,191,255,
255,172,0,0,0,0,0,0,0,1,5,105,5,106,0,0,1,40,
0,0,0,2,0,0,0,4,0,0,0,9,0,0,0,28,0,0,
0,68,0,0,0,176,0,0,0,224,0,0,1,4,0,0,1,22,
0,4,0,6,0,2,0,12,0,1,0,0,0,23,0,20,0,30,
4,104,4,104,0,38,255,255,255,255,0,0,0,4,0,5,0,6,
0,7,0,8,0,0,0,0,0,0,0,0,0,1,0,0,0,2,
0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,
0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,
0,0,0,3,0,0,0,0,0,0,0,0,0,1,0,4,0,2,
0,5,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,
0,0,0,6,0,0,0,0,0,0,0,0,0,1,0,0,0,2,
0,7,0,0,0,0,0,0,0,0,0,2,128,0,0,0,0,4,
128,0,0,0,0,3,128,0,0,0,0,0,160,0,0,0,0,0,
160,0,0,3,0,5,128,0,0,0,0,0,160,0,0,6,63,255,
255,235,63,255,251,153,191,255,255,238,63,255,255,236,63,255,251,156,
191,255,255,241,63,255,255,239,63,255,251,159,191,255,255,242,0,0,
0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,2,0,127,
0,126,0,128,0,0,1,100,0,0,0,2,0,0,0,1,0,0,
0,9,0,0,0,28,0,0,0,68,0,0,0,140,0,0,0,206,
0,0,1,30,0,0,1,70,0,4,0,6,0,2,0,12,0,1,
0,0,0,73,0,73,0,30,0,177,0,174,0,32,255,255,255,255,
0,0,0,4,0,5,0,6,0,7,0,8,0,0,0,0,0,0,
0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,2,0,3,0,4,0,5,0,6,0,0,0,0,0,0,
0,0,0,1,0,7,0,8,0,9,0,10,0,0,0,0,0,0,
0,2,128,0,0,0,0,3,128,0,0,0,0,0,160,0,0,0,
0,0,160,0,0,2,0,0,160,0,0,4,0,0,160,0,0,6,
0,0,160,0,0,8,0,0,160,0,0,11,0,0,160,0,0,14,
0,0,160,0,0,17,63,255,255,82,191,255,255,184,63,255,255,83,
191,255,255,186,63,255,255,84,191,255,255,188,63,255,255,85,191,255,
255,190,63,255,255,90,63,255,255,192,191,255,255,193,63,255,255,92,
63,255,255,195,191,255,255,196,63,255,255,94,63,255,255,198,191,255,
255,199,63,255,255,96,63,255,255,201,191,255,255,202,0,0,0,0,
0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,0,0,4,
0,0,0,0,0,5,0,0,0,0,0,6,0,0,0,0,0,7,
5,110,5,111,5,108,5,109,5,114,5,115,5,112,5,113,0,0,
0,0,0,1,0,0,0,0,201,137,111,49,0,0,0,0,193,173,
138,185,0,0,0,0,203,255,22,112,
};
static const unsigned char fontdata1[]={
0,1,0,0,0,17,1,0,0,4,0,16,70,70,84,77,87,53,
253,32,0,1,113,100,0,0,0,28,79,83,47,50,149,101,59,25,
0,0,1,152,0,0,0,96,99,109,97,112,24,38,120,0,0,0,
15,224,0,0,6,6,99,118,116,32,0,33,2,121,0,0,21,232,
0,0,0,4,102,101,97,116,0,6,4,84,0,1,112,40,0,0,
0,44,103,97,115,112,255,255,0,3,0,1,110,96,0,0,0,8,
103,108,121,102,53,108,186,62,0,0,28,228,0,1,43,52,104,101,
97,100,253,229,153,186,0,0,1,28,0,0,0,54,104,104,101,97,
14,104,11,42,0,0,1,84,0,0,0,36,104,109,116,120,40,195,
206,227,0,0,1,248,0,0,13,232,107,101,114,110,3,59,2,148,
0,1,72,24,0,0,0,228,108,111,99,97,192,176,116,144,0,0,
21,236,0,0,6,246,109,97,120,112,3,203,1,22,0,0,1,120,
0,0,0,32,109,111,114,120,33,171,37,156,0,1,112,84,0,0,
1,16,110,97,109,101,247,95,122,13,0,1,72,252,0,0,8,201,
112,111,115,116,247,119,47,181,0,1,81,200,0,0,28,150,112,114,
111,112,183,32,72,154,0,1,110,104,0,0,1,190,0,1,0,0,
0,1,71,174,231,59,238,169,95,15,60,245,0,11,8,0,0,0,
0,0,203,255,3,82,0,0,0,0,203,255,3,82,252,30,253,71,
10,169,9,36,0,1,0,8,0,2,0,0,0,0,0,0,0,1,
0,0,7,158,254,7,0,0,11,17,252,30,254,151,10,169,0,1,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,122,0,1,
0,0,3,122,0,141,0,9,0,131,0,4,0,2,0,0,0,1,
0,1,0,0,0,64,0,0,0,2,0,3,0,4,4,117,2,188,
0,5,0,0,5,51,5,153,0,0,1,30,5,51,5,153,0,0,
3,215,0,102,2,18,0,0,2,11,8,3,6,1,0,0,0,0,
160,0,2,239,16,0,32,123,0,0,0,0,0,0,0,0,80,102,
69,100,0,160,0,32,248,243,6,61,254,7,0,0,7,158,1,195,
32,0,1,159,0,0,0,0,4,49,5,176,0,0,0,32,0,1,
5,129,0,100,0,0,0,0,2,170,0,0,2,104,0,0,1,201,
0,69,3,106,0,129,6,29,0,119,3,159,0,20,5,155,0,94,
5,4,0,59,1,208,0,129,2,141,0,31,2,131,0,80,4,148,
0,87,3,204,0,68,1,188,0,56,3,192,0,98,1,195,0,64,
3,79,255,214,4,153,0,80,4,153,0,229,4,153,0,92,4,153,
0,93,4,153,0,90,4,153,0,94,4,153,0,109,4,153,0,98,
4,153,0,68,4,153,0,107,1,184,0,64,1,184,0,64,3,96,
0,45,3,139,0,55,3,96,0,55,4,10,0,47,6,201,0,79,
5,141,0,20,4,198,0,115,5,129,0,100,4,249,0,115,4,187,
0,115,4,167,0,115,5,141,0,90,4,229,0,115,2,43,0,143,
4,219,0,102,5,53,0,115,4,146,0,115,6,119,0,115,5,51,
0,115,5,129,0,100,4,170,0,115,5,157,0,98,4,200,0,115,
4,178,0,83,5,73,0,78,4,251,0,115,5,22,0,70,6,172,
0,74,5,46,0,64,5,46,0,67,5,98,0,72,2,231,0,121,
3,88,255,217,2,231,0,119,4,57,0,122,4,217,0,78,2,24,
0,77,4,56,0,90,4,98,0,119,4,23,0,86,4,98,0,74,
4,69,0,88,3,14,0,74,4,113,0,74,4,97,0,119,2,22,
0,121,2,22,255,20,3,231,0,119,2,49,0,139,6,39,0,119,
4,97,0,119,4,81,0,92,4,108,0,119,4,108,0,74,3,90,
0,122,3,190,0,78,2,194,0,72,4,88,0,108,4,36,0,72,
5,169,0,57,4,30,0,27,4,82,0,108,3,237,0,66,2,235,
0,80,1,212,0,115,2,235,0,121,2,247,0,53,1,53,255,199,
3,116,0,70,4,243,0,74,3,219,0,53,4,112,0,45,1,149,
0,80,2,182,0,33,3,165,0,67,4,65,255,178,2,72,0,30,
3,139,0,51,4,96,0,143,3,182,0,88,4,200,0,84,3,192,
0,98,2,251,255,239,3,215,0,129,2,216,0,72,2,155,0,48,
2,65,0,78,4,104,0,143,5,6,0,111,1,239,0,93,2,16,
0,57,1,246,0,49,2,251,255,239,3,215,0,127,4,226,0,31,
4,226,0,31,5,34,0,29,3,186,255,213,5,141,0,20,5,141,
0,20,5,12,0,20,5,12,0,20,5,12,0,20,5,12,0,20,
6,53,0,10,4,196,0,110,4,187,0,115,4,187,0,115,4,126,
0,115,4,126,0,115,2,155,255,216,2,155,0,143,2,155,255,126,
2,155,255,133,5,200,0,135,5,12,0,115,5,67,0,100,5,67,
0,100,5,67,0,100,5,67,0,100,5,67,0,100,3,65,0,33,
5,145,0,100,5,18,0,115,5,18,0,115,5,18,0,115,5,18,
0,115,4,155,0,67,5,104,0,135,4,237,0,62,4,12,0,90,
4,12,0,90,4,12,0,90,4,12,0,90,4,12,0,90,4,12,
0,90,6,228,0,90,3,79,0,86,4,69,0,88,4,69,0,88,
3,196,0,88,3,196,0,88,2,38,255,212,2,32,0,138,2,34,
255,128,2,36,255,140,4,38,0,72,4,65,0,119,4,126,0,92,
4,129,0,92,4,126,0,92,4,126,0,92,4,126,0,92,3,235,
0,118,4,20,0,53,3,223,0,108,4,0,0,108,4,0,0,108,
4,0,0,108,3,215,0,108,4,69,0,119,3,215,0,108,5,141,
0,20,4,56,0,90,5,141,0,20,4,56,0,90,5,141,255,252,
4,56,0,90,5,30,0,100,4,23,0,86,5,30,0,100,4,23,
0,86,5,30,0,100,4,23,0,86,5,30,0,100,4,23,0,86,
4,249,0,115,5,68,0,74,5,200,0,135,4,98,0,74,4,187,
0,115,4,69,0,88,4,187,0,115,4,69,0,88,4,187,0,115,
4,69,0,88,4,187,0,115,4,69,0,88,4,187,0,115,4,69,
0,88,5,141,0,90,4,113,0,74,5,141,0,90,4,113,0,74,
5,141,0,90,4,113,0,74,5,141,0,90,4,113,0,74,4,229,
0,115,4,97,0,119,4,229,0,44,4,97,0,40,2,43,255,210,
2,22,255,194,2,43,255,150,2,22,255,137,2,43,255,179,2,22,
255,180,2,43,0,137,2,22,0,120,2,43,0,114,2,22,0,139,
6,171,0,143,3,161,0,121,4,227,0,102,2,22,255,20,5,53,
0,115,3,231,0,119,4,5,0,23,4,196,0,115,2,49,0,139,
4,196,0,115,2,49,0,92,4,196,0,115,3,4,0,139,4,196,
0,115,3,51,0,139,4,196,0,0,2,49,0,0,5,63,0,115,
4,97,0,119,5,63,0,115,4,97,0,119,5,63,0,115,4,97,
0,119,5,114,0,66,5,64,0,119,4,97,0,119,5,129,0,100,
4,81,0,92,5,129,0,100,4,81,0,92,5,67,0,100,4,129,
0,92,6,125,0,100,6,91,0,92,4,186,0,115,3,90,0,122,
4,186,0,115,3,90,0,122,4,186,0,115,3,90,0,77,4,178,
0,83,3,190,0,78,4,178,0,83,3,190,0,78,4,178,0,83,
3,190,0,78,4,178,0,83,3,190,0,78,5,73,0,78,2,194,
0,72,5,73,0,78,3,116,0,72,5,73,0,78,2,194,0,40,
5,67,0,115,4,88,0,108,5,67,0,115,4,88,0,108,5,67,
0,115,4,88,0,108,5,67,0,115,4,88,0,108,5,18,0,115,
4,0,0,108,5,67,0,115,4,88,0,108,6,133,0,74,5,169,
0,57,5,34,0,67,4,82,0,108,5,34,0,67,5,137,0,72,
3,237,0,66,5,137,0,72,3,237,0,66,5,137,0,72,3,237,
0,66,3,14,0,213,5,2,0,28,6,35,0,10,6,148,0,74,
4,178,0,83,3,190,0,78,5,73,0,78,2,194,0,72,5,67,
1,61,5,67,1,61,4,190,1,120,3,108,1,48,2,206,0,130,
2,16,0,56,4,65,0,252,5,18,1,82,0,0,252,69,0,0,
252,60,0,0,252,102,0,0,252,224,0,0,252,161,0,0,252,149,
0,0,253,75,0,0,252,40,0,0,252,171,0,0,252,60,0,0,
252,102,0,0,252,149,0,0,253,75,0,0,252,40,0,0,252,171,
1,188,0,56,0,0,252,30,0,0,252,30,0,0,252,161,1,239,
0,93,4,114,1,209,4,114,0,78,5,141,0,47,5,161,0,53,
5,181,0,37,2,200,0,37,6,4,0,42,5,34,0,66,6,98,
0,29,3,22,255,64,5,141,0,47,4,202,0,119,4,167,0,115,
6,12,0,108,4,187,0,114,5,137,0,72,4,229,0,115,5,129,
0,100,2,43,0,143,5,53,0,115,5,22,0,70,6,12,0,66,
5,63,0,119,4,167,0,115,5,129,0,100,4,229,0,115,4,124,
0,121,6,12,0,50,5,73,0,78,5,34,0,66,6,22,0,96,
5,18,0,53,4,88,0,92,5,129,0,31,2,43,255,134,5,34,
0,66,5,47,0,91,3,146,0,86,4,97,0,119,3,22,0,135,
4,79,0,78,5,47,0,91,4,237,0,62,4,36,0,72,4,81,
0,92,3,146,0,86,4,97,0,56,4,97,0,119,4,153,0,80,
3,22,0,138,4,5,0,23,4,36,0,72,4,104,0,143,4,36,
0,72,4,97,0,39,4,81,0,92,4,97,0,47,4,81,0,92,
4,23,0,86,4,126,0,92,4,97,0,119,4,79,0,108,4,244,
0,58,3,86,0,30,4,88,0,92,6,176,0,108,3,22,255,128,
4,79,0,39,4,81,0,92,4,79,0,108,6,176,0,108,4,153,
0,105,4,104,0,92,6,176,0,108,4,187,0,114,4,229,255,210,
4,167,0,115,5,30,0,90,4,178,0,83,2,43,0,143,2,43,
255,139,4,227,0,102,7,165,0,66,6,181,0,115,4,97,0,0,
5,53,0,115,5,34,255,188,4,214,0,116,5,141,0,47,4,124,
0,121,4,202,0,119,4,167,0,115,6,140,0,74,4,187,0,114,
6,133,0,113,4,153,0,93,5,63,0,119,5,63,0,119,5,53,
0,115,5,122,0,66,6,12,0,66,4,229,0,115,5,129,0,100,
4,229,0,115,4,124,0,121,5,30,0,90,5,73,0,78,5,34,
255,188,6,22,0,96,5,18,0,53,4,229,0,115,4,97,0,119,
6,108,0,115,7,92,0,115,5,8,0,30,4,224,0,121,4,124,
0,121,5,30,0,90,6,116,0,143,4,186,0,121,4,56,0,90,
4,81,0,92,3,232,0,53,4,90,0,119,4,166,0,68,4,69,
0,78,5,169,0,84,3,146,0,86,4,97,0,130,4,97,0,130,
4,5,0,23,4,62,0,22,5,50,0,63,4,97,0,115,4,81,
0,92,5,190,0,119,4,108,0,119,4,23,0,86,4,97,0,119,
4,82,0,108,4,104,0,92,4,30,0,27,5,42,0,119,4,97,
0,128,6,34,0,119,7,18,0,119,4,162,0,28,4,174,0,52,
3,239,0,52,4,23,0,86,6,11,0,139,3,239,0,52,4,69,
0,78,4,97,0,119,4,90,0,119,4,23,0,86,3,190,0,78,
2,22,0,121,2,22,255,123,2,22,255,20,6,54,0,22,4,97,
0,115,4,97,0,6,4,5,0,23,4,82,0,108,4,18,0,119,
4,202,0,115,4,98,0,119,4,249,0,115,4,98,0,74,4,251,
0,115,4,58,0,64,4,167,0,115,3,14,0,74,4,230,0,115,
4,27,0,119,5,54,0,115,3,232,0,113,4,197,0,115,2,49,
0,117,4,197,0,10,2,49,255,145,4,197,0,115,2,49,255,149,
6,12,0,115,6,39,0,119,6,13,0,66,6,52,0,119,5,64,
0,119,4,27,0,119,5,64,0,119,4,27,0,119,5,64,0,119,
4,27,0,119,4,124,0,115,4,108,0,119,4,187,0,121,3,70,
0,119,4,187,0,121,3,70,0,33,4,187,0,121,3,70,0,33,
4,178,0,83,3,190,0,78,4,179,0,88,3,172,0,78,5,73,
0,78,2,194,0,72,5,75,0,78,2,195,0,72,5,75,0,78,
2,195,255,223,6,133,0,74,5,169,0,57,6,133,0,74,5,169,
0,57,6,133,0,74,5,169,0,57,5,36,0,66,3,242,0,109,
4,27,0,119,5,68,0,111,5,34,0,67,4,82,0,108,6,28,
0,138,4,10,0,0,8,0,0,0,1,85,0,0,1,0,0,0,
0,205,0,0,0,170,0,0,4,97,0,120,4,97,0,120,4,153,
0,68,5,63,0,119,6,12,0,66,6,12,0,0,1,129,0,9,
1,129,0,38,1,129,0,32,1,129,0,21,3,2,0,17,3,2,
0,30,3,2,0,36,3,2,0,30,3,96,0,46,3,96,0,46,
3,56,0,98,3,56,0,252,2,67,0,30,4,138,0,30,6,203,
0,30,8,86,0,94,11,17,0,94,2,47,0,51,2,123,0,127,
3,110,0,69,4,38,0,59,3,193,0,98,1,64,254,43,7,112,
0,47,5,162,0,47,5,30,0,69,5,6,0,111,5,7,0,111,
5,7,0,111,1,184,0,64,4,88,0,27,2,247,0,53,2,32,
0,108,2,32,0,108,2,32,0,108,2,32,0,108,2,32,0,108,
2,32,0,108,2,32,0,108,2,138,0,30,1,246,0,49,2,216,
0,72,2,155,0,48,2,200,0,52,2,190,0,69,2,146,0,64,
2,186,0,66,2,162,0,54,2,128,0,38,1,234,0,49,2,90,
0,49,2,118,0,94,1,178,0,50,1,178,0,56,2,106,0,56,
2,138,0,30,1,246,0,49,2,216,0,72,2,155,0,48,2,200,
0,52,2,190,0,69,2,146,0,64,2,186,0,66,2,162,0,54,
2,128,0,38,1,234,0,48,2,90,0,49,2,118,0,94,1,178,
0,50,1,178,0,56,2,102,0,35,2,108,0,45,2,108,0,50,
2,208,0,63,2,108,0,54,1,239,0,93,1,239,0,93,4,154,
0,135,4,154,0,131,4,222,0,25,4,154,0,31,4,154,0,43,
5,122,0,25,5,56,0,25,8,100,0,25,6,196,0,25,6,30,
0,25,5,48,0,25,4,154,1,78,4,202,0,125,5,54,0,25,
4,228,0,25,4,154,0,248,4,154,0,150,4,154,0,37,4,154,
0,109,5,77,0,25,4,154,0,16,4,154,0,129,4,154,0,70,
4,154,0,21,4,154,0,12,4,154,0,105,7,68,0,10,6,210,
0,119,5,249,0,41,5,129,0,31,4,247,0,49,4,54,0,31,
4,210,0,52,4,54,0,31,4,220,0,52,4,192,0,51,4,192,
0,52,4,54,0,31,4,202,0,50,4,54,0,31,4,242,0,51,
4,242,0,69,4,242,0,66,4,54,0,31,2,43,0,143,3,198,
0,143,5,98,0,143,7,56,0,143,5,22,0,70,6,240,0,70,
8,154,0,70,10,52,0,70,7,72,0,143,5,18,0,53,6,236,
0,53,8,138,0,53,4,196,0,115,5,30,0,90,4,249,0,115,
6,12,0,66,2,22,0,121,3,162,0,121,5,46,0,121,5,244,
0,121,4,36,0,72,5,238,0,72,7,120,0,72,9,2,0,72,
6,80,0,121,4,30,0,27,6,44,0,27,7,182,0,27,2,49,
0,139,4,23,0,86,4,98,0,74,6,39,0,119,8,66,0,90,
4,249,0,115,10,32,0,72,5,30,0,90,4,23,0,86,5,30,
0,90,3,48,0,42,4,54,0,30,6,138,0,49,3,244,0,65,
6,138,0,70,3,244,0,67,6,138,0,49,3,244,0,65,6,138,
1,2,6,138,0,237,6,138,0,238,6,138,1,2,6,138,0,49,
6,138,0,70,6,138,0,145,6,138,0,138,6,138,0,49,3,244,
0,65,6,138,0,70,3,244,0,65,6,138,0,49,6,138,0,17,
6,138,0,49,3,244,0,63,6,138,0,49,3,244,0,65,3,244,
0,65,3,244,0,49,3,244,0,100,3,244,0,49,3,244,0,100,
3,244,0,70,6,138,0,49,6,138,255,227,6,138,0,21,6,138,
1,2,6,138,0,70,6,138,0,40,6,138,0,61,6,138,255,255,
6,138,255,255,4,0,1,142,4,0,0,71,6,138,0,70,6,138,
0,70,4,0,1,142,4,0,0,72,6,138,0,49,6,138,0,145,
6,138,0,49,6,138,0,37,6,138,1,6,6,138,0,70,6,138,
1,6,6,138,255,255,6,138,255,255,5,141,0,47,4,98,0,66,
4,187,0,114,4,200,0,38,6,12,0,108,6,12,0,108,4,229,
0,115,6,12,0,50,3,14,0,74,5,22,0,0,5,22,0,0,
5,22,0,0,8,101,0,63,3,254,0,64,3,203,0,22,2,247,
0,53,1,239,0,93,2,247,0,53,3,139,0,55,3,215,0,124,
3,215,0,124,4,200,0,84,4,200,0,84,1,239,0,93,5,23,
1,27,6,156,0,130,3,152,0,137,4,167,0,115,1,238,0,19,
8,195,0,74,7,31,0,72,6,234,0,86,4,153,0,215,4,153,
0,202,4,153,0,229,4,153,0,85,4,153,0,92,4,153,0,82,
4,153,0,110,4,153,0,58,4,153,0,66,4,153,0,110,4,56,
0,91,4,56,0,91,4,56,0,91,4,56,0,91,4,56,0,91,
4,56,0,91,4,56,0,91,4,56,0,91,4,56,0,91,4,56,
0,91,4,30,0,27,6,13,0,66,6,52,0,119,6,13,0,66,
6,52,0,119,5,64,0,119,4,27,0,119,4,187,0,121,3,70,
0,53,5,75,0,78,2,195,255,221,4,179,0,88,3,172,0,78,
4,230,0,115,4,27,0,119,4,230,0,115,4,197,0,115,2,49,
255,225,4,197,0,18,2,49,255,156,4,187,0,121,3,70,255,197,
4,187,0,121,3,70,255,197,2,22,255,20,1,239,0,93,3,192,
0,98,4,200,0,84,6,146,0,120,4,200,0,84,0,0,0,3,
0,0,0,3,0,0,0,28,0,1,0,0,0,0,3,252,0,3,
0,1,0,0,0,28,0,4,3,224,0,0,0,196,0,128,0,6,
0,68,0,127,1,127,1,146,1,227,2,27,2,199,2,221,3,7,
3,12,3,16,3,40,3,49,3,122,3,134,3,138,3,140,3,161,
3,206,3,209,3,214,4,12,4,79,4,92,4,95,30,3,30,13,
30,31,30,37,30,59,30,73,30,87,30,99,30,111,30,133,30,143,
30,150,30,158,30,243,30,251,32,5,32,10,32,21,32,38,32,49,
32,58,32,61,32,68,32,73,32,77,32,79,32,83,32,86,32,91,
32,94,32,142,32,148,32,153,32,185,33,3,33,22,33,34,33,38,
33,46,33,134,33,137,33,168,33,204,34,0,34,3,34,7,34,15,
34,18,34,28,34,30,34,43,34,52,34,60,34,69,34,72,34,96,
34,101,34,149,34,151,34,196,37,202,167,71,224,150,225,6,225,33,
226,89,226,104,239,173,239,184,246,190,248,231,248,241,248,243,255,255,
0,0,0,32,0,161,1,146,1,226,2,24,2,198,2,216,3,0,
3,10,3,16,3,35,3,49,3,122,3,132,3,136,3,140,3,142,
3,163,3,209,3,213,4,1,4,14,4,81,4,94,30,2,30,10,
30,30,30,36,30,52,30,64,30,86,30,90,30,106,30,128,30,142,
30,150,30,158,30,242,30,250,32,3,32,9,32,16,32,24,32,48,
32,57,32,60,32,67,32,71,32,75,32,79,32,82,32,86,32,88,
32,93,32,112,32,144,32,152,32,160,33,3,33,22,33,34,33,38,
33,46,33,83,33,137,33,144,33,176,34,0,34,2,34,5,34,15,
34,17,34,26,34,30,34,43,34,52,34,60,34,69,34,72,34,96,
34,100,34,149,34,151,34,196,37,202,167,70,224,149,225,4,225,24,
226,80,226,104,239,160,239,176,246,190,248,229,248,241,248,243,255,255,
0,0,255,193,255,175,255,96,255,44,254,130,254,114,254,80,254,78,
254,75,254,57,254,49,253,233,253,224,253,223,253,222,253,221,253,220,
253,218,253,215,253,173,253,172,253,171,253,170,228,8,228,2,227,242,
227,238,227,224,227,220,227,208,227,206,227,200,227,184,227,176,227,170,
227,163,227,80,227,74,226,67,226,64,226,59,226,57,226,48,226,41,
226,40,226,35,226,33,226,32,226,31,226,29,226,27,226,26,226,25,
226,8,226,7,226,4,225,254,225,181,225,163,225,152,225,149,225,142,
225,106,225,104,225,98,225,91,225,40,225,39,225,38,225,31,225,30,
225,23,225,22,225,10,225,2,224,251,224,243,224,241,224,218,224,215,
224,168,224,167,224,123,221,118,91,251,34,174,34,65,34,48,33,2,
32,244,19,189,19,187,12,182,10,144,10,135,10,134,0,1,0,196,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,4,
0,5,0,6,0,7,0,8,0,9,0,10,0,11,0,12,0,13,
0,14,0,15,0,16,0,17,0,18,0,19,0,20,0,21,0,22,
0,23,0,24,0,25,0,26,0,27,0,28,0,29,0,30,0,31,
0,32,0,33,0,34,0,35,0,36,0,37,0,38,0,39,0,40,
0,41,0,42,0,43,0,44,0,45,0,46,0,47,0,48,0,49,
0,50,0,51,0,52,0,53,0,54,0,55,0,56,0,57,0,58,
0,59,0,60,0,61,0,62,0,63,0,64,0,65,0,66,0,67,
0,68,0,69,0,70,0,71,0,72,0,73,0,74,0,75,0,76,
0,77,0,78,0,79,0,80,0,81,0,82,0,83,0,84,0,85,
0,86,0,87,0,88,0,89,0,90,0,91,0,92,0,93,0,94,
0,95,0,96,0,97,0,0,0,6,2,10,0,0,0,0,1,0,
0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,
0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,1,0,0,0,0,0,3,0,4,0,5,0,6,
0,7,0,8,0,9,0,10,0,11,0,12,0,13,0,14,0,15,
0,16,0,17,0,18,0,19,0,20,0,21,0,22,0,23,0,24,
0,25,0,26,0,27,0,28,0,29,0,30,0,31,0,32,0,33,
0,34,0,35,0,36,0,37,0,38,0,39,0,40,0,41,0,42,
0,43,0,44,0,45,0,46,0,47,0,48,0,49,0,50,0,51,
0,52,0,53,0,54,0,55,0,56,0,57,0,58,0,59,0,60,
0,61,0,62,0,63,0,64,0,65,0,66,0,67,0,68,0,69,
0,70,0,71,0,72,0,73,0,74,0,75,0,76,0,77,0,78,
0,79,0,80,0,81,0,82,0,83,0,84,0,85,0,86,0,87,
0,88,0,89,0,90,0,91,0,92,0,93,0,94,0,95,0,96,
0,97,0,0,0,133,0,134,0,136,0,138,0,146,0,151,0,157,
0,162,0,161,0,163,0,165,0,164,0,166,0,168,0,170,0,169,
0,171,0,172,0,174,0,173,0,175,0,176,0,178,0,180,0,179,
0,181,0,183,0,182,0,187,0,186,0,188,0,189,2,89,0,113,
0,99,0,100,0,104,2,91,0,119,0,160,0,111,0,106,2,186,
0,117,0,105,3,58,0,135,0,153,3,52,0,114,3,59,3,60,
0,102,0,118,3,41,3,47,3,46,1,156,3,53,0,107,0,123,
1,133,0,167,0,185,0,128,0,98,0,109,3,49,1,65,3,57,
3,44,0,108,0,124,2,95,0,0,0,129,0,132,0,150,1,19,
1,20,2,78,2,79,2,85,2,86,2,81,2,82,0,184,3,64,
0,192,1,57,2,103,2,170,2,98,2,99,0,0,0,0,2,90,
0,120,2,83,2,87,2,96,0,131,0,139,0,130,0,140,0,137,
0,142,0,143,0,144,0,141,0,148,0,149,0,0,0,147,0,155,
0,156,0,154,0,242,1,72,1,78,0,112,1,74,1,75,1,76,
0,121,1,79,1,77,1,73,0,0,0,33,2,121,0,0,0,206,
0,206,0,206,0,206,0,246,1,54,1,104,1,188,2,8,2,76,
2,110,2,138,2,166,3,26,3,50,3,84,3,98,3,118,3,132,
3,186,3,206,4,6,4,72,4,104,4,162,4,218,4,238,5,62,
5,118,5,130,5,142,5,164,5,184,5,204,6,14,6,116,6,146,
6,206,7,14,7,54,7,78,7,100,7,164,7,190,7,204,7,240,
8,14,8,30,8,60,8,84,8,150,8,200,9,18,9,76,9,150,
9,170,9,212,9,234,10,10,10,44,10,68,10,90,10,108,10,124,
10,142,10,162,10,176,10,232,11,44,11,104,11,154,11,214,12,12,
12,52,12,134,12,176,12,202,12,244,13,18,13,38,13,98,13,140,
13,176,13,236,14,46,14,80,14,148,14,180,14,222,14,242,15,16,
15,46,15,108,15,128,15,178,15,190,15,244,16,36,16,76,16,134,
16,194,17,4,17,46,17,66,17,146,17,184,17,252,18,84,18,114,
18,130,18,140,18,240,18,254,19,32,19,46,19,136,19,232,20,30,
20,68,20,140,20,150,20,192,20,208,20,248,21,24,21,68,21,176,
22,42,22,110,22,122,22,134,22,146,22,158,22,170,22,182,22,220,
22,232,22,244,23,0,23,12,23,24,23,36,23,48,23,60,23,72,
23,122,23,134,23,146,23,158,23,170,23,182,23,194,23,220,24,46,
24,58,24,70,24,82,24,94,24,106,24,150,24,238,24,250,25,6,
25,18,25,30,25,42,25,54,25,158,25,170,25,182,25,194,25,206,
25,218,25,230,25,242,26,14,26,56,26,142,26,154,26,166,26,178,
26,190,26,202,26,214,27,0,27,70,27,82,27,94,27,106,27,118,
27,130,27,184,27,196,27,208,27,220,27,232,27,244,28,0,28,12,
28,24,28,36,28,48,28,60,28,72,28,84,28,96,28,108,28,120,
28,216,29,20,29,88,29,100,29,112,29,124,29,136,29,148,29,160,
29,172,29,184,29,196,29,208,29,220,29,232,29,244,30,0,30,12,
30,24,30,32,30,40,30,52,30,64,30,104,30,154,30,166,30,254,
31,10,31,32,31,44,31,94,31,106,31,118,31,130,31,144,31,210,
32,28,32,40,32,88,32,96,32,104,32,132,32,144,32,156,32,168,
32,180,32,232,33,32,33,44,33,56,33,84,33,116,33,128,33,140,
33,148,33,156,33,168,33,180,33,194,34,22,34,108,34,120,34,132,
34,144,34,156,34,168,34,180,35,0,35,80,35,92,35,104,35,116,
35,128,35,140,35,152,35,164,35,176,35,188,35,200,35,212,35,224,
35,236,35,248,36,4,36,16,36,28,36,96,36,126,36,166,36,178,
36,190,36,202,36,214,36,226,36,238,36,250,37,6,37,18,37,30,
37,42,37,54,37,66,37,78,37,90,37,102,37,114,37,126,37,138,
37,150,37,162,37,174,37,186,37,224,38,26,38,72,38,190,38,202,
38,214,38,222,38,230,38,250,39,14,39,56,39,78,39,118,39,168,
39,248,40,70,40,84,40,98,40,118,40,164,40,178,40,228,41,2,
41,54,41,104,41,126,41,146,41,218,41,248,42,44,42,94,42,140,
42,168,42,196,42,210,42,228,43,20,43,92,43,104,43,118,43,132,
43,146,43,158,43,182,43,196,43,206,43,236,44,68,44,86,44,108,
44,132,44,154,44,180,45,46,45,60,45,90,45,112,45,142,45,166,
45,196,46,56,46,76,46,122,46,152,46,172,46,196,47,72,47,104,
47,152,48,0,48,12,48,24,48,36,48,48,48,60,48,72,48,84,
48,158,49,18,49,40,49,86,49,176,49,240,50,48,50,126,50,164,
50,192,50,214,51,6,51,26,51,118,51,156,51,180,51,220,52,26,
52,66,52,112,52,198,53,48,53,78,53,128,54,24,54,36,54,144,
54,224,54,236,54,248,55,88,55,144,56,40,56,96,56,184,56,196,
57,26,57,144,57,158,57,204,58,10,58,86,58,146,58,212,58,224,
58,236,59,6,59,36,59,84,59,172,59,190,59,230,59,254,60,48,
60,136,60,162,60,224,60,254,61,40,61,70,61,96,61,212,61,232,
62,22,62,102,62,122,62,166,63,42,63,74,63,94,63,158,63,184,
63,214,64,6,64,60,64,108,64,188,65,12,65,68,65,166,65,226,
66,56,66,74,66,112,66,182,66,224,67,58,67,82,67,94,67,122,
67,166,67,196,67,224,68,6,68,28,68,118,68,180,68,200,69,28,
69,84,69,114,69,140,69,198,69,228,70,6,70,64,70,126,70,180,
70,246,71,64,71,124,71,218,72,24,72,36,72,102,72,228,73,4,
73,48,73,102,73,186,73,214,74,24,74,36,74,48,74,74,74,86,
74,98,74,110,74,122,74,184,75,8,75,20,75,32,75,82,75,142,
75,180,75,216,76,0,76,44,76,90,76,140,76,164,76,192,76,204,
76,216,77,14,77,94,77,142,77,202,77,250,78,54,78,86,78,130,
78,142,78,154,78,226,79,24,79,104,79,166,79,222,80,6,80,18,
80,30,80,122,80,212,80,224,80,236,81,22,81,76,81,102,81,140,
81,152,81,164,81,176,81,188,81,200,81,212,82,4,82,86,82,130,
82,188,82,200,82,212,82,240,83,32,83,32,83,32,83,32,83,32,
83,32,83,46,83,60,83,74,83,88,83,102,83,116,83,126,83,136,
83,146,83,154,83,166,83,178,83,188,83,250,84,18,84,54,84,82,
84,96,84,118,84,156,84,210,85,102,86,38,86,56,86,74,86,158,
86,246,87,4,87,18,87,204,88,88,88,220,89,52,89,88,89,124,
89,180,89,226,90,56,90,86,90,116,90,146,90,176,90,206,90,248,
91,46,91,118,91,134,91,224,92,64,92,92,92,170,92,238,93,0,
93,106,93,176,93,196,93,210,93,230,94,10,94,46,94,106,94,178,
94,194,95,26,95,120,95,148,95,226,96,40,96,58,96,164,96,236,
97,0,97,14,97,34,97,68,97,104,97,196,98,10,98,56,98,82,
98,150,98,168,98,186,99,2,99,110,99,200,99,236,100,82,100,152,
100,208,101,128,102,4,102,76,102,136,102,204,103,32,103,70,103,114,
103,172,104,60,104,150,104,220,105,20,105,128,105,196,105,238,106,188,
106,214,107,24,107,138,107,208,107,248,108,96,108,198,109,56,109,244,
110,84,111,0,111,174,112,26,112,116,113,12,113,138,114,86,115,18,
115,146,115,170,115,184,115,204,115,232,116,6,116,28,116,58,116,94,
116,138,116,178,116,210,116,250,117,40,117,56,117,136,117,180,117,210,
117,242,118,42,118,124,118,170,118,190,118,236,119,50,119,146,119,202,
119,232,120,32,120,112,120,134,120,196,121,32,121,116,121,232,122,20,
122,102,122,182,122,240,123,66,123,92,124,6,124,26,124,46,124,68,
124,90,124,120,124,150,124,172,124,194,124,216,124,238,125,16,125,50,
125,92,125,134,125,162,125,190,125,218,125,246,126,20,126,50,126,76,
126,102,126,128,126,154,126,190,126,216,126,240,127,8,127,32,127,56,
127,80,127,140,127,198,127,226,128,20,128,100,128,180,128,196,128,214,
128,232,128,248,129,8,129,24,129,42,129,58,129,96,129,134,129,172,
129,214,130,0,130,42,130,84,130,110,130,136,130,166,130,224,130,248,
131,102,131,124,131,148,131,168,131,198,131,212,131,236,131,248,132,4,
132,80,132,142,132,232,133,62,133,80,133,246,134,24,134,52,134,80,
134,184,135,30,135,48,135,76,135,100,135,136,135,182,135,214,136,160,
137,14,137,148,137,218,137,240,138,78,138,164,138,196,139,16,139,92,
139,112,139,226,140,42,140,86,140,98,140,110,140,122,140,134,140,146,
140,158,140,170,140,182,140,194,140,240,141,82,141,212,142,30,142,138,
142,204,143,30,143,130,143,206,144,14,144,90,144,210,145,72,145,142,
145,224,146,0,146,60,146,124,146,192,147,8,147,102,147,178,148,22,
148,106,148,142,148,160,148,182,149,32,149,54,149,154,0,0,0,4,
0,100,255,227,5,49,5,209,0,51,0,63,0,99,0,137,0,0,
1,21,35,53,52,55,54,55,54,55,54,55,54,55,54,55,54,53,
52,39,38,39,38,35,34,6,7,39,54,55,54,51,50,23,22,23,
22,23,30,1,21,20,7,6,7,6,7,14,2,7,6,7,52,55,
54,50,22,21,20,6,34,39,38,1,52,38,39,38,39,38,35,34,
7,6,7,6,7,6,7,6,21,20,23,22,23,22,23,30,1,51,
50,55,54,55,54,55,54,55,54,37,52,55,54,55,54,55,54,55,
54,32,23,22,23,30,1,23,22,21,20,7,6,7,6,7,6,7,
6,35,34,39,38,39,38,39,38,39,38,2,254,131,9,8,16,12,
19,26,9,15,16,14,9,10,15,14,23,20,25,38,52,3,131,9,
59,60,94,33,37,35,30,29,23,22,28,10,9,15,16,17,18,36,
30,9,10,144,23,24,66,48,48,66,24,23,1,169,34,35,34,70,
68,91,75,58,56,38,40,22,26,8,9,10,11,23,25,36,38,116,
73,75,58,57,37,40,22,26,8,9,252,77,20,19,48,45,71,69,
106,105,1,8,105,106,69,67,96,19,20,20,19,48,46,70,68,107,
105,131,130,105,109,67,70,46,47,21,20,2,109,64,95,24,21,18,
18,14,15,21,7,11,18,16,19,22,21,28,18,17,8,7,52,38,
20,83,53,54,8,8,16,16,23,22,66,37,32,35,31,21,22,16,
16,28,26,17,18,212,34,23,24,48,33,32,48,24,23,1,106,89,
170,73,72,46,45,30,29,50,53,61,71,62,67,72,82,70,75,70,
74,51,53,66,33,32,54,58,67,77,68,73,79,98,102,95,101,95,
77,75,46,46,46,46,74,71,202,96,102,98,104,108,101,109,103,81,
78,50,49,49,51,77,81,102,105,105,101,0,0,0,0,2,0,69,
255,223,1,141,5,203,0,9,0,23,0,0,55,52,54,50,22,20,
6,35,34,38,1,20,6,35,34,38,53,3,52,54,51,50,22,21,
69,96,136,96,96,68,67,97,1,7,72,27,29,71,41,96,43,44,
97,131,68,96,96,136,96,97,1,120,23,36,36,23,3,181,37,57,
57,35,0,0,0,2,0,129,4,20,2,223,6,6,0,19,0,38,
0,0,1,3,52,54,59,1,50,22,23,22,21,3,14,1,35,34,
38,39,52,38,37,3,52,54,59,1,50,22,23,22,21,3,14,1,
35,34,38,39,38,2,12,20,79,34,4,30,77,5,2,20,1,71,
25,23,66,4,1,254,138,21,79,34,4,31,76,5,2,20,1,70,
25,24,66,3,1,4,68,1,118,34,42,31,25,6,14,254,138,21,
27,21,18,1,6,2,1,118,34,42,30,26,6,14,254,138,21,27,
21,18,3,0,0,0,0,2,0,119,0,47,5,161,5,123,0,3,
0,31,0,0,1,53,35,21,5,17,35,17,35,17,35,17,33,53,
33,53,33,53,33,17,51,17,51,17,51,17,33,21,33,21,33,21,
3,108,185,1,183,254,185,254,254,194,1,62,254,194,1,62,254,185,
254,1,55,254,201,1,55,2,84,240,240,240,254,203,1,53,254,203,
1,53,240,240,237,1,74,254,182,1,74,254,182,237,240,240,0,3,
0,20,255,101,3,248,6,1,0,38,0,45,0,53,0,0,1,51,
21,30,1,23,5,46,1,39,17,30,4,21,20,6,7,21,35,53,
46,3,39,55,22,23,22,23,17,36,17,52,54,55,19,17,14,1,
21,20,22,19,17,54,53,52,46,2,1,176,170,125,180,64,254,248,
31,34,40,71,100,119,74,50,220,194,168,79,141,102,71,21,246,52,
33,39,44,254,121,231,158,2,59,56,54,229,139,9,26,60,6,1,
133,10,123,116,82,46,30,10,254,176,24,42,75,86,131,80,165,227,
19,129,129,6,73,109,119,63,82,110,39,45,7,1,158,86,1,70,
147,198,9,253,248,1,26,7,80,36,66,69,254,181,254,151,31,139,
21,42,57,53,0,5,0,94,0,63,5,51,5,109,0,10,0,22,
0,33,0,45,0,49,0,0,1,20,22,50,54,53,52,38,35,34,
6,7,52,54,51,50,22,21,20,6,35,34,38,1,20,22,50,54,
53,52,38,35,34,6,7,52,54,51,50,22,21,20,6,35,34,38,
1,35,1,51,3,172,50,76,48,51,37,35,51,215,176,127,125,178,
178,125,127,176,254,96,50,76,48,51,37,34,52,215,177,126,127,178,
178,127,126,177,1,135,210,2,159,201,1,115,46,55,53,48,44,64,
64,45,131,183,183,130,128,180,179,3,65,46,54,52,48,44,65,65,
43,130,183,184,130,128,179,179,252,196,4,194,0,1,0,59,255,203,
4,160,5,240,0,49,0,0,1,46,1,35,34,6,21,20,22,59,
1,21,35,34,6,21,20,22,51,50,54,53,35,53,33,21,35,20,
14,3,35,34,46,1,53,16,55,46,3,53,52,54,51,50,22,23,
2,199,21,90,59,67,99,103,79,170,166,106,135,130,101,111,110,174,
2,74,158,34,75,108,162,96,131,225,136,239,29,61,62,40,252,185,
139,193,47,4,143,42,69,83,77,82,90,239,160,119,100,140,99,71,
217,215,51,109,111,87,55,113,205,126,1,73,108,12,45,70,104,59,
180,222,136,110,0,1,0,129,4,20,1,104,6,6,0,18,0,0,
19,3,52,54,59,1,50,22,23,22,21,3,14,1,35,34,38,39,
38,150,21,79,34,4,31,76,5,2,20,1,70,25,24,66,3,1,
4,68,1,118,34,42,30,26,6,14,254,138,21,27,21,18,3,0,
0,1,0,31,255,172,2,41,6,27,0,12,0,0,5,38,2,53,
16,1,33,6,2,21,20,18,23,1,33,145,113,1,2,1,8,133,
131,136,128,84,183,1,144,240,1,236,1,76,195,254,82,209,200,254,
86,187,0,1,0,80,255,160,2,90,6,13,0,12,0,0,5,33,
54,18,53,52,2,39,33,0,17,20,2,1,84,254,252,127,137,138,
126,1,5,1,5,118,96,185,1,181,201,192,1,188,186,254,176,254,
26,234,254,103,0,1,0,87,1,10,4,59,4,151,0,80,0,0,
1,55,50,22,29,1,20,6,7,6,35,39,23,22,21,20,6,7,
34,21,7,6,35,34,39,38,47,1,7,6,35,34,39,34,39,46,
1,53,52,55,54,63,1,7,34,38,61,1,52,54,55,54,51,23,
39,38,53,52,54,63,1,54,51,50,23,22,31,1,55,54,51,50,
31,1,30,1,21,20,7,6,7,2,251,244,34,42,30,26,6,14,
246,134,6,44,22,1,2,40,43,29,13,7,5,112,110,16,45,43,
32,1,2,23,48,2,1,7,133,243,34,42,30,26,6,14,248,136,
6,44,22,4,37,45,29,14,6,5,112,110,16,46,42,32,4,23,
47,1,3,6,3,53,14,79,34,4,31,76,5,2,13,205,12,13,
27,58,12,1,1,22,14,5,11,220,219,27,18,2,13,56,24,8,
3,9,10,205,14,79,34,4,31,76,5,2,13,206,12,13,27,58,
13,2,22,15,6,10,219,218,28,18,2,14,55,24,8,4,9,9,
0,0,0,1,0,68,0,233,3,93,4,38,0,11,0,0,19,33,
17,51,17,33,21,33,17,35,17,33,68,1,10,240,1,31,254,224,
239,254,246,2,248,1,46,254,210,240,254,225,1,31,0,1,0,56,
255,51,1,126,1,42,0,19,0,0,37,20,14,2,7,39,62,1,
53,52,39,46,1,53,52,54,51,50,22,1,126,42,62,54,21,74,
11,34,2,47,69,96,63,79,88,137,57,118,90,60,17,43,18,82,
22,5,6,11,85,70,60,101,101,0,0,1,0,98,2,2,3,102,
2,242,0,3,0,0,19,33,21,33,98,3,4,252,252,2,242,240,
0,0,0,1,0,64,255,223,1,136,1,39,0,8,0,0,55,52,
54,50,22,20,6,34,38,64,96,136,96,96,136,96,131,68,96,96,
136,96,97,0,0,0,0,1,255,214,0,0,3,113,6,8,0,3,
0,0,51,33,1,33,245,254,225,2,143,1,12,6,8,0,0,2,
0,80,255,228,4,65,5,210,0,14,0,31,0,0,19,16,0,51,
50,0,17,20,2,6,43,1,34,38,2,37,20,30,3,51,50,62,
2,53,16,38,35,34,6,80,1,14,240,239,1,4,117,230,157,1,
157,230,117,1,12,13,31,53,83,56,70,94,52,21,93,138,139,103,
2,244,1,89,1,133,254,125,254,165,230,254,159,201,201,1,96,231,
110,163,137,85,47,69,144,191,138,1,18,218,222,0,0,0,0,1,
0,229,0,0,3,2,5,176,0,7,0,0,1,53,33,63,1,33,
17,33,1,246,254,239,32,244,1,9,254,244,4,160,22,30,220,250,
80,0,0,1,0,92,0,0,4,37,5,212,0,36,0,0,1,39,
54,36,51,50,30,3,21,20,6,7,14,3,7,33,21,33,52,54,
55,62,5,53,52,38,35,34,6,1,102,238,29,1,10,152,64,120,
123,90,57,71,92,46,158,122,111,19,2,147,252,55,83,123,41,115,
95,99,68,43,106,86,82,101,4,52,71,145,200,25,64,99,161,102,
121,166,91,46,122,90,115,50,240,172,238,124,41,91,65,82,75,98,
55,102,109,86,0,0,0,1,0,93,255,228,4,76,5,210,0,45,
0,0,19,37,30,1,51,50,54,53,52,38,43,1,53,51,50,54,
53,52,38,35,34,6,7,39,18,33,50,30,2,21,20,7,30,3,
21,20,14,2,35,34,46,1,93,1,2,37,136,74,102,131,141,92,
165,142,75,110,109,82,59,89,19,250,108,1,52,89,154,127,74,145,
49,70,74,40,76,131,189,106,113,189,159,1,67,70,93,86,123,92,
91,131,213,119,71,96,103,66,45,66,1,26,45,90,156,103,172,104,
33,62,95,126,75,91,167,125,74,69,161,0,0,2,0,90,0,0,
4,58,5,176,0,10,0,13,0,0,1,51,21,35,17,33,17,33,
53,1,33,9,1,33,3,176,138,138,254,243,253,183,2,53,1,33,
254,251,254,177,1,79,2,73,237,254,164,1,92,204,3,136,254,161,
253,251,0,0,0,1,0,94,255,230,4,82,5,176,0,35,0,0,
1,34,7,37,19,33,21,33,3,54,51,50,30,1,16,14,1,35,
34,46,3,39,37,30,4,51,50,54,53,52,38,2,86,110,57,254,
255,118,2,171,254,43,55,38,109,143,230,135,135,230,143,90,159,111,
86,48,10,1,9,4,21,42,52,77,43,110,134,135,2,207,59,90,
2,194,239,254,221,22,119,224,254,224,224,119,53,83,107,101,48,46,
19,49,54,45,29,140,105,107,151,0,0,0,0,2,0,109,255,228,
4,43,5,176,0,11,0,33,0,0,1,52,38,35,34,6,21,20,
22,51,50,54,1,54,51,50,0,21,20,14,2,35,34,46,1,53,
52,62,2,55,1,33,3,30,120,94,92,115,122,87,94,118,254,250,
5,49,212,1,9,71,124,184,104,135,221,119,41,41,76,7,1,17,
1,31,1,173,96,135,137,90,97,128,135,2,42,5,254,246,207,84,
164,129,80,131,210,118,81,165,91,142,14,2,20,0,0,0,0,1,
0,98,0,0,4,134,5,176,0,5,0,0,9,1,33,1,33,53,
4,134,253,32,254,188,2,93,253,165,5,176,250,80,4,178,254,0,
0,0,0,3,0,68,255,228,4,88,5,209,0,11,0,22,0,55,
0,0,37,50,54,53,52,38,35,34,6,21,20,22,3,20,22,51,
50,54,53,52,38,34,6,19,50,4,21,20,14,5,7,30,1,21,
20,14,2,35,34,36,53,52,54,55,46,3,53,52,54,2,78,113,
141,153,101,120,134,140,83,104,93,89,107,101,194,98,195,206,1,5,
17,18,44,20,56,7,26,87,158,82,144,190,110,239,254,233,162,83,
29,53,66,40,253,193,134,106,104,139,135,108,106,134,3,134,87,85,
85,87,78,97,98,1,61,222,172,36,68,47,54,23,43,5,17,23,
215,131,111,178,113,59,254,207,127,222,20,17,42,72,103,59,178,216,
0,2,0,107,0,0,4,41,5,204,0,11,0,33,0,0,1,20,
22,51,50,54,53,52,38,35,34,6,1,6,35,34,0,53,52,62,
2,51,50,30,1,21,20,14,2,7,1,33,1,120,120,94,92,115,
122,87,94,118,1,6,5,49,212,254,247,71,124,184,104,135,221,119,
41,41,76,7,254,239,254,225,4,3,96,135,137,90,97,128,135,253,
214,5,1,10,207,84,164,129,80,131,210,118,81,165,91,142,14,253,
236,0,0,0,255,255,0,64,255,223,1,136,3,255,16,39,0,17,
0,0,2,216,16,6,0,17,0,0,255,255,0,64,255,51,1,136,
4,0,16,38,0,15,10,0,16,7,0,17,0,0,2,217,0,1,
0,45,0,24,3,27,4,213,0,5,0,0,37,9,1,33,9,1,
1,207,254,94,1,162,1,76,254,93,1,161,24,2,100,2,89,253,
164,253,159,0,0,0,0,2,0,55,1,53,3,88,3,147,0,3,
0,7,0,0,19,33,21,33,17,33,21,33,55,3,33,252,223,3,
33,252,223,2,37,240,2,94,239,0,0,1,0,55,0,20,3,39,
4,211,0,5,0,0,37,33,9,1,33,1,1,137,254,174,1,166,
254,90,1,83,1,157,20,2,100,2,91,253,169,0,0,2,0,47,
255,223,3,215,5,217,0,9,0,45,0,0,37,52,54,50,22,20,
6,35,34,38,1,21,33,53,52,62,5,53,52,46,1,35,34,6,
7,37,62,1,51,50,30,3,21,20,14,5,1,87,96,136,96,96,
68,67,97,1,40,254,244,37,58,70,71,58,37,62,85,51,79,103,
7,254,244,19,243,191,74,140,123,93,53,38,61,73,73,61,38,131,
68,96,96,136,96,97,1,210,131,195,49,84,62,57,57,61,82,48,
56,74,29,105,79,41,169,218,32,66,93,131,77,75,126,84,70,56,
54,65,0,2,0,79,255,223,6,124,5,215,0,58,0,70,0,0,
1,23,14,1,35,34,36,38,2,53,52,18,54,36,51,50,4,22,
18,21,20,6,35,34,38,39,6,35,34,38,53,52,54,51,50,22,
21,20,22,51,50,54,53,52,2,36,35,34,14,2,21,20,30,2,
51,50,54,1,20,22,51,50,54,53,52,38,35,34,6,4,200,112,
104,214,143,163,254,217,213,125,125,213,1,39,163,162,1,35,210,122,
187,118,56,110,36,85,193,166,237,237,166,163,220,56,37,41,61,152,
254,246,160,120,221,160,95,95,160,221,120,98,193,254,37,108,76,77,
93,102,68,75,109,1,4,147,74,72,119,202,1,28,159,158,1,28,
203,119,114,196,254,240,153,160,227,64,63,154,226,159,149,214,208,140,
56,98,98,70,152,1,3,152,94,160,220,120,121,221,160,94,76,2,
10,78,104,114,82,69,91,95,0,2,0,20,0,0,5,97,5,176,
0,2,0,11,0,0,1,3,33,3,1,33,3,48,33,3,33,1,
2,188,174,1,91,19,2,11,254,201,136,254,49,136,254,201,2,11,
4,100,254,9,3,67,250,80,1,126,254,130,5,176,0,3,0,115,
0,0,4,135,5,176,0,5,0,14,0,38,0,0,1,17,51,32,
16,33,3,17,51,50,54,53,52,38,35,37,33,50,30,5,21,20,
6,7,30,2,21,20,14,3,35,33,1,127,227,1,25,254,231,227,
168,138,118,119,137,254,76,1,180,93,154,106,82,48,30,11,115,94,
96,139,58,21,68,108,195,127,253,243,2,126,254,114,1,142,2,66,
254,174,97,70,71,100,240,28,45,65,67,79,67,35,109,135,29,23,
132,140,63,53,105,125,93,63,0,1,0,100,255,227,5,17,5,205,
0,44,0,0,1,46,2,35,34,14,3,21,20,30,3,51,50,54,
55,33,14,4,35,34,46,3,53,52,62,3,51,50,30,3,23,3,
234,14,72,126,75,74,116,74,48,20,20,48,74,117,73,110,154,23,
1,38,9,58,101,133,180,100,130,212,138,94,41,41,94,138,212,130,
101,180,132,102,58,9,3,201,67,121,88,61,100,138,142,78,77,141,
136,100,61,166,106,71,143,133,103,62,93,151,200,206,105,107,207,201,
151,93,63,104,135,143,71,0,0,0,0,2,0,115,0,0,4,172,
5,176,0,8,0,19,0,0,1,52,2,43,1,17,51,50,18,37,
20,2,4,35,33,17,33,50,4,18,3,145,214,177,139,139,179,212,
1,27,154,254,231,179,254,45,1,211,181,1,26,151,2,240,204,1,
5,252,47,1,23,233,213,254,169,196,5,176,190,254,192,0,0,0,
0,1,0,115,0,0,4,73,5,176,0,11,0,0,19,33,21,33,
17,33,21,33,17,33,21,33,115,3,214,253,54,2,139,253,117,2,
202,252,42,5,176,240,254,162,240,254,126,240,0,1,0,115,0,0,
4,73,5,176,0,9,0,0,19,33,21,33,17,33,21,33,17,33,
115,3,214,253,54,2,139,253,117,254,244,5,176,239,254,161,239,253,
141,0,0,1,0,90,255,229,5,8,5,217,0,44,0,0,5,34,
46,3,53,52,62,3,51,50,22,23,5,46,1,35,34,14,2,21,
20,30,2,51,50,62,3,53,33,53,33,21,20,14,3,2,201,132,
214,140,96,41,41,96,140,216,132,154,254,61,254,254,15,147,49,84,
136,80,42,42,80,134,84,71,109,63,40,14,254,209,2,69,35,86,
128,201,27,95,155,208,217,114,106,202,193,145,89,159,138,86,52,91,
90,146,171,88,99,190,162,100,48,73,100,89,46,240,146,101,188,182,
135,82,0,0,0,1,0,115,0,0,4,114,5,176,0,11,0,0,
19,33,17,33,17,33,17,33,17,33,17,33,115,1,12,1,229,1,
14,254,242,254,27,254,244,5,176,253,176,2,80,250,80,2,112,253,
144,0,0,1,0,143,0,0,1,155,5,176,0,3,0,0,51,17,
33,17,143,1,12,5,176,250,80,0,0,0,0,1,0,102,255,221,
4,104,5,176,0,20,0,0,19,33,16,51,50,62,2,53,17,33,
17,20,2,6,35,34,46,3,102,1,12,246,69,100,52,23,1,12,
112,234,166,105,171,119,81,38,2,74,254,131,66,114,127,74,3,102,
252,154,185,254,236,160,62,111,156,185,0,0,0,1,0,115,0,0,
5,10,5,176,0,11,0,0,19,33,17,1,33,9,1,33,1,7,
17,33,115,1,12,2,31,1,79,253,212,2,73,254,176,254,58,117,
254,244,5,176,253,145,2,111,253,120,252,216,2,116,132,254,16,0,
0,1,0,115,0,0,4,75,5,176,0,5,0,0,19,33,17,33,
21,33,115,1,12,2,204,252,40,5,176,251,64,240,0,1,0,115,
0,0,6,4,5,176,0,12,0,0,51,17,33,9,1,33,17,33,
17,1,33,1,17,115,1,104,1,94,1,100,1,103,254,244,254,200,
254,242,254,205,5,176,251,248,4,8,250,80,3,194,252,62,3,194,
252,62,0,1,0,115,0,0,4,192,5,176,0,9,0,0,51,17,
33,1,17,33,17,33,1,17,115,1,4,2,61,1,12,254,248,253,
199,5,176,252,84,3,172,250,80,3,205,252,51,0,0,2,0,100,
255,227,5,49,5,205,0,22,0,44,0,0,1,52,46,2,35,34,
14,3,21,20,30,3,51,50,62,3,37,52,62,3,32,30,3,21,
20,14,3,32,46,3,4,23,33,73,135,91,74,116,74,48,20,20,
48,74,117,73,74,117,73,48,20,252,77,41,94,138,212,1,4,212,
138,94,40,40,94,138,212,254,252,212,138,94,41,2,214,99,175,154,
91,61,100,138,142,78,77,141,136,100,61,61,100,136,141,77,107,207,
201,151,93,93,151,201,207,107,106,205,200,151,93,93,151,200,206,0,
0,0,0,2,0,115,0,0,4,79,5,176,0,13,0,32,0,0,
1,51,50,62,3,52,46,3,43,1,37,33,50,30,5,20,14,5,
35,17,33,1,127,71,79,105,100,57,34,34,57,100,105,79,71,254,
244,1,12,80,100,168,109,132,78,53,53,78,131,111,167,101,79,254,
244,3,56,7,23,43,71,104,71,43,23,7,240,3,17,32,64,90,
141,178,140,90,65,32,17,3,253,184,0,0,0,2,0,98,255,221,
5,56,5,215,0,23,0,50,0,0,1,52,46,1,35,34,14,2,
21,20,30,4,51,50,55,39,55,23,62,1,37,52,62,3,51,50,
30,3,21,20,6,7,23,7,39,14,1,35,34,46,3,4,23,67,
152,109,91,134,74,35,13,29,51,70,103,62,94,39,160,147,158,23,
33,252,75,39,93,138,217,134,125,207,137,95,42,72,53,136,150,133,
58,180,106,121,205,140,99,46,2,242,138,221,142,86,147,171,97,60,
119,126,107,86,49,37,118,197,131,43,204,79,95,194,200,154,98,87,
145,193,207,109,162,255,77,99,190,109,52,63,93,156,206,221,0,2,
0,115,255,255,4,134,5,175,0,13,0,36,0,0,1,51,50,62,
3,52,46,3,43,1,9,1,6,35,34,38,35,17,33,17,33,50,
30,5,21,20,6,7,1,1,127,71,79,105,100,57,34,34,57,100,
105,79,71,1,213,254,193,26,33,17,64,10,254,244,1,12,79,101,
167,111,131,78,53,153,152,1,104,3,56,7,23,42,72,102,72,43,
24,7,251,63,2,71,2,1,253,186,5,176,3,17,32,65,90,140,
89,152,201,40,253,141,0,1,0,83,255,227,4,102,5,212,0,50,
0,0,19,37,30,1,51,50,54,53,52,46,4,39,46,3,53,52,
62,2,51,50,4,23,5,38,35,34,6,21,20,30,3,23,30,4,
21,20,4,35,34,36,83,1,12,25,134,110,111,121,38,57,95,85,
126,45,60,82,85,44,81,138,171,95,168,1,1,44,254,239,49,147,
93,118,54,99,95,125,32,57,86,84,53,32,254,222,216,209,254,213,
1,148,43,101,133,106,85,46,75,49,49,32,50,21,29,53,85,120,
77,98,157,97,50,174,132,51,116,75,86,40,68,53,39,47,15,27,
52,75,85,116,69,197,236,239,0,0,0,1,0,78,0,0,5,0,
5,176,0,7,0,0,19,33,21,33,17,33,17,33,78,4,178,254,
55,254,244,254,35,5,176,240,251,64,4,192,0,0,0,1,0,115,
255,221,4,136,5,176,0,24,0,0,5,34,38,2,53,17,33,17,
20,30,2,51,50,62,3,53,17,33,17,20,2,6,2,125,166,239,
117,1,12,26,56,103,69,56,89,57,38,15,1,12,118,238,35,160,
1,21,184,3,102,252,154,73,128,114,66,45,73,101,105,57,3,102,
252,154,184,254,235,160,0,0,0,1,0,70,0,0,4,207,5,176,
0,6,0,0,1,33,1,33,1,33,1,3,185,1,22,254,95,254,
195,254,85,1,33,1,39,5,176,250,80,5,176,251,235,0,0,1,
0,74,0,0,6,10,5,176,0,12,0,0,19,33,27,1,33,27,
1,33,3,33,11,1,33,74,1,15,127,181,1,58,181,127,1,15,
238,254,192,178,178,254,192,5,176,252,66,3,163,252,87,3,196,250,
80,3,207,252,49,0,0,0,0,1,0,64,0,0,4,238,5,175,
0,11,0,0,19,33,9,1,33,9,1,33,9,1,33,1,67,1,
84,1,0,1,0,1,84,254,76,1,183,254,172,254,253,254,253,254,
172,1,183,5,175,254,37,1,219,253,43,253,38,1,224,254,32,2,
218,0,0,0,0,1,0,67,0,0,4,235,5,175,0,8,0,0,
19,33,9,1,33,1,17,33,17,67,1,84,1,0,1,0,1,84,
254,51,254,244,5,175,254,37,1,219,253,3,253,78,2,178,0,1,
0,72,0,0,5,26,5,176,0,7,0,0,19,33,1,33,21,33,
1,33,139,4,143,252,246,3,4,251,52,3,12,253,55,5,176,251,
64,240,4,192,0,0,0,1,0,121,255,158,2,111,5,252,0,7,
0,0,5,33,17,33,21,35,17,51,2,111,254,10,1,246,248,248,
98,6,94,240,251,127,0,1,255,217,0,0,3,127,6,7,0,3,
0,0,33,1,33,1,2,73,253,144,1,36,2,130,6,7,249,249,
0,0,0,1,0,119,255,158,2,107,5,252,0,7,0,0,23,53,
51,17,35,53,33,17,119,246,246,1,244,98,239,4,127,240,249,162,
0,0,0,1,0,122,4,124,3,158,5,212,0,6,0,0,1,33,
39,7,33,1,51,3,158,254,241,132,124,254,235,1,28,236,4,124,
161,158,1,85,0,0,0,1,0,78,254,231,4,143,255,215,0,3,
0,0,19,53,33,21,78,4,65,254,231,240,240,0,0,0,0,1,
0,77,5,248,2,11,7,153,0,33,0,0,1,37,38,39,38,53,
52,55,54,55,54,55,54,55,54,51,50,23,5,22,23,22,21,20,
7,6,7,6,7,6,7,6,35,34,1,150,254,205,15,4,3,4,
7,18,16,19,20,23,11,8,17,11,1,27,5,2,2,5,9,12,
12,19,18,18,8,2,7,5,253,213,11,19,12,14,18,16,31,21,
19,14,15,6,3,10,247,4,9,10,8,16,15,30,15,15,16,15,
5,2,0,2,0,90,255,227,3,210,4,78,0,8,0,44,0,0,
0,34,6,20,22,51,50,54,52,1,50,22,23,53,52,46,3,35,
34,14,1,7,39,62,1,51,50,30,3,21,25,1,33,53,14,1,
35,34,38,16,54,2,111,176,115,114,89,88,104,254,235,99,150,20,
33,50,69,61,34,46,89,42,39,103,45,194,80,82,143,132,94,55,
254,255,21,147,99,153,211,210,2,12,101,134,98,97,136,1,61,101,
64,82,59,88,51,31,10,19,17,17,164,36,58,31,74,111,170,107,
254,208,254,207,136,64,101,222,1,74,218,0,0,2,0,119,255,228,
4,39,5,174,0,19,0,38,0,0,41,1,17,33,17,62,1,51,
50,30,2,20,14,2,35,34,38,39,1,52,46,2,34,14,2,21,
20,30,2,51,50,62,2,1,121,254,254,1,2,52,168,87,96,148,
90,45,46,90,148,95,86,169,52,1,170,38,64,71,78,74,68,41,
41,68,74,39,36,73,64,39,5,174,253,231,82,101,91,159,201,234,
199,155,89,103,82,1,124,88,132,74,35,33,71,135,90,91,135,72,
33,42,78,131,0,0,0,1,0,86,255,227,3,211,4,76,0,30,
0,0,1,38,35,34,6,21,20,22,51,50,62,6,55,23,14,1,
35,34,0,17,52,0,51,50,22,23,2,254,65,115,99,139,149,109,
20,33,24,24,12,18,6,17,2,214,59,192,119,239,254,231,1,26,
218,116,219,58,2,244,114,191,147,146,183,6,7,18,9,27,9,33,
3,111,98,135,1,50,0,255,252,1,60,127,105,0,0,0,0,2,
0,74,255,228,3,250,5,174,0,19,0,38,0,0,33,53,14,1,
35,34,46,2,52,62,2,51,50,22,23,17,33,17,1,20,30,2,
51,50,62,2,53,52,46,2,34,14,2,2,248,52,169,86,95,148,
90,46,45,90,148,96,87,168,52,1,2,253,84,39,64,73,36,39,
74,68,41,41,68,74,78,71,64,38,157,82,103,89,155,199,234,201,
159,91,101,82,2,25,250,82,2,25,80,131,78,42,33,72,135,91,
90,135,71,33,35,74,132,0,0,0,0,2,0,88,255,227,4,2,
4,74,0,6,0,32,0,0,1,33,46,1,35,34,6,19,50,55,
23,14,1,35,34,46,2,53,52,0,51,50,22,18,29,1,33,30,
4,1,107,1,157,7,110,90,89,111,209,99,55,228,62,214,106,99,
180,133,78,1,24,201,132,209,116,253,104,1,32,46,60,51,2,139,
90,127,129,253,230,66,98,94,104,86,148,212,120,240,1,65,145,255,
0,160,68,65,101,56,35,11,0,0,0,1,0,74,0,0,3,22,
5,209,0,24,0,0,1,17,33,17,35,53,51,53,52,62,2,51,
50,23,7,46,1,35,34,6,29,1,51,21,1,215,254,254,139,139,
55,91,133,71,136,91,149,16,53,19,43,39,165,3,76,252,180,3,
76,229,80,50,117,102,67,89,179,19,20,42,45,100,229,0,0,0,
0,2,0,74,254,51,3,250,4,76,0,36,0,55,0,0,5,53,
14,1,35,34,46,2,52,62,2,51,50,22,23,53,33,17,20,14,
2,35,34,46,3,39,54,55,30,1,50,54,1,20,30,2,51,50,
62,2,53,52,46,2,34,14,2,2,248,52,169,86,95,148,90,46,
45,90,148,96,87,168,52,1,2,60,113,181,112,89,149,99,71,35,
5,148,95,9,101,188,115,254,86,39,64,73,36,39,74,68,41,41,
68,74,78,71,64,38,70,227,82,103,89,155,199,234,201,159,91,101,
82,156,251,157,81,146,116,68,48,75,98,94,47,7,4,67,82,89,
2,173,80,131,78,42,33,72,135,91,90,135,71,33,35,74,132,0,
0,0,0,1,0,119,0,0,3,246,5,174,0,26,0,0,41,1,
17,33,17,62,1,51,50,30,2,21,17,33,17,52,46,2,35,34,
14,3,21,1,121,254,254,1,2,45,175,103,55,109,93,57,254,254,
25,50,61,44,35,55,53,35,21,5,174,253,226,82,108,57,105,170,
102,253,100,2,25,100,134,69,27,16,44,72,119,80,0,2,0,121,
0,0,1,159,5,214,0,7,0,11,0,0,18,52,54,50,22,20,
6,34,7,33,17,33,121,87,120,87,87,120,69,1,2,254,254,4,
245,130,95,95,130,95,101,251,207,0,0,0,0,2,255,20,254,80,
1,159,5,214,0,7,0,24,0,0,18,52,54,50,22,20,6,34,
1,55,30,1,51,50,54,53,17,33,17,20,14,1,35,34,38,121,
87,120,87,87,120,254,68,169,12,52,26,50,66,1,2,111,179,95,
83,113,4,245,130,95,95,130,95,250,29,172,17,25,63,48,4,141,
251,172,100,185,112,40,0,1,0,119,0,0,3,228,5,174,0,11,
0,0,9,1,33,1,7,17,33,17,33,17,1,33,2,66,1,162,
254,218,254,201,14,254,254,1,2,1,25,1,59,2,85,253,171,1,
211,23,254,68,5,174,253,30,1,101,0,0,0,1,0,139,255,227,
1,234,5,174,0,8,0,0,1,20,51,21,34,38,53,17,33,1,
141,93,185,166,1,2,1,25,87,223,134,171,4,154,0,0,0,1,
0,119,0,0,5,190,4,78,0,40,0,0,41,1,17,52,38,35,
34,6,21,17,33,17,33,21,62,3,51,50,30,3,31,1,62,2,
51,50,22,21,17,33,17,52,38,34,6,21,3,156,254,254,64,81,
82,62,254,254,1,2,17,49,68,89,46,48,80,49,39,16,7,7,
26,80,124,60,132,156,254,254,63,162,63,2,27,163,166,165,164,253,
229,4,49,158,30,59,61,37,34,47,64,48,23,24,52,103,85,225,
209,253,100,2,27,163,166,166,163,0,0,1,0,119,0,0,3,246,
4,78,0,26,0,0,41,1,17,33,21,62,1,51,50,30,2,21,
17,33,17,52,46,2,35,34,14,3,21,1,121,254,254,1,2,45,
175,103,55,109,93,57,254,254,25,50,61,44,35,55,53,35,21,4,
50,162,82,108,57,105,170,102,253,100,2,25,100,134,69,27,16,44,
72,119,80,0,0,2,0,92,255,227,4,12,4,76,0,5,0,15,
0,0,1,16,32,17,16,32,3,16,18,32,18,16,2,35,34,2,
1,88,1,188,254,68,252,248,1,194,246,246,225,226,247,2,25,254,
181,1,75,1,73,254,183,1,4,1,47,254,210,253,246,254,207,1,
46,0,0,0,0,2,0,119,254,86,4,39,4,76,0,19,0,38,
0,0,1,33,17,33,21,62,1,51,50,30,2,20,14,2,35,34,
38,39,1,52,46,2,34,14,2,21,20,30,2,51,50,62,2,1,
121,254,254,1,2,52,168,87,96,148,90,45,46,90,148,95,86,169,
52,1,170,38,64,71,78,74,68,41,41,68,74,39,36,73,64,39,
254,86,5,219,156,82,101,91,159,201,234,199,155,89,103,82,1,124,
88,132,74,35,33,71,135,90,91,135,72,33,42,78,131,0,0,2,
0,74,254,63,4,101,4,76,0,25,0,44,0,0,5,17,14,1,
35,34,46,2,52,62,2,51,50,22,23,53,33,17,20,22,51,21,
34,38,1,20,30,2,51,50,62,2,53,52,46,2,34,14,2,2,
248,52,169,86,95,148,90,46,45,90,148,96,87,168,52,1,2,41,
66,182,183,254,86,39,64,73,36,39,74,68,41,41,68,74,78,71,
64,38,141,1,42,82,103,89,155,199,234,201,159,91,101,82,156,251,
70,44,30,238,148,3,70,80,131,78,42,33,72,135,91,90,135,71,
33,35,74,132,0,1,0,122,0,0,3,65,4,78,0,18,0,0,
1,38,35,34,14,2,21,17,33,17,33,21,62,1,51,50,22,23,
2,224,108,48,55,82,43,20,254,254,1,2,42,146,61,50,111,43,
3,39,61,58,97,104,56,253,215,4,49,161,80,110,53,41,0,0,
0,1,0,78,255,227,3,117,4,76,0,46,0,0,1,46,3,53,
52,54,51,50,22,23,7,46,1,35,34,6,21,20,30,2,23,30,
1,21,20,6,35,34,38,39,55,30,1,51,50,62,2,53,52,46,
3,1,86,61,69,62,26,201,169,157,204,19,240,11,68,57,60,66,
50,65,130,48,115,105,235,165,162,213,32,232,11,98,64,35,48,47,
24,33,65,67,97,1,235,32,48,73,97,69,133,157,180,119,43,65,
47,36,51,33,48,25,50,23,56,152,126,129,170,172,147,39,60,68,
6,18,40,30,27,45,36,29,41,0,0,1,0,72,255,241,2,113,
5,43,0,20,0,0,19,35,53,51,53,33,21,51,21,35,17,20,
59,1,21,35,34,46,2,53,213,141,141,1,2,154,154,111,39,39,
107,143,84,35,3,76,229,250,250,229,253,221,95,217,37,79,111,81,
0,0,0,1,0,108,255,227,3,235,4,49,0,25,0,0,41,1,
53,14,1,35,34,2,25,1,33,17,20,30,3,51,50,62,3,53,
17,33,3,235,254,254,45,173,99,148,172,1,2,23,35,49,47,26,
27,50,54,41,26,1,3,161,81,109,1,31,1,21,2,26,253,231,
79,121,71,44,15,16,44,71,121,79,2,24,0,0,0,1,0,72,
0,0,3,195,4,49,0,6,0,0,33,1,33,27,1,51,1,1,
155,254,173,1,15,180,193,247,254,173,4,49,253,82,2,174,251,207,
0,1,0,57,0,0,5,105,4,53,0,12,0,0,1,3,35,1,
33,27,1,51,27,1,51,1,35,2,203,142,201,254,197,0,255,168,
130,232,130,170,243,254,197,219,2,152,253,104,4,49,253,99,2,161,
253,98,2,154,251,207,0,1,0,27,0,0,4,2,4,49,0,11,
0,0,41,1,11,1,33,9,1,33,27,1,33,1,3,253,254,205,
190,190,254,205,1,85,254,189,1,34,190,187,1,58,254,166,1,79,
254,177,2,24,2,25,254,182,1,74,253,240,0,1,0,108,254,47,
3,235,4,49,0,40,0,0,5,20,14,2,35,34,38,39,55,30,
1,51,50,54,61,1,14,1,35,34,2,25,1,33,17,20,30,3,
51,50,62,3,53,17,33,17,3,235,80,126,163,79,149,219,47,204,
19,107,79,84,112,45,173,99,148,172,1,2,23,35,49,47,26,27,
50,54,41,26,1,3,29,79,160,121,76,140,101,112,54,67,94,80,
220,81,109,1,31,1,21,2,26,253,231,79,121,71,44,15,16,44,
71,121,79,2,24,251,236,0,0,0,0,1,0,66,0,0,3,153,
4,49,0,7,0,0,37,33,21,33,1,33,53,33,1,227,1,150,
252,201,1,180,254,125,3,38,240,240,3,66,239,0,0,1,0,80,
255,154,2,133,6,25,0,31,0,0,19,62,4,55,54,55,54,55,
21,34,6,21,16,7,22,17,20,22,51,21,38,39,38,39,46,4,
80,69,84,28,10,12,16,45,115,48,138,86,72,133,133,72,86,152,
53,99,42,16,12,10,28,84,2,217,23,141,182,179,160,30,84,21,
8,4,213,64,88,254,103,58,56,254,101,88,63,213,3,12,23,78,
30,161,179,182,141,0,0,1,0,115,0,0,1,102,5,174,0,3,
0,0,51,17,51,17,115,243,5,174,250,82,0,1,0,121,255,154,
2,174,6,25,0,35,0,0,1,14,4,7,14,4,7,34,35,53,
50,54,53,16,55,38,17,52,38,35,53,22,23,22,23,30,4,2,
174,69,84,28,10,12,16,17,52,58,78,75,49,11,6,86,72,133,
133,72,86,151,52,101,42,16,12,10,28,84,2,217,22,141,182,179,
161,30,32,44,24,12,3,1,213,63,88,1,155,56,58,1,153,88,
64,213,4,11,23,79,30,160,179,182,141,0,0,1,0,53,2,0,
2,178,3,143,0,31,0,0,19,62,4,51,50,30,3,51,50,62,
1,55,17,14,3,35,34,46,2,34,14,2,7,53,6,43,27,42,
43,22,27,58,51,51,60,29,32,77,33,36,5,51,33,60,29,39,
83,60,70,54,52,31,56,14,3,40,5,38,20,27,13,31,45,45,
31,43,30,34,254,252,4,43,23,24,48,56,48,20,21,46,10,0,
0,2,255,199,255,227,1,15,5,207,0,13,0,23,0,0,19,52,
54,51,50,22,21,19,20,6,35,34,38,53,1,20,6,34,38,52,
54,51,50,22,8,72,27,29,71,41,96,43,44,97,1,47,96,136,
96,96,68,67,97,3,246,23,36,36,23,252,75,37,57,57,35,4,
236,68,96,96,136,96,97,0,0,1,0,70,0,78,2,223,4,184,
0,37,0,0,1,46,1,53,52,62,2,55,53,51,21,30,1,23,
7,35,34,46,1,35,34,6,21,20,22,51,50,62,2,55,23,14,
1,7,21,35,1,57,104,139,45,72,81,39,230,42,116,37,159,1,
1,28,57,38,56,79,72,61,30,46,14,36,2,161,42,102,48,230,
1,37,17,182,139,70,124,84,56,11,232,231,9,80,51,128,25,26,
80,51,61,89,15,8,40,2,136,52,67,4,207,0,0,0,0,1,
0,74,0,0,4,176,5,195,0,39,0,0,1,35,53,51,16,18,
51,50,22,23,7,46,1,35,34,14,2,29,2,33,21,33,14,3,
7,33,50,54,55,23,6,35,33,62,2,1,38,220,237,174,207,125,
169,55,230,14,51,54,32,48,26,13,1,101,254,157,2,21,11,26,
17,1,207,29,51,13,146,70,172,252,201,10,80,63,2,37,229,1,
93,1,92,162,175,22,61,70,58,92,97,48,106,68,229,10,134,51,
91,32,49,28,152,156,38,209,214,0,0,2,0,53,1,49,3,166,
4,168,0,11,0,44,0,0,1,20,22,51,50,54,53,52,38,35,
34,6,19,6,35,34,39,21,33,17,51,38,53,52,55,35,17,33,
21,54,51,50,22,23,53,33,17,35,22,21,20,7,51,17,33,1,
137,61,40,38,58,58,38,42,59,207,40,66,68,39,254,178,111,21,
17,107,1,78,42,65,17,74,15,1,78,111,17,21,115,254,178,2,
240,43,54,59,38,43,57,56,254,140,18,16,117,1,78,51,60,62,
46,1,78,108,19,11,8,108,254,178,66,42,43,68,254,178,0,1,
0,45,0,0,4,45,5,117,0,22,0,0,1,33,53,51,1,33,
27,1,33,1,51,21,33,21,33,21,33,17,33,17,33,53,33,1,
164,254,235,170,254,244,1,27,231,248,1,6,254,226,155,254,252,1,
4,254,252,254,254,254,235,1,21,2,123,229,2,21,254,3,1,253,
253,235,229,121,229,254,227,1,29,229,0,2,0,80,0,0,1,68,
5,154,0,3,0,7,0,0,1,17,35,17,53,17,51,17,1,68,
244,244,2,154,253,102,2,154,102,2,154,253,102,0,0,2,0,33,
0,57,2,154,5,61,0,42,0,55,0,0,1,54,51,50,30,2,
21,20,14,1,35,34,38,39,55,30,1,59,1,50,54,55,6,35,
34,46,2,53,52,62,1,51,50,22,23,7,46,2,35,34,19,52,
38,35,34,7,20,22,51,50,22,51,50,1,23,13,17,66,129,100,
62,86,152,88,91,144,58,215,4,51,15,4,32,44,7,19,25,64,
121,98,59,76,145,90,95,117,68,214,2,30,25,5,53,118,69,49,
17,9,76,42,1,5,2,18,3,237,9,70,120,175,97,128,228,139,
120,136,43,30,39,65,52,19,60,112,184,113,126,222,139,107,135,50,
21,31,11,253,248,85,144,11,83,150,1,0,0,2,0,67,6,57,
3,98,7,129,0,10,0,21,0,0,19,52,54,50,22,20,6,35,
34,39,38,37,52,54,50,22,20,6,35,34,39,38,67,96,136,96,
96,68,67,49,48,1,215,96,136,96,96,68,67,49,48,6,221,68,
96,96,136,96,49,48,67,68,96,96,136,96,49,48,0,0,0,3,
255,178,0,193,3,236,5,18,0,12,0,32,0,42,0,0,3,52,
62,1,32,30,1,16,14,1,32,46,1,5,6,35,34,38,52,54,
51,50,23,7,38,34,6,21,20,22,51,50,55,36,16,22,51,50,
54,16,38,35,34,78,145,249,1,38,249,145,145,249,254,218,249,145,
2,220,83,101,106,148,148,106,111,73,113,34,76,56,56,38,44,32,
254,67,216,153,154,216,216,154,153,2,233,151,254,148,148,255,254,212,
254,148,148,254,16,83,149,212,148,73,117,29,56,38,39,56,27,222,
254,204,218,218,1,52,218,0,0,2,0,30,4,36,2,12,6,138,
0,12,0,57,0,0,1,34,6,21,20,23,22,51,50,55,54,52,
38,23,7,6,35,34,38,53,52,55,54,51,50,31,1,39,46,1,
39,38,39,38,35,34,7,6,15,1,39,55,54,55,54,51,50,23,
22,23,22,23,22,23,22,21,17,35,1,21,34,42,21,20,36,33,
19,18,36,34,9,42,58,87,120,59,60,86,59,42,5,3,6,18,
13,17,10,18,10,23,17,23,5,50,75,18,24,55,52,44,52,30,
43,33,35,28,26,16,15,178,5,56,36,23,22,18,17,17,17,46,
36,241,6,29,126,92,94,60,62,29,3,9,17,18,6,7,1,2,
4,5,2,21,119,14,19,17,15,7,10,19,20,32,31,48,47,56,
254,182,0,0,0,2,0,51,2,24,3,39,4,94,0,5,0,11,
0,0,1,51,3,19,35,11,1,51,3,19,35,3,2,80,215,192,
192,215,193,159,219,192,188,215,189,4,94,254,221,254,221,1,35,1,
35,254,221,254,221,1,35,0,0,0,0,1,0,143,1,94,3,236,
3,174,0,5,0,0,1,35,17,33,53,33,3,236,230,253,137,3,
93,1,94,1,92,244,255,255,0,88,2,174,3,92,3,158,16,7,
0,16,255,246,0,172,0,0,0,4,0,84,1,165,4,113,5,240,
0,18,0,39,0,50,0,71,0,0,1,20,30,2,50,62,2,53,
52,46,2,35,34,14,2,7,52,62,3,51,50,30,2,21,20,14,
1,35,34,46,3,37,50,22,51,50,54,53,52,38,43,1,39,51,
50,22,21,20,14,7,7,23,35,47,1,21,35,1,27,61,98,113,
114,114,95,60,65,101,109,51,58,114,97,60,199,65,108,138,145,72,
106,192,143,84,153,239,133,75,148,137,105,63,1,222,6,27,8,48,
26,39,54,22,140,140,123,127,3,8,6,16,6,22,6,27,2,95,
151,71,27,140,3,195,85,136,81,42,47,85,133,79,88,143,84,44,
45,85,142,87,111,188,127,90,41,84,146,209,118,156,252,134,43,90,
126,179,123,1,19,39,38,20,133,89,102,17,29,24,17,17,9,14,
4,14,1,182,167,5,171,0,0,0,0,1,0,98,6,150,3,102,
7,21,0,3,0,0,19,33,21,33,98,3,4,252,252,7,21,127,
0,0,0,2,255,239,3,98,2,106,5,210,0,9,0,17,0,0,
19,20,22,50,54,53,52,38,34,14,1,16,54,32,22,16,6,32,
156,84,122,83,83,122,84,173,186,1,8,185,185,254,248,4,154,63,
87,87,63,62,88,88,192,1,4,182,182,254,252,182,0,0,255,255,
0,129,0,192,3,154,5,69,16,39,0,14,0,61,1,31,16,7,
0,16,0,33,254,190,0,0,0,1,0,72,3,117,2,85,6,135,
0,57,0,0,19,39,55,54,55,54,51,50,23,22,23,22,23,22,
23,22,21,20,7,6,7,6,15,1,6,7,6,7,33,21,33,53,
52,55,54,55,54,55,54,55,54,55,54,55,54,55,54,55,54,55,
54,53,52,38,34,7,6,7,239,156,4,17,71,72,83,28,38,33,
33,34,25,26,15,15,19,20,48,24,21,70,51,16,19,7,1,59,
253,243,5,5,11,13,20,24,31,16,35,32,21,24,24,21,18,16,
9,9,42,68,20,18,13,5,138,47,17,82,53,54,7,6,18,19,
26,28,43,44,54,66,44,46,48,24,15,53,39,17,20,9,160,20,
40,37,36,33,40,29,35,31,16,28,25,15,16,20,17,20,18,20,
21,24,43,42,17,15,42,0,0,1,0,48,3,117,2,86,6,148,
0,64,0,0,19,55,23,22,23,22,51,50,55,54,53,52,39,38,
43,1,53,51,50,55,54,53,52,39,38,35,34,7,6,15,1,39,
55,54,51,50,22,23,22,23,22,21,20,7,30,1,23,22,23,22,
21,20,7,6,7,6,7,6,35,34,39,38,39,38,39,48,167,7,
17,28,29,31,44,26,27,30,28,39,103,92,27,23,22,21,23,32,
23,17,18,7,6,164,8,58,169,47,84,35,33,22,21,59,9,34,
18,21,10,11,21,21,35,37,49,52,56,57,54,49,45,41,25,4,
70,45,16,41,18,18,25,25,38,35,28,27,146,25,23,28,40,19,
21,13,13,18,16,43,21,154,24,25,23,46,44,55,84,53,7,30,
24,28,32,36,39,51,45,46,33,35,19,20,19,17,45,41,67,0,
0,0,0,1,0,78,5,248,2,12,7,153,0,32,0,0,19,6,
35,34,39,38,39,46,1,39,38,53,52,55,54,55,37,54,51,50,
23,22,23,22,23,22,23,22,21,20,7,6,7,195,7,6,2,8,
18,18,19,24,9,6,2,2,6,1,26,11,18,9,10,23,20,19,
16,17,7,4,3,5,13,5,253,5,2,5,15,16,30,30,20,14,
5,10,8,5,247,10,3,6,15,14,19,20,32,16,18,14,12,20,
10,0,0,1,0,143,254,115,3,238,3,121,0,23,0,0,37,17,
35,17,51,17,20,30,2,51,50,54,53,17,51,17,35,53,14,1,
35,34,38,1,131,244,248,40,63,63,29,67,109,244,244,24,105,41,
55,130,78,254,37,5,6,254,90,72,108,56,26,173,89,1,166,252,
135,84,52,61,66,0,0,4,0,111,0,0,4,116,5,161,0,7,
0,26,0,32,0,48,0,0,1,17,50,22,51,17,34,6,7,14,
8,21,20,30,5,23,19,51,17,34,38,35,3,17,46,4,53,52,
62,3,51,33,17,2,223,5,138,5,5,138,248,2,28,11,28,14,
23,13,13,6,9,22,17,34,16,37,3,243,148,6,137,5,243,66,
98,106,67,44,95,154,199,208,101,1,16,4,197,254,86,14,1,192,
8,77,1,12,6,14,11,16,17,21,25,13,23,40,30,22,20,9,
16,1,253,150,1,80,5,253,198,2,106,18,37,63,79,119,74,84,
145,100,71,33,250,95,255,255,0,93,2,90,1,165,3,162,16,7,
0,17,0,29,2,123,0,0,0,1,0,57,254,147,1,159,0,74,
0,27,0,0,23,62,8,53,52,46,1,39,55,22,21,20,14,3,
7,14,2,7,57,3,26,11,26,14,21,12,13,5,3,20,20,162,
108,34,38,80,35,43,3,4,6,2,238,1,15,7,15,10,16,12,
14,14,7,22,25,43,21,90,96,111,30,60,40,53,19,22,2,2,
3,1,0,1,0,49,3,117,1,134,6,117,0,5,0,0,19,35,
55,51,17,35,216,167,181,160,174,5,208,165,253,0,0,0,0,2,
255,239,3,98,2,106,5,210,0,11,0,21,0,0,19,20,22,50,
55,54,52,39,38,34,7,14,1,16,55,54,32,22,16,6,32,39,
156,84,122,42,41,41,42,122,42,42,173,93,92,1,10,184,184,254,
246,92,4,154,62,88,44,42,128,42,44,44,43,193,1,4,91,91,
182,254,252,182,91,0,0,2,0,127,2,25,3,115,4,95,0,5,
0,11,0,0,1,19,3,35,19,3,37,19,3,35,19,3,1,86,
193,193,215,192,192,2,55,189,189,215,188,192,4,95,254,220,254,222,
1,34,1,35,1,254,220,254,222,1,34,1,35,0,0,0,0,4,
0,31,255,28,4,181,6,117,0,10,0,13,0,19,0,23,0,0,
37,51,21,35,21,35,53,33,53,1,51,3,7,51,1,35,55,51,
17,35,19,35,1,51,4,112,69,69,174,254,219,1,35,176,170,111,
111,253,0,167,181,160,174,62,210,3,181,201,104,158,174,174,128,1,
210,254,249,171,5,102,165,253,0,251,251,6,204,0,0,3,0,31,
255,28,4,184,6,117,0,5,0,63,0,67,0,0,19,35,55,51,
17,35,1,39,55,54,55,54,51,50,23,22,23,22,23,22,23,22,
21,20,7,6,7,6,15,1,6,7,6,7,33,21,33,53,52,55,
54,55,54,55,54,55,54,55,54,55,54,55,54,55,54,55,54,53,
52,38,34,7,6,7,1,35,1,51,198,167,181,160,174,2,140,156,
4,17,71,72,83,27,39,33,33,34,25,24,16,16,19,20,48,24,
21,70,51,16,19,7,1,59,253,244,4,5,11,13,20,24,31,16,
35,32,21,24,24,21,18,16,9,9,42,68,20,18,13,253,172,210,
3,181,201,5,208,165,253,0,253,188,47,17,82,53,54,7,6,18,
19,26,26,45,46,53,65,44,46,48,24,15,53,39,17,20,9,160,
20,48,29,36,33,40,29,35,31,16,28,25,15,17,19,17,20,18,
20,21,23,44,42,17,15,42,254,44,6,204,0,0,0,4,0,29,
255,28,4,253,6,148,0,63,0,74,0,77,0,81,0,0,19,55,
23,22,23,22,51,50,54,53,52,39,38,43,1,53,51,50,55,54,
53,52,39,38,35,34,7,6,15,1,39,55,54,51,50,22,23,22,
23,22,21,20,7,30,1,23,22,23,22,21,20,7,6,7,6,7,
6,35,34,39,38,39,38,39,1,51,21,35,21,35,53,33,53,1,
51,3,7,51,5,35,1,51,29,167,7,17,28,28,32,44,52,29,
28,39,102,90,28,23,22,21,23,31,24,17,18,7,6,164,8,58,
169,47,84,35,33,22,21,59,9,34,18,21,10,10,20,21,35,37,
49,52,56,57,54,49,45,41,25,4,147,69,69,174,254,219,1,35,
176,170,111,111,253,62,210,3,181,201,4,70,45,16,41,18,18,50,
38,36,27,27,146,25,23,28,40,19,21,13,13,18,16,43,21,154,
24,25,23,46,44,55,84,53,7,30,24,28,32,33,42,53,43,46,
33,35,19,20,19,17,45,41,67,252,54,158,174,174,128,1,210,254,
249,171,250,6,204,0,0,2,255,213,255,221,3,125,5,215,0,35,
0,45,0,0,1,53,33,21,20,14,5,21,20,30,1,51,50,54,
55,5,14,1,35,34,46,3,53,52,62,5,1,20,6,34,38,52,
54,51,50,22,1,45,1,12,37,58,70,71,58,37,62,85,51,79,
103,7,1,12,19,243,191,74,140,123,93,53,38,61,73,73,61,38,
1,40,96,136,96,96,68,67,97,3,164,131,195,49,84,62,57,57,
61,82,48,56,74,29,105,79,41,169,218,32,66,93,131,77,75,126,
84,70,56,54,65,1,181,68,96,96,136,96,97,0,0,0,255,255,
0,20,0,0,5,97,7,153,16,38,0,36,0,0,16,7,0,67,
1,89,0,0,255,255,0,20,0,0,5,97,7,153,16,38,0,36,
0,0,16,7,0,117,2,18,0,0,255,255,0,20,0,0,5,97,
7,112,16,39,0,65,0,178,1,156,16,6,0,36,0,0,255,255,
0,20,0,0,5,97,7,125,16,39,0,97,1,72,3,238,16,6,
0,36,0,0,255,255,0,20,0,0,5,97,7,35,16,39,0,105,
0,236,255,162,16,6,0,36,0,0,255,255,0,20,0,0,5,97,
8,48,16,39,0,113,1,150,2,94,16,6,0,36,0,0,0,2,
0,10,0,0,5,193,5,176,0,15,0,18,0,0,1,33,3,33,
1,33,21,33,17,33,21,33,17,33,21,33,17,3,51,3,51,254,
234,233,254,214,2,64,3,119,254,124,1,132,254,123,1,133,253,114,
198,198,2,84,253,172,5,176,253,254,149,250,254,172,250,5,6,254,
65,0,255,255,0,110,254,38,5,27,5,205,16,39,0,121,1,190,
255,147,16,6,0,38,10,0,255,255,0,115,0,0,4,73,7,153,
16,38,0,40,0,0,16,7,0,67,1,44,0,0,255,255,0,115,
0,0,4,73,7,153,16,38,0,40,0,0,16,7,0,117,1,184,
0,0,255,255,0,115,0,0,4,73,7,89,16,39,0,65,0,123,
1,133,16,6,0,40,0,0,255,255,0,115,0,0,4,73,7,55,
16,39,0,105,0,184,255,182,16,6,0,40,0,0,255,255,255,216,
0,0,1,155,7,153,16,38,0,44,0,0,16,6,0,67,139,0,
0,0,255,255,0,143,0,0,2,78,7,153,16,38,0,44,0,0,
16,6,0,117,66,0,0,0,255,255,255,126,0,0,2,162,7,89,
16,39,0,65,255,4,1,133,16,6,0,44,0,0,255,255,255,133,
0,0,2,164,7,70,16,39,0,105,255,66,255,197,16,6,0,44,
0,0,0,2,0,135,0,0,5,77,5,176,0,16,0,28,0,0,
1,35,53,51,17,33,50,30,1,18,16,2,14,1,43,2,1,17,
51,50,18,16,2,43,1,17,51,21,1,4,125,125,1,180,147,250,
169,95,97,171,248,145,225,211,1,12,168,172,222,223,171,169,247,2,
100,239,2,93,114,196,254,244,254,210,254,244,195,113,2,100,254,143,
1,14,1,172,1,14,254,152,239,0,0,0,255,255,0,115,0,0,
4,192,7,104,16,39,0,97,1,12,3,217,16,6,0,49,0,0,
255,255,0,100,255,227,5,49,9,36,16,39,0,67,1,68,1,139,
16,6,0,50,0,0,255,255,0,100,255,227,5,49,7,153,16,38,
0,50,0,0,16,7,0,67,1,48,0,0,255,255,0,100,255,227,
5,49,7,153,16,38,0,50,0,0,16,7,0,117,2,12,0,0,
255,255,0,100,255,227,5,49,7,155,16,39,0,97,1,96,4,12,
16,6,0,50,0,0,255,255,0,100,255,227,5,49,7,110,16,39,
0,105,0,244,255,237,16,6,0,50,0,0,0,1,0,33,1,21,
3,24,4,6,0,11,0,0,19,55,39,55,23,55,23,7,23,7,
39,7,62,187,216,169,215,201,171,202,205,168,204,187,1,202,189,212,
171,212,205,169,205,201,171,202,190,0,0,3,0,100,255,227,5,49,
5,213,0,27,0,41,0,54,0,0,5,7,33,55,38,2,53,52,
62,3,51,50,23,55,33,7,22,18,21,20,14,3,35,34,55,30,
2,51,50,62,4,53,52,39,9,1,34,38,35,34,14,3,21,20,
22,2,33,13,254,228,67,101,114,42,95,140,213,131,100,60,8,1,
16,61,121,108,35,90,134,219,136,86,8,9,24,24,19,64,106,70,
53,28,13,62,253,223,1,88,3,38,22,79,123,74,47,17,34,6,
23,164,101,1,88,147,115,213,199,147,88,23,27,145,110,254,187,186,
86,189,209,164,108,252,1,6,3,49,85,103,119,107,51,200,140,253,
127,3,47,8,65,102,142,137,76,57,189,0,255,255,0,115,255,221,
4,136,7,153,16,38,0,56,0,0,16,7,0,67,1,4,0,0,
255,255,0,115,255,221,4,136,7,153,16,38,0,56,0,0,16,7,
0,117,1,204,0,0,255,255,0,115,255,221,4,136,7,118,16,39,
0,65,0,133,1,162,16,6,0,56,0,0,255,255,0,115,255,221,
4,136,7,73,16,39,0,105,0,190,255,200,16,6,0,56,0,0,
255,255,0,67,0,0,4,235,9,8,16,39,0,117,1,182,1,111,
16,6,0,60,0,0,0,2,0,135,0,0,4,48,5,176,0,8,
0,26,0,0,1,50,62,3,53,52,33,1,33,17,50,30,4,21,
20,14,3,35,17,33,1,147,62,108,108,76,48,254,110,254,244,1,
12,91,158,155,121,94,50,76,122,179,181,111,254,244,2,14,11,31,
49,81,52,211,1,239,254,255,18,39,69,96,140,87,112,168,100,61,
22,254,225,0,0,1,0,62,255,227,4,134,5,248,0,58,0,0,
19,18,33,50,22,21,20,6,7,30,3,21,20,4,35,34,39,55,
22,51,50,62,1,53,52,38,43,1,58,1,62,1,52,62,2,63,
1,50,62,2,53,52,38,35,34,7,6,10,1,7,35,54,18,2,
18,159,140,1,90,207,250,104,65,28,74,73,50,254,221,249,153,50,
98,33,47,90,136,88,200,166,35,2,2,1,1,1,1,4,2,15,
54,100,99,60,101,102,192,74,26,19,16,23,233,22,15,1,28,4,
236,1,12,254,201,130,153,23,6,60,92,138,72,210,218,52,203,31,
38,94,72,104,146,1,3,4,8,8,13,8,150,21,47,95,66,114,
107,154,56,254,11,253,251,66,52,1,115,1,138,1,124,0,0,0,
255,255,0,90,255,227,3,210,6,61,16,38,0,68,0,0,16,7,
0,67,0,156,254,164,255,255,0,90,255,227,3,210,6,59,16,38,
0,68,0,0,16,7,0,117,1,22,254,162,255,255,0,90,255,227,
3,210,5,202,16,38,0,65,4,246,16,6,0,68,0,0,0,0,
255,255,0,90,255,227,3,210,6,6,16,39,0,97,0,199,2,119,
16,6,0,68,0,0,255,255,0,90,255,227,3,210,5,215,16,39,
0,105,0,91,254,86,16,6,0,68,0,0,255,255,0,90,255,227,
3,210,6,202,16,39,0,113,0,235,0,248,16,6,0,68,0,0,
0,3,0,90,255,227,6,120,4,78,0,8,0,63,0,70,0,0,
0,34,6,20,22,51,50,54,52,5,50,55,23,14,1,35,34,39,
21,33,53,14,1,35,34,38,16,54,51,50,22,23,61,1,52,46,
3,35,34,14,1,7,39,62,1,51,32,23,62,1,51,50,22,18,
29,1,33,30,4,3,33,46,1,35,34,6,2,111,176,115,114,89,
88,104,1,225,99,55,228,62,214,106,122,108,254,255,21,147,99,153,
211,210,150,98,151,20,33,50,69,61,34,46,89,42,39,103,45,194,
80,1,8,132,65,171,95,132,209,116,253,104,1,32,46,60,51,189,
1,157,7,110,90,89,111,2,12,101,134,98,97,136,223,66,98,94,
104,64,35,136,64,101,222,1,74,218,100,64,15,66,59,88,51,31,
10,19,17,17,164,36,58,153,71,78,145,255,0,160,68,65,101,56,
35,11,1,194,90,127,129,0,0,0,255,255,0,86,254,43,3,211,
4,76,16,39,0,121,1,2,255,152,16,6,0,70,0,0,255,255,
0,88,255,227,4,2,6,61,16,38,0,72,0,0,16,7,0,67,
0,162,254,164,255,255,0,88,255,227,4,2,6,59,16,38,0,72,
0,0,16,7,0,117,1,56,254,162,255,255,0,88,255,227,4,2,
5,216,16,38,0,65,59,4,16,6,0,72,0,0,0,0,255,255,
0,88,255,227,4,2,5,192,16,39,0,105,0,104,254,63,16,6,
0,72,0,0,255,255,255,212,0,0,1,146,6,61,16,39,0,67,
255,135,254,164,16,6,0,242,0,0,255,255,0,138,0,0,2,72,
6,61,16,39,0,117,0,60,254,164,16,6,0,242,0,0,0,2,
255,128,0,0,2,164,5,210,0,6,0,10,0,0,1,33,39,7,
33,1,51,3,33,17,33,2,164,254,241,132,124,254,235,1,28,236,
253,1,13,254,243,4,122,161,158,1,85,254,95,251,207,0,0,0,
0,3,255,140,0,0,2,171,5,207,0,9,0,18,0,22,0,0,
1,52,54,50,22,20,6,35,34,38,37,52,54,50,22,20,6,34,
38,5,33,17,33,1,99,96,136,96,96,68,67,97,254,41,96,136,
96,96,136,96,0,255,1,13,254,243,5,43,68,96,96,136,96,97,
67,68,96,96,136,96,97,183,251,207,0,0,0,2,0,72,255,207,
3,185,5,232,0,11,0,56,0,0,1,20,22,51,50,54,53,52,
38,35,34,6,1,22,18,23,22,21,20,7,20,0,35,34,46,3,
53,52,18,51,50,22,23,52,38,39,7,39,55,46,2,43,1,34,
7,39,54,55,51,50,22,23,55,23,1,74,113,59,76,114,135,82,
59,86,1,159,66,123,8,11,3,255,0,186,92,148,100,66,30,236,
175,70,126,42,95,48,89,152,84,18,21,56,42,2,59,47,20,34,
114,5,85,149,43,119,163,1,211,131,156,176,111,112,144,160,2,154,
77,254,245,115,76,84,46,58,240,254,197,56,96,134,150,84,207,1,
18,92,61,55,211,45,82,154,73,13,12,12,10,193,14,2,56,34,
111,185,0,0,255,255,0,119,0,0,3,246,6,20,16,39,0,97,
0,199,2,133,16,6,0,81,0,0,255,255,0,92,255,227,4,12,
6,59,16,38,0,82,0,0,16,7,0,67,0,144,254,162,255,255,
0,92,255,227,4,12,6,59,16,38,0,82,0,0,16,7,0,117,
1,100,254,162,255,255,0,92,255,227,4,12,5,206,16,38,0,65,
38,250,16,6,0,82,0,0,0,0,255,255,0,92,255,227,4,12,
6,12,16,39,0,97,0,195,2,125,16,6,0,82,0,0,255,255,
0,92,255,227,4,12,5,203,16,39,0,105,0,92,254,74,16,6,
0,82,0,0,0,3,0,118,0,117,3,122,4,149,0,9,0,19,
0,23,0,0,1,52,54,50,22,20,6,35,34,38,17,52,54,50,
22,20,6,35,34,38,3,33,21,33,1,91,96,136,96,96,68,67,
97,96,136,96,96,68,67,97,229,3,4,252,252,3,241,68,96,96,
136,96,97,253,107,68,96,96,136,96,97,2,38,240,0,0,0,3,
0,53,255,227,4,37,4,78,0,8,0,17,0,42,0,0,9,1,
22,51,50,62,1,53,52,39,38,35,34,14,1,21,20,23,1,55,
46,1,53,52,18,54,51,50,22,23,55,33,7,30,1,21,20,0,
35,34,38,39,7,2,252,254,248,25,40,58,99,54,143,30,25,69,
106,51,13,254,200,137,42,56,115,222,149,42,115,31,32,1,7,127,
47,55,254,246,201,50,114,34,31,2,123,254,98,20,99,151,81,66,
252,20,104,151,83,63,27,254,41,207,59,194,101,164,1,0,148,29,
20,51,203,68,193,106,242,254,193,25,22,47,255,255,0,108,255,227,
3,235,6,61,16,38,0,88,0,0,16,7,0,67,0,171,254,164,
255,255,0,108,255,227,3,235,6,59,16,38,0,88,0,0,16,7,
0,117,1,80,254,162,255,255,0,108,255,227,3,235,5,239,16,38,
0,65,35,27,16,6,0,88,0,0,0,0,255,255,0,108,255,227,
3,235,5,207,16,39,0,105,0,90,254,78,16,6,0,88,0,0,
255,255,0,108,254,47,3,235,6,59,16,38,0,92,0,0,16,7,
0,117,1,120,254,162,0,2,0,119,0,0,3,246,5,174,0,22,
0,34,0,0,41,1,17,33,17,62,1,51,50,22,18,21,20,14,
3,35,34,46,2,39,1,52,38,35,34,6,21,20,22,51,50,54,
1,121,254,254,1,2,27,126,66,129,194,95,28,66,99,154,97,36,
69,49,31,8,1,123,125,64,77,121,113,75,77,122,5,174,254,217,
61,111,171,254,246,155,97,174,162,118,71,34,51,41,15,1,236,139,
213,214,137,183,222,221,255,255,0,108,254,47,3,235,5,207,16,39,
0,105,0,74,254,78,16,6,0,92,0,0,255,255,0,20,0,0,
5,97,7,21,16,39,0,112,0,236,0,0,16,6,0,36,0,0,
255,255,0,90,255,227,3,210,5,136,16,39,0,112,0,52,254,115,
16,6,0,68,0,0,255,255,0,20,0,0,5,97,7,150,16,38,
1,74,0,0,16,6,0,36,0,0,0,0,255,255,0,90,255,227,
3,210,6,56,16,39,1,74,255,70,254,162,16,6,0,68,0,0,
255,255,255,252,254,168,5,118,5,176,16,39,1,77,3,216,0,0,
16,6,0,36,232,0,255,255,0,90,254,168,4,36,4,78,16,39,
1,77,2,134,0,0,16,6,0,68,0,0,255,255,0,100,255,227,
5,17,7,153,16,39,0,117,1,244,0,0,16,6,0,38,0,0,
255,255,0,86,255,227,3,211,6,59,16,39,0,117,1,128,254,162,
16,6,0,70,0,0,255,255,0,100,255,227,5,17,7,114,16,38,
1,72,0,0,16,6,0,38,0,0,0,0,255,255,0,86,255,227,
3,211,5,208,16,39,1,72,255,114,254,94,16,6,0,70,0,0,
255,255,0,100,255,227,5,17,7,78,16,39,1,75,0,255,255,205,
16,6,0,38,0,0,255,255,0,86,255,227,3,211,5,233,16,39,
1,75,0,96,254,104,16,6,0,70,0,0,255,255,0,100,255,227,
5,17,7,114,16,38,1,73,0,0,16,6,0,38,0,0,0,0,
255,255,0,86,255,227,3,229,5,208,16,39,1,73,255,132,254,94,
16,6,0,70,0,0,255,255,0,115,0,0,4,172,7,114,16,38,
1,73,142,0,16,6,0,39,0,0,0,0,0,3,0,74,255,228,
5,22,5,234,0,24,0,44,0,63,0,0,1,20,7,6,7,6,
7,6,7,39,54,55,54,53,52,39,38,39,38,53,52,54,51,50,
22,1,53,14,1,35,34,46,2,52,62,2,51,50,22,23,17,33,
17,1,20,30,2,51,50,62,2,53,52,46,2,34,14,2,5,22,
15,15,21,20,21,22,11,52,6,13,12,1,33,24,24,66,45,55,
62,253,226,52,169,86,95,148,90,46,45,90,148,96,87,168,52,1,
2,253,84,39,64,73,36,39,74,68,41,41,68,74,78,71,64,38,
5,105,47,46,48,35,34,26,27,10,34,11,37,33,17,6,2,9,
34,35,55,49,80,80,250,102,157,82,103,89,155,199,234,201,159,91,
101,82,2,25,250,82,2,25,80,131,78,42,33,72,135,91,90,135,
71,33,35,74,132,0,0,2,0,135,0,0,5,77,5,176,0,23,
0,37,0,0,1,35,53,51,17,33,50,23,22,23,22,23,22,21,
20,7,6,7,6,7,6,43,2,1,17,51,50,18,53,52,39,38,
43,1,17,51,21,1,4,125,125,1,180,148,124,126,84,83,49,47,
49,48,86,85,124,122,147,225,211,1,12,168,172,222,112,111,171,169,
247,2,100,239,2,93,57,58,97,97,135,131,154,149,136,134,98,97,
57,56,2,100,254,143,1,14,214,213,136,135,254,152,239,0,0,0,
0,2,0,74,255,228,4,62,5,174,0,18,0,46,0,0,1,20,
30,2,51,50,62,2,53,52,46,2,34,14,2,1,53,14,1,35,
34,46,2,52,62,2,51,50,22,23,53,35,53,51,53,33,21,51,
21,35,17,1,78,39,64,73,36,39,74,68,41,41,68,74,78,71,
64,38,1,170,52,169,86,95,148,90,46,45,90,148,96,87,168,52,
184,184,1,2,68,68,2,25,80,131,78,42,33,72,135,91,90,135,
71,33,35,74,132,253,143,157,82,103,89,155,199,234,201,159,91,101,
82,223,240,74,74,240,251,140,0,0,255,255,0,115,0,0,4,73,
7,21,16,39,0,112,0,152,0,0,16,6,0,40,0,0,255,255,
0,88,255,227,4,2,5,137,16,39,0,112,0,89,254,116,16,6,
0,72,0,0,255,255,0,115,0,0,4,73,7,150,16,39,1,74,
255,116,0,0,16,6,0,40,0,0,255,255,0,88,255,227,4,2,
6,56,16,39,1,74,255,91,254,162,16,6,0,72,0,0,255,255,
0,115,0,0,4,73,7,129,16,39,1,75,0,196,0,0,16,6,
0,40,0,0,255,255,0,88,255,227,4,2,5,236,16,39,1,75,
0,96,254,107,16,6,0,72,0,0,255,255,0,115,254,168,4,77,
5,176,16,39,1,77,2,175,0,0,16,6,0,40,0,0,255,255,
0,88,254,168,4,2,4,74,16,39,1,77,1,94,0,0,16,6,
0,72,0,0,255,255,0,115,0,0,4,73,7,114,16,38,1,73,
172,0,16,6,0,40,0,0,0,0,255,255,0,88,255,227,4,2,
5,209,16,39,1,73,255,102,254,95,16,6,0,72,0,0,255,255,
0,90,255,229,5,8,7,114,16,38,1,72,0,0,16,6,0,42,
0,0,0,0,255,255,0,74,254,51,3,250,5,207,16,39,1,72,
255,115,254,93,16,6,0,74,0,0,255,255,0,90,255,229,5,8,
7,150,16,38,1,74,243,0,16,6,0,42,0,0,0,0,255,255,
0,74,254,51,3,250,6,59,16,39,1,74,255,8,254,165,16,6,
0,74,0,0,255,255,0,90,255,229,5,8,7,129,16,39,1,75,
0,244,0,0,16,6,0,42,0,0,255,255,0,74,254,51,3,250,
5,237,16,39,1,75,0,84,254,108,16,6,0,74,0,0,255,255,
0,90,255,229,5,8,5,217,16,6,0,42,0,0,255,255,0,74,
254,51,3,250,4,76,16,6,0,74,0,0,255,255,0,115,0,0,
4,114,7,114,16,38,1,72,160,0,16,6,0,43,0,0,0,0,
255,255,0,119,0,0,3,246,7,114,16,38,1,72,147,0,16,6,
0,75,0,0,0,0,0,2,0,44,0,0,4,185,5,176,0,19,
0,23,0,0,19,33,21,33,53,33,21,51,21,35,17,33,17,33,
17,33,17,35,53,51,5,33,21,33,115,1,12,1,229,1,14,71,
71,254,242,254,27,254,244,71,71,2,241,254,27,1,229,5,176,142,
142,142,240,251,206,2,112,253,144,4,50,240,240,210,0,1,0,40,
0,0,3,246,5,174,0,34,0,0,41,1,17,35,53,51,53,33,
21,51,21,35,21,62,1,51,50,30,2,21,17,33,17,52,46,2,
35,34,14,3,21,1,121,254,254,79,79,1,2,247,247,45,175,103,
55,109,93,57,254,254,25,50,61,44,35,55,53,35,21,4,136,240,
54,54,240,248,82,108,57,105,170,102,253,100,2,25,100,134,69,27,
16,44,72,119,80,0,255,255,255,210,0,0,2,79,7,121,16,39,
1,78,254,214,0,0,16,6,0,44,0,0,0,2,255,194,0,0,
2,63,6,59,0,3,0,54,0,0,19,33,17,33,3,62,1,55,
54,55,54,55,54,51,50,23,22,23,30,1,23,30,1,51,50,55,
54,55,54,55,17,6,7,6,7,6,7,6,35,34,39,38,39,38,
39,38,35,34,7,6,7,6,7,6,7,139,1,2,254,254,201,11,
34,17,4,31,22,21,24,19,27,29,30,25,13,24,13,26,60,29,
32,39,33,21,36,17,3,28,15,27,17,29,30,29,39,42,41,30,
27,38,35,27,29,24,30,11,8,36,28,14,4,49,251,207,5,212,
8,32,13,3,20,14,6,7,15,16,22,11,24,11,23,30,21,18,
19,33,16,254,252,3,23,12,20,12,12,12,24,23,29,25,27,24,
10,12,8,6,28,22,11,0,255,255,255,150,0,0,2,154,7,21,
16,39,0,112,255,52,0,0,16,6,0,44,0,0,0,2,255,137,
0,0,2,141,5,134,0,3,0,7,0,0,19,33,17,33,1,33,
21,33,139,1,2,254,254,254,254,3,4,252,252,4,49,251,207,5,
134,127,0,0,255,255,255,179,0,0,2,113,7,150,16,39,1,74,
254,59,0,0,16,6,0,44,0,0,0,2,255,180,0,0,2,114,
6,18,0,3,0,28,0,0,19,33,17,33,19,54,55,51,22,21,
20,7,6,7,6,34,39,38,39,38,53,52,55,51,22,23,22,23,
54,139,1,2,254,254,202,47,80,157,1,70,40,83,78,160,78,83,
40,70,1,161,56,66,22,49,42,4,49,251,207,5,100,34,140,10,
21,117,118,68,47,45,45,47,68,118,117,21,10,129,44,15,2,2,
0,0,255,255,0,137,254,168,1,239,5,176,16,38,1,77,81,0,
16,6,0,44,0,0,0,0,255,255,0,120,254,168,1,222,5,214,
16,38,1,77,64,0,16,6,0,76,0,0,0,0,255,255,0,114,
0,0,1,186,7,129,16,39,1,75,255,66,0,0,16,6,0,44,
0,0,0,1,0,139,0,0,1,141,4,49,0,3,0,0,19,33,
17,33,139,1,2,254,254,4,49,251,207,0,0,2,0,143,255,221,
6,48,5,176,0,35,0,39,0,0,1,51,20,23,22,23,22,23,
22,51,50,55,54,55,54,55,54,53,17,33,17,20,7,6,7,6,
35,34,39,38,39,38,39,38,39,38,1,17,33,17,2,46,241,14,
13,32,31,54,55,74,70,49,51,25,25,12,12,1,12,56,56,117,
118,165,106,84,88,58,59,41,39,20,19,254,97,1,12,2,74,69,
64,60,57,55,31,31,31,32,54,53,62,61,74,3,102,252,154,184,
139,138,80,80,31,32,54,54,80,75,95,91,254,35,5,176,250,80,
0,4,0,121,254,80,3,42,5,214,0,11,0,32,0,40,0,44,
0,0,0,52,55,54,50,23,22,20,7,6,34,39,1,55,22,23,
22,51,50,55,54,53,17,33,17,20,6,7,6,35,34,39,38,2,
52,54,50,22,20,6,34,7,33,17,33,2,4,44,44,118,44,44,
44,44,118,44,254,111,169,12,26,28,24,51,32,33,1,2,112,88,
91,94,81,58,55,92,87,120,87,87,120,69,1,2,254,254,4,247,
126,49,48,48,49,126,49,48,48,249,237,172,17,12,13,31,32,48,
4,141,251,172,99,188,54,56,20,19,6,126,130,95,95,130,95,101,
251,207,0,0,255,255,0,102,255,221,5,111,7,110,16,39,1,72,
1,14,255,252,16,6,0,45,0,0,0,2,255,20,254,80,2,157,
5,210,0,19,0,26,0,0,3,55,22,23,22,51,50,55,54,53,
17,33,17,20,14,1,35,34,39,38,1,33,39,7,33,1,51,236,
169,12,26,28,24,51,32,33,1,2,110,182,93,82,58,54,3,83,
254,241,132,124,254,235,1,28,236,254,179,172,17,12,13,31,32,48,
4,141,251,172,101,184,112,20,18,6,4,161,158,1,85,0,255,255,
0,115,0,0,5,10,5,176,16,6,0,46,0,0,255,255,0,119,
0,0,3,228,5,174,16,6,0,78,0,0,0,1,0,23,255,255,
4,2,4,50,0,10,0,0,1,17,33,17,33,17,1,33,9,1,
33,1,35,254,244,1,12,1,144,1,79,254,5,1,246,254,176,1,
158,254,97,4,51,254,110,1,145,253,244,253,219,0,255,255,0,115,
0,0,4,75,7,153,16,39,0,117,1,48,0,0,16,6,0,47,
0,0,255,255,0,139,255,227,2,73,7,153,16,38,0,117,61,0,
16,6,0,79,0,0,0,0,255,255,0,115,254,147,4,75,5,176,
16,39,0,121,1,89,0,0,16,6,0,47,0,0,255,255,0,92,
254,147,1,234,5,174,16,38,0,121,35,0,16,6,0,79,0,0,
0,0,0,2,0,115,0,0,4,75,5,234,0,24,0,30,0,0,
1,20,7,6,7,6,7,6,7,39,54,55,54,53,52,39,38,39,
38,53,52,54,51,50,22,37,33,17,33,21,33,2,211,15,15,21,
20,21,22,11,52,6,13,12,1,33,24,24,66,45,55,62,253,160,
1,12,2,204,252,40,5,105,47,46,48,35,34,26,27,10,34,11,
37,33,17,6,2,9,34,35,55,49,80,80,22,251,64,240,0,2,
0,139,255,227,2,211,5,234,0,24,0,33,0,0,1,20,7,6,
7,6,7,6,7,39,54,55,54,53,52,39,38,39,38,53,52,54,
51,50,22,1,20,51,21,34,38,53,17,33,2,211,15,15,21,20,
21,22,11,52,6,13,12,1,33,24,24,66,45,55,62,254,186,93,
185,166,1,2,5,105,47,46,48,35,34,26,27,10,34,11,37,33,
17,6,2,9,34,35,55,49,80,80,251,127,87,223,134,171,4,154,
0,0,255,255,0,115,0,0,4,75,5,176,16,39,0,120,1,251,
0,0,16,6,0,47,0,0,255,255,0,139,255,227,3,43,5,174,
16,39,0,120,1,134,0,0,16,6,0,79,0,0,0,1,0,0,
0,0,4,125,5,176,0,13,0,0,17,53,55,17,33,17,37,7,
5,17,33,21,33,17,115,1,12,1,2,1,254,255,2,254,251,246,
1,144,230,100,2,214,254,21,225,234,223,254,19,240,1,244,0,1,
0,0,255,227,1,252,5,174,0,17,0,0,17,53,55,17,33,17,
55,15,1,17,20,51,21,34,39,38,61,1,139,1,2,111,1,110,
93,186,82,83,1,144,230,121,2,191,254,35,97,234,95,254,48,87,
223,67,68,170,245,0,0,0,255,255,0,115,0,0,4,192,7,153,
16,39,0,117,1,139,0,0,16,6,0,49,0,0,255,255,0,119,
0,0,3,246,6,61,16,39,0,117,1,72,254,164,16,6,0,81,
0,0,255,255,0,115,0,0,4,192,5,176,16,6,0,49,0,0,
255,255,0,119,0,0,3,246,4,78,16,6,0,81,0,0,255,255,
0,115,0,0,4,192,7,114,16,38,1,73,0,0,16,6,0,49,
0,0,0,0,255,255,0,119,0,0,3,246,5,209,16,39,1,73,
255,100,254,95,16,6,0,81,0,0,255,255,0,66,0,0,5,7,
5,210,16,39,0,15,0,10,4,168,16,7,0,81,1,17,0,0,
0,0,0,1,0,119,0,0,4,198,5,203,0,54,0,0,37,55,
22,23,22,51,50,55,54,61,1,35,17,52,39,38,39,38,39,38,
39,38,35,34,7,6,7,6,21,17,33,17,33,21,54,55,54,51,
50,23,22,23,22,23,22,21,19,20,6,7,6,35,34,39,38,2,
77,169,12,26,28,24,51,32,33,3,9,10,13,15,24,27,21,27,
34,128,89,86,90,11,254,254,1,2,194,68,123,143,54,55,58,44,
45,29,29,3,112,88,91,94,81,58,55,99,172,17,12,13,31,32,
48,92,1,230,82,58,63,32,36,21,24,6,8,46,45,101,13,126,
252,107,5,175,162,109,29,52,29,31,49,51,87,84,103,253,116,99,
188,54,56,20,19,0,0,0,0,1,0,119,254,80,3,249,4,78,
0,55,0,0,1,55,22,23,22,51,50,55,54,61,1,35,17,52,
39,38,39,38,39,38,39,38,34,7,6,7,6,7,6,7,6,21,
17,33,17,33,21,54,55,54,51,50,23,30,1,23,22,21,19,20,
14,1,35,34,39,38,1,128,169,12,26,28,24,51,32,33,3,8,
9,15,16,22,25,25,27,66,29,27,27,26,18,17,11,11,254,254,
1,2,44,89,87,103,57,53,51,98,27,28,3,110,182,93,82,58,
54,254,179,172,17,12,13,31,32,48,92,2,25,88,52,59,36,39,
19,22,7,8,8,7,23,21,37,35,60,63,77,253,232,4,50,162,
81,55,54,28,27,110,82,84,103,253,65,101,184,112,20,18,0,0,
255,255,0,100,255,227,5,49,7,21,16,39,0,112,0,224,0,0,
16,6,0,50,0,0,255,255,0,92,255,227,4,12,5,136,16,39,
0,112,0,90,254,115,16,6,0,82,0,0,255,255,0,100,255,227,
5,49,7,150,16,38,1,74,0,0,16,6,0,50,0,0,0,0,
255,255,0,92,255,227,4,12,6,58,16,39,1,74,255,79,254,164,
16,6,0,82,0,0,255,255,0,100,255,227,5,49,7,154,16,38,
1,79,84,0,16,6,0,50,0,0,0,0,255,255,0,92,255,227,
4,85,6,74,16,39,1,79,255,238,254,176,16,6,0,82,0,0,
0,2,0,100,255,227,6,49,5,209,0,35,0,55,0,0,33,53,
6,35,34,46,5,53,52,62,5,51,50,23,37,21,33,29,1,51,
33,21,33,35,17,21,33,21,1,38,35,34,14,4,21,20,30,5,
51,50,55,3,55,88,110,92,154,106,83,48,31,11,11,31,48,83,
106,154,92,111,87,2,250,254,18,35,1,140,254,116,35,1,238,253,
6,47,151,52,84,50,35,15,6,3,12,19,37,49,76,46,151,47,
7,36,62,102,139,142,157,124,57,56,119,147,133,129,94,57,34,1,
239,98,253,239,254,253,128,240,4,94,131,54,92,103,121,84,41,35,
72,112,97,104,74,47,146,0,0,3,0,92,255,227,6,0,4,76,
0,10,0,40,0,52,0,0,1,33,46,3,35,34,14,2,3,6,
35,34,46,1,16,62,1,51,50,23,54,51,50,30,1,29,1,33,
18,51,50,54,55,23,14,1,35,34,1,16,51,50,55,54,53,52,
39,38,35,34,3,185,1,77,4,17,36,64,46,45,65,35,18,136,
113,182,136,200,97,97,200,136,181,113,119,181,130,191,96,253,184,6,
170,41,41,32,228,64,177,101,184,253,168,182,134,29,9,9,29,134,
182,2,139,47,70,65,35,36,65,71,253,183,140,157,254,1,54,252,
156,137,135,147,251,163,68,254,244,27,39,98,97,101,2,54,254,181,
196,58,77,77,59,193,255,255,0,115,255,255,4,134,7,153,16,39,
0,117,1,52,0,0,16,6,0,53,0,0,255,255,0,122,0,0,
3,65,6,59,16,39,0,117,0,204,254,162,16,6,0,85,0,0,
255,255,0,115,254,147,4,134,5,175,16,39,0,121,1,89,0,0,
16,6,0,53,0,0,255,255,0,122,254,147,3,65,4,78,16,38,
0,121,65,0,16,6,0,85,0,0,0,0,255,255,0,115,255,255,
4,134,7,110,16,39,1,73,255,73,255,252,16,6,0,53,0,0,
255,255,0,77,0,0,3,113,5,176,16,39,1,73,255,16,254,62,
16,6,0,85,0,0,255,255,0,83,255,227,4,102,7,153,16,39,
0,117,1,148,0,0,16,6,0,54,0,0,255,255,0,78,255,227,
3,117,6,61,16,39,0,117,1,36,254,164,16,6,0,86,0,0,
255,255,0,83,255,227,4,102,7,114,16,38,1,72,139,0,16,6,
0,54,0,0,0,0,255,255,0,78,255,227,3,135,5,208,16,39,
1,72,255,38,254,94,16,6,0,86,0,0,255,255,0,83,254,147,
4,102,5,212,16,39,0,121,1,89,0,0,16,6,0,54,0,0,
255,255,0,78,254,147,3,117,4,76,16,39,0,121,0,220,0,0,
16,6,0,86,0,0,255,255,0,83,255,227,4,102,7,114,16,38,
1,73,193,0,16,6,0,54,0,0,0,0,255,255,0,78,255,227,
3,131,5,177,16,39,1,73,255,34,254,63,16,6,0,86,0,0,
255,255,0,78,254,147,5,0,5,176,16,39,0,121,1,167,0,0,
16,6,0,55,0,0,255,255,0,72,254,147,2,113,5,43,16,38,
0,121,114,0,16,6,0,87,0,0,0,0,255,255,0,78,0,0,
5,0,7,116,16,38,1,73,232,2,16,6,0,55,0,0,0,0,
0,2,0,72,255,241,3,84,5,234,0,24,0,45,0,0,1,20,
7,6,7,6,7,6,7,39,54,55,54,53,52,39,38,39,38,53,
52,54,51,50,22,1,35,53,51,53,33,21,51,21,35,17,20,59,
1,21,35,34,46,2,53,3,84,15,15,21,20,21,22,11,52,6,
13,12,1,33,24,24,66,45,55,62,253,129,141,141,1,2,154,154,
111,39,39,107,143,84,35,5,105,47,46,48,35,34,26,27,10,34,
11,37,33,17,6,2,9,34,35,55,49,80,80,253,178,229,250,250,
229,253,221,95,217,37,79,111,81,0,0,1,0,78,0,0,5,0,
5,176,0,15,0,0,19,33,21,33,17,51,21,35,17,33,17,33,
53,33,17,33,78,4,178,254,55,245,245,254,244,254,253,1,3,254,
35,5,176,240,254,50,240,253,254,2,2,240,1,206,0,0,0,1,
0,40,255,241,2,143,5,43,0,28,0,0,19,35,53,51,53,33,
21,51,21,35,21,51,21,35,21,20,59,1,21,35,34,46,2,61,
1,35,53,51,213,141,141,1,2,154,154,184,184,111,39,39,107,143,
84,35,173,173,3,76,229,250,250,229,90,240,217,95,217,37,79,111,
81,221,240,0,0,0,255,255,0,115,255,221,4,136,7,121,16,38,
1,78,82,0,16,6,0,56,0,0,0,0,255,255,0,108,255,227,
3,235,6,60,16,39,1,78,255,242,254,195,16,6,0,88,0,0,
255,255,0,115,255,221,4,136,7,21,16,39,0,112,0,153,0,0,
16,6,0,56,0,0,255,255,0,108,255,227,3,235,5,137,16,39,
0,112,0,85,254,116,16,6,0,88,0,0,255,255,0,115,255,221,
4,136,7,150,16,38,1,74,180,0,16,6,0,56,0,0,0,0,
255,255,0,108,255,227,3,235,6,60,16,39,1,74,255,70,254,166,
16,6,0,88,0,0,255,255,0,115,255,221,4,136,7,150,16,39,
1,76,1,40,0,0,16,6,0,56,0,0,255,255,0,108,255,227,
3,235,6,61,16,39,1,76,0,195,254,167,16,6,0,88,0,0,
255,255,0,115,255,221,4,136,7,154,16,38,1,79,0,0,16,6,
0,56,0,0,0,0,255,255,0,108,255,227,4,34,6,74,16,39,
1,79,255,187,254,176,16,6,0,88,0,0,255,255,0,115,254,168,
4,136,5,176,16,39,1,77,1,192,0,0,16,6,0,56,0,0,
255,255,0,108,254,168,4,62,4,49,16,39,1,77,2,160,0,0,
16,6,0,88,0,0,255,255,0,74,0,0,6,10,7,114,16,38,
1,72,120,0,16,6,0,58,0,0,0,0,255,255,0,57,0,0,
5,105,5,209,16,39,1,72,255,254,254,95,16,6,0,90,0,0,
255,255,0,67,0,0,4,235,7,114,16,38,1,72,193,0,16,6,
0,60,0,0,0,0,255,255,0,108,254,47,3,235,5,208,16,39,
1,72,255,90,254,94,16,6,0,92,0,0,255,255,0,67,0,0,
4,235,7,129,16,39,0,105,0,198,0,0,16,6,0,60,0,0,
255,255,0,72,0,0,5,26,7,153,16,39,0,117,1,239,0,0,
16,6,0,61,0,0,255,255,0,66,0,0,3,153,6,61,16,39,
0,117,1,8,254,164,16,6,0,93,0,0,255,255,0,72,0,0,
5,26,7,77,16,39,1,75,1,4,255,204,16,6,0,61,0,0,
255,255,0,66,0,0,3,153,5,233,16,39,1,75,0,49,254,104,
16,6,0,93,0,0,255,255,0,72,0,0,5,26,7,114,16,38,
1,73,0,0,16,6,0,61,0,0,0,0,255,255,0,66,0,0,
3,153,5,209,16,39,1,73,255,56,254,95,16,6,0,93,0,0,
0,1,0,213,0,0,3,22,5,209,0,22,0,0,19,53,52,55,
54,55,62,1,51,50,23,7,38,39,38,35,34,7,6,29,1,17,
33,213,27,24,50,46,132,71,135,92,149,15,28,26,19,43,20,19,
254,254,4,49,80,51,58,53,56,52,66,89,179,18,11,10,21,20,
46,100,251,207,0,1,0,28,254,176,4,196,5,156,0,33,0,0,
9,1,33,1,39,55,23,55,54,55,54,55,54,55,54,51,50,23,
22,23,7,38,39,38,39,48,35,34,7,6,15,1,51,7,2,232,
254,72,254,236,1,192,154,78,156,44,15,48,47,59,66,68,58,32,
47,24,129,27,4,18,70,39,109,5,31,54,21,19,34,190,78,3,
94,251,82,4,186,3,215,4,131,45,48,46,32,35,6,5,8,46,
58,236,63,45,25,11,27,10,45,76,215,0,0,3,0,10,0,0,
5,194,7,0,0,3,0,19,0,22,0,0,1,33,21,33,19,33,
3,33,1,33,21,33,17,33,21,33,17,33,21,33,17,3,51,2,
115,3,5,252,251,193,254,233,233,254,214,2,64,3,120,254,124,1,
132,254,122,1,134,253,114,199,199,7,0,240,252,69,253,171,5,178,
255,254,149,250,254,172,250,5,7,254,65,0,0,0,0,4,0,74,
255,227,6,73,5,132,0,3,0,53,0,69,0,78,0,0,1,33,
21,33,1,22,23,22,51,50,55,23,6,7,6,35,34,39,6,7,
6,35,34,39,38,53,52,55,54,51,50,23,52,39,38,35,34,7,
6,7,39,54,55,54,51,50,23,54,51,50,23,22,29,1,37,34,
7,6,21,20,23,22,51,50,55,54,53,52,39,38,37,33,38,39,
38,35,34,7,6,1,195,3,5,252,251,1,238,17,112,32,46,124,
46,238,64,180,85,79,211,141,38,30,83,145,200,128,102,149,114,163,
125,51,79,42,53,103,104,27,10,53,125,45,39,86,234,102,134,182,
218,131,108,251,175,132,44,12,90,43,55,98,54,25,97,34,1,139,
1,158,11,95,43,58,126,56,20,5,132,239,253,17,160,47,14,104,
69,165,69,31,173,40,30,103,142,113,153,194,118,92,51,92,49,25,
37,9,3,197,47,6,4,135,131,187,153,222,115,134,107,33,39,105,
49,22,86,42,48,120,44,15,96,134,57,26,125,42,0,0,255,255,
0,83,254,9,4,102,5,212,16,38,0,54,0,0,16,7,1,95,
1,137,0,0,255,255,0,78,254,9,3,117,4,76,16,38,0,86,
0,0,16,7,1,95,0,254,0,0,255,255,0,78,254,147,5,0,
5,176,16,6,1,35,0,0,255,255,0,72,254,147,2,113,5,43,
16,6,1,36,0,0,0,1,1,61,6,26,4,97,7,114,0,6,
0,0,1,33,39,7,33,1,51,4,97,254,241,132,124,254,235,1,
28,236,6,26,161,158,1,85,0,0,0,1,1,61,6,26,4,97,
7,114,0,6,0,0,9,1,35,1,33,23,55,4,97,254,228,236,
254,228,1,21,124,132,7,114,254,168,1,85,158,161,0,1,1,120,
5,236,4,54,7,150,0,24,0,0,1,54,55,51,22,21,20,7,
6,7,6,34,39,38,39,38,53,52,55,51,22,23,22,23,54,3,
25,47,80,157,1,70,40,83,78,160,78,83,40,70,1,161,56,66,
22,49,42,6,232,34,140,10,21,117,118,68,47,45,45,47,68,118,
117,21,10,129,44,15,2,2,0,1,1,48,6,57,2,120,7,129,
0,10,0,0,1,52,54,50,22,20,6,35,34,39,38,1,48,96,
136,96,96,68,67,49,48,6,221,68,96,96,136,96,49,48,0,2,
0,130,5,213,2,76,7,150,0,9,0,23,0,0,0,20,22,50,
54,52,39,38,34,7,6,52,55,54,51,50,23,22,20,7,6,35,
34,39,0,255,60,88,60,30,30,88,30,155,67,67,95,96,66,67,
67,65,97,96,66,6,226,90,62,62,90,32,31,31,170,186,66,66,
66,67,184,67,65,65,0,1,0,56,254,168,1,158,0,95,0,29,
0,0,5,7,38,39,48,39,38,39,38,39,38,39,38,53,52,55,
23,6,7,6,7,6,21,20,23,22,23,22,23,22,1,158,113,14,
35,54,25,27,34,12,20,12,12,108,162,18,12,10,2,1,15,18,
16,20,22,26,217,127,6,20,30,14,22,28,13,22,25,26,26,111,
96,90,20,23,21,13,8,26,14,17,20,11,14,13,16,0,0,1,
0,252,5,234,3,121,7,121,0,50,0,0,19,62,1,55,54,55,
54,55,54,51,50,23,22,23,30,1,23,30,1,51,50,55,54,55,
54,55,17,6,7,6,7,6,7,6,35,34,39,38,39,38,39,38,
35,34,7,6,7,6,7,6,7,252,11,34,17,4,31,22,21,24,
19,28,28,30,25,13,24,13,26,60,29,32,39,33,21,36,17,3,
28,15,27,17,29,30,29,39,42,41,30,27,38,34,28,29,24,30,
11,8,36,28,14,7,18,8,32,13,3,20,14,6,7,15,16,22,
11,24,11,23,30,21,18,19,33,16,254,252,3,23,12,20,12,12,
12,24,23,29,25,27,24,10,12,8,6,28,22,11,0,2,1,82,
5,204,4,103,7,154,0,23,0,49,0,0,1,6,35,34,39,38,
39,46,1,53,52,55,19,54,51,50,23,22,23,30,1,21,20,7,
1,6,35,34,39,38,39,38,39,38,53,52,55,19,54,51,50,23,
22,23,22,23,22,21,20,7,3,107,7,15,19,21,20,18,14,34,
4,209,13,31,19,28,27,15,20,34,10,253,137,8,14,19,21,20,
18,15,17,16,4,209,13,31,19,28,27,15,21,17,16,10,5,213,
9,10,9,13,10,56,19,9,5,1,56,19,10,9,13,13,62,27,
20,13,254,226,9,10,9,13,11,27,26,21,9,5,1,56,19,10,
9,13,14,30,29,29,20,13,0,1,252,69,5,22,254,0,6,20,
0,3,0,0,1,33,39,33,254,0,254,237,168,1,12,5,22,254,
0,1,252,60,5,22,253,247,6,20,0,3,0,0,1,33,7,33,
252,235,1,12,168,254,237,6,20,254,0,1,252,102,4,149,255,137,
5,241,0,6,0,0,3,5,39,7,33,1,55,119,254,241,133,123,
254,236,1,26,238,4,153,4,164,158,1,84,2,0,0,1,252,224,
4,134,255,94,6,22,0,28,0,0,1,54,51,54,51,50,23,22,
51,48,51,50,63,1,3,7,6,35,34,39,38,35,48,35,34,7,
6,15,1,252,224,80,2,50,51,48,85,88,56,6,65,101,6,2,
74,51,51,63,95,82,39,6,31,27,26,45,46,5,176,65,37,74,
78,101,6,254,252,62,33,80,72,15,14,33,34,0,0,0,0,1,
252,161,4,149,255,166,5,132,0,3,0,0,1,33,21,33,252,161,
3,5,252,251,5,132,239,0,0,1,252,149,4,126,255,174,5,204,
0,29,0,0,1,22,23,22,23,22,51,50,55,54,55,21,55,51,
6,7,6,7,6,7,6,35,34,39,38,39,38,39,38,39,253,100,
17,13,30,43,44,43,54,41,39,34,33,195,16,23,23,26,57,76,
80,95,84,81,78,58,23,27,21,25,5,204,46,13,53,25,25,23,
22,52,2,65,40,47,48,33,72,45,47,38,37,73,29,53,41,63,
0,1,253,75,4,140,254,147,5,212,0,15,0,0,1,52,55,54,
51,50,23,22,21,20,7,6,35,34,39,38,253,75,84,33,47,97,
47,20,84,35,45,97,46,21,5,48,98,46,20,84,33,47,96,47,
21,84,34,0,0,0,0,2,252,40,4,140,255,72,5,212,0,15,
0,31,0,0,1,52,55,54,51,50,23,22,21,20,7,6,35,34,
39,38,37,52,55,54,51,50,23,22,21,20,7,6,35,34,39,38,
254,0,84,33,47,96,47,21,85,34,45,98,46,20,254,40,84,33,
47,98,46,20,84,35,45,97,47,20,5,48,98,46,20,84,34,46,
96,47,21,84,33,47,98,46,20,84,33,47,96,47,21,84,33,0,
0,0,0,2,252,171,4,91,255,39,6,204,0,15,0,31,0,0,
1,20,23,22,51,50,55,54,53,52,39,38,35,34,7,6,7,52,
55,54,51,50,23,22,21,20,7,6,35,34,39,38,253,87,78,34,
34,87,40,16,77,32,34,87,40,19,172,125,82,111,156,96,66,125,
85,108,156,96,66,5,147,93,40,17,78,36,36,93,40,16,77,36,
36,155,95,63,123,84,106,155,93,64,121,84,0,2,252,60,5,22,
255,139,6,20,0,3,0,7,0,0,1,33,7,33,37,33,7,33,
252,235,1,12,168,254,237,2,67,1,12,168,254,237,6,20,254,254,
254,0,0,1,252,102,4,149,255,137,5,241,0,6,0,0,1,39,
1,33,23,55,5,254,110,238,254,230,1,20,123,133,1,15,4,149,
2,1,84,158,164,4,0,2,252,149,4,126,255,174,7,16,0,29,
0,45,0,0,1,22,23,22,23,22,51,50,55,54,55,21,55,51,
6,7,6,7,6,7,6,35,34,39,38,39,38,39,38,39,55,52,
55,54,51,50,23,22,21,20,7,6,35,34,39,38,253,100,17,13,
30,43,44,43,54,41,39,34,33,195,16,23,23,26,57,76,80,95,
84,81,78,58,23,27,21,25,229,84,33,47,98,46,20,84,34,46,
96,47,21,5,204,46,13,53,25,25,23,22,52,2,65,40,47,48,
33,72,45,47,38,37,73,29,53,41,63,160,98,46,20,84,33,47,
96,47,21,84,34,0,0,1,253,75,254,57,254,147,255,129,0,15,
0,0,1,52,55,54,51,50,23,22,21,20,7,6,35,34,39,38,
253,75,84,35,45,97,47,20,84,33,47,97,46,21,254,221,96,47,
21,84,33,47,97,47,20,84,35,0,0,0,0,2,252,40,254,61,
255,72,255,133,0,15,0,31,0,0,1,52,55,54,51,50,23,22,
21,20,7,6,35,34,39,38,37,52,55,54,51,50,23,22,21,20,
7,6,35,34,39,38,254,0,84,34,46,96,47,21,85,35,44,98,
46,20,254,40,84,34,46,98,46,20,84,34,46,97,47,20,254,225,
97,46,21,84,34,46,96,47,21,84,33,47,97,46,21,84,33,47,
97,46,21,84,33,0,0,0,0,2,252,171,253,71,255,39,255,184,
0,15,0,31,0,0,1,20,23,22,51,50,55,54,53,52,39,38,
35,34,7,6,7,52,55,54,51,50,23,22,21,20,7,6,35,34,
39,38,253,87,78,32,36,87,40,16,77,32,34,87,40,19,172,125,
82,111,156,96,66,125,85,108,156,96,66,254,127,93,41,16,78,36,
36,93,40,16,78,36,35,155,95,63,123,84,106,155,93,64,121,84,
0,1,0,56,254,9,1,126,0,0,0,26,0,0,5,20,7,6,
7,6,7,6,7,39,54,55,54,53,52,39,38,39,38,53,52,55,
54,51,50,23,22,1,126,21,22,30,33,25,29,19,74,15,13,17,
2,47,35,34,48,47,64,80,43,44,161,57,59,61,43,47,28,32,
15,43,27,33,42,20,5,6,11,42,41,72,60,51,50,50,52,0,
0,0,0,1,252,30,254,147,253,132,0,74,0,13,0,0,5,54,
55,54,53,52,39,55,22,21,20,7,6,7,252,30,107,16,8,43,
162,108,202,3,41,238,62,26,11,12,65,46,90,96,111,104,105,1,
22,0,0,0,0,1,252,30,254,147,253,132,0,74,0,13,0,0,
1,38,35,38,53,52,55,23,6,21,20,23,22,23,253,20,42,1,
203,108,162,43,9,17,105,254,147,23,105,104,111,96,90,46,65,10,
13,27,61,0,0,0,0,1,252,161,254,137,255,166,255,121,0,3,
0,0,5,33,21,33,252,161,3,5,252,251,135,240,0,0,0,1,
0,93,2,66,1,165,3,138,0,7,0,0,18,52,54,50,22,20,
6,34,93,96,136,96,96,136,2,162,136,96,96,136,96,0,0,1,
1,209,4,143,2,229,6,63,0,27,0,0,1,6,7,6,34,39,
38,39,38,39,38,55,19,54,55,54,55,51,50,23,22,23,22,23,
22,21,20,7,2,135,3,13,14,52,18,16,29,25,9,4,1,51,
5,27,23,23,13,20,15,26,27,28,12,6,2,4,168,11,7,7,
3,3,19,16,19,10,5,1,54,23,12,11,1,3,5,19,20,26,
12,11,3,8,0,3,0,78,4,143,4,36,6,63,0,27,0,35,
0,43,0,0,1,6,7,6,35,34,39,38,39,38,39,38,55,19,
54,55,54,55,48,51,50,23,22,23,22,23,22,7,4,52,54,50,
22,20,6,34,36,52,54,50,22,20,6,34,2,105,3,13,14,27,
26,18,15,29,26,9,3,1,50,5,27,23,24,13,20,15,25,27,
28,12,9,5,253,138,96,136,96,96,136,2,46,96,136,96,96,136,
4,168,11,7,7,3,2,20,18,17,8,7,1,54,23,12,11,1,
3,4,20,20,26,19,15,212,136,96,96,136,96,96,136,96,96,136,
96,0,0,0,255,255,0,47,0,0,5,94,6,63,16,38,1,110,
0,0,16,7,1,100,254,224,0,0,255,255,0,53,0,0,5,60,
6,63,16,39,1,114,0,244,0,0,16,7,1,100,254,100,0,0,
0,0,255,255,0,37,0,0,5,81,6,63,16,39,1,116,0,224,
0,0,16,7,1,100,254,84,0,0,0,0,255,255,0,37,0,0,
2,100,6,63,16,39,1,118,0,200,0,0,16,7,1,100,254,84,
0,0,0,0,255,255,0,42,255,227,5,160,6,63,16,38,1,124,
111,0,16,7,1,100,254,89,0,0,0,1,0,66,0,0,4,224,
5,176,0,8,0,0,19,33,9,1,33,1,17,33,17,66,1,28,
1,54,1,54,1,22,254,61,254,243,5,176,253,231,2,25,253,17,
253,63,2,193,255,255,0,29,0,0,5,254,6,63,16,39,1,133,
0,156,0,0,16,7,1,100,254,76,0,0,0,0,255,255,255,64,
4,146,3,22,6,66,16,7,1,101,254,242,0,3,0,0,0,2,
0,47,0,0,5,94,5,176,0,2,0,10,0,0,1,3,33,23,
33,3,33,1,33,1,33,2,214,159,1,44,75,254,64,136,254,201,
2,51,1,0,1,252,254,205,4,24,254,89,246,254,133,5,176,250,
80,0,0,0,0,3,0,119,0,0,4,139,5,176,0,7,0,17,
0,54,0,0,1,17,51,50,54,53,52,33,3,17,51,50,55,54,
52,39,38,35,37,33,50,23,22,23,22,23,22,23,22,23,22,23,
22,21,20,7,6,7,22,23,22,23,22,21,20,7,6,7,6,7,
6,7,6,35,33,1,131,227,155,130,254,227,227,168,137,60,59,59,
61,136,254,76,1,180,90,79,78,52,53,41,39,25,22,16,15,5,
5,56,56,93,97,69,70,28,29,11,11,33,33,55,54,98,99,125,
253,243,2,127,254,113,116,91,192,2,68,254,170,51,50,142,49,50,
237,14,14,22,23,33,32,34,30,42,40,34,37,31,108,68,69,28,
23,66,67,69,72,61,50,55,56,60,61,47,46,32,32,0,0,0,
0,1,0,115,0,0,4,73,5,176,0,5,0,0,1,17,33,17,
33,21,1,127,254,244,3,214,4,193,251,63,5,176,239,0,0,0,
0,2,0,108,0,0,5,160,5,176,0,3,0,6,0,0,51,1,
33,1,37,33,1,108,2,21,1,14,2,17,252,91,2,30,254,238,
5,176,250,80,240,3,24,0,0,1,0,114,0,0,4,72,5,176,
0,11,0,0,19,33,21,33,17,33,21,33,17,33,21,33,114,3,
214,253,54,2,140,253,116,2,202,252,42,5,176,239,254,161,239,254,
125,240,0,1,0,72,0,0,5,26,5,176,0,7,0,0,19,33,
1,33,21,33,1,33,139,4,143,252,226,3,24,251,52,3,32,253,
35,5,176,251,64,240,4,193,0,0,0,1,0,115,0,0,4,113,
5,176,0,11,0,0,19,33,17,33,17,33,17,33,17,33,17,33,
115,1,12,1,229,1,13,254,243,254,27,254,244,5,176,253,176,2,
80,250,80,2,113,253,143,0,0,3,0,100,255,227,5,49,5,209,
0,3,0,39,0,77,0,0,1,33,21,33,37,52,38,39,38,39,
38,35,34,7,6,7,6,7,6,7,6,21,20,23,22,23,22,23,
30,1,51,50,55,54,55,54,55,54,55,54,37,52,55,54,55,54,
55,54,55,54,32,23,22,23,30,1,23,22,21,20,7,6,7,6,
7,6,7,6,35,34,39,38,39,38,39,38,39,38,1,230,1,197,
254,59,2,49,34,35,34,70,68,91,75,58,56,38,40,22,26,8,
9,10,11,23,25,36,38,116,73,75,58,57,37,40,22,26,8,9,
252,77,20,19,48,45,71,69,106,105,1,8,105,106,69,67,96,19,
20,20,19,48,46,70,68,107,105,131,130,105,109,67,70,46,47,21,
20,3,99,240,127,89,170,73,72,46,45,30,29,50,53,61,71,62,
67,72,82,70,75,70,74,51,53,66,33,32,54,58,67,77,68,73,
79,98,102,95,101,95,77,75,46,46,46,46,74,71,202,96,102,98,
104,108,101,109,103,81,78,50,49,49,51,77,81,102,105,105,101,0,
0,1,0,143,0,0,1,156,5,176,0,3,0,0,51,17,33,17,
143,1,13,5,176,250,80,0,0,0,0,1,0,115,0,0,5,10,
5,176,0,11,0,0,19,33,17,1,33,9,1,33,1,7,17,33,
115,1,12,2,31,1,79,253,212,2,73,254,176,254,58,117,254,244,
5,176,253,145,2,111,253,120,252,216,2,116,132,254,16,0,0,1,
0,70,0,0,4,208,5,176,0,6,0,0,33,9,1,33,1,33,
1,3,186,254,212,254,218,254,222,1,172,1,60,1,162,4,21,251,
235,5,176,250,80,0,0,1,0,66,0,0,5,211,5,176,0,12,
0,0,51,17,33,9,1,33,17,33,17,1,33,1,17,66,1,104,
1,93,1,101,1,103,254,250,254,194,254,242,254,199,5,176,251,248,
4,8,250,80,3,231,252,25,3,220,252,36,0,1,0,119,0,0,
4,197,5,176,0,9,0,0,51,17,33,1,17,33,17,33,1,17,
119,1,4,2,61,1,13,254,247,253,199,5,176,252,84,3,172,250,
80,3,205,252,51,0,0,3,0,115,0,0,4,73,5,177,0,3,
0,7,0,11,0,0,55,37,21,5,17,37,21,5,19,37,21,5,
115,3,214,252,42,3,214,252,42,87,3,18,252,238,240,1,240,1,
5,176,1,240,1,254,162,1,240,1,0,0,0,2,0,100,255,227,
5,49,5,209,0,35,0,73,0,0,1,52,38,39,38,39,38,35,
34,7,6,7,6,7,6,7,6,21,20,23,22,23,22,23,30,1,
51,50,55,54,55,54,55,54,55,54,37,52,55,54,55,54,55,54,
55,54,32,23,22,23,30,1,23,22,21,20,7,6,7,6,7,6,
7,6,35,34,39,38,39,38,39,38,39,38,4,23,34,35,34,70,
68,91,75,58,56,38,40,22,26,8,9,10,11,23,25,36,38,116,
73,75,58,57,37,40,22,26,8,9,252,77,20,19,48,45,71,69,
106,105,1,8,105,106,69,67,96,19,20,20,19,48,46,70,68,107,
105,131,130,105,109,67,70,46,47,21,20,2,242,89,170,73,72,46,
45,30,29,50,53,61,71,62,67,72,82,70,75,70,74,51,53,66,
33,32,54,58,67,77,68,73,79,98,102,95,101,95,77,75,46,46,
46,46,74,71,202,96,102,98,104,108,101,109,103,81,78,50,49,49,
51,77,81,102,105,105,101,0,0,0,0,1,0,115,0,0,4,113,
5,176,0,7,0,0,19,33,17,33,17,33,17,33,115,3,254,254,
243,254,27,254,244,5,176,250,80,4,193,251,63,0,0,2,0,121,
0,0,4,45,5,176,0,5,0,26,0,0,1,51,32,16,33,35,
37,33,51,50,23,22,23,30,1,21,20,7,6,7,6,7,6,43,
1,17,33,1,133,130,1,20,254,236,130,254,244,1,12,130,136,105,
110,64,65,70,37,38,68,70,104,107,126,130,254,244,3,55,1,138,
239,34,36,58,59,158,91,92,78,81,59,61,34,35,253,188,0,1,
0,50,0,0,4,128,5,145,0,11,0,0,41,1,17,9,1,17,
33,17,33,9,1,33,4,128,251,178,1,77,254,179,4,78,252,200,
1,166,254,100,3,46,1,104,1,93,1,101,1,103,254,250,254,57,
254,66,0,0,0,1,0,78,0,0,5,0,5,176,0,7,0,0,
19,33,21,33,17,33,17,33,78,4,178,254,55,254,244,254,35,5,
176,239,251,63,4,193,0,0,0,1,0,66,0,0,4,224,5,176,
0,8,0,0,19,33,9,1,33,1,17,33,17,66,1,28,1,54,
1,54,1,22,254,61,254,243,5,176,253,231,2,25,253,17,253,63,
2,193,0,3,0,96,0,0,5,182,5,174,0,43,0,61,0,84,
0,0,1,17,35,17,38,39,38,39,38,39,38,39,38,53,52,55,
54,55,54,55,54,55,54,55,53,51,21,22,23,22,23,30,1,23,
22,20,7,6,7,6,7,6,7,6,3,17,54,55,54,55,54,55,
54,53,52,39,38,39,38,39,38,39,3,17,34,6,35,6,7,6,
7,6,7,6,21,20,23,22,23,22,23,22,23,22,50,3,157,243,
52,21,99,90,94,71,73,42,44,44,43,72,66,99,93,96,45,28,
243,21,34,90,87,88,134,42,41,41,42,66,63,92,84,93,51,5,
11,22,72,69,65,42,40,27,28,43,47,56,61,58,244,3,12,3,
67,64,65,47,49,29,29,29,31,47,52,60,64,67,3,12,1,59,
254,197,1,58,6,4,17,36,37,56,57,83,86,103,102,86,84,57,
52,40,38,16,8,3,169,171,2,6,17,37,38,110,85,83,212,83,
86,55,53,39,36,17,8,2,229,253,252,1,4,13,29,28,55,53,
75,59,47,48,28,31,18,20,7,253,250,2,7,2,8,19,20,29,
30,46,45,60,61,45,48,28,31,18,19,8,1,0,0,1,0,53,
0,0,4,201,5,176,0,11,0,0,19,33,9,1,33,9,1,33,
11,1,33,1,59,1,53,1,13,1,16,1,54,254,88,1,174,254,
175,251,247,254,175,1,171,5,176,254,11,1,245,253,39,253,41,1,
204,254,52,2,215,0,0,1,0,92,0,0,4,12,5,179,0,28,
0,0,1,48,17,16,7,6,7,17,33,17,38,39,38,17,48,53,
19,51,3,48,21,20,23,17,33,17,54,53,3,4,12,123,83,128,
254,243,133,84,124,3,251,2,89,1,13,86,3,5,178,253,254,254,
251,153,102,33,254,117,1,137,33,103,153,1,0,6,2,2,253,254,
7,202,77,3,29,252,229,78,206,2,3,0,0,1,0,31,0,0,
5,98,5,209,0,68,0,0,37,21,33,53,51,38,39,38,39,38,
53,52,55,54,55,54,55,54,55,54,32,23,22,23,30,1,23,22,
21,20,7,6,7,6,7,51,21,33,53,54,55,54,55,54,55,54,
53,52,38,39,38,39,38,35,34,7,6,7,6,7,6,7,6,21,
20,23,30,2,2,121,253,166,212,33,22,47,21,20,20,19,48,45,
71,69,106,105,1,8,105,106,69,67,96,19,20,20,19,48,23,32,
191,253,166,60,76,71,23,24,8,9,34,35,34,70,68,91,75,58,
56,38,40,22,26,8,9,10,11,46,126,229,229,229,54,48,105,105,
101,112,98,102,95,101,95,77,75,46,46,46,46,74,71,202,96,102,
98,104,108,101,109,52,51,229,229,16,64,61,80,83,69,73,79,89,
170,73,72,46,45,30,29,50,53,61,71,62,67,72,82,70,75,140,
126,0,0,0,255,255,255,134,0,0,2,165,7,129,16,38,1,118,
0,0,16,7,0,105,255,67,0,0,255,255,0,66,0,0,4,224,
7,129,16,38,1,129,0,0,16,7,0,105,0,194,0,0,255,255,
0,91,255,224,4,203,6,63,16,38,1,141,0,0,16,6,1,100,
0,0,0,0,255,255,0,86,255,227,3,74,6,63,16,38,1,145,
0,0,16,6,1,100,169,0,0,0,255,255,0,119,254,116,3,246,
6,63,16,38,1,147,0,0,16,6,1,100,0,0,0,0,255,255,
0,135,0,12,3,3,6,63,16,38,1,149,0,0,16,7,1,100,
254,182,0,0,255,255,0,78,255,216,4,36,6,63,16,38,1,161,
0,0,16,6,1,101,0,0,0,0,0,2,0,91,255,224,4,203,
4,74,0,5,0,45,0,0,1,16,32,17,16,32,37,7,38,39,
38,39,17,54,55,54,55,23,6,7,6,35,6,35,34,47,1,7,
6,35,34,39,38,17,16,55,54,51,50,31,1,54,51,50,23,22,
1,87,1,122,254,134,3,113,168,13,25,16,23,20,21,26,12,169,
46,63,76,61,16,9,63,62,69,41,91,122,171,123,123,124,125,196,
101,84,71,68,121,74,61,73,2,22,254,181,1,75,1,74,98,172,
18,12,7,4,253,167,1,11,12,17,172,52,27,32,2,38,12,23,
45,152,151,1,7,1,5,151,152,41,52,68,32,39,0,1,0,62,
254,116,4,134,5,248,0,77,0,0,19,18,33,50,23,22,21,20,
7,6,7,22,23,22,23,22,23,22,21,20,7,6,35,34,39,55,
22,51,50,55,54,55,54,53,52,38,35,42,1,38,34,43,1,50,
55,50,55,54,55,62,1,53,52,39,38,35,34,7,6,7,6,7,
6,3,2,7,6,7,35,54,55,54,19,18,55,54,55,54,159,139,
1,91,208,124,125,52,52,65,27,38,40,34,35,26,25,146,145,249,
154,49,98,32,48,92,66,69,43,44,200,166,6,11,7,5,1,1,
1,24,57,47,51,48,50,60,50,51,102,106,62,64,34,22,10,12,
1,1,10,9,19,233,19,7,8,1,2,2,3,14,13,4,236,1,
12,127,128,200,131,76,76,23,6,30,32,44,46,69,68,73,209,110,
109,52,203,31,19,20,46,47,72,104,146,1,194,10,11,23,24,96,
65,114,53,54,40,41,73,45,167,185,254,151,254,144,184,175,51,45,
127,129,1,101,1,136,126,154,140,132,0,0,0,1,0,72,254,116,
3,195,4,49,0,7,0,0,33,1,33,27,1,51,1,35,1,155,
254,173,1,15,180,193,247,254,46,197,4,49,253,82,2,174,250,67,
0,0,0,2,0,92,255,227,4,12,5,234,0,17,0,23,0,0,
19,16,55,54,55,39,53,33,21,33,1,22,16,2,35,34,39,38,
19,16,32,17,16,32,92,124,87,133,188,2,254,254,88,1,67,123,
246,225,226,123,124,252,1,188,254,68,2,25,1,4,151,107,31,188,
240,240,254,187,152,253,248,254,206,151,153,1,6,254,181,1,75,1,
73,0,0,0,0,1,0,86,255,227,3,74,4,85,0,60,0,0,
37,6,7,6,7,6,35,34,39,38,39,46,1,53,52,55,54,55,
54,55,54,55,38,53,52,55,54,55,54,55,54,51,50,23,7,38,
39,38,35,34,6,21,20,23,22,59,1,7,35,34,7,6,21,20,
23,22,51,50,55,54,55,3,74,34,59,61,69,72,84,77,73,70,
50,49,58,16,14,28,25,29,27,36,109,28,27,49,52,53,55,70,
231,81,222,11,24,25,34,45,62,31,32,41,80,2,93,53,38,40,
37,38,56,39,41,38,21,234,92,59,61,25,26,28,27,47,46,128,
67,52,51,46,37,33,26,24,24,79,128,75,61,58,34,36,15,16,
211,65,27,17,18,58,54,41,32,34,237,37,38,50,52,34,35,25,
23,53,0,0,0,1,0,56,254,130,4,21,5,175,0,39,0,0,
1,33,53,33,21,1,6,7,6,21,20,23,22,51,22,23,22,23,
22,23,22,21,20,7,6,7,39,54,53,52,39,38,43,1,34,39,
38,17,52,55,2,62,254,58,3,72,253,178,43,9,3,77,76,108,
74,30,139,111,101,13,1,29,27,48,212,31,31,31,42,80,239,141,
140,124,4,191,240,240,253,185,49,81,20,19,104,75,73,8,2,9,
99,73,174,6,13,57,60,59,33,163,29,54,42,32,33,138,137,1,
0,163,157,0,0,0,0,1,0,119,254,116,3,246,4,78,0,39,
0,0,41,1,17,33,21,54,55,54,51,50,23,30,1,23,22,29,
1,17,33,17,53,52,39,38,39,38,39,38,39,38,34,7,6,7,
6,7,6,7,6,21,1,121,254,254,1,2,44,89,87,103,57,53,
51,98,27,28,254,254,8,9,15,16,22,25,25,27,66,29,27,27,
26,18,17,11,11,4,50,162,81,55,54,28,27,110,82,84,103,245,
252,205,3,57,108,88,52,59,36,39,19,22,7,8,8,7,23,21,
37,35,60,63,77,0,0,0,0,3,0,80,255,228,4,65,5,210,
0,18,0,27,0,46,0,0,19,16,55,54,51,50,23,22,17,20,
2,7,6,43,1,34,38,39,38,1,33,38,39,38,35,34,7,6,
1,33,22,23,22,23,22,23,22,23,22,51,50,55,54,55,54,55,
54,80,135,134,241,238,131,130,118,114,115,157,1,157,230,59,58,1,
17,1,208,11,32,46,138,139,51,37,1,201,254,41,1,4,5,17,
15,27,28,40,42,56,71,46,48,25,26,10,7,2,244,1,89,195,
194,194,193,254,165,227,254,154,99,100,200,177,174,1,127,158,75,109,
111,78,254,119,42,60,74,76,67,43,43,23,24,34,35,72,72,95,
57,0,0,1,0,138,0,12,3,3,4,49,0,21,0,0,19,33,
3,21,20,23,22,51,50,55,54,55,23,6,7,6,35,34,39,46,
1,53,138,1,3,1,33,32,51,24,28,26,12,169,54,55,58,81,
94,91,88,112,4,49,253,104,57,50,30,31,13,12,17,172,60,19,
20,56,54,188,99,0,0,1,0,23,255,255,4,2,4,50,0,10,
0,0,1,17,33,17,33,17,1,33,9,1,33,1,35,254,244,1,
12,1,144,1,79,254,5,1,246,254,176,1,158,254,97,4,51,254,
110,1,145,253,244,253,219,0,0,1,0,72,0,0,3,195,5,234,
0,7,0,0,1,3,51,1,35,11,1,33,1,155,120,197,1,219,
247,193,180,254,241,4,49,1,185,250,22,2,174,253,82,0,0,1,
0,143,254,115,3,238,4,49,0,29,0,0,37,17,35,17,51,17,
20,23,22,23,22,23,22,51,50,55,54,53,17,51,17,35,53,6,
7,6,35,34,39,38,1,131,244,248,20,19,32,28,36,30,30,68,
54,54,244,244,24,52,54,40,56,64,66,78,254,37,5,190,253,162,
71,55,53,29,26,15,13,87,86,89,2,94,251,207,84,52,30,31,
33,34,0,0,0,1,0,72,0,0,3,195,4,49,0,6,0,0,
33,1,33,27,1,51,1,1,155,254,173,1,15,180,193,247,254,173,
4,49,253,82,2,174,251,207,0,1,0,39,254,130,4,21,5,208,
0,63,0,0,37,50,23,22,23,22,23,22,21,20,7,6,7,39,
54,53,52,39,38,43,1,6,35,34,39,38,39,38,39,38,53,52,
55,54,55,54,55,54,55,38,53,52,55,35,53,33,21,33,6,7,
6,21,20,22,59,1,21,35,34,7,6,21,20,22,2,64,50,54,
160,90,101,13,1,29,29,46,212,31,31,31,42,27,34,19,107,93,
95,65,68,36,38,20,19,38,36,36,32,52,145,26,149,3,126,254,
153,62,44,54,110,75,142,165,92,70,71,130,211,10,28,80,73,174,
6,13,57,60,59,33,163,29,54,42,32,33,2,37,38,62,65,81,
85,89,73,65,61,49,46,33,30,34,103,173,85,70,240,240,8,42,
51,96,72,118,213,66,66,90,93,122,0,0,0,2,0,92,255,227,
4,12,4,76,0,5,0,19,0,0,1,16,32,17,16,32,3,16,
55,54,51,50,23,22,16,2,35,34,39,38,1,88,1,188,254,68,
252,124,125,224,225,123,123,246,225,226,123,124,2,25,254,181,1,75,
1,73,254,183,1,4,151,152,151,152,253,248,254,206,151,153,0,1,
0,47,0,1,4,50,4,50,0,11,0,0,1,33,17,33,17,35,
53,33,21,35,17,33,2,244,254,134,254,254,73,4,3,60,254,254,
3,66,252,191,3,65,240,240,252,191,0,2,0,92,254,85,4,12,
4,76,0,14,0,20,0,0,19,16,55,54,51,50,23,22,16,2,
35,34,39,17,39,19,16,32,17,16,32,92,124,125,224,225,123,123,
246,225,128,93,251,251,1,188,254,68,2,25,1,4,151,152,151,152,
253,248,254,206,47,254,67,1,3,195,254,181,1,75,1,73,0,0,
0,1,0,86,255,227,3,211,4,76,0,38,0,0,1,38,35,34,
7,6,21,20,23,22,51,50,55,54,55,62,1,55,23,6,7,6,
7,6,7,6,35,34,39,38,17,52,55,54,51,50,23,22,23,2,
254,64,116,99,69,70,74,75,109,40,26,28,14,12,28,8,214,26,
37,32,51,47,57,60,60,239,141,140,141,141,218,115,111,108,59,2,
244,114,96,97,145,148,90,91,10,11,15,13,46,17,111,43,42,36,
38,35,19,20,153,152,1,0,253,157,158,64,62,106,0,0,0,2,
0,92,255,227,4,116,4,76,0,15,0,21,0,0,19,16,55,54,
51,33,23,35,22,21,16,2,35,34,39,38,19,16,32,17,16,32,
92,124,125,224,2,62,1,173,69,246,225,226,123,124,252,1,188,254,
68,2,25,1,4,151,152,234,134,195,254,252,254,206,151,153,1,6,
254,181,1,75,1,73,0,1,0,119,0,21,4,42,4,50,0,25,
0,0,19,33,21,5,3,21,20,23,22,51,50,54,55,23,6,7,
6,35,34,39,38,39,38,39,3,37,119,3,131,254,191,6,33,34,
49,27,50,13,169,54,54,58,82,93,91,96,50,52,3,4,254,202,
4,50,239,1,254,96,57,49,30,32,24,18,172,61,18,20,56,60,
89,92,100,1,160,1,0,0,0,1,0,108,255,216,3,236,4,96,
0,54,0,0,1,17,20,23,22,23,22,23,22,51,50,54,51,54,
55,54,55,54,55,54,55,54,53,52,39,38,39,38,39,38,35,55,
50,30,1,23,22,21,20,7,6,7,6,7,6,7,6,35,34,39,
38,39,38,25,1,1,110,12,9,19,22,34,35,35,2,10,2,36,
16,25,27,28,20,19,14,13,20,19,32,30,37,36,39,93,95,150,
88,23,24,24,23,45,53,66,66,73,64,61,59,74,106,108,74,4,
49,253,231,80,60,50,46,54,21,20,1,4,4,7,23,23,35,32,
64,19,120,103,71,65,38,35,19,18,234,92,156,102,106,147,64,117,
110,68,82,40,42,18,16,16,24,117,81,1,81,2,26,0,0,0,
0,2,0,58,254,116,4,155,3,244,0,50,0,68,0,0,1,17,
38,39,38,39,46,1,39,38,53,52,55,54,55,54,55,23,6,7,
6,21,20,22,23,22,23,30,1,51,17,52,55,54,55,54,59,1,
22,23,22,23,22,21,20,7,6,7,6,7,17,19,38,35,34,7,
6,29,1,17,54,55,54,55,62,1,53,52,38,1,224,18,25,73,
69,68,106,31,32,33,33,53,56,67,66,49,30,30,62,48,49,57,
1,5,1,56,56,88,59,95,22,99,68,76,38,42,77,76,120,70,
97,125,21,18,30,24,33,23,7,55,49,48,60,66,254,116,1,125,
4,7,21,45,44,128,88,91,103,110,95,96,61,65,44,199,43,71,
70,88,83,140,39,40,21,1,2,1,189,98,95,92,56,36,24,72,
83,95,105,117,155,127,126,67,39,16,254,130,4,161,12,29,30,50,
57,254,63,7,3,23,43,42,132,80,88,144,0,0,0,1,0,30,
254,116,3,48,4,49,0,11,0,0,1,35,11,1,35,9,1,51,
27,1,51,1,3,48,252,141,141,252,1,11,254,245,252,141,141,252,
254,245,254,116,1,132,254,124,2,222,2,223,254,124,1,132,253,33,
0,0,0,1,0,92,254,116,4,12,4,236,0,30,0,0,1,48,
17,16,7,6,7,17,33,17,38,39,38,53,48,53,54,53,52,39,
33,6,17,20,23,17,33,17,54,53,3,4,12,123,84,127,254,243,
133,84,124,3,3,1,1,5,89,1,13,86,3,4,49,253,232,254,
252,153,103,33,254,128,1,126,33,103,153,250,12,248,134,133,21,62,
254,38,209,77,3,241,252,17,78,206,2,24,0,1,0,108,255,216,
6,106,4,96,0,102,0,0,1,17,33,17,20,23,22,23,22,23,
22,51,50,54,51,54,55,54,55,54,55,54,55,54,53,52,39,38,
39,38,39,38,35,55,50,22,23,22,23,22,21,20,7,6,7,14,
1,7,6,35,34,39,38,39,6,7,6,35,34,39,38,39,38,39,
38,39,38,53,52,55,62,2,51,23,34,7,6,7,6,7,6,21,
20,23,22,23,22,23,22,23,22,23,50,22,51,50,55,54,55,54,
55,54,2,234,1,2,12,9,20,23,32,35,36,3,8,3,34,17,
25,27,28,20,19,14,13,20,19,32,30,37,36,39,93,95,150,44,
46,22,23,24,23,45,51,136,71,64,61,59,74,79,80,79,80,74,
59,61,64,73,66,66,53,45,23,24,24,23,88,150,95,93,38,36,
39,29,32,19,20,13,14,20,21,26,27,25,16,36,2,10,2,35,
35,34,22,20,9,11,2,24,1,8,254,248,80,60,46,50,54,21,
20,1,4,4,7,23,23,35,32,64,19,120,103,71,65,38,35,19,
18,234,92,78,81,99,102,151,64,117,110,68,80,84,18,16,16,18,
69,69,18,16,16,18,42,40,82,68,110,117,64,147,106,102,156,92,
234,18,20,34,38,65,71,103,120,19,61,35,37,21,23,7,4,4,
1,20,21,54,50,46,55,0,0,0,255,255,255,128,0,12,3,3,
5,235,16,38,1,149,0,0,16,7,0,105,255,61,254,106,0,3,
0,39,255,216,3,236,5,234,0,7,0,15,0,70,0,0,18,52,
54,50,22,20,6,34,36,52,54,50,22,20,6,34,7,17,20,23,
22,23,22,23,22,51,50,54,51,54,55,54,55,54,55,54,55,54,
53,52,39,38,39,38,39,38,35,55,50,30,1,23,22,21,20,7,
6,7,6,7,6,7,6,35,34,39,38,39,38,25,1,39,96,136,
96,96,136,1,119,96,136,96,96,136,240,12,9,19,22,34,35,35,
2,10,2,36,16,25,27,28,20,19,14,13,20,19,32,30,37,36,
39,93,95,150,88,23,24,24,23,45,53,66,66,73,64,61,59,74,
106,108,74,5,2,136,96,96,136,96,96,136,96,96,136,96,113,253,
231,80,60,50,46,54,21,20,1,4,4,7,23,23,35,32,64,19,
120,103,71,65,38,35,19,18,234,92,156,102,106,147,64,117,110,68,
82,40,42,18,16,16,24,117,81,1,81,2,26,0,0,0,0,3,
0,92,255,227,4,12,6,63,0,5,0,19,0,47,0,0,1,16,
32,17,16,32,3,16,55,54,51,50,23,22,16,2,35,34,39,38,
1,6,7,6,34,39,38,39,38,39,38,55,19,54,55,54,55,51,
50,23,22,23,22,23,22,21,20,7,1,88,1,188,254,68,252,124,
125,224,225,123,123,246,225,226,123,124,2,43,3,13,14,52,18,16,
29,25,9,4,1,51,5,27,23,23,13,20,15,26,27,28,12,6,
2,2,25,254,181,1,75,1,73,254,183,1,4,151,152,151,152,253,
248,254,206,151,153,3,149,11,7,7,3,3,19,16,19,10,5,1,
54,23,12,11,1,3,5,19,20,26,12,11,3,8,255,255,0,108,
255,216,3,236,6,63,16,38,1,161,0,0,16,6,1,100,154,0,
0,0,255,255,0,108,255,216,6,106,6,63,16,38,1,165,0,0,
16,7,1,100,1,17,0,0,0,2,0,105,255,228,4,65,5,210,
0,47,0,63,0,0,19,51,6,21,20,23,22,23,22,23,22,51,
50,55,54,55,54,55,54,55,34,39,38,39,38,39,48,53,52,63,
1,54,32,23,22,17,20,2,7,6,43,1,34,39,38,39,38,53,
37,38,39,38,35,34,7,6,21,20,23,22,23,22,23,22,105,234,
1,16,24,33,34,41,42,56,71,46,48,25,26,10,7,3,199,139,
140,78,74,6,31,1,136,1,220,131,130,118,114,115,157,1,157,115,
132,42,33,2,202,7,38,55,119,195,8,2,31,32,54,56,59,56,
2,154,14,28,78,81,122,40,42,23,24,34,35,72,72,95,57,87,
56,56,80,74,173,28,113,50,1,193,194,193,254,165,227,254,154,99,
100,100,116,161,129,161,222,197,81,121,121,22,12,70,49,51,25,27,
11,11,0,3,0,92,254,116,4,12,5,174,0,20,0,25,0,30,
0,0,19,16,55,54,55,17,51,17,22,23,22,16,7,6,7,17,
35,17,38,39,38,1,6,21,20,23,19,17,54,53,52,92,124,88,
137,243,139,90,123,123,89,140,243,138,87,124,1,93,97,97,243,104,
2,25,1,4,151,108,31,1,111,254,146,30,109,152,253,248,153,110,
31,254,133,1,124,32,106,153,2,41,73,218,220,73,2,77,253,174,
72,226,225,0,0,0,0,2,0,108,255,216,6,106,4,101,0,39,
0,101,0,0,19,33,21,35,22,23,22,21,20,7,6,7,14,1,
7,6,35,34,39,38,39,6,7,6,35,34,39,38,39,38,39,38,
39,38,53,52,55,54,55,35,1,17,33,17,20,23,22,23,22,23,
22,51,50,54,51,54,55,54,55,54,55,54,55,54,53,52,39,38,
39,38,39,38,39,33,6,7,6,7,6,7,6,21,20,23,22,23,
22,23,22,23,22,23,50,22,51,50,55,54,55,54,55,54,114,5,
244,55,23,13,23,24,23,45,51,136,71,64,61,59,74,79,80,79,
80,74,59,61,64,73,66,66,53,45,23,24,24,13,23,54,2,120,
1,2,12,9,20,23,32,35,36,3,8,3,34,17,25,27,28,20,
19,14,13,20,19,32,30,37,28,28,253,143,28,28,39,29,32,19,
20,13,14,20,21,26,27,25,16,36,2,10,2,35,35,34,22,20,
9,11,4,101,240,55,60,102,151,64,117,110,68,80,84,18,16,16,
18,69,69,18,16,16,18,42,40,82,68,110,117,64,147,106,60,55,
254,163,1,8,254,248,80,60,46,50,54,21,20,1,4,4,7,23,
23,35,32,64,19,120,103,71,65,38,35,19,14,3,3,14,20,34,
38,65,71,103,120,19,61,35,37,21,23,7,4,4,1,20,21,54,
50,46,55,0,0,3,0,114,0,0,4,72,7,129,0,10,0,21,
0,33,0,0,19,52,54,50,22,20,6,35,34,39,38,37,52,54,
50,22,20,6,35,34,39,38,5,33,21,33,17,33,21,33,17,33,
21,33,253,96,136,96,96,68,67,49,48,1,215,96,136,96,96,68,
67,49,48,253,158,3,214,253,54,2,140,253,116,2,202,252,42,6,
221,68,96,96,136,96,49,48,67,68,96,96,136,96,49,48,234,239,
254,161,239,254,125,240,0,0,0,1,255,210,0,0,4,109,5,172,
0,60,0,0,41,1,17,35,53,33,21,35,17,54,55,54,51,50,
23,30,1,23,22,29,1,51,21,20,14,1,35,34,39,38,39,55,
22,23,22,51,50,55,54,61,1,35,53,52,39,38,39,38,39,38,
39,38,35,34,7,6,7,6,7,6,21,1,121,254,254,165,2,92,
181,35,124,78,140,93,53,51,126,27,28,1,110,182,93,82,58,54,
54,169,12,26,28,24,51,32,33,1,8,9,29,30,40,44,24,27,
33,44,32,69,43,10,32,23,4,188,240,240,254,212,50,86,54,28,
27,110,82,84,103,179,92,101,184,112,20,18,61,172,17,12,13,31,
33,47,86,111,88,52,58,37,38,20,22,7,8,8,20,68,15,80,
58,82,0,0,255,255,0,115,0,0,4,73,7,153,16,38,1,191,
0,0,16,7,0,117,1,60,0,0,0,1,0,90,255,223,4,208,
5,217,0,54,0,0,1,2,33,34,39,38,39,38,39,38,39,38,
53,52,55,54,55,54,55,54,55,54,51,50,23,22,23,7,38,39,
38,35,34,7,6,7,14,1,7,20,6,21,33,21,33,22,23,22,
23,22,23,22,51,50,55,4,208,159,254,164,137,111,110,71,70,48,
49,19,20,21,21,48,49,71,73,109,111,134,177,130,129,57,255,41,
66,68,63,79,62,63,39,38,52,10,2,1,187,254,64,3,14,22,
39,41,69,70,90,136,112,1,54,254,169,44,44,75,75,101,103,111,
114,120,119,105,107,95,98,68,70,40,41,91,90,129,89,66,46,47,
27,28,46,46,132,70,2,9,3,240,40,67,98,75,78,43,44,201,
0,0,0,1,0,83,255,227,4,102,5,212,0,77,0,0,19,37,
22,23,22,51,50,55,54,53,52,39,38,39,38,39,38,39,46,1,
39,38,39,38,39,38,39,38,39,38,39,38,53,52,55,54,55,54,
55,54,51,50,23,22,23,5,38,35,34,7,6,21,20,23,22,23,
22,23,22,23,22,23,22,23,22,23,22,23,22,23,22,21,20,4,
35,34,39,38,83,1,12,26,66,69,108,111,61,60,19,21,26,29,
47,53,37,7,75,24,71,37,49,31,28,44,38,25,23,17,16,41,
42,67,67,88,84,96,167,129,130,43,254,239,50,146,94,58,59,27,
25,51,44,54,83,27,71,23,50,50,42,43,41,28,24,18,16,254,
222,216,209,149,150,1,148,43,102,65,67,53,52,86,47,37,40,22,
25,23,26,15,3,28,10,29,17,24,18,17,35,31,37,35,53,51,
63,97,79,82,46,47,26,25,87,87,132,51,116,37,38,86,40,34,
32,28,24,22,34,10,27,11,24,29,25,38,37,43,37,64,57,70,
197,236,119,120,0,1,0,143,0,0,1,156,5,176,0,3,0,0,
51,17,33,17,143,1,13,5,176,250,80,0,0,0,0,3,255,139,
0,0,2,170,7,129,0,10,0,21,0,25,0,0,3,52,54,50,
22,20,6,35,34,39,38,37,52,54,50,22,20,6,35,34,39,38,
3,17,33,17,117,96,136,96,96,68,67,49,48,1,215,96,136,96,
96,68,67,49,48,211,1,13,6,221,68,96,96,136,96,49,48,67,
68,96,96,136,96,49,48,249,102,5,176,250,80,0,0,0,0,1,
0,102,255,221,4,104,5,176,0,38,0,0,19,51,20,23,22,23,
22,23,22,51,50,55,54,55,54,55,54,53,17,33,53,33,21,17,
20,7,6,7,6,35,34,39,38,39,38,39,38,39,38,102,241,14,
13,32,31,54,55,74,70,49,51,25,25,12,12,254,141,2,127,56,
56,117,118,165,106,84,88,58,59,41,39,20,19,2,74,69,64,60,
57,55,31,31,31,32,54,53,62,61,74,2,118,240,240,253,138,184,
139,138,80,80,31,32,54,54,80,75,95,91,0,0,0,2,0,66,
0,0,7,100,5,176,0,41,0,47,0,0,1,33,21,17,51,50,
23,22,23,30,1,21,20,7,6,7,6,7,6,43,1,33,17,35,
3,6,7,14,1,35,34,39,38,39,55,22,23,22,51,50,63,1,
1,17,51,32,16,33,2,83,2,105,130,126,107,102,71,68,76,34,
33,69,65,107,105,137,130,254,244,125,120,20,35,55,182,93,82,58,
54,54,169,12,26,28,24,43,32,41,3,3,130,1,20,254,236,5,
176,239,254,171,35,34,61,59,162,89,93,77,76,62,59,35,34,4,
193,252,204,134,59,92,112,20,18,61,172,17,12,13,24,87,1,37,
254,118,1,138,0,2,0,115,0,0,6,106,5,176,0,29,0,35,
0,0,19,33,17,33,17,33,51,17,51,50,23,22,23,30,1,21,
20,7,6,7,6,7,6,43,1,33,17,33,17,33,37,51,32,16,
33,35,115,1,12,1,55,1,12,1,129,126,107,102,71,68,76,34,
33,69,65,107,105,137,129,254,243,254,201,254,244,3,80,129,1,20,
254,236,129,5,176,253,176,2,80,253,188,35,34,61,59,162,89,93,
77,76,62,59,35,34,2,113,253,143,239,1,138,0,0,0,0,1,
0,0,0,0,3,246,5,174,0,41,0,0,41,1,17,35,53,33,
21,35,17,54,55,54,51,50,23,30,1,23,22,21,17,33,17,52,
39,38,39,38,39,38,39,38,34,7,6,7,6,7,6,7,6,21,
1,121,254,254,119,1,248,127,44,89,87,103,57,53,51,98,27,28,
254,254,8,9,15,16,22,25,25,27,66,29,27,27,26,18,17,11,
11,4,190,240,240,254,210,81,55,54,28,27,110,82,84,103,253,100,
2,25,88,52,59,36,39,19,22,7,8,8,7,23,21,37,35,60,
63,77,0,0,255,255,0,115,0,0,5,10,7,153,16,38,1,198,
0,0,16,7,0,117,1,156,0,0,255,255,255,188,0,0,4,224,
7,129,16,38,1,207,0,0,16,7,0,105,0,200,0,0,0,1,
0,116,255,16,4,114,5,176,0,11,0,0,5,53,33,17,33,17,
33,17,33,17,33,21,1,248,254,124,1,12,1,228,1,14,254,118,
240,240,5,176,251,63,4,193,250,80,240,0,0,0,0,2,0,47,
0,0,5,94,5,176,0,2,0,10,0,0,1,3,33,23,33,3,
33,1,33,1,33,2,214,159,1,44,75,254,64,136,254,201,2,51,
1,0,1,252,254,205,4,24,254,89,246,254,133,5,176,250,80,0,
0,0,0,2,0,121,0,0,4,45,5,176,0,23,0,29,0,0,
51,17,53,33,21,33,17,51,50,23,22,23,22,23,22,21,20,6,
7,6,7,6,43,1,25,1,51,32,16,33,121,3,31,253,237,130,
126,107,104,70,68,38,37,70,65,64,110,105,136,130,130,1,20,254,
236,4,192,240,240,254,172,35,34,61,59,81,78,92,91,158,59,58,
36,34,2,121,254,118,1,138,0,3,0,119,0,0,4,139,5,176,
0,7,0,17,0,54,0,0,1,17,51,50,54,53,52,33,3,17,
51,50,55,54,52,39,38,35,37,33,50,23,22,23,22,23,22,23,
22,23,22,23,22,21,20,7,6,7,22,23,22,23,22,21,20,7,
6,7,6,7,6,7,6,35,33,1,131,227,155,130,254,227,227,168,
137,60,59,59,61,136,254,76,1,180,90,79,78,52,53,41,39,25,
22,16,15,5,5,56,56,93,97,69,70,28,29,11,11,33,33,55,
54,98,99,125,253,243,2,127,254,113,116,91,192,2,68,254,170,51,
50,142,49,50,237,14,14,22,23,33,32,34,30,42,40,34,37,31,
108,68,69,28,23,66,67,69,72,61,50,55,56,60,61,47,46,32,
32,0,0,0,0,1,0,115,0,0,4,73,5,176,0,5,0,0,
1,17,33,17,33,21,1,127,254,244,3,214,4,193,251,63,5,176,
239,0,0,0,0,2,0,74,255,15,6,40,5,176,0,14,0,20,
0,0,1,33,17,23,17,35,53,33,21,35,17,37,54,63,1,5,
3,35,3,6,7,2,83,2,229,240,240,252,2,240,1,47,16,7,
41,2,115,1,248,120,15,23,5,176,251,64,1,254,32,241,241,1,
224,1,8,5,87,97,3,206,252,204,102,55,0,1,0,114,0,0,
4,72,5,176,0,11,0,0,19,33,21,33,17,33,21,33,17,33,
21,33,114,3,214,253,54,2,140,253,116,2,202,252,42,5,176,239,
254,161,239,254,125,240,0,1,0,113,0,0,6,14,5,176,0,23,
0,0,19,33,1,17,39,23,53,33,51,3,23,1,33,9,1,33,
3,7,17,33,17,3,33,1,119,1,53,1,11,1,1,1,13,5,
5,2,1,13,1,53,254,91,1,171,254,175,247,2,254,243,245,254,
175,1,171,5,176,254,15,1,238,3,2,2,254,15,4,1,245,253,
39,253,41,1,204,4,254,56,1,200,254,56,2,215,0,0,0,1,
0,93,255,228,4,76,5,210,0,58,0,0,19,37,22,23,22,51,
50,55,54,53,52,39,38,43,1,53,51,50,55,54,53,52,38,35,
34,7,6,7,39,18,33,50,23,30,2,21,20,7,22,23,22,23,
22,23,22,21,20,7,6,7,6,7,6,35,34,39,46,1,93,1,
2,37,68,67,75,101,67,65,71,69,93,165,142,75,55,55,108,83,
58,45,44,20,250,108,1,52,91,75,76,128,74,145,52,32,39,33,
37,20,20,38,36,68,64,96,93,107,115,93,94,160,1,67,70,92,
44,43,62,61,92,91,66,65,213,60,59,71,97,102,33,32,46,66,
1,26,22,22,92,154,104,173,103,34,30,35,43,48,63,65,73,90,
85,81,65,61,38,37,34,34,164,0,0,0,0,1,0,119,0,0,
4,197,5,176,0,9,0,0,19,33,17,1,33,17,33,17,1,33,
119,1,12,2,57,1,9,254,243,253,195,254,252,5,176,252,51,3,
205,250,80,3,172,252,84,0,0,0,0,2,0,119,0,0,4,197,
7,150,0,9,0,34,0,0,19,33,17,1,33,17,33,17,1,33,
1,54,55,51,22,21,20,7,6,7,6,34,39,38,39,38,53,52,
55,51,22,23,22,23,54,119,1,12,2,57,1,9,254,243,253,195,
254,252,2,102,47,80,157,1,70,40,83,78,160,78,83,40,70,1,
161,56,66,22,49,42,5,176,252,51,3,205,250,80,3,172,252,84,
6,232,34,140,10,21,117,118,68,47,45,45,47,68,118,117,21,10,
129,44,15,2,2,0,0,0,0,1,0,115,0,0,5,10,5,176,
0,11,0,0,19,33,17,1,33,9,1,33,1,7,17,33,115,1,
12,2,31,1,79,253,212,2,73,254,176,254,58,117,254,244,5,176,
253,145,2,111,253,120,252,216,2,116,132,254,16,0,0,1,0,66,
0,0,5,56,5,176,0,23,0,0,1,33,17,33,17,35,3,6,
7,14,1,35,34,39,38,39,55,22,23,22,51,50,63,1,2,83,
2,229,254,243,248,120,20,35,55,182,93,82,58,54,54,169,12,26,
28,24,43,32,41,5,176,250,80,4,193,252,204,134,59,92,112,20,
18,61,172,17,12,13,24,87,0,1,0,66,0,0,5,211,5,176,
0,12,0,0,51,17,33,9,1,33,17,33,17,1,33,1,17,66,
1,104,1,93,1,101,1,103,254,250,254,194,254,242,254,199,5,176,
251,248,4,8,250,80,3,231,252,25,3,220,252,36,0,1,0,115,
0,0,4,113,5,176,0,11,0,0,19,33,17,33,17,33,17,33,
17,33,17,33,115,1,12,1,229,1,13,254,243,254,27,254,244,5,
176,253,176,2,80,250,80,2,113,253,143,0,0,2,0,100,255,227,
5,49,5,209,0,35,0,73,0,0,1,52,38,39,38,39,38,35,
34,7,6,7,6,7,6,7,6,21,20,23,22,23,22,23,30,1,
51,50,55,54,55,54,55,54,55,54,37,52,55,54,55,54,55,54,
55,54,32,23,22,23,30,1,23,22,21,20,7,6,7,6,7,6,
7,6,35,34,39,38,39,38,39,38,39,38,4,23,34,35,34,70,
68,91,75,58,56,38,40,22,26,8,9,10,11,23,25,36,38,116,
73,75,58,57,37,40,22,26,8,9,252,77,20,19,48,45,71,69,
106,105,1,8,105,106,69,67,96,19,20,20,19,48,46,70,68,107,
105,131,130,105,109,67,70,46,47,21,20,2,242,89,170,73,72,46,
45,30,29,50,53,61,71,62,67,72,82,70,75,70,74,51,53,66,
33,32,54,58,67,77,68,73,79,98,102,95,101,95,77,75,46,46,
46,46,74,71,202,96,102,98,104,108,101,109,103,81,78,50,49,49,
51,77,81,102,105,105,101,0,0,0,0,1,0,115,0,0,4,113,
5,176,0,7,0,0,19,33,17,33,17,33,17,33,115,3,254,254,
243,254,27,254,244,5,176,250,80,4,193,251,63,0,0,2,0,121,
0,0,4,45,5,176,0,5,0,26,0,0,1,51,32,16,33,35,
37,33,51,50,23,22,23,30,1,21,20,7,6,7,6,7,6,43,
1,17,33,1,133,130,1,20,254,236,130,254,244,1,12,130,136,105,
110,64,65,70,37,38,68,70,104,107,126,130,254,244,3,55,1,138,
239,34,36,58,59,158,91,92,78,81,59,61,34,35,253,188,0,1,
0,90,255,223,4,208,5,217,0,50,0,0,1,2,33,34,39,38,
39,38,39,38,39,38,53,52,55,54,55,54,55,54,55,54,51,50,
23,22,23,7,38,39,38,35,34,7,6,7,14,1,7,6,21,20,
23,22,23,22,23,22,51,50,55,4,208,159,254,164,137,111,110,71,
70,48,49,19,20,21,21,48,49,71,73,109,111,134,177,130,129,57,
255,41,66,68,63,79,62,63,39,38,52,10,11,21,22,39,41,69,
70,90,136,112,1,54,254,169,44,44,75,75,101,103,111,114,120,119,
105,107,95,98,68,70,40,41,91,90,129,89,66,46,47,27,28,46,
46,132,70,74,80,111,96,98,75,78,43,44,201,0,0,1,0,78,
0,0,5,0,5,176,0,7,0,0,19,33,21,33,17,33,17,33,
78,4,178,254,55,254,244,254,35,5,176,239,251,63,4,193,0,0,
0,1,255,188,0,0,4,224,5,176,0,21,0,0,19,33,9,1,
33,9,1,14,1,35,34,39,38,39,55,22,23,22,51,50,55,19,
66,1,28,1,54,1,54,1,22,254,60,254,226,55,182,93,82,58,
54,54,169,12,26,28,24,52,31,254,5,176,253,231,2,25,253,17,
254,11,92,112,20,18,61,172,17,12,13,31,1,189,0,0,0,3,
0,96,0,0,5,182,5,174,0,43,0,61,0,84,0,0,1,17,
35,17,38,39,38,39,38,39,38,39,38,53,52,55,54,55,54,55,
54,55,54,55,53,51,21,22,23,22,23,30,1,23,22,20,7,6,
7,6,7,6,7,6,3,17,54,55,54,55,54,55,54,53,52,39,
38,39,38,39,38,39,3,17,34,6,35,6,7,6,7,6,7,6,
21,20,23,22,23,22,23,22,23,22,50,3,157,243,52,21,99,90,
94,71,73,42,44,44,43,72,66,99,93,96,45,28,243,21,34,90,
87,88,134,42,41,41,42,66,63,92,84,93,51,5,11,22,72,69,
65,42,40,27,28,43,47,56,61,58,244,3,12,3,67,64,65,47,
49,29,29,29,31,47,52,60,64,67,3,12,1,59,254,197,1,58,
6,4,17,36,37,56,57,83,86,103,102,86,84,57,52,40,38,16,
8,3,169,171,2,6,17,37,38,110,85,83,212,83,86,55,53,39,
36,17,8,2,229,253,252,1,4,13,29,28,55,53,75,59,47,48,
28,31,18,20,7,253,250,2,7,2,8,19,20,29,30,46,45,60,
61,45,48,28,31,18,19,8,1,0,0,1,0,53,0,0,4,201,
5,176,0,11,0,0,19,33,9,1,33,9,1,33,11,1,33,1,
59,1,53,1,13,1,16,1,54,254,88,1,174,254,175,251,247,254,
175,1,171,5,176,254,11,1,245,253,39,253,41,1,204,254,52,2,
215,0,0,1,0,115,0,0,4,113,5,176,0,7,0,0,51,17,
33,17,33,17,33,17,115,1,12,1,229,1,13,5,176,251,63,4,
193,250,80,0,0,0,0,1,0,119,0,0,3,246,5,175,0,38,
0,0,1,33,17,33,17,14,1,35,34,39,38,39,46,1,61,1,
17,33,17,21,20,23,22,23,22,23,22,23,22,50,55,54,55,54,
55,54,55,54,53,2,244,1,2,254,254,45,174,104,54,55,58,44,
45,58,1,2,9,10,13,15,24,27,21,27,68,29,27,27,26,18,
17,11,10,5,175,250,81,2,31,82,108,29,31,49,51,174,100,245,
1,167,254,83,108,82,58,63,32,36,21,24,6,8,8,8,22,21,
37,34,62,57,82,0,0,0,0,1,0,115,0,0,6,8,5,176,
0,11,0,0,51,17,33,17,33,17,33,17,33,17,33,17,115,1,
12,1,35,1,12,1,77,1,13,5,176,251,63,4,193,251,63,4,
193,250,80,0,0,0,0,1,0,115,255,28,6,248,5,176,0,15,
0,0,51,17,33,17,33,17,33,17,33,17,33,17,55,17,35,53,
115,1,12,1,35,1,12,1,77,1,13,240,240,5,176,251,63,4,
193,251,63,4,193,251,63,1,254,44,228,0,0,2,0,30,0,0,
4,234,5,176,0,22,0,28,0,0,33,17,33,53,33,17,51,50,
23,22,23,22,23,22,21,20,6,7,6,7,6,43,1,25,1,51,
32,16,33,1,54,254,232,2,36,130,127,107,102,71,68,38,37,68,
67,65,108,105,137,130,130,1,20,254,236,4,192,240,253,188,35,34,
61,59,81,78,92,93,154,61,59,35,34,2,121,254,118,1,138,0,
0,3,0,121,0,0,4,124,5,176,0,5,0,26,0,30,0,0,
1,17,51,50,16,35,1,17,33,17,51,50,22,23,22,23,22,21,
20,7,6,7,6,7,6,43,1,33,17,33,17,1,66,98,164,164,
254,213,1,12,31,95,158,51,52,28,28,26,25,51,49,80,78,103,
98,2,45,1,13,2,121,254,118,1,138,253,135,5,176,253,188,70,
60,61,79,78,92,90,80,76,62,59,35,34,5,176,250,80,0,0,
0,2,0,121,0,0,4,45,5,176,0,5,0,26,0,0,1,17,
51,32,16,33,1,17,33,17,51,50,23,22,23,22,23,22,21,20,
6,7,6,7,6,43,1,1,133,130,1,20,254,236,254,114,1,12,
130,126,107,104,70,68,38,37,70,65,64,110,105,136,130,2,121,254,
118,1,138,253,135,5,176,253,188,35,34,61,59,81,78,92,91,158,
59,58,36,34,0,0,0,1,0,90,255,223,4,208,5,217,0,50,
0,0,19,37,22,51,50,55,54,55,54,55,54,53,52,39,46,1,
39,38,39,38,35,34,7,6,7,39,54,55,54,51,50,23,22,23,
22,23,22,23,22,21,20,7,6,7,6,7,6,7,6,35,32,90,
1,3,113,135,90,70,69,41,39,22,21,11,10,52,38,39,63,62,
79,63,68,66,41,255,57,129,130,177,134,111,109,73,71,49,48,21,
21,20,19,49,48,70,71,110,111,137,254,164,1,54,100,201,44,43,
78,75,98,96,111,80,74,70,132,46,46,28,27,47,46,66,89,129,
90,91,41,40,70,68,98,95,107,105,119,120,114,111,103,101,75,75,
44,44,0,0,0,2,0,143,255,228,6,28,5,210,0,26,0,51,
0,0,51,17,33,17,51,54,55,54,51,50,23,22,17,20,7,14,
1,43,1,34,39,38,39,38,39,35,17,1,20,23,22,23,22,23,
22,23,22,51,50,55,54,55,54,55,54,53,16,39,38,35,34,6,
143,1,13,150,24,104,134,241,238,131,130,58,59,230,157,1,157,115,
114,59,48,9,145,1,155,7,5,17,15,27,28,40,42,55,71,46,
48,25,27,10,10,46,46,139,140,102,5,176,253,218,239,151,194,194,
193,254,165,231,175,178,200,100,99,178,146,171,253,102,2,244,98,94,
74,76,67,43,43,23,24,34,35,72,77,90,91,143,1,19,108,109,
222,0,0,2,0,121,0,0,4,140,5,176,0,5,0,31,0,0,
1,17,35,32,16,33,1,33,1,38,39,38,53,52,55,54,55,54,
55,54,59,1,33,17,33,17,35,34,6,35,34,39,3,128,128,254,
234,1,22,254,171,254,206,1,116,132,73,72,34,33,69,65,108,105,
138,128,1,12,254,244,38,12,36,5,43,22,3,55,1,138,254,118,
252,201,2,115,56,108,107,122,93,77,76,62,59,35,34,250,80,2,
68,1,2,0,0,0,0,2,0,90,255,227,3,210,4,78,0,14,
0,64,0,0,1,34,7,6,20,23,22,51,50,55,54,53,52,39,
38,39,50,23,22,23,53,52,39,38,39,46,1,39,38,35,34,6,
7,14,1,7,39,54,55,54,51,50,23,22,23,22,23,22,23,22,
21,25,1,33,53,6,7,6,35,34,39,38,16,55,54,2,23,89,
56,58,57,56,90,86,54,52,52,53,172,99,75,76,19,17,17,23,
25,70,31,33,31,45,90,21,4,41,15,103,46,96,99,78,77,77,
72,65,69,44,47,27,28,254,255,20,75,74,98,153,105,106,105,105,
2,12,50,52,132,50,49,49,48,68,69,49,50,217,51,52,62,82,
58,45,44,25,27,30,5,5,18,9,1,19,6,164,37,28,29,16,
15,37,39,53,56,85,89,103,254,208,254,207,136,62,52,51,111,112,
1,72,110,109,0,2,0,92,255,227,4,12,5,234,0,26,0,36,
0,0,1,33,21,33,34,7,6,29,1,54,51,50,23,22,16,2,
35,34,39,38,17,52,55,17,52,62,1,3,18,51,50,17,16,35,
34,7,21,1,222,1,175,254,81,74,20,33,89,125,225,123,123,246,
225,226,123,124,1,110,182,41,3,219,222,222,182,33,5,234,240,20,
33,47,118,44,151,152,253,248,254,206,151,153,1,6,31,15,2,22,
101,184,112,252,37,254,191,1,75,1,73,223,116,0,0,0,0,3,
0,53,255,255,3,179,4,52,0,8,0,18,0,54,0,0,1,17,
51,50,55,54,53,52,35,3,21,51,50,54,53,52,39,38,35,37,
33,50,23,22,23,30,1,23,22,23,22,23,22,21,20,7,6,7,
22,23,22,23,22,21,20,7,6,7,6,7,6,7,6,35,33,1,
60,161,115,47,48,210,161,117,101,88,44,43,102,254,132,1,189,71,
54,57,39,40,58,18,19,10,13,2,3,41,43,67,71,51,54,19,
21,7,7,26,26,39,38,74,72,95,254,2,1,216,254,217,43,44,
66,142,1,173,253,76,52,50,38,37,175,10,10,17,17,46,26,27,
27,34,20,26,25,83,48,51,20,17,49,52,48,53,46,42,36,38,
47,48,33,32,25,24,0,0,0,1,0,119,0,0,3,246,4,50,
0,5,0,0,19,33,21,33,3,33,119,3,127,253,141,10,254,254,
4,50,239,252,189,0,0,0,0,2,0,68,255,28,4,106,4,50,
0,14,0,20,0,0,5,35,53,33,21,35,17,51,54,63,1,19,
37,17,51,33,17,35,3,6,7,4,106,240,253,186,240,112,10,4,
42,98,2,44,240,254,10,70,64,13,24,228,228,228,1,212,6,3,
87,2,225,1,252,190,2,82,254,71,90,63,0,2,0,78,255,227,
3,248,4,74,0,8,0,43,0,0,1,33,38,39,38,35,34,7,
6,19,50,55,23,6,7,6,35,34,39,38,39,38,39,38,53,52,
55,54,51,50,23,22,23,22,29,1,33,22,23,22,23,22,23,22,
1,96,1,158,8,54,56,90,89,55,56,210,100,54,228,61,108,109,
104,101,89,90,66,68,38,38,140,139,201,132,105,103,60,58,253,104,
1,23,23,35,32,36,33,2,139,91,62,64,64,65,253,230,66,98,
93,52,53,43,44,73,75,105,104,122,240,161,160,72,71,130,126,162,
68,80,57,58,26,24,12,11,0,1,0,84,0,0,5,66,4,49,
0,18,0,0,33,17,39,3,33,9,1,33,19,17,33,17,19,33,
9,1,33,3,17,2,70,1,190,254,205,1,85,254,189,1,34,190,
1,13,187,1,34,254,189,1,85,254,205,188,1,77,2,254,177,2,
24,2,25,254,182,1,74,254,187,1,69,253,231,253,232,1,75,254,
181,0,0,1,0,86,255,227,3,74,4,85,0,60,0,0,63,1,
22,23,22,51,50,55,54,53,52,39,38,43,1,39,51,50,55,54,
53,52,39,38,35,34,6,7,39,54,51,50,22,23,22,23,22,21,
20,7,22,23,22,23,22,23,22,21,20,7,6,7,6,7,6,35,
34,39,38,39,38,86,239,21,38,41,39,56,38,37,40,38,53,93,
2,80,41,32,31,30,31,46,33,50,11,221,81,231,69,110,51,48,
27,28,109,36,27,29,25,29,14,15,29,30,47,50,70,73,78,83,
72,71,60,59,234,60,53,23,25,35,34,52,50,38,37,237,34,32,
41,55,28,29,36,26,65,211,32,35,33,59,61,75,128,79,24,24,
26,33,39,44,48,55,67,64,66,44,47,27,28,26,25,61,59,0,
0,0,0,1,0,130,0,0,3,251,4,53,0,9,0,0,19,51,
17,1,51,17,35,17,1,35,130,216,1,203,214,217,254,49,209,4,
53,253,48,2,208,251,203,2,184,253,72,0,0,0,255,255,0,130,
0,0,3,251,6,61,16,38,1,228,0,0,16,7,1,74,255,91,
254,167,0,1,0,23,255,255,4,2,4,50,0,10,0,0,1,17,
33,17,33,17,1,33,9,1,33,1,35,254,244,1,12,1,144,1,
79,254,5,1,246,254,176,1,158,254,97,4,51,254,110,1,145,253,
244,253,219,0,0,1,0,22,255,252,4,28,4,50,0,24,0,0,
41,1,17,35,3,6,7,6,7,6,35,34,39,38,39,55,22,23,
22,51,50,63,1,19,37,4,28,254,250,70,64,20,36,55,90,91,
94,81,58,55,54,170,12,26,28,24,42,32,42,98,2,44,3,66,
254,71,132,61,93,55,56,20,19,60,172,17,12,13,24,87,2,225,
1,0,0,1,0,63,0,0,4,243,4,53,0,12,0,0,51,17,
33,9,1,33,17,33,17,3,35,3,17,63,1,85,1,2,1,8,
1,85,254,243,235,200,232,4,53,253,5,2,251,251,203,2,227,253,
29,2,219,253,37,0,0,0,0,1,0,115,0,0,3,250,4,50,
0,11,0,0,19,33,3,33,19,33,3,33,17,33,17,33,119,1,
12,4,1,106,4,1,13,4,254,243,254,150,254,244,4,50,254,103,
1,153,251,206,1,170,254,86,0,0,0,2,0,92,255,227,4,12,
4,76,0,5,0,19,0,0,1,16,32,17,16,32,3,16,55,54,
51,50,23,22,16,2,35,34,39,38,1,88,1,188,254,68,252,124,
125,224,225,123,123,246,225,226,123,124,2,25,254,181,1,75,1,73,
254,183,1,4,151,152,151,152,253,248,254,206,151,153,0,1,0,119,
255,255,3,174,4,50,0,7,0,0,19,37,17,33,17,33,3,33,
119,3,55,254,243,254,226,1,254,245,4,49,1,251,206,3,66,252,
189,0,0,0,0,2,0,119,254,86,4,39,4,76,0,25,0,56,
0,0,1,33,17,33,21,54,55,54,51,50,30,1,23,22,20,7,
6,7,6,7,6,35,34,39,38,39,1,52,39,38,39,38,39,38,
35,34,7,6,7,6,7,6,21,20,23,22,23,22,23,22,51,50,
55,54,55,62,1,1,121,254,254,1,2,52,84,82,89,95,150,88,
23,23,23,23,45,44,75,72,97,84,86,85,52,1,170,19,19,32,
30,37,36,39,40,36,37,34,32,22,21,21,21,33,36,35,36,40,
37,36,37,31,33,38,254,86,5,219,156,82,51,50,92,156,102,103,
230,101,99,79,76,46,44,52,52,81,1,124,90,64,65,38,35,19,
18,16,16,36,33,71,68,89,91,68,69,34,38,15,16,21,22,38,
41,128,0,0,0,1,0,86,255,227,3,211,4,76,0,38,0,0,
1,38,35,34,7,6,21,20,23,22,51,50,55,54,55,62,1,55,
23,6,7,6,7,6,7,6,35,34,39,38,17,52,55,54,51,50,
23,22,23,2,254,64,116,99,69,70,74,75,109,40,26,28,14,12,
28,8,214,26,37,32,51,47,57,60,60,239,141,140,141,141,218,115,
111,108,59,2,244,114,96,97,145,148,90,91,10,11,15,13,46,17,
111,43,42,36,38,35,19,20,153,152,1,0,253,157,158,64,62,106,
0,0,0,1,0,119,0,0,3,250,4,50,0,7,0,0,19,33,
21,5,17,33,17,37,119,3,131,254,191,254,244,254,202,4,50,239,
1,252,190,3,66,1,0,1,0,108,254,47,3,235,4,49,0,54,
0,0,5,20,7,6,7,6,7,6,35,34,39,38,39,55,22,23,
22,51,50,54,61,1,6,7,6,35,34,39,38,25,1,33,17,20,
23,22,23,22,23,30,1,51,50,55,54,55,54,55,54,55,54,53,
17,33,17,3,235,40,41,62,66,78,82,79,150,109,110,46,204,20,
52,54,79,84,112,46,85,89,97,149,85,86,1,2,12,13,15,17,
25,22,52,24,25,27,25,27,28,20,19,14,13,1,3,29,80,79,
81,59,63,36,38,70,71,100,112,56,32,33,94,80,220,82,53,55,
143,145,1,20,2,26,253,231,80,60,67,29,33,24,21,16,8,7,
23,23,35,32,64,58,81,2,24,251,236,0,0,3,0,92,254,116,
4,12,5,174,0,20,0,25,0,30,0,0,19,16,55,54,55,17,
51,17,22,23,22,16,7,6,7,17,35,17,38,39,38,1,6,21,
20,23,19,17,54,53,52,92,124,88,137,243,139,90,123,123,89,140,
243,138,87,124,1,93,97,97,243,104,2,25,1,4,151,108,31,1,
111,254,146,30,109,152,253,248,153,110,31,254,133,1,124,32,106,153,
2,41,73,218,220,73,2,77,253,174,72,226,225,0,0,0,0,1,
0,27,0,0,4,2,4,49,0,11,0,0,41,1,11,1,33,9,
1,33,27,1,33,1,3,253,254,205,190,190,254,205,1,85,254,189,
1,34,190,187,1,58,254,166,1,79,254,177,2,24,2,25,254,182,
1,74,253,240,0,1,0,119,255,28,4,234,4,50,0,11,0,0,
5,35,53,33,19,33,19,33,3,33,17,51,4,234,240,252,125,2,
1,9,1,1,106,1,1,13,241,228,228,4,50,252,189,3,67,252,
190,0,0,1,0,128,0,0,3,174,4,49,0,36,0,0,1,51,
17,35,17,14,1,35,34,39,38,39,38,39,38,61,1,17,51,17,
21,20,22,23,22,23,22,23,22,50,54,55,62,1,55,54,53,2,
190,240,240,41,148,94,49,49,47,49,46,26,25,241,14,15,13,21,
20,24,23,64,48,25,23,24,9,10,4,49,251,207,1,151,62,80,
21,20,41,38,65,62,78,184,1,43,254,209,82,62,84,30,27,16,
16,6,6,12,17,16,54,45,50,54,0,1,0,119,0,0,5,190,
4,51,0,12,0,0,1,33,17,33,17,33,17,33,17,33,19,37,
17,2,135,1,12,1,30,1,13,250,185,1,11,1,1,2,4,51,
252,189,3,66,251,206,4,50,252,189,2,3,66,0,0,0,0,1,
0,119,255,28,6,174,4,51,0,16,0,0,1,33,17,33,17,33,
17,55,17,35,53,33,17,33,19,37,17,2,135,1,12,1,30,1,
13,240,240,250,185,1,11,1,1,2,4,51,252,189,3,66,252,189,
1,254,44,228,4,50,252,189,2,3,66,0,0,2,0,28,0,0,
4,102,4,50,0,8,0,34,0,0,1,17,51,50,55,54,53,52,
35,1,33,29,1,51,22,23,22,23,22,23,22,21,20,7,6,7,
6,7,6,7,6,35,33,17,35,1,238,161,116,47,48,211,253,141,
1,210,117,180,103,86,52,53,20,21,8,7,26,26,39,40,72,69,
97,254,1,203,1,217,254,217,43,43,67,142,2,89,240,185,1,37,
30,53,54,51,52,46,36,42,38,47,48,33,34,24,23,3,66,0,
0,0,0,3,0,52,0,0,4,134,4,50,0,3,0,12,0,35,
0,0,1,33,17,33,1,17,51,50,55,54,53,52,35,1,33,17,
51,22,23,22,23,22,23,22,21,20,7,6,7,6,7,6,7,6,
35,33,3,132,1,2,254,254,253,183,86,74,47,48,169,254,163,1,
7,42,139,103,86,51,53,20,21,8,7,26,26,39,40,72,69,97,
254,118,4,49,251,207,1,217,254,217,43,43,67,142,2,89,254,87,
2,36,30,53,54,51,52,46,36,42,38,47,48,33,34,24,23,0,
0,2,0,52,0,0,3,179,4,50,0,8,0,31,0,0,1,17,
51,50,55,54,53,52,35,1,33,17,51,22,23,22,23,22,23,22,
21,20,7,6,7,6,7,6,7,6,35,33,1,59,161,116,47,48,
211,254,88,1,7,117,180,103,87,51,53,20,21,8,7,26,26,39,
40,72,69,97,254,1,1,217,254,217,43,43,67,142,2,89,254,87,
1,37,31,52,54,51,52,46,36,42,38,47,48,33,34,24,23,0,
0,1,0,86,255,227,3,211,4,76,0,40,0,0,1,39,54,55,
54,51,50,0,21,20,0,35,34,39,38,39,38,39,38,39,55,22,
23,22,23,22,23,22,51,50,55,54,55,33,53,33,38,39,38,35,
34,1,43,213,58,110,111,114,218,1,26,254,230,238,60,60,59,46,
48,34,37,26,214,11,10,10,18,14,28,26,39,108,75,46,18,254,
163,1,87,18,34,69,100,115,2,244,112,105,63,64,254,196,252,255,
254,206,20,19,35,35,39,42,43,111,23,17,16,20,15,11,10,91,
57,75,240,61,47,96,0,2,0,139,255,235,5,194,4,79,0,25,
0,48,0,0,51,17,51,17,51,54,55,54,51,50,23,22,17,20,
7,14,1,43,1,34,38,39,38,39,35,17,1,20,22,23,22,23,
30,1,51,50,54,55,54,55,54,53,52,39,38,35,34,7,6,139,
253,141,23,97,127,226,223,123,122,55,55,216,147,1,148,216,55,44,
9,136,1,130,12,15,16,23,25,78,53,66,88,24,25,10,10,44,
43,130,132,48,48,4,53,254,105,178,111,144,144,143,254,255,171,129,
130,150,150,129,107,128,254,19,2,47,81,120,51,53,29,31,36,52,
53,56,68,67,105,202,82,81,83,83,0,2,0,52,0,0,3,179,
4,50,0,25,0,34,0,0,41,1,17,35,3,33,1,38,39,38,
39,38,39,38,53,52,55,54,55,54,55,54,55,54,51,33,1,17,
35,34,7,6,21,20,51,3,178,254,250,97,227,254,206,1,13,28,
12,85,52,53,20,21,8,7,26,26,39,38,74,72,94,1,255,254,
249,161,116,47,48,211,1,169,254,87,1,195,8,4,29,54,55,49,
52,47,36,42,38,47,48,33,32,25,24,254,39,1,39,43,43,67,
142,0,0,0,0,4,0,78,255,227,3,248,5,234,0,7,0,15,
0,24,0,59,0,0,18,52,54,50,22,20,6,34,36,52,54,50,
22,20,6,34,1,33,38,39,38,35,34,7,6,19,50,55,23,6,
7,6,35,34,39,38,39,38,39,38,53,52,55,54,51,50,23,22,
23,22,29,1,33,22,23,22,23,22,23,22,151,96,136,96,96,136,
1,119,96,136,96,96,136,254,146,1,158,8,54,56,90,89,55,56,
210,100,54,228,61,108,109,104,101,89,90,66,68,38,38,140,139,201,
132,105,103,60,58,253,104,1,23,23,35,32,36,33,5,2,136,96,
96,136,96,96,136,96,96,136,96,253,233,91,62,64,64,65,253,230,
66,98,93,52,53,43,44,73,75,105,104,122,240,161,160,72,71,130,
126,162,68,80,57,58,26,24,12,11,0,0,0,1,0,119,0,0,
3,246,5,174,0,37,0,0,41,1,17,33,17,54,55,54,51,50,
23,30,1,23,22,21,17,33,17,52,39,38,39,38,39,38,39,38,
34,7,6,7,6,7,6,7,6,21,1,121,254,254,1,2,44,89,
87,103,57,53,51,98,27,28,254,254,8,9,15,16,22,25,25,27,
66,29,27,27,26,18,17,11,11,5,174,253,226,81,55,54,28,27,
110,82,84,103,253,100,2,25,88,52,59,36,39,19,22,7,8,8,
7,23,21,37,35,60,63,77,0,0,255,255,0,119,0,0,3,246,
6,61,16,38,1,223,0,0,16,7,0,117,1,43,254,164,0,1,
0,86,255,227,3,211,4,76,0,41,0,0,1,38,35,34,7,6,
7,33,21,33,22,23,22,51,50,55,54,55,62,1,55,23,6,7,
6,7,6,7,6,35,34,39,38,17,52,55,54,51,50,23,22,23,
2,254,64,116,99,69,35,18,1,87,254,163,18,45,75,109,40,26,
28,14,12,28,8,214,26,37,32,51,47,57,60,60,239,141,140,141,
141,218,115,111,108,59,2,244,114,96,49,59,240,76,56,91,10,11,
15,13,46,17,111,43,42,36,38,35,19,20,153,152,1,0,253,157,
158,64,62,106,0,1,0,78,255,227,3,117,4,76,0,82,0,0,
1,38,39,38,39,38,39,46,1,53,52,55,54,51,50,23,22,23,
22,23,22,23,7,38,39,38,35,34,7,14,1,7,6,21,20,23,
22,23,22,23,30,1,23,22,23,30,1,21,20,7,6,7,6,35,
34,39,38,39,55,22,23,22,51,50,55,54,55,54,55,54,55,54,
53,52,39,38,39,38,39,46,1,39,38,1,86,21,57,30,30,27,
18,15,20,100,100,170,84,66,71,45,49,27,29,9,240,10,34,33,
59,20,28,20,40,8,10,14,15,27,20,42,9,55,18,39,54,114,
106,55,57,89,90,109,162,107,106,32,232,10,50,49,64,34,13,19,
23,18,16,13,9,9,17,18,30,33,33,11,55,16,53,1,235,11,
34,18,27,24,33,27,94,51,134,78,78,26,28,42,45,51,54,53,
43,64,24,24,4,3,18,17,20,25,26,20,21,14,10,16,4,21,
7,15,25,55,154,125,87,68,70,37,37,86,85,148,39,59,35,34,
1,1,7,5,11,8,19,18,24,26,23,25,16,18,15,5,22,7,
23,0,0,0,0,2,0,121,0,0,1,159,5,214,0,11,0,15,
0,0,18,52,55,54,50,23,22,20,7,6,34,39,7,33,17,33,
121,43,44,120,44,43,43,44,120,44,25,1,2,254,254,4,245,130,
47,48,48,47,130,47,48,48,149,251,207,0,0,0,0,3,255,123,
0,0,2,154,5,215,0,10,0,21,0,25,0,0,3,52,54,50,
22,20,6,35,34,39,38,37,52,54,50,22,20,6,35,34,39,38,
7,33,17,33,133,96,136,96,96,68,67,49,48,1,215,96,136,96,
96,68,67,49,48,199,1,2,254,254,5,51,68,96,96,136,96,49,
48,67,68,96,96,136,96,49,48,191,251,207,0,2,255,20,254,80,
1,159,5,214,0,11,0,31,0,0,18,52,55,54,50,23,22,20,
7,6,34,39,1,55,22,23,22,51,50,55,54,53,17,33,17,20,
14,1,35,34,39,38,121,43,44,120,44,43,43,44,120,44,254,112,
169,12,26,28,24,51,32,33,1,2,110,182,93,82,58,54,4,245,
130,47,48,48,47,130,47,48,48,249,237,172,17,12,13,31,32,48,
4,141,251,172,101,184,112,20,18,0,0,0,0,2,0,22,255,252,
6,32,4,49,0,8,0,52,0,0,1,17,51,50,55,54,53,52,
35,1,33,17,51,22,23,22,23,22,23,22,21,20,7,6,7,6,
7,6,7,6,35,33,17,35,3,6,7,6,7,6,35,34,39,38,
39,55,22,23,22,51,50,63,1,4,28,87,73,47,49,169,253,125,
2,44,43,136,105,86,51,53,20,22,8,7,26,26,39,40,72,69,
98,254,119,70,64,20,36,55,90,91,94,81,58,55,54,170,12,26,
28,24,42,32,42,1,217,254,217,43,44,66,142,2,88,254,88,1,
37,30,53,54,51,55,43,36,42,38,47,48,33,34,24,23,3,66,
254,71,132,61,93,55,56,20,19,60,172,17,12,13,24,87,0,0,
0,1,0,115,0,0,3,250,4,50,0,11,0,0,19,33,3,33,
19,33,3,33,17,33,17,33,119,1,12,4,1,106,4,1,13,4,
254,243,254,150,254,244,4,50,254,103,1,153,251,206,1,170,254,86,
0,0,0,1,0,6,0,0,3,246,5,174,0,41,0,0,41,1,
17,35,53,33,21,33,17,54,55,54,51,50,23,30,1,23,22,21,
17,33,17,52,39,38,39,38,39,38,39,38,34,7,6,7,6,7,
6,7,6,21,1,121,254,254,113,2,210,254,161,44,89,87,103,57,
53,51,98,27,28,254,254,8,9,15,16,22,25,25,27,66,29,27,
27,26,18,17,11,11,4,190,240,240,254,210,81,55,54,28,27,110,
82,84,103,253,100,2,25,88,52,59,36,39,19,22,7,8,8,7,
23,21,37,35,60,63,77,0,255,255,0,23,255,255,4,2,6,60,
16,38,1,230,0,0,16,7,0,117,0,238,254,163,255,255,0,108,
254,47,3,235,6,61,16,38,1,239,0,0,16,7,1,74,255,86,
254,167,0,1,0,119,255,16,3,174,4,51,0,11,0,0,5,53,
33,17,33,19,33,17,33,17,5,21,1,155,254,220,1,11,1,1,
30,1,13,254,221,240,241,4,50,252,189,3,66,251,207,1,240,0,
255,255,0,115,0,0,4,135,7,129,16,38,0,37,0,0,16,7,
1,75,0,136,0,0,255,255,0,119,255,228,4,39,7,129,16,38,
0,69,0,0,16,6,1,75,120,0,0,0,255,255,0,115,0,0,
4,172,7,129,16,38,0,39,0,0,16,7,1,75,0,148,0,0,
255,255,0,74,255,228,3,250,7,129,16,38,0,71,0,0,16,6,
1,75,108,0,0,0,0,3,0,115,254,57,4,173,5,178,0,15,
0,26,0,37,0,0,1,52,55,54,51,50,23,22,21,20,7,6,
35,34,39,38,1,52,39,38,43,1,17,51,50,55,54,37,16,7,
6,35,33,17,33,32,23,22,1,218,84,34,46,96,47,21,84,33,
47,98,46,20,1,184,137,83,112,199,199,170,93,69,1,27,193,168,
254,254,45,1,211,1,29,174,156,254,221,96,47,21,84,34,46,97,
47,20,84,33,4,66,254,130,82,252,46,180,135,197,254,168,217,191,
5,178,224,196,0,3,0,64,254,57,3,210,5,176,0,15,0,34,
0,50,0,0,1,52,55,54,51,50,23,22,21,20,7,6,35,34,
39,38,1,6,35,34,39,38,17,52,55,54,51,50,23,22,23,17,
33,17,33,1,20,23,22,51,50,55,54,17,52,39,38,35,34,7,
6,1,121,84,35,45,98,46,20,84,33,47,96,47,21,1,87,94,
99,177,118,168,102,127,209,19,28,103,68,1,2,254,254,254,116,45,
57,95,31,28,148,68,67,97,42,44,86,254,221,96,47,21,84,33,
47,97,47,20,84,35,1,150,99,101,146,1,38,220,166,205,2,8,
84,1,191,250,80,2,21,131,88,113,12,60,1,8,148,94,94,51,
107,0,255,255,0,115,0,0,4,73,7,129,16,38,0,41,0,0,
16,7,1,75,0,160,0,0,255,255,0,74,0,0,3,22,7,129,
16,38,0,73,0,0,16,6,1,75,0,0,0,0,0,2,0,115,
254,57,4,114,5,178,0,15,0,27,0,0,1,52,55,54,51,50,
23,22,21,20,7,6,35,34,39,38,1,33,17,33,17,33,17,33,
17,33,17,33,1,207,84,35,45,97,47,20,84,33,47,97,46,21,
254,164,1,12,1,230,1,13,254,243,254,26,254,244,254,221,96,47,
21,84,33,47,97,47,20,84,35,7,2,253,175,2,81,250,78,2,
113,253,143,0,0,0,0,2,0,119,254,57,3,206,5,176,0,15,
0,37,0,0,1,52,55,54,51,50,23,22,21,20,7,6,35,34,
39,38,19,33,17,33,17,54,51,50,19,22,21,17,33,17,52,39,
38,35,34,7,6,21,1,105,84,35,45,97,46,21,84,33,47,97,
47,20,16,254,254,1,2,83,214,197,72,31,254,253,69,28,34,74,
67,66,254,221,96,47,21,84,34,46,97,47,20,84,33,1,82,5,
176,254,9,150,254,252,121,150,253,196,2,56,168,94,39,82,79,103,
0,2,0,115,254,137,5,12,5,178,0,3,0,15,0,0,5,33,
21,33,3,33,17,1,33,9,1,33,1,7,17,33,1,25,3,5,
252,251,166,1,12,2,32,1,59,253,182,2,124,254,175,254,18,78,
254,244,135,240,7,41,253,144,2,112,253,68,253,10,2,76,92,254,
16,0,0,0,0,2,0,113,254,137,3,228,5,176,0,3,0,15,
0,0,23,33,21,33,9,1,33,1,7,17,33,17,33,17,1,33,
113,3,5,252,251,1,209,1,162,254,219,254,201,15,254,254,1,2,
1,25,1,60,135,240,3,206,253,169,1,211,22,254,67,5,176,253,
30,1,100,0,0,2,0,115,254,57,4,126,5,178,0,15,0,21,
0,0,1,52,55,54,51,50,23,22,21,20,7,6,35,34,39,38,
1,33,17,33,21,33,1,191,84,35,45,97,46,21,84,33,47,97,
47,20,254,180,1,12,2,255,251,245,254,221,96,47,21,84,34,46,
97,47,20,84,33,7,4,251,62,240,0,0,0,2,0,117,254,57,
1,234,5,176,0,15,0,25,0,0,19,52,55,54,51,50,23,22,
21,20,7,6,35,34,39,38,1,20,51,21,34,39,38,53,17,33,
117,84,34,46,97,46,21,84,33,47,97,47,20,1,25,92,236,72,
43,1,3,254,221,96,47,21,84,34,46,97,47,20,84,33,2,107,
86,224,113,67,126,4,155,0,0,0,0,3,0,10,254,57,4,126,
7,0,0,3,0,19,0,25,0,0,19,33,21,33,1,52,55,54,
51,50,23,22,21,20,7,6,35,34,39,38,1,33,17,33,21,33,
10,3,5,252,251,1,181,84,35,45,97,46,21,84,33,47,97,47,
20,254,180,1,12,2,255,251,245,7,0,240,248,205,96,47,21,84,
34,46,97,47,20,84,33,7,4,251,62,240,0,3,255,145,254,57,
2,150,7,0,0,3,0,19,0,29,0,0,3,33,21,33,19,52,
55,54,51,50,23,22,21,20,7,6,35,34,39,38,1,20,51,21,
34,39,38,53,17,33,111,3,5,252,251,228,84,34,46,97,46,21,
84,33,47,97,47,20,1,25,92,236,72,43,1,3,7,0,240,248,
205,96,47,21,84,34,46,97,47,20,84,33,2,107,86,224,113,67,
126,4,155,0,0,2,0,115,254,137,4,126,5,178,0,3,0,9,
0,0,23,33,21,33,3,33,17,33,21,33,223,3,5,252,251,108,
1,12,2,255,251,245,135,240,7,41,251,62,240,0,0,0,0,2,
255,149,254,137,2,154,5,176,0,3,0,13,0,0,7,33,21,33,
1,20,51,21,34,39,38,53,17,33,107,3,5,252,251,1,249,92,
236,72,43,1,3,135,240,2,144,86,224,113,67,126,4,155,0,0,
255,255,0,115,0,0,6,4,7,129,16,38,0,48,0,0,16,7,
1,75,1,52,0,0,255,255,0,119,0,0,5,190,5,233,16,38,
0,80,0,0,16,7,1,75,1,68,254,104,0,2,0,66,254,57,
5,212,5,178,0,15,0,28,0,0,1,52,55,54,51,50,23,22,
21,20,7,6,35,34,39,38,1,17,33,9,1,33,17,33,17,1,
33,1,17,2,99,84,35,45,97,46,21,84,33,47,97,47,20,253,
223,1,104,1,93,1,103,1,102,254,250,254,194,254,242,254,198,254,
221,96,47,21,84,34,46,97,47,20,84,33,1,82,5,178,251,246,
4,10,250,78,3,232,252,22,3,222,252,36,0,2,0,119,254,57,
5,192,4,79,0,15,0,50,0,0,1,52,55,54,51,50,23,22,
21,20,7,6,35,34,39,38,1,33,17,2,39,34,7,6,21,17,
33,17,33,21,54,55,50,23,48,23,54,51,50,19,22,21,17,33,
17,2,39,34,7,6,21,2,117,84,35,45,97,47,20,84,33,47,
97,46,21,1,40,254,253,10,92,82,60,45,254,254,1,2,80,101,
224,63,4,112,210,234,51,16,254,254,10,93,81,60,45,254,221,96,
47,21,84,33,47,97,47,20,84,35,1,80,2,56,1,29,16,94,
73,97,253,163,4,50,117,141,5,146,8,154,254,219,96,142,253,196,
2,56,1,29,16,94,73,97,0,0,0,2,0,119,0,0,4,198,
7,80,0,15,0,25,0,0,1,52,55,54,51,50,23,22,21,20,
7,6,35,34,39,38,1,17,33,1,17,33,17,33,1,17,1,252,
84,34,46,98,46,20,84,33,47,96,47,21,254,123,1,4,2,62,
1,13,254,247,253,198,6,172,96,47,21,84,33,47,98,46,20,84,
34,249,130,5,178,252,83,3,173,250,78,3,206,252,50,0,0,2,
0,119,0,0,3,206,5,212,0,15,0,37,0,0,1,52,55,54,
51,50,23,22,21,20,7,6,35,34,39,38,19,33,17,33,21,54,
51,50,19,22,21,17,33,17,52,39,38,35,34,7,6,21,1,105,
84,33,47,97,46,21,84,34,46,97,47,20,16,254,254,1,2,93,
204,197,72,31,254,253,69,28,34,74,67,66,5,48,98,46,20,84,
35,45,96,47,21,84,33,250,255,4,50,92,121,254,252,121,150,253,
196,2,56,168,94,39,82,79,103,0,0,2,0,119,254,57,4,198,
5,178,0,15,0,25,0,0,1,52,55,54,51,50,23,22,21,20,
7,6,35,34,39,38,1,17,33,1,17,33,17,33,1,17,1,252,
84,34,46,98,46,20,84,33,47,96,47,21,254,123,1,4,2,62,
1,13,254,247,253,198,254,221,96,47,21,84,33,47,97,47,20,84,
35,1,80,5,178,252,83,3,173,250,78,3,206,252,50,0,0,2,
0,119,254,57,3,206,4,79,0,15,0,37,0,0,1,52,55,54,
51,50,23,22,21,20,7,6,35,34,39,38,19,33,17,33,21,54,
51,50,19,22,21,17,33,17,52,39,38,35,34,7,6,21,1,105,
84,35,45,97,46,21,84,33,47,97,47,20,16,254,254,1,2,93,
204,197,72,31,254,253,69,28,34,74,67,66,254,221,96,47,21,84,
34,46,97,47,20,84,33,1,82,4,50,92,121,254,252,121,150,253,
196,2,56,168,94,39,82,79,103,0,0,2,0,119,254,137,4,198,
5,178,0,3,0,13,0,0,5,33,21,33,3,17,33,1,17,33,
17,33,1,17,1,29,3,5,252,251,166,1,4,2,62,1,13,254,
247,253,198,135,240,1,119,5,178,252,83,3,173,250,78,3,206,252,
50,0,0,2,0,119,254,137,3,206,4,79,0,3,0,25,0,0,
23,33,21,33,19,33,17,33,21,54,51,50,19,22,21,17,33,17,
52,39,38,35,34,7,6,21,139,3,5,252,251,238,254,254,1,2,
93,204,197,72,31,254,253,69,28,34,74,67,66,135,240,1,119,4,
50,92,121,254,252,121,150,253,196,2,56,168,94,39,82,79,103,0,
255,255,0,115,0,0,4,79,7,129,16,38,0,51,0,0,16,6,
1,75,84,0,0,0,255,255,0,119,254,86,4,39,5,237,16,38,
0,83,0,0,16,7,1,75,0,120,254,108,0,3,0,121,254,57,
4,140,5,178,0,15,0,26,0,44,0,0,1,52,55,54,51,50,
23,22,21,20,7,6,35,34,39,38,3,51,32,55,54,53,52,39,
38,43,1,9,1,48,35,17,33,17,33,51,32,23,22,21,20,7,
6,7,1,1,185,84,35,45,97,46,21,84,33,47,97,47,20,51,
98,1,24,23,2,233,44,28,98,1,213,254,127,84,254,243,1,13,
98,1,107,147,74,199,69,86,1,190,254,221,96,47,21,84,34,46,
97,47,20,84,33,4,138,189,24,15,148,16,2,251,62,2,68,253,
188,5,178,185,94,127,227,124,46,22,253,135,0,2,0,119,254,57,
3,62,4,79,0,15,0,33,0,0,19,52,55,54,51,50,23,22,
21,20,7,6,35,34,39,38,1,38,35,34,7,6,21,17,33,17,
33,21,54,51,50,23,22,23,254,84,34,46,98,46,20,84,33,47,
96,47,21,1,224,107,30,97,76,47,254,254,1,2,99,110,93,106,
30,15,254,221,96,47,21,84,33,47,97,47,20,84,35,4,120,61,
115,74,65,253,153,4,50,115,144,62,19,13,0,4,0,121,254,57,
4,140,7,0,0,3,0,19,0,30,0,48,0,0,19,33,21,33,
1,52,55,54,51,50,23,22,21,20,7,6,35,34,39,38,3,51,
32,55,54,53,52,39,38,43,1,9,1,48,35,17,33,17,33,51,
32,23,22,21,20,7,6,7,1,176,3,5,252,251,1,9,84,35,
45,97,46,21,84,33,47,97,47,20,51,98,1,24,23,2,233,44,
28,98,1,213,254,127,84,254,243,1,13,98,1,107,147,74,199,69,
86,1,190,7,0,240,248,205,96,47,21,84,34,46,97,47,20,84,
33,4,138,189,24,15,148,16,2,251,62,2,68,253,188,5,178,185,
94,127,227,124,46,22,253,135,0,0,0,3,0,33,254,57,3,62,
5,132,0,3,0,19,0,37,0,0,19,33,21,33,19,52,55,54,
51,50,23,22,21,20,7,6,35,34,39,38,1,38,35,34,7,6,
21,17,33,17,33,21,54,51,50,23,22,23,33,3,5,252,251,221,
84,34,46,98,46,20,84,33,47,96,47,21,1,224,107,30,97,76,
47,254,254,1,2,99,110,93,106,30,15,5,132,239,250,72,96,47,
21,84,33,47,97,47,20,84,35,4,120,61,115,74,65,253,153,4,
50,115,144,62,19,13,0,0,0,3,0,121,254,137,4,140,5,178,
0,3,0,14,0,32,0,0,23,33,21,33,19,51,32,55,54,53,
52,39,38,43,1,9,1,48,35,17,33,17,33,51,32,23,22,21,
20,7,6,7,1,219,3,5,252,251,171,98,1,24,23,2,233,44,
28,98,1,213,254,127,84,254,243,1,13,98,1,107,147,74,199,69,
86,1,190,135,240,4,175,189,24,15,148,16,2,251,62,2,68,253,
188,5,178,185,94,127,227,124,46,22,253,135,0,2,0,33,254,137,
3,62,4,79,0,3,0,21,0,0,23,33,21,33,1,38,35,34,
7,6,21,17,33,17,33,21,54,51,50,23,22,23,33,3,5,252,
251,2,189,107,30,97,76,47,254,254,1,2,99,110,93,106,30,15,
135,240,4,159,61,115,74,65,253,153,4,50,115,144,62,19,13,0,
0,0,255,255,0,83,255,227,4,102,7,129,16,38,0,54,0,0,
16,7,1,75,0,160,0,0,255,255,0,78,255,227,3,117,5,234,
16,38,0,86,0,0,16,7,1,75,0,34,254,105,0,2,0,88,
254,57,4,104,5,212,0,15,0,59,0,0,1,52,55,54,51,50,
23,22,21,20,7,6,35,34,39,38,1,55,22,23,22,51,50,55,
54,53,52,39,38,39,36,39,38,53,52,55,54,51,32,19,5,38,
39,48,35,34,21,20,23,22,23,4,23,22,21,20,7,6,35,32,
1,181,84,35,45,97,46,21,84,33,47,97,47,20,254,163,248,72,
72,56,85,174,45,13,199,39,59,254,141,60,10,213,119,158,1,81,
138,254,248,62,131,22,211,235,13,36,1,33,97,68,187,137,183,254,
140,254,221,96,47,21,84,34,46,97,47,20,84,33,2,191,82,154,
43,37,127,37,37,140,82,16,16,96,238,41,48,234,108,59,254,234,
78,109,8,162,125,78,4,11,100,137,97,125,224,128,91,0,0,0,
0,2,0,78,254,57,3,101,4,77,0,15,0,58,0,0,1,52,
55,54,51,50,23,22,21,20,7,6,35,34,39,38,19,38,39,38,
53,52,55,54,51,50,23,22,23,7,38,39,34,7,6,21,20,23,
30,1,23,4,21,16,7,6,35,32,39,38,39,55,22,51,50,53,
52,39,38,1,49,85,35,44,97,47,20,84,33,47,97,46,21,144,
244,66,28,182,87,110,188,107,48,12,240,30,83,101,8,2,84,8,
24,5,1,111,236,69,88,254,251,102,23,12,232,24,140,135,105,40,
254,221,96,47,21,84,33,47,97,47,20,84,35,3,13,82,119,53,
64,213,84,41,152,70,77,44,105,8,80,16,8,50,45,3,9,2,
108,228,254,251,69,21,213,51,56,37,127,119,58,46,17,0,0,0,
255,255,0,78,0,0,5,0,7,129,16,38,0,55,0,0,16,7,
1,75,0,224,0,0,255,255,0,72,255,241,2,113,7,129,16,38,
0,87,0,0,16,6,1,75,128,0,0,0,0,2,0,78,254,57,
5,1,5,178,0,15,0,23,0,0,1,52,55,54,51,50,23,22,
21,20,7,6,35,34,39,38,1,33,21,33,17,33,17,33,2,0,
85,35,44,98,46,20,84,33,47,96,47,21,254,78,4,179,254,55,
254,244,254,34,254,221,96,47,21,84,33,47,97,47,20,84,35,7,
2,240,251,62,4,194,0,2,0,72,254,57,2,113,5,44,0,15,
0,35,0,0,19,52,55,54,51,50,23,22,21,20,7,6,35,34,
39,38,19,35,53,51,53,33,21,51,21,35,17,20,59,1,21,35,
32,39,38,53,189,84,34,46,97,46,21,84,33,47,97,47,20,24,
141,141,1,3,153,153,110,39,39,254,245,69,33,254,221,96,47,21,
84,34,46,97,47,20,84,33,4,159,229,250,250,229,253,206,94,218,
134,63,111,0,0,0,0,2,0,78,254,137,5,1,5,178,0,3,
0,11,0,0,5,33,21,33,3,33,21,33,17,33,17,33,1,35,
3,5,252,251,213,4,179,254,55,254,244,254,34,135,240,7,41,240,
251,62,4,194,0,2,255,223,254,137,2,228,5,44,0,3,0,23,
0,0,7,33,21,33,19,35,53,51,53,33,21,51,21,35,17,20,
59,1,21,35,32,39,38,53,33,3,5,252,251,246,141,141,1,3,
153,153,110,39,39,254,245,69,33,135,240,4,196,229,250,250,229,253,
206,94,218,134,63,111,0,0,255,255,0,74,0,0,6,10,7,151,
16,38,0,58,0,0,16,7,0,67,1,255,255,254,255,255,0,57,
0,0,5,105,6,59,16,38,0,90,0,0,16,7,0,67,1,56,
254,162,255,255,0,74,0,0,6,10,7,153,16,38,0,58,0,0,
16,7,0,117,2,122,0,0,255,255,0,57,0,0,5,105,6,61,
16,38,0,90,0,0,16,7,0,117,2,27,254,164,255,255,0,74,
0,0,6,10,7,129,16,38,0,58,0,0,16,7,0,105,1,130,
0,0,255,255,0,57,0,0,5,105,5,233,16,38,0,90,0,0,
16,7,0,105,1,5,254,104,0,2,0,66,0,0,4,226,7,80,
0,15,0,24,0,0,1,52,55,54,51,50,23,22,21,20,7,6,
35,34,39,38,5,33,9,1,33,1,17,33,17,1,238,84,34,46,
98,46,20,84,33,47,96,47,21,254,84,1,31,1,53,1,54,1,
22,254,59,254,244,6,172,96,47,21,84,33,47,98,46,20,84,34,
204,253,230,2,26,253,15,253,63,2,193,0,0,0,0,2,0,109,
254,47,3,196,5,212,0,15,0,54,0,0,1,52,55,54,51,50,
23,22,21,20,7,6,35,34,39,38,19,22,23,22,51,50,55,54,
61,1,6,35,34,39,38,53,17,33,17,20,23,22,51,50,55,54,
53,17,33,25,1,20,7,6,35,34,39,38,39,1,84,84,33,47,
98,46,20,84,34,46,96,47,21,4,21,111,38,21,92,49,29,62,
114,223,117,80,1,2,78,40,38,72,59,51,1,3,173,113,137,172,
137,65,28,5,48,98,46,20,84,33,47,96,47,21,84,34,250,141,
67,39,15,82,47,66,107,97,207,142,192,2,50,253,211,151,106,55,
92,79,102,2,84,253,178,253,255,231,125,80,121,56,65,0,0,2,
0,119,254,137,3,206,5,176,0,3,0,25,0,0,23,33,21,33,
19,33,17,33,17,54,51,50,19,22,21,17,33,17,52,39,38,35,
34,7,6,21,139,3,5,252,251,238,254,254,1,2,83,214,197,72,
31,254,253,69,28,34,74,67,66,135,240,1,119,5,176,254,9,150,
254,252,121,150,253,196,2,56,168,94,39,82,79,103,0,1,0,111,
0,0,5,28,5,178,0,33,0,0,1,33,1,22,23,22,21,20,
7,6,35,53,50,55,54,53,52,39,38,47,1,1,35,21,34,7,
6,25,1,33,17,16,55,18,2,132,2,152,254,116,239,89,68,187,
135,184,174,45,12,199,30,21,227,1,61,215,56,46,171,254,238,88,
139,5,178,253,189,90,125,97,124,225,128,90,242,127,34,40,139,82,
13,6,82,1,197,2,27,95,254,152,253,34,2,222,1,9,176,1,
21,0,0,0,255,255,0,67,0,0,4,235,7,153,16,38,0,60,
0,0,16,7,0,67,1,24,0,0,255,255,0,108,254,47,3,235,
6,59,16,38,0,92,0,0,16,7,0,67,0,216,254,162,0,1,
0,138,0,0,5,243,5,176,0,14,0,0,1,33,17,33,21,33,
34,39,38,53,17,33,17,20,51,1,233,1,12,2,254,251,246,186,
82,83,1,2,93,5,176,251,64,240,67,68,170,4,126,251,135,87,
0,1,0,0,255,227,4,10,5,174,0,31,0,0,1,20,51,21,
34,39,38,53,17,35,53,51,17,33,17,51,17,33,17,51,21,35,
17,20,51,21,34,39,38,53,17,35,1,141,93,186,82,83,139,139,
1,2,233,1,2,146,146,93,186,82,83,233,1,25,87,223,67,68,
170,2,97,127,1,186,254,70,1,186,254,70,127,253,164,87,223,67,
68,170,2,97,0,0,0,1,0,120,1,170,3,246,2,154,0,3,
0,0,19,33,21,33,120,3,126,252,130,2,154,240,0,0,0,1,
0,120,1,170,3,246,2,154,0,3,0,0,19,33,21,33,120,3,
126,252,130,2,154,240,0,0,0,1,0,68,1,170,4,88,2,154,
0,3,0,0,19,33,21,33,68,4,20,251,236,2,154,240,0,0,
0,1,0,119,1,170,4,196,2,154,0,3,0,0,19,33,21,33,
119,4,77,251,179,2,154,240,0,0,0,1,0,66,1,170,5,212,
2,153,0,3,0,0,19,33,21,33,66,5,146,250,110,2,153,239,
0,0,0,1,0,0,1,170,6,12,2,152,0,3,0,0,17,33,
21,33,6,12,249,244,2,152,238,0,0,0,255,255,0,9,4,87,
1,79,6,78,16,15,0,15,1,135,5,129,192,0,255,255,0,38,
4,78,1,108,6,69,16,7,0,15,255,238,5,27,0,0,255,255,
0,32,255,68,1,102,1,59,16,7,2,82,255,250,250,246,0,0,
255,255,0,21,4,87,1,91,6,78,16,6,2,81,12,0,255,255,
0,17,4,87,2,233,6,80,16,38,2,81,8,2,16,7,2,81,
1,154,0,0,255,255,0,30,4,78,2,223,6,71,16,38,2,82,
248,2,16,7,2,82,1,115,0,0,255,255,0,36,255,66,2,229,
1,59,16,7,2,86,0,6,250,244,0,0,0,2,0,30,4,78,
2,223,6,71,0,19,0,39,0,0,1,52,54,51,50,22,21,20,
6,7,6,21,20,22,23,7,46,3,37,52,54,51,50,22,21,20,
6,7,6,21,20,22,23,7,46,3,1,153,88,79,63,96,69,47,
2,34,11,74,21,54,62,42,254,133,88,79,63,96,69,47,2,34,
11,74,21,54,62,42,5,166,60,101,101,60,70,85,11,6,5,22,
82,18,43,17,60,90,118,55,60,101,101,60,70,85,11,6,5,22,
82,18,43,17,60,90,118,0,0,0,0,1,0,46,0,0,3,50,
5,174,0,11,0,0,1,33,21,33,17,35,17,33,53,33,17,51,
2,41,1,9,254,247,243,254,248,1,8,243,4,48,240,252,192,3,
64,240,1,126,0,1,0,46,0,0,3,50,5,174,0,19,0,0,
1,33,21,33,17,33,21,33,17,35,17,33,53,33,17,33,53,33,
53,51,2,41,1,9,254,247,1,9,254,247,243,254,248,1,8,254,
248,1,8,243,5,32,240,253,220,240,254,228,1,28,240,2,36,240,
142,0,0,0,0,1,0,98,1,47,2,222,3,161,0,15,0,0,
19,52,55,54,51,50,23,22,21,20,7,6,35,34,39,38,98,125,
85,108,158,94,66,125,87,106,158,94,66,2,103,155,95,64,123,84,
107,155,93,64,121,84,0,1,0,252,1,101,2,208,3,105,0,2,
0,0,19,9,1,252,1,212,254,46,3,105,254,254,254,254,0,1,
0,30,255,223,1,102,1,39,0,10,0,0,55,52,54,50,22,20,
6,35,34,39,38,30,96,136,96,96,68,67,49,48,131,68,96,96,
136,96,49,48,0,0,0,2,0,30,255,223,3,173,1,39,0,10,
0,21,0,0,37,52,54,50,22,20,6,35,34,39,38,37,52,54,
50,22,20,6,35,34,39,38,2,101,96,136,96,96,68,67,49,48,
253,185,96,136,96,96,68,67,49,48,131,68,96,96,136,96,49,48,
67,68,96,96,136,96,49,48,0,0,0,3,0,30,255,223,5,238,
1,39,0,10,0,21,0,32,0,0,37,52,54,50,22,20,6,35,
34,39,38,37,52,54,50,22,20,6,35,34,39,38,37,52,54,50,
22,20,6,35,34,39,38,4,166,96,136,96,96,68,67,49,48,253,
191,96,136,96,96,68,67,49,48,253,185,96,136,96,96,68,67,49,
48,131,68,96,96,136,96,49,48,67,68,96,96,136,96,49,48,67,
68,96,96,136,96,49,48,0,0,0,0,7,0,94,0,64,7,238,
5,110,0,15,0,31,0,47,0,63,0,67,0,83,0,99,0,0,
1,20,23,22,51,50,55,54,53,52,39,38,35,34,7,6,7,52,
55,54,51,50,23,22,21,20,7,6,35,34,39,38,1,20,23,22,
51,50,55,54,53,52,39,38,35,34,7,6,7,52,55,54,51,50,
23,22,21,20,7,6,35,34,39,38,1,39,1,23,1,20,23,22,
51,50,55,54,53,52,39,38,35,34,7,6,7,52,55,54,51,50,
23,22,21,20,7,6,35,34,39,38,3,173,66,14,8,72,12,2,
53,18,17,54,24,8,215,121,83,99,149,93,61,120,82,101,154,90,
59,254,96,65,14,9,72,12,2,54,18,16,54,24,8,216,121,80,
103,151,93,61,123,79,103,154,90,60,1,136,211,2,160,201,1,234,
66,14,8,72,12,2,53,18,17,54,24,8,215,121,83,99,149,93,
62,121,82,101,154,90,59,1,115,80,18,2,73,16,11,73,28,8,
62,24,23,158,94,62,123,83,108,157,89,61,123,78,3,43,80,18,
2,74,16,10,72,29,8,62,24,23,158,94,62,123,83,108,156,90,
61,123,82,252,169,2,4,196,2,252,56,80,18,2,73,16,11,73,
28,8,62,24,23,158,94,62,123,85,106,156,90,61,123,78,0,0,
0,9,0,94,0,64,10,169,5,110,0,15,0,31,0,47,0,63,
0,67,0,83,0,99,0,115,0,131,0,0,1,20,23,22,51,50,
55,54,53,52,39,38,35,34,7,6,7,52,55,54,51,50,23,22,
21,20,7,6,35,34,39,38,1,20,23,22,51,50,55,54,53,52,
39,38,35,34,7,6,7,52,55,54,51,50,23,22,21,20,7,6,
35,34,39,38,1,39,1,23,1,20,23,22,51,50,55,54,53,52,
39,38,35,34,7,6,7,52,55,54,51,50,23,22,21,20,7,6,
35,34,39,38,37,20,23,22,51,50,55,54,53,52,39,38,35,34,
7,6,7,52,55,54,51,50,23,22,21,20,7,6,35,34,39,38,
3,173,66,14,8,72,12,2,53,18,17,54,24,8,215,121,83,99,
149,93,61,120,82,101,154,90,59,254,96,65,14,9,72,12,2,54,
18,16,54,24,8,216,121,80,103,151,93,61,123,79,103,154,90,60,
1,136,211,2,160,201,1,234,66,14,8,72,12,2,53,18,17,54,
24,8,215,121,83,99,149,93,62,121,82,101,154,90,59,3,146,66,
14,8,72,12,2,53,18,17,54,24,8,215,121,83,99,149,93,62,
121,82,101,154,90,59,1,115,80,18,2,73,16,11,73,28,8,62,
24,23,158,94,62,123,83,108,157,89,61,123,78,3,43,80,18,2,
74,16,10,72,29,8,62,24,23,158,94,62,123,83,108,156,90,61,
123,82,252,169,2,4,196,2,252,56,80,18,2,73,16,11,73,28,
8,62,24,23,158,94,62,123,85,106,156,90,61,123,78,106,80,18,
2,73,16,11,73,28,8,62,24,23,158,94,62,123,85,106,156,90,
61,123,78,0,0,0,0,1,0,51,1,68,1,203,3,140,0,5,
0,0,19,23,3,19,35,3,240,219,193,189,215,189,3,140,2,254,
221,254,221,1,35,0,0,1,0,127,1,68,2,23,3,140,0,5,
0,0,1,3,35,19,3,55,2,23,193,215,193,193,215,2,103,254,
221,1,35,1,35,2,0,4,0,69,255,223,3,41,5,203,0,16,
0,26,0,43,0,53,0,0,1,20,6,35,34,39,38,53,3,52,
55,54,51,50,23,22,21,1,52,54,50,22,20,6,35,34,38,3,
20,6,35,34,39,38,53,3,52,55,54,51,50,23,22,21,1,52,
54,50,22,20,6,35,34,38,2,232,72,27,29,36,35,41,48,49,
42,44,49,48,254,209,96,136,96,96,68,66,98,149,72,27,29,36,
35,41,48,49,42,44,49,48,254,209,96,136,96,96,68,66,98,1,
184,23,36,18,17,24,3,181,37,28,29,29,28,35,251,20,68,96,
96,136,96,98,1,119,23,36,18,17,24,3,181,37,28,29,29,28,
35,251,20,68,96,96,136,96,98,0,0,0,0,3,0,59,255,223,
3,227,5,217,0,9,0,44,0,54,0,0,37,52,54,50,22,20,
6,35,34,38,19,6,7,6,7,37,54,55,54,51,50,23,30,1,
23,22,23,22,21,20,7,6,7,6,7,6,7,6,7,14,1,29,
2,33,27,1,55,54,55,54,53,52,39,38,1,99,96,136,96,96,
68,66,98,48,6,11,52,7,254,244,19,122,121,191,76,68,72,120,
48,44,28,27,19,19,31,31,35,26,48,41,25,31,38,254,244,246,
9,10,31,17,18,31,23,131,68,96,96,136,96,98,4,127,5,11,
53,78,41,168,110,109,16,17,64,48,44,68,66,76,77,61,62,43,
44,33,25,38,32,23,28,64,38,21,110,3,63,254,206,10,33,38,
41,48,56,37,28,0,0,0,0,1,0,98,1,121,3,103,3,87,
0,3,0,0,19,33,17,33,98,3,5,252,251,3,87,254,34,0,
0,1,254,43,255,112,2,169,6,60,0,3,0,0,5,35,1,51,
254,253,210,3,181,201,144,6,204,0,0,4,0,47,255,223,7,34,
5,217,0,49,0,60,0,115,0,125,0,0,1,54,51,50,23,22,
23,30,2,21,20,7,6,7,6,7,6,7,6,7,6,7,6,29,
1,33,53,52,55,54,55,54,55,54,55,54,55,54,55,54,53,52,
39,38,39,38,35,34,7,3,52,54,50,22,20,6,35,34,39,38,
1,21,33,53,52,55,54,55,54,55,62,1,55,54,55,54,55,54,
53,52,39,38,39,38,35,34,7,6,7,37,54,55,54,51,50,23,
30,1,23,22,23,22,21,20,7,6,7,6,7,6,7,6,7,14,
1,1,52,54,50,22,20,6,35,34,38,4,6,121,192,76,68,70,
61,60,96,52,19,20,29,27,41,36,36,57,11,29,20,19,254,244,
18,16,32,26,38,17,53,32,33,29,18,19,31,29,45,42,51,80,
51,30,96,136,96,96,68,67,49,48,253,221,254,244,19,17,30,26,
38,14,53,4,28,36,31,17,18,31,30,43,42,52,79,51,52,7,
254,244,19,122,121,191,76,68,72,120,48,44,28,27,19,19,31,31,
35,26,48,41,25,31,38,254,216,96,136,96,96,68,66,98,5,108,
109,16,16,33,32,96,128,78,77,61,64,41,38,39,34,29,45,10,
26,34,32,38,131,195,49,42,38,35,28,32,14,42,26,34,31,40,
43,46,56,37,35,16,15,53,251,211,68,96,96,136,96,49,48,1,
210,131,195,47,44,40,33,28,32,11,42,3,22,38,33,38,41,48,
56,37,36,15,15,53,53,78,41,168,110,109,16,17,64,48,44,68,
66,76,77,61,62,43,44,33,25,38,32,23,28,64,254,75,68,96,
96,136,96,98,0,4,0,47,255,223,5,99,5,217,0,16,0,26,
0,81,0,91,0,0,1,20,6,35,34,39,38,53,3,52,55,54,
51,50,23,22,21,1,52,54,50,22,20,6,35,34,38,1,21,33,
53,52,55,54,55,54,55,62,1,55,54,55,54,55,54,53,52,39,
38,39,38,35,34,7,6,7,37,54,55,54,51,50,23,30,1,23,
22,23,22,21,20,7,6,7,6,7,6,7,6,7,14,1,1,52,
54,50,22,20,6,35,34,38,5,34,72,27,29,36,35,41,48,49,
42,44,49,48,254,209,96,136,96,96,68,66,98,254,100,254,244,19,
17,30,26,38,14,53,4,28,36,31,17,18,31,30,43,42,52,79,
51,52,7,254,244,19,122,121,191,76,68,72,120,48,44,28,27,19,
19,31,31,35,26,48,41,25,31,38,254,216,96,136,96,96,68,66,
98,1,184,23,36,18,17,24,3,181,37,28,29,29,28,35,251,20,
68,96,96,136,96,98,1,209,131,195,47,44,40,33,28,32,11,42,
3,22,38,33,38,41,48,56,37,36,15,15,53,53,78,41,168,110,
109,16,17,64,48,44,68,66,76,77,61,62,43,44,33,25,38,32,
23,28,64,254,75,68,96,96,136,96,98,0,0,0,0,4,0,69,
255,223,4,220,5,217,0,49,0,60,0,77,0,87,0,0,1,54,
51,50,23,22,23,30,2,21,20,7,6,7,6,7,6,7,6,7,
6,7,6,29,1,33,53,52,55,54,55,54,55,54,55,54,55,54,
55,54,53,52,39,38,39,38,35,34,7,3,52,54,50,22,20,6,
35,34,39,38,1,20,6,35,34,39,38,53,3,52,55,54,51,50,
23,22,21,1,52,54,50,22,20,6,35,34,38,1,192,121,192,76,
68,70,61,60,96,52,19,20,29,27,41,36,36,57,11,29,20,19,
254,244,18,16,32,26,38,17,53,32,33,29,18,19,31,29,45,42,
51,80,51,30,96,136,96,96,68,67,49,48,254,240,72,27,29,36,
35,41,48,49,42,44,49,48,254,209,96,136,96,96,68,66,98,5,
108,109,16,16,33,32,96,128,78,77,61,64,41,38,39,34,29,45,
10,26,34,32,38,131,195,49,42,38,35,28,32,14,42,26,34,31,
40,43,46,56,37,35,16,15,53,251,211,68,96,96,136,96,49,48,
1,120,23,36,18,17,24,3,181,37,28,29,29,28,35,251,20,68,
96,96,136,96,98,0,0,0,0,4,0,111,0,0,4,116,5,161,
0,7,0,23,0,30,0,52,0,0,1,34,38,35,17,50,54,51,
19,17,54,55,54,55,62,1,53,52,39,38,39,38,39,38,1,17,
34,7,6,35,17,5,33,17,33,50,23,22,23,30,1,23,22,21,
20,7,14,1,7,6,7,6,7,2,4,13,122,13,10,128,10,243,
17,24,19,26,22,30,15,14,24,21,24,24,254,253,28,46,69,5,
1,135,253,120,1,16,98,107,109,95,102,148,50,48,22,21,70,51,
55,47,51,64,4,197,8,254,64,14,1,93,254,215,5,13,11,17,
15,60,40,29,24,23,15,13,14,14,252,113,1,85,2,3,254,176,
229,5,161,17,17,35,37,96,75,72,84,75,59,57,82,31,33,17,
19,17,0,0,0,2,0,111,0,172,4,118,4,26,0,3,0,16,
0,0,1,17,23,17,1,38,39,38,53,52,37,54,41,1,17,5,
39,2,224,148,254,120,240,82,59,1,16,219,1,11,1,17,254,254,
148,3,60,254,86,15,1,193,253,158,66,116,83,124,211,123,101,252,
150,4,4,0,0,2,0,111,0,172,4,118,4,26,0,12,0,16,
0,0,37,7,37,17,33,32,23,4,21,20,7,6,7,1,17,55,
17,2,5,148,254,254,1,16,1,11,219,1,17,60,82,239,254,120,
148,176,4,4,3,106,101,123,211,123,84,116,66,2,98,254,63,15,
1,170,0,0,0,2,0,64,255,51,1,136,4,0,0,7,0,34,
0,0,18,52,54,50,22,20,6,34,3,52,55,54,51,50,23,22,
21,20,7,6,7,6,21,20,23,22,23,7,38,39,38,39,38,39,
38,64,96,136,96,96,136,94,44,43,80,64,47,48,34,35,47,2,
17,13,15,74,19,29,25,33,30,22,21,3,24,136,96,96,136,96,
253,209,59,52,50,50,51,60,72,41,42,11,6,5,20,42,33,27,
43,15,32,27,48,43,61,58,0,3,0,27,255,217,4,39,5,169,
0,10,0,21,0,25,0,0,19,52,54,50,22,20,6,35,34,39,
38,1,52,54,50,22,20,6,35,34,39,38,5,35,1,51,56,96,
136,96,96,68,67,49,48,2,167,96,136,96,96,68,67,49,48,254,
14,210,3,45,201,5,3,68,96,96,136,96,49,48,251,195,68,96,
96,136,96,49,48,103,5,208,0,0,0,1,0,53,2,0,2,178,
3,143,0,54,0,0,19,54,55,54,55,54,55,54,55,54,51,50,
23,22,23,30,1,23,22,23,22,51,50,55,54,55,54,55,17,6,
7,6,7,6,7,6,35,34,39,38,39,38,39,38,35,34,7,6,
7,14,2,7,6,7,53,6,21,7,29,8,26,22,20,25,19,28,
28,27,27,13,26,13,27,28,30,29,31,39,38,18,17,35,7,23,
15,27,16,31,30,29,38,42,43,29,27,38,35,27,29,24,33,9,
4,13,19,7,29,13,3,40,4,20,6,23,7,16,14,6,7,15,
14,24,11,24,11,24,14,15,21,20,17,15,34,254,252,7,19,12,
20,12,12,12,24,25,27,25,27,24,10,13,7,3,10,16,5,22,
11,0,0,2,0,108,1,99,1,180,7,51,0,7,0,15,0,0,
0,34,38,52,54,50,22,20,2,34,38,52,54,50,22,20,1,84,
136,96,96,136,96,96,136,96,96,136,96,5,235,96,136,96,96,136,
251,24,96,136,96,96,136,0,0,2,0,108,1,99,1,180,7,51,
0,7,0,15,0,0,0,34,38,52,54,50,22,20,2,34,38,52,
54,50,22,20,1,84,136,96,96,136,96,96,136,96,96,136,96,5,
235,96,136,96,96,136,251,24,96,136,96,96,136,0,0,2,0,108,
1,99,1,180,7,51,0,7,0,15,0,0,0,34,38,52,54,50,
22,20,2,34,38,52,54,50,22,20,1,84,136,96,96,136,96,96,
136,96,96,136,96,5,235,96,136,96,96,136,251,24,96,136,96,96,
136,0,0,2,0,108,1,99,1,180,7,51,0,7,0,15,0,0,
0,34,38,52,54,50,22,20,2,34,38,52,54,50,22,20,1,84,
136,96,96,136,96,96,136,96,96,136,96,5,235,96,136,96,96,136,
251,24,96,136,96,96,136,0,0,2,0,108,1,99,1,180,7,51,
0,7,0,15,0,0,0,34,38,52,54,50,22,20,2,34,38,52,
54,50,22,20,1,84,136,96,96,136,96,96,136,96,96,136,96,5,
235,96,136,96,96,136,251,24,96,136,96,96,136,0,0,3,0,108,
0,0,1,180,5,208,0,7,0,15,0,23,0,0,0,34,38,52,
54,50,22,20,2,34,38,52,54,50,22,20,2,34,38,52,54,50,
22,20,1,84,136,96,96,136,96,96,136,96,96,136,96,96,136,96,
96,136,96,4,136,96,136,96,96,136,253,95,96,136,96,96,136,253,
89,96,136,96,96,136,0,0,0,4,0,108,255,28,1,180,7,51,
0,7,0,15,0,23,0,31,0,0,0,34,38,52,54,50,22,20,
2,34,38,52,54,50,22,20,2,34,38,52,54,50,22,20,2,34,
38,52,54,50,22,20,1,84,136,96,96,136,96,96,136,96,96,136,
96,96,136,96,96,136,96,96,136,96,96,136,96,5,235,96,136,96,
96,136,253,89,96,136,96,96,136,253,95,96,136,96,96,136,253,89,
96,136,96,96,136,0,0,0,0,2,0,30,3,117,2,63,6,148,
0,20,0,46,0,0,19,54,51,50,23,22,21,20,7,6,7,6,
43,1,34,39,38,39,38,53,52,23,20,23,22,23,22,23,22,23,
22,51,50,55,54,55,54,55,54,53,52,39,38,35,34,7,6,103,
72,131,130,69,70,31,30,63,64,84,1,84,64,63,30,31,174,4,
3,7,8,10,10,18,16,22,28,19,18,12,13,4,5,20,20,55,
56,23,23,6,44,104,104,105,178,115,96,92,54,55,55,54,92,95,
116,178,178,42,52,43,28,32,18,17,10,9,14,14,31,33,45,52,
62,131,48,47,48,49,0,0,0,1,0,49,3,117,1,134,6,117,
0,5,0,0,19,35,55,51,17,35,216,167,181,160,174,5,208,165,
253,0,0,0,0,1,0,72,3,117,2,85,6,135,0,57,0,0,
19,39,55,54,55,54,51,50,23,22,23,22,23,22,23,22,21,20,
7,6,7,6,15,1,6,7,6,7,33,21,33,53,52,55,54,55,
54,55,54,55,54,55,54,55,54,55,54,55,54,55,54,53,52,38,
34,7,6,7,239,156,4,17,71,72,83,28,38,33,33,34,25,26,
15,15,19,20,48,24,21,70,51,16,19,7,1,59,253,243,5,5,
11,13,20,24,31,16,35,32,21,24,24,21,18,16,9,9,42,68,
20,18,13,5,138,47,17,82,53,54,7,6,18,19,26,28,43,44,
54,66,44,46,48,24,15,53,39,17,20,9,160,20,40,37,36,33,
40,29,35,31,16,28,25,15,16,20,17,20,18,20,21,24,43,42,
17,15,42,0,0,1,0,48,3,117,2,86,6,148,0,64,0,0,
19,55,23,22,23,22,51,50,55,54,53,52,39,38,43,1,53,51,
50,55,54,53,52,39,38,35,34,7,6,15,1,39,55,54,51,50,
22,23,22,23,22,21,20,7,30,1,23,22,23,22,21,20,7,6,
7,6,7,6,35,34,39,38,39,38,39,48,167,7,17,28,29,31,
44,26,27,30,28,39,103,92,27,23,22,21,23,32,23,17,18,7,
6,164,8,58,169,47,84,35,33,22,21,59,9,34,18,21,10,11,
21,21,35,37,49,52,56,57,54,49,45,41,25,4,70,45,16,41,
18,18,25,25,38,35,28,27,146,25,23,28,40,19,21,13,13,18,
16,43,21,154,24,25,23,46,44,55,84,53,7,30,24,28,32,36,
39,51,45,46,33,35,19,20,19,17,45,41,67,0,0,0,0,2,
0,52,3,117,2,76,6,117,0,10,0,13,0,0,1,51,21,35,
21,35,53,33,53,1,51,3,7,51,2,6,70,70,174,254,220,1,
35,175,170,110,110,4,194,159,174,174,128,1,210,254,249,171,0,0,
0,1,0,69,3,117,2,107,6,130,0,50,0,0,1,7,39,19,
33,21,35,7,54,51,50,22,23,22,21,20,7,14,1,35,34,39,
38,39,46,1,39,38,47,1,55,23,22,23,22,23,22,23,22,23,
22,51,50,55,54,53,52,39,38,35,34,1,20,9,157,65,1,123,
238,19,19,29,77,124,36,37,37,36,124,77,50,41,44,29,31,44,
14,13,6,4,172,4,1,5,4,9,10,10,10,17,16,18,45,29,
28,28,29,45,47,4,210,9,55,1,130,160,97,3,64,61,63,76,
75,63,61,64,14,15,22,23,56,28,25,29,20,30,19,8,10,9,
12,14,8,9,6,6,29,28,45,47,31,32,0,2,0,64,3,117,
2,70,6,131,0,14,0,42,0,0,1,52,39,38,35,34,7,6,
21,20,23,22,51,50,54,3,22,23,22,21,20,7,6,7,6,7,
6,35,34,38,39,38,53,52,55,54,55,54,55,54,55,19,51,1,
152,24,25,38,36,24,23,24,26,34,38,48,76,110,68,72,19,19,
34,33,50,52,54,75,116,34,32,10,9,13,10,20,20,2,142,189,
4,110,40,27,28,28,27,38,43,24,26,54,1,37,3,69,72,112,
47,44,45,35,35,21,22,70,58,55,66,46,41,37,30,24,36,37,
5,1,21,0,0,1,0,66,3,117,2,149,6,117,0,5,0,0,
9,1,35,1,33,53,2,149,254,124,207,1,47,254,223,6,117,253,
0,2,89,167,0,3,0,54,3,117,2,104,6,148,0,41,0,56,
0,70,0,0,0,22,21,20,7,6,7,6,15,1,6,15,1,22,
23,22,21,20,7,6,7,6,7,6,35,34,38,53,52,55,54,55,
38,39,38,39,38,53,52,55,54,51,7,20,23,22,51,50,55,54,
53,52,39,38,35,34,6,18,50,55,54,53,52,38,35,34,7,6,
21,20,23,1,189,142,4,5,5,7,5,18,13,13,3,28,30,44,
22,23,39,38,52,54,55,127,152,45,30,27,13,19,17,13,12,70,
69,113,78,20,18,41,39,19,20,19,21,39,40,38,29,100,28,29,
64,43,52,27,28,29,6,148,122,96,22,17,20,12,16,6,22,15,
10,2,17,40,59,72,62,47,48,32,31,15,16,138,113,70,61,39,
18,10,21,19,30,30,32,97,61,60,218,33,17,15,16,17,32,31,
18,19,38,254,51,28,29,44,43,58,28,30,43,44,29,0,0,0,
0,2,0,38,3,117,2,45,6,131,0,13,0,44,0,0,19,20,
22,51,50,55,54,53,52,39,38,35,34,6,19,38,39,38,53,52,
55,54,55,54,55,54,51,50,23,22,23,22,21,20,7,6,7,6,
7,14,2,7,3,35,212,50,37,36,24,24,25,26,34,38,48,77,
112,67,72,19,19,34,33,50,52,54,73,60,59,33,33,11,9,13,
15,14,5,12,5,1,142,189,5,138,39,56,28,29,36,42,25,26,
54,254,219,3,69,72,112,47,44,45,35,35,21,22,36,36,56,57,
64,41,46,37,30,34,26,10,20,10,2,254,235,0,0,1,0,49,
3,211,1,149,5,55,0,11,0,0,19,51,53,51,21,51,21,35,
21,35,53,35,49,92,160,104,104,160,92,4,208,103,103,159,94,94,
0,1,0,49,4,48,2,24,4,208,0,3,0,0,19,33,21,33,
49,1,231,254,25,4,208,160,0,0,0,2,0,94,3,211,2,22,
5,100,0,3,0,7,0,0,19,33,21,33,17,33,21,33,94,1,
184,254,72,1,184,254,72,4,115,160,1,145,160,0,0,1,0,50,
3,29,1,113,6,125,0,19,0,0,19,38,53,52,63,1,51,7,
6,7,6,21,20,23,22,31,1,35,39,38,79,29,133,6,179,21,
64,32,32,33,33,62,22,180,6,76,3,235,105,121,254,170,8,31,
94,106,107,99,98,103,104,90,32,8,95,0,0,0,0,1,0,56,
3,28,1,119,6,123,0,19,0,0,19,35,55,54,55,54,53,52,
39,38,47,1,51,23,22,21,20,7,6,7,234,178,22,63,32,33,
34,33,62,21,178,6,135,30,30,75,3,28,32,92,104,106,98,90,
111,108,91,31,8,174,249,120,105,107,92,0,0,0,0,1,0,56,
3,117,2,31,5,196,0,37,0,0,19,35,17,51,21,54,55,54,
51,50,23,22,23,22,23,22,21,17,35,17,52,39,38,39,38,39,
46,1,35,34,6,7,6,7,6,7,6,21,225,169,169,19,31,34,
57,32,31,30,27,28,14,15,169,4,5,5,6,9,11,12,18,14,
22,9,11,7,7,5,4,3,117,2,65,43,17,19,21,16,16,30,
31,44,46,54,254,158,1,33,42,24,29,13,16,7,9,4,6,8,
10,13,15,27,24,42,0,0,0,2,0,30,255,28,2,63,2,59,
0,20,0,46,0,0,19,54,51,50,23,22,21,20,7,6,7,6,
43,1,34,39,38,39,38,53,52,23,20,23,22,23,22,23,22,23,
22,51,50,55,54,55,54,55,54,53,52,39,38,35,34,7,6,103,
72,131,130,69,70,31,30,63,64,84,1,84,64,63,30,31,174,4,
3,7,8,10,10,18,16,22,28,19,18,12,13,4,5,20,20,55,
56,23,23,1,211,104,104,105,178,115,96,92,54,55,55,54,92,95,
116,178,178,42,52,43,28,32,18,17,10,9,14,13,32,33,45,52,
62,131,48,47,48,49,0,0,0,1,0,49,255,28,1,134,2,28,
0,5,0,0,19,35,55,51,17,35,216,167,181,160,174,1,119,165,
253,0,0,0,0,1,0,72,255,28,2,85,2,46,0,56,0,0,
19,39,55,54,55,54,51,50,23,22,23,22,23,30,1,21,20,7,
6,7,6,15,1,6,7,6,7,33,21,33,53,52,55,54,55,54,
55,54,55,54,55,54,55,54,55,54,55,54,55,54,53,52,38,34,
7,6,7,239,156,4,17,71,72,83,28,38,33,33,34,25,26,30,
19,20,48,24,21,70,51,16,19,7,1,59,253,243,5,5,11,13,
20,24,31,16,35,32,21,24,24,21,18,16,9,9,42,68,20,18,
13,1,49,47,17,82,53,54,7,6,18,19,26,28,86,56,65,44,
46,48,24,15,53,39,17,20,9,160,20,40,37,36,33,40,29,35,
31,16,28,25,15,17,19,17,20,18,20,21,23,44,42,17,15,42,
0,1,0,48,255,28,2,86,2,58,0,64,0,0,23,55,23,22,
23,22,51,50,55,54,53,52,38,43,1,53,51,50,55,54,53,52,
39,38,35,34,7,6,15,1,39,55,54,51,50,23,22,23,22,23,
22,21,20,7,30,1,23,22,23,22,21,20,7,6,7,6,7,6,
35,34,39,38,39,38,39,48,167,7,17,28,29,31,44,26,27,60,
37,103,92,28,22,22,21,22,33,24,16,18,7,6,164,8,58,169,
50,39,42,35,33,22,21,59,9,34,18,21,10,11,21,21,35,37,
49,52,56,57,54,49,45,41,25,19,45,16,41,18,18,25,25,37,
36,56,146,24,23,28,39,20,20,12,13,18,16,43,21,153,11,12,
25,23,46,43,56,84,53,7,30,24,28,32,36,40,50,45,46,33,
35,19,20,19,17,45,41,67,0,2,0,52,255,28,2,76,2,28,
0,10,0,13,0,0,37,51,21,35,21,35,53,33,53,1,51,3,
7,51,2,6,70,70,174,254,220,1,35,175,170,110,110,104,158,174,
174,128,1,210,254,249,171,0,0,0,0,1,0,69,255,28,2,107,
2,42,0,49,0,0,37,7,39,19,33,21,35,7,54,51,50,23,
22,23,22,21,20,7,14,1,35,34,39,38,39,46,1,39,38,47,
1,55,23,22,23,22,23,22,23,22,23,22,51,50,55,54,52,38,
35,34,1,20,9,157,65,1,123,238,19,13,35,78,61,62,36,37,
37,36,124,77,50,41,44,29,31,44,14,13,6,4,172,4,1,5,
4,9,10,10,10,17,17,17,45,29,28,56,46,47,121,9,55,1,
131,160,98,2,31,32,61,63,75,76,63,61,64,14,15,22,23,56,
28,25,29,20,30,19,7,11,9,12,14,8,9,6,6,29,28,92,
62,0,0,0,0,2,0,64,255,28,2,70,2,42,0,15,0,44,
0,0,37,52,39,38,35,34,7,6,21,20,23,22,51,50,55,54,
3,22,23,22,21,20,7,6,7,6,7,6,35,34,39,38,39,38,
53,52,55,54,55,54,55,54,55,19,51,1,152,24,25,38,36,24,
23,24,26,34,37,25,24,76,110,68,72,19,19,34,33,50,52,54,
73,60,59,33,32,10,9,13,10,20,20,2,142,189,20,41,27,28,
28,27,39,42,24,26,28,27,1,36,3,69,72,113,46,44,45,35,
35,21,22,36,36,56,55,67,45,41,37,30,24,36,37,5,1,21,
0,1,0,66,255,28,2,149,2,28,0,5,0,0,9,1,35,1,
33,53,2,149,254,124,207,1,47,254,223,2,28,253,0,2,89,167,
0,3,0,54,255,28,2,104,2,59,0,41,0,56,0,70,0,0,
0,22,21,20,7,6,7,6,15,1,6,15,1,22,23,22,21,20,
7,6,7,6,7,6,35,34,38,53,52,55,54,55,38,39,38,39,
38,53,52,55,54,51,7,20,23,22,51,50,55,54,53,52,39,38,
35,34,6,18,50,55,54,53,52,38,35,34,7,6,21,20,23,1,
189,142,4,5,5,7,5,18,13,13,3,28,30,44,22,23,39,38,
52,54,55,127,152,45,30,27,13,19,17,13,12,70,69,113,78,20,
18,41,39,19,20,19,21,39,40,38,29,100,28,29,64,43,52,27,
28,29,2,59,122,95,23,17,20,12,16,6,22,15,10,2,17,40,
59,73,61,47,48,32,31,15,16,138,112,70,62,39,18,10,21,19,
30,30,33,96,61,60,217,34,17,15,16,17,33,30,18,19,38,254,
51,28,29,43,44,58,28,30,44,43,29,0,0,0,0,2,0,38,
255,28,2,45,2,42,0,14,0,45,0,0,19,20,22,51,50,55,
54,53,52,39,38,35,34,7,6,19,38,39,38,53,52,55,54,55,
54,55,54,51,50,23,22,23,22,21,20,7,6,7,6,7,14,2,
7,3,35,212,50,37,36,24,24,25,26,34,37,25,24,77,112,67,
72,19,19,34,33,50,52,54,73,60,59,33,33,11,9,13,15,14,
5,12,5,1,142,189,1,50,40,56,28,28,38,41,25,26,28,27,
254,220,3,69,72,113,46,44,45,35,35,21,22,36,36,56,57,65,
40,46,37,30,34,26,10,20,10,2,254,235,0,0,0,1,0,48,
255,122,1,148,0,222,0,11,0,0,55,51,53,51,21,51,21,35,
21,35,53,35,48,93,160,103,103,160,93,119,103,103,159,94,94,0,
0,1,0,49,255,215,2,24,0,119,0,3,0,0,55,33,21,33,
49,1,231,254,25,119,160,0,0,0,0,2,0,94,255,122,2,22,
1,10,0,3,0,7,0,0,55,33,21,33,17,33,21,33,94,1,
184,254,72,1,184,254,72,26,160,1,144,160,0,0,0,1,0,50,
254,196,1,113,2,36,0,19,0,0,23,38,53,52,63,1,51,7,
6,7,6,21,20,23,22,31,1,35,39,38,79,29,133,6,179,21,
64,32,32,33,33,62,22,180,6,76,110,105,121,254,170,8,31,94,
106,107,99,97,104,104,90,32,8,95,0,1,0,56,254,196,1,119,
2,34,0,19,0,0,19,35,55,54,55,54,53,52,39,38,47,1,
51,23,22,21,20,7,6,7,234,178,22,63,32,33,34,33,62,21,
178,6,135,30,30,75,254,196,31,92,104,107,97,90,111,108,91,31,
8,174,249,120,105,107,92,0,0,0,0,2,0,35,255,14,2,6,
1,106,0,11,0,61,0,0,37,34,6,20,22,51,50,54,53,52,
39,38,55,38,39,38,39,38,39,38,39,38,35,34,7,6,15,2,
39,55,54,55,54,51,50,23,22,23,22,23,22,23,22,21,17,35,
53,6,7,6,35,34,38,53,52,55,54,51,50,23,22,1,21,35,
46,44,38,36,40,21,19,34,2,3,7,10,10,14,17,10,18,11,
22,19,20,5,34,16,70,14,26,51,49,46,51,30,37,38,34,27,
26,15,14,168,4,28,24,57,86,116,58,59,83,56,43,1,34,40,
48,38,36,26,24,21,19,109,15,7,16,12,11,6,7,1,2,4,
4,2,14,7,111,12,21,15,14,7,9,20,19,31,31,46,43,60,
254,188,26,3,20,17,122,91,92,59,60,28,1,0,0,2,0,45,
255,28,2,42,1,119,0,7,0,44,0,0,55,51,38,39,38,35,
34,6,23,55,23,7,6,7,6,35,34,39,38,39,38,39,38,53,
52,55,54,51,50,23,22,23,22,29,1,33,22,23,22,23,22,23,
22,51,50,226,160,6,20,19,35,36,38,140,9,150,13,33,59,57,
59,56,47,49,36,35,21,21,75,74,112,72,57,56,32,31,254,181,
3,8,7,15,14,13,12,15,41,152,22,24,22,44,223,11,64,20,
51,29,28,23,24,40,40,56,57,63,127,87,86,39,39,69,68,85,
54,20,24,19,12,10,5,4,0,0,0,2,0,50,255,28,2,50,
1,121,0,14,0,28,0,0,55,20,23,22,51,50,54,53,52,39,
38,35,34,7,6,39,54,51,50,23,22,16,7,6,35,34,38,53,
52,216,23,24,43,44,48,24,25,43,42,25,23,99,68,121,123,66,
67,67,66,123,122,134,75,80,32,33,66,79,78,33,34,34,32,140,
83,82,84,254,240,84,83,164,139,137,0,0,0,1,0,63,255,28,
2,124,1,92,0,11,0,0,5,35,39,7,35,19,3,51,23,55,
51,3,2,121,201,84,83,202,184,173,191,84,82,205,186,228,147,147,
1,32,1,32,144,144,254,228,0,0,0,2,0,54,255,28,2,51,
1,119,0,7,0,42,0,0,5,35,22,23,22,50,55,54,39,7,
39,55,54,55,54,51,50,23,22,23,30,1,21,20,6,35,34,39,
38,39,38,61,1,33,38,39,38,39,38,39,38,35,34,1,127,160,
6,19,19,72,19,19,140,10,149,13,33,59,57,58,56,47,51,34,
37,40,150,110,71,58,56,32,32,1,75,3,7,6,17,14,13,12,
15,40,4,26,21,22,22,21,225,12,65,19,51,29,28,23,25,38,
42,108,67,126,174,40,39,69,70,82,55,25,19,17,13,11,4,4,
0,0,0,1,0,93,2,66,1,165,3,138,0,7,0,0,18,52,
54,50,22,20,6,34,93,96,136,96,96,136,2,162,136,96,96,136,
96,0,0,1,0,93,2,66,1,165,3,138,0,7,0,0,18,52,
54,50,22,20,6,34,93,96,136,96,96,136,2,162,136,96,96,136,
96,0,0,1,0,135,0,0,4,19,5,122,0,47,0,0,33,17,
46,1,39,38,39,38,53,52,55,54,55,54,55,54,51,50,23,22,
23,7,38,39,38,35,34,7,14,1,7,6,21,20,23,22,23,53,
33,21,33,21,33,21,33,21,33,21,1,109,68,88,27,25,11,11,
24,24,50,49,79,78,110,105,90,92,46,189,27,38,37,42,61,41,
42,44,9,10,4,5,14,2,166,254,33,1,197,254,59,1,223,1,
181,30,110,64,59,77,75,62,100,89,88,67,66,39,39,54,55,110,
68,44,31,30,26,26,86,55,62,51,48,40,48,38,217,182,193,182,
218,182,0,3,0,131,0,0,4,24,6,10,0,41,0,58,0,66,
0,0,1,6,15,1,35,55,38,39,7,35,19,38,39,38,39,38,
53,16,55,54,63,1,51,7,51,50,23,55,51,3,22,23,48,23,
22,23,22,23,7,3,54,55,3,46,1,39,38,39,38,35,34,7,
6,7,3,22,23,22,23,3,6,7,6,7,6,29,1,4,24,118,
249,25,152,27,70,69,35,152,61,48,29,27,16,15,170,79,114,49,
133,43,9,84,67,50,133,62,15,16,31,16,19,13,13,168,143,60,
52,90,4,16,4,9,18,29,26,17,8,16,7,151,18,19,36,58,
137,55,15,5,1,2,1,138,250,23,121,129,12,35,176,1,27,59,
74,69,86,83,96,1,59,161,73,29,218,201,23,224,254,221,11,16,
31,21,28,18,31,60,253,69,40,94,2,129,2,12,2,6,5,12,
1,2,1,253,34,26,15,36,17,2,224,68,121,29,28,38,24,43,
0,0,0,1,0,25,255,223,4,198,5,219,0,54,0,0,1,7,
38,35,34,7,6,21,17,54,55,5,2,33,32,3,38,53,16,55,
54,33,32,23,22,23,5,38,39,38,35,32,3,6,7,6,21,16,
23,30,1,23,22,23,17,33,21,54,51,50,23,22,23,30,1,4,
198,97,107,30,99,73,47,70,69,1,4,161,254,165,254,98,150,71,
213,158,1,10,0,255,161,51,27,255,0,66,102,34,36,254,222,54,
3,4,3,151,6,13,6,13,13,1,3,99,110,93,106,5,19,5,
11,3,241,201,61,115,73,66,254,141,47,119,100,254,169,1,115,178,
238,1,138,201,150,187,62,61,90,106,39,15,254,157,25,47,38,40,
254,184,141,5,11,5,12,6,3,60,115,144,62,3,13,4,8,0,
0,0,0,1,0,31,0,0,4,126,5,178,0,21,0,0,1,33,
17,33,17,35,53,51,53,35,53,51,17,33,21,33,21,33,21,33,
21,33,4,104,253,25,254,244,86,86,86,86,4,9,253,3,2,231,
253,25,2,231,1,150,254,106,1,150,230,120,230,1,216,240,232,230,
120,0,0,1,0,43,0,0,4,114,5,196,0,67,0,0,37,6,
35,33,19,52,62,2,53,54,55,35,53,51,54,55,54,55,35,53,
33,54,55,54,55,54,55,54,55,54,51,50,19,7,38,39,38,35,
34,7,6,29,1,33,21,33,22,29,1,33,21,33,14,1,7,14,
1,7,14,1,7,37,50,63,1,52,55,4,114,69,173,252,245,121,
1,1,1,1,2,201,240,3,2,1,2,248,1,0,11,23,24,37,
38,48,50,62,37,45,223,105,188,27,86,14,13,54,40,24,1,88,
254,170,2,1,84,254,139,2,6,2,2,4,1,10,10,10,1,162,
51,37,2,2,156,156,1,92,1,4,3,3,1,3,8,230,15,31,
14,30,229,97,90,92,76,78,49,51,15,8,254,174,21,111,18,2,
139,84,72,33,229,30,14,46,230,7,27,5,9,12,3,30,26,22,
2,65,6,3,2,0,0,0,0,1,0,25,255,35,5,98,5,46,
0,43,0,0,41,1,17,52,38,39,34,7,3,17,35,7,33,1,
52,39,38,39,34,7,6,21,17,33,17,33,21,54,59,1,50,23,
22,23,19,33,7,51,50,19,22,23,22,21,5,98,254,253,54,48,
23,24,140,213,90,254,225,1,76,28,27,48,84,57,45,254,254,1,
2,83,97,10,102,64,69,34,152,1,12,92,6,235,50,11,3,3,
2,56,143,150,8,8,254,172,253,247,221,3,21,140,78,75,8,94,
72,98,253,163,4,50,117,146,32,35,64,1,98,223,254,219,53,56,
60,69,0,0,0,3,0,25,0,0,5,32,5,178,0,27,0,30,
0,34,0,0,1,35,17,33,3,33,17,33,17,35,53,51,53,35,
53,51,17,33,1,33,17,33,17,51,21,35,21,51,37,53,35,7,
39,35,21,5,32,92,254,247,166,254,108,254,244,92,92,92,92,1,
4,1,39,1,23,1,13,92,92,92,254,151,139,158,133,136,1,29,
254,227,1,29,254,227,1,29,230,229,230,1,228,254,28,1,228,254,
28,230,229,2,227,229,229,229,0,2,0,25,255,227,8,76,5,178,
0,103,0,120,0,0,1,20,7,14,1,7,6,35,33,34,38,39,
38,39,38,53,17,35,14,1,7,6,7,6,35,17,33,17,33,50,
23,22,23,22,23,22,23,51,53,33,21,51,21,35,17,20,23,22,
51,50,55,54,51,50,55,54,53,52,39,38,39,38,39,38,39,46,
1,53,52,55,54,55,54,55,54,51,50,23,22,23,22,23,22,23,
7,38,39,38,35,34,7,6,21,20,23,22,23,22,23,22,23,22,
23,22,1,52,39,38,39,38,39,38,35,17,51,50,55,62,1,55,
54,8,76,30,31,102,73,72,86,254,94,83,144,44,47,25,26,94,
39,128,71,81,75,83,79,254,244,1,33,89,100,101,80,81,58,57,
12,51,1,2,154,154,32,30,49,105,103,104,104,62,37,36,36,39,
54,56,64,66,54,55,74,30,31,50,51,69,72,77,64,63,60,46,
49,30,31,11,240,10,29,28,45,56,27,28,36,38,52,48,70,62,
56,53,37,36,250,31,33,34,48,55,50,63,43,21,47,58,55,88,
28,29,1,66,93,66,68,82,21,21,28,33,35,59,61,92,2,54,
74,106,29,33,11,12,253,188,5,178,20,20,44,44,75,73,108,250,
250,229,253,206,53,21,20,6,6,27,26,66,37,26,28,22,23,25,
26,35,36,106,79,84,63,65,41,42,21,22,22,21,40,43,51,54,
68,44,38,38,37,24,25,55,35,26,27,23,21,32,28,39,37,52,
51,2,123,65,37,39,17,20,4,5,254,118,8,8,48,40,41,0,
0,2,0,25,255,227,6,172,5,178,0,74,0,87,0,0,1,3,
35,17,33,17,33,51,32,23,22,21,20,7,6,7,6,7,1,22,
23,22,23,22,51,50,55,54,55,54,55,54,53,52,39,46,1,39,
38,39,38,39,38,53,52,55,54,51,50,23,22,23,7,38,39,34,
7,6,21,20,31,1,30,1,21,16,7,6,35,34,39,38,39,46,
1,19,52,39,38,43,2,17,51,32,55,54,53,2,58,193,84,254,
244,1,12,99,1,107,147,74,199,29,44,35,48,1,0,25,51,56,
59,46,50,23,11,65,57,54,37,36,104,4,19,5,18,10,246,63,
29,183,90,106,188,108,47,12,240,30,83,100,8,2,84,37,179,188,
236,68,90,118,110,106,93,95,156,61,234,22,12,37,99,99,1,24,
23,2,1,35,1,33,253,188,5,178,185,94,127,222,129,19,21,17,
11,254,150,36,21,23,7,6,1,3,17,16,31,30,44,58,46,2,
8,2,6,3,84,117,55,62,213,84,41,152,70,77,44,105,8,80,
10,14,49,46,14,69,154,113,254,251,69,21,14,13,35,35,124,3,
92,148,16,2,254,118,189,14,5,0,0,0,0,4,0,25,0,0,
6,6,5,178,0,31,0,34,0,38,0,41,0,0,1,3,51,21,
35,7,51,21,35,3,33,3,33,3,33,3,35,53,51,39,35,53,
51,3,33,19,51,19,33,19,51,19,3,35,23,5,39,35,7,39,
35,23,6,6,80,71,108,37,145,182,47,254,200,67,254,204,68,254,
217,45,172,135,35,100,63,75,1,24,74,168,107,1,27,115,178,76,
111,86,53,254,221,55,90,56,176,78,31,5,178,254,28,230,229,230,
254,227,1,29,254,227,1,29,230,229,230,1,228,254,28,1,201,254,
55,1,228,253,54,211,18,229,229,229,205,0,0,2,0,25,0,0,
5,24,5,178,0,18,0,37,0,0,1,17,33,17,52,39,38,35,
48,43,1,17,33,17,33,51,32,23,22,1,17,33,17,20,23,22,
51,48,59,1,17,33,17,33,35,32,39,38,3,206,254,237,246,20,
9,30,101,254,244,1,12,101,1,64,161,99,253,149,1,18,246,20,
9,31,100,1,13,254,243,100,254,190,160,98,4,7,254,166,1,90,
167,18,2,251,62,5,178,173,108,253,17,1,85,254,171,166,18,2,
4,194,250,78,172,105,0,3,1,78,2,210,3,77,6,96,0,25,
0,41,0,45,0,0,1,35,53,6,35,34,39,38,53,52,55,54,
59,1,22,23,53,35,53,51,53,51,21,51,21,35,3,52,39,38,
35,34,7,6,21,20,23,22,51,50,55,54,19,33,53,33,3,23,
129,46,50,91,57,84,51,64,105,24,50,34,154,154,129,54,54,125,
33,35,47,21,22,43,23,27,49,14,14,74,144,254,77,1,179,3,
136,35,49,51,72,147,108,85,103,6,42,76,115,33,33,115,254,201,
76,45,47,25,55,90,69,40,58,7,30,254,193,127,0,0,0,1,
0,125,0,164,4,72,5,2,0,55,0,0,1,35,53,51,54,55,
54,51,50,23,22,23,7,38,35,34,7,6,7,33,21,33,6,21,
23,33,21,33,22,23,22,51,50,55,54,55,54,55,23,6,7,6,
7,6,7,6,35,34,38,39,35,53,51,38,53,52,1,5,130,150,
50,121,122,153,107,88,87,83,156,82,127,54,62,61,8,1,13,254,
221,6,5,1,30,254,250,15,63,62,44,52,24,25,30,31,33,174,
37,24,34,37,47,55,58,77,168,250,33,151,136,3,2,248,166,152,
102,102,46,46,107,133,103,38,37,52,166,6,32,75,166,37,26,25,
3,3,16,16,36,133,46,21,30,22,28,11,12,184,133,166,43,35,
29,0,0,0,0,1,0,25,0,0,5,30,5,178,0,19,0,0,
41,1,1,7,17,33,17,35,53,51,17,33,17,51,1,33,1,33,
21,33,5,30,254,176,254,18,78,254,243,108,108,1,13,26,2,5,
1,60,254,16,1,90,254,178,2,76,92,254,16,2,124,229,2,81,
253,175,2,81,253,175,229,0,0,1,0,25,0,0,4,204,5,178,
0,23,0,0,1,33,21,37,21,5,21,37,21,5,17,33,17,5,
53,37,53,5,53,37,17,33,53,33,4,204,254,55,1,64,254,192,
1,64,254,192,254,243,254,174,1,82,254,174,1,82,254,35,4,179,
4,194,203,80,230,80,121,80,229,80,254,77,1,113,84,230,84,121,
84,229,84,1,13,240,0,4,0,248,0,0,3,163,5,178,0,3,
0,17,0,31,0,34,0,0,19,1,51,1,3,6,43,1,21,35,
17,59,1,50,23,22,21,20,37,43,1,21,51,50,55,54,55,54,
53,52,39,38,11,1,51,248,1,25,147,0,255,189,83,120,27,166,
146,47,160,82,51,254,246,27,27,27,58,27,29,7,4,21,19,27,
107,203,2,218,2,216,253,40,254,48,61,205,2,148,88,54,79,105,
172,145,15,16,26,11,10,28,18,16,2,170,254,211,0,2,0,150,
255,207,4,5,5,212,0,67,0,97,0,0,5,34,39,38,39,38,
39,38,53,52,55,54,55,54,55,54,51,50,23,22,23,52,39,38,
39,38,39,38,39,46,1,39,38,35,34,7,6,43,1,39,54,55,
54,55,54,51,48,51,50,23,22,23,22,23,22,23,22,23,22,29,
1,6,7,6,7,6,7,6,19,52,39,38,39,46,1,35,34,7,
14,1,7,6,21,20,23,22,23,22,23,22,51,50,55,54,55,54,
55,54,2,74,117,83,82,53,53,24,24,26,28,51,53,76,77,101,
77,58,61,42,21,23,36,37,60,57,74,8,24,4,16,18,39,48,
34,38,13,16,15,23,32,16,32,16,42,50,67,62,75,109,69,71,
41,43,16,16,1,29,27,55,55,82,83,74,16,14,29,26,82,50,
40,27,26,38,7,8,20,22,58,16,17,18,21,49,36,35,25,22,
13,11,49,42,42,71,72,94,96,104,93,84,89,66,68,40,41,47,
49,57,51,66,72,61,62,62,58,35,4,11,2,8,10,7,201,6,
3,4,1,2,24,22,44,63,91,94,102,106,108,105,97,130,91,105,
97,82,81,49,50,2,4,42,50,42,41,36,46,29,28,84,42,46,
28,74,66,71,45,12,9,10,30,30,44,40,53,45,0,4,0,37,
0,0,4,120,5,178,0,34,0,45,0,55,0,60,0,0,1,35,
6,7,6,43,1,17,33,17,35,53,51,53,35,53,51,17,33,51,
32,23,22,23,22,23,51,21,35,22,21,20,6,7,51,37,38,39,
38,39,38,43,2,21,51,5,52,39,33,21,51,33,54,55,54,7,
33,21,51,50,4,120,84,38,114,163,243,100,254,243,96,96,96,96,
1,13,100,1,65,161,20,20,18,12,90,68,6,2,2,66,254,90,
25,44,41,50,22,8,30,100,47,1,103,13,254,119,47,1,95,5,
1,2,54,254,160,100,179,3,132,116,85,119,253,188,3,132,78,119,
78,1,27,173,21,32,28,29,78,30,36,19,18,16,197,15,11,11,
4,2,43,144,33,33,119,12,13,18,121,76,0,0,0,2,0,109,
0,0,4,46,5,176,0,9,0,43,0,0,1,17,6,7,6,21,
20,22,23,22,1,35,53,38,39,38,53,52,55,54,55,53,51,21,
22,23,22,23,7,38,39,17,54,55,54,53,35,53,33,21,16,7,
6,7,1,211,49,37,45,46,42,16,1,15,244,181,95,82,131,92,
135,244,115,88,45,27,207,12,56,93,30,13,89,1,56,137,90,132,
1,117,2,220,43,76,102,128,100,168,64,24,254,112,144,54,185,167,
206,250,169,115,38,128,121,27,92,49,58,70,43,33,252,245,39,127,
49,50,192,117,254,246,152,99,24,0,0,3,0,25,0,0,5,73,
5,178,0,23,0,26,0,30,0,0,41,1,3,33,3,33,19,35,
53,51,55,35,53,33,19,33,19,33,21,35,23,51,21,35,1,39,
7,19,39,33,7,5,73,254,205,93,253,250,101,254,203,110,110,198,
48,246,1,78,229,1,1,207,1,45,221,41,180,98,254,20,60,65,
239,39,254,232,43,1,29,254,227,1,29,230,121,229,2,81,253,175,
229,121,230,2,68,185,185,254,162,121,121,0,0,0,0,1,0,16,
255,227,4,140,5,212,0,73,0,0,1,33,6,21,20,22,51,50,
55,54,55,54,55,54,55,23,6,7,6,35,34,38,39,38,39,38,
53,52,55,54,55,35,53,51,54,55,54,55,33,53,33,53,52,46,
1,39,38,35,34,7,6,7,37,54,55,54,51,50,23,22,23,30,
1,29,2,51,21,35,6,7,6,7,33,4,140,252,225,21,136,96,
57,46,37,39,35,24,29,18,248,73,129,131,200,99,186,68,70,41,
42,2,1,5,62,210,42,62,59,60,254,79,3,24,42,64,43,56,
29,64,50,49,30,254,248,72,122,120,161,98,85,90,68,71,78,82,
176,34,46,43,53,1,96,1,242,40,44,107,94,19,16,33,30,44,
53,39,82,181,106,107,58,56,58,80,83,108,15,28,19,22,230,36,
32,31,22,229,13,53,64,34,5,6,31,31,55,78,147,66,65,23,
25,48,51,148,99,7,13,229,38,31,29,23,0,0,0,2,0,129,
0,0,4,26,5,176,0,11,0,40,0,0,1,6,7,6,7,6,
21,20,22,23,22,23,37,6,7,21,35,53,38,39,38,39,38,53,
16,55,54,55,53,51,21,22,23,22,23,7,38,39,17,54,55,1,
252,105,24,5,1,2,60,57,10,10,2,30,105,193,244,225,96,27,
16,15,170,83,126,244,131,89,37,30,219,29,39,35,39,4,81,61,
179,27,28,38,22,129,180,54,10,6,35,223,50,133,133,49,236,69,
86,83,94,1,56,164,77,29,124,124,30,107,43,66,77,52,30,253,
64,35,70,0,0,0,0,1,0,70,255,227,4,87,5,176,0,25,
0,0,5,34,39,38,53,17,33,17,33,17,35,53,51,17,33,17,
33,17,33,17,51,21,35,17,20,51,4,87,238,69,43,254,171,254,
254,92,92,1,2,1,85,1,2,92,92,92,29,113,67,126,1,240,
252,251,3,5,229,1,198,254,58,1,198,254,58,229,254,20,86,0,
0,4,0,21,255,174,4,134,5,212,0,18,0,117,0,129,0,140,
0,0,19,22,23,22,23,22,23,53,52,7,6,7,6,7,6,23,
22,23,22,37,20,7,6,7,21,35,53,43,1,21,35,53,38,39,
38,39,21,35,53,38,39,46,1,39,46,1,39,38,39,38,53,52,
54,53,54,55,54,55,54,55,51,50,23,30,1,29,1,54,51,50,
23,54,51,50,23,30,1,21,54,55,54,53,52,39,38,39,38,39,
36,39,38,39,38,53,52,55,54,51,32,19,5,38,39,38,43,1,
34,21,20,23,22,31,1,22,23,22,23,22,1,52,39,38,39,6,
7,6,29,1,54,55,37,52,38,39,6,7,6,29,1,22,23,119,
4,8,2,12,7,8,15,16,12,18,4,5,3,3,8,8,4,22,
186,63,73,153,31,78,154,35,20,28,25,152,18,14,5,20,5,6,
22,4,23,12,10,1,3,20,20,42,27,39,9,32,26,30,42,32,
39,102,40,57,94,128,24,2,2,23,16,13,199,21,26,27,25,254,
137,55,7,1,2,213,121,156,1,81,138,254,248,29,50,49,65,23,
211,58,57,121,49,149,92,95,50,67,254,37,13,12,10,32,22,20,
50,59,254,249,24,11,31,22,20,55,53,1,88,14,18,5,24,13,
12,197,13,1,2,4,5,12,14,17,16,20,18,55,228,124,42,22,
80,53,53,66,5,5,6,10,92,184,16,23,8,34,8,11,42,6,
39,42,38,31,3,11,3,43,33,32,16,9,2,10,12,42,33,22,
36,61,61,151,14,16,15,29,38,36,38,140,82,10,8,8,6,99,
235,25,20,28,16,235,107,59,254,234,78,52,33,32,162,63,53,53,
34,15,44,61,62,70,95,254,172,68,29,28,4,5,34,27,45,82,
7,22,35,70,54,5,5,34,33,39,61,19,6,0,0,0,0,2,
0,12,0,0,4,142,5,178,0,3,0,11,0,0,1,33,53,33,
17,33,17,33,17,33,53,33,4,142,251,126,4,130,254,80,254,243,
254,59,4,130,4,194,240,253,169,252,165,3,91,240,0,1,0,105,
0,0,4,52,5,178,0,39,0,0,19,55,33,52,39,38,39,38,
35,33,55,33,7,35,22,23,22,23,51,7,35,6,7,6,7,1,
33,1,53,50,22,51,50,55,54,55,54,55,54,55,105,123,1,70,
11,31,31,35,42,254,213,123,3,80,115,166,11,6,8,4,252,115,
133,30,99,98,136,1,185,254,244,254,52,23,84,20,48,43,50,33,
34,33,28,16,3,198,205,1,11,32,18,20,205,205,20,19,28,15,
205,130,87,86,21,253,126,2,124,168,4,10,12,18,19,33,28,46,
0,0,0,3,0,10,255,223,6,246,6,60,0,9,0,23,0,74,
0,0,18,20,22,51,50,54,52,38,35,34,0,16,55,54,51,50,
23,22,16,7,6,35,34,39,1,2,33,34,39,38,39,38,39,38,
39,38,53,52,55,54,55,54,55,54,55,54,51,50,23,22,23,7,
38,39,38,35,34,7,6,7,14,1,7,6,21,20,23,22,23,22,
23,22,51,50,55,183,84,61,60,84,84,60,61,254,255,93,92,133,
132,92,93,93,92,132,133,92,6,143,159,254,164,137,111,110,71,70,
48,49,19,20,21,21,48,49,71,73,109,111,134,177,130,129,57,255,
41,66,68,63,79,62,63,39,38,52,10,11,21,22,39,41,69,70,
90,135,113,5,66,124,88,88,124,88,254,232,1,4,91,91,91,91,
254,252,91,91,91,253,15,254,169,44,44,75,75,101,103,111,114,120,
119,105,107,95,98,68,70,40,41,91,90,129,89,66,46,47,27,28,
46,46,132,70,74,80,111,96,98,75,78,43,44,201,0,4,0,119,
0,0,6,140,5,209,0,3,0,17,0,30,0,40,0,0,1,33,
21,33,19,20,23,22,51,50,54,53,52,38,35,34,7,6,38,54,
51,50,23,22,16,7,6,35,34,38,53,1,17,33,1,17,33,17,
33,1,17,4,40,2,100,253,156,226,23,24,43,44,48,48,44,43,
24,23,166,134,122,124,65,67,67,66,123,122,134,252,19,1,4,1,
52,1,13,254,247,254,208,2,154,240,2,250,80,32,33,66,79,78,
66,33,32,58,164,81,84,254,240,84,83,164,139,251,92,5,176,252,
84,3,172,250,80,3,205,252,51,0,0,2,0,41,4,50,5,208,
7,60,0,12,0,20,0,0,1,17,51,27,1,51,17,35,17,3,
35,3,17,1,33,21,35,17,35,17,35,2,214,222,157,161,222,181,
116,171,113,252,158,2,139,228,184,239,4,50,3,10,254,48,1,208,
252,246,1,108,254,148,1,101,254,155,3,10,170,253,160,2,96,0,
0,1,0,31,0,0,5,98,5,209,0,68,0,0,37,21,33,53,
51,38,39,38,39,38,53,52,55,54,55,54,55,54,55,54,32,23,
22,23,30,1,23,22,21,20,7,6,7,6,7,51,21,33,53,54,
55,54,55,54,55,54,53,52,38,39,38,39,38,35,34,7,6,7,
6,7,6,7,6,21,20,23,30,2,2,121,253,166,212,33,22,47,
21,20,20,19,48,45,71,69,106,105,1,8,105,106,69,67,96,19,
20,20,19,48,23,32,191,253,166,60,76,71,23,24,8,9,34,35,
34,70,68,91,75,58,56,38,40,22,26,8,9,10,11,46,126,229,
229,229,54,48,105,105,101,112,98,102,95,101,95,77,75,46,46,46,
46,74,71,202,96,102,98,104,108,101,109,52,51,229,229,16,64,61,
80,83,69,73,79,89,170,73,72,46,45,30,29,50,53,61,71,62,
67,72,82,70,75,140,126,0,0,0,0,2,0,49,0,0,4,198,
4,48,0,43,0,66,0,0,1,17,20,23,22,23,22,23,22,51,
50,55,54,55,51,6,7,6,7,6,35,34,39,38,39,38,53,52,
55,54,55,54,51,50,23,22,23,22,19,33,34,7,14,1,37,17,
52,39,38,39,38,35,34,7,6,7,6,7,6,21,17,20,51,33,
50,55,54,1,10,27,24,50,48,70,72,79,109,97,99,66,109,112,
107,63,55,60,83,140,102,101,82,162,164,85,98,100,140,125,98,96,
86,167,14,252,91,9,3,5,6,2,226,57,57,88,90,79,71,74,
71,47,48,27,29,23,2,177,16,5,5,1,237,254,250,21,32,28,
34,33,20,21,47,48,75,124,44,25,9,10,36,36,77,153,233,228,
159,79,35,36,32,31,70,135,254,228,1,2,12,74,1,1,42,46,
47,31,32,23,22,32,32,29,31,18,254,232,14,6,7,0,0,3,
0,31,255,28,3,246,6,117,0,63,0,69,0,73,0,0,5,55,
23,22,23,22,51,50,54,52,39,38,43,1,53,51,50,55,54,53,
52,39,38,35,34,7,6,15,1,39,55,54,51,50,23,22,23,22,
23,22,21,20,7,30,1,23,22,23,22,21,20,7,6,7,6,7,
6,35,34,39,38,39,38,39,1,35,55,51,17,35,19,1,39,1,
1,209,167,7,17,28,28,32,44,52,29,30,37,102,90,28,23,22,
21,22,32,25,16,18,7,6,164,8,58,169,51,38,42,35,33,22,
21,59,9,34,18,21,10,10,20,21,35,37,49,52,56,57,54,49,
45,41,25,254,255,167,181,160,174,9,2,232,186,253,16,19,45,16,
41,18,18,50,74,27,28,146,24,23,28,39,20,20,12,13,18,16,
43,21,153,11,12,25,23,46,43,56,84,53,7,30,24,28,32,33,
43,52,43,46,33,35,19,20,19,17,45,41,67,5,247,165,253,0,
254,65,2,91,77,253,168,0,0,0,0,3,0,52,255,28,4,176,
6,135,0,57,0,121,0,125,0,0,19,39,55,54,55,54,51,50,
23,22,23,22,23,22,23,22,21,20,7,6,7,6,15,1,6,7,
6,7,33,21,33,53,52,55,54,55,54,55,54,55,54,55,54,55,
54,55,54,55,54,55,54,53,52,38,34,7,6,7,1,55,23,22,
23,22,51,50,54,52,39,38,43,1,53,51,50,55,54,53,52,39,
38,35,34,7,6,15,1,39,55,54,51,50,23,22,23,22,23,22,
21,20,7,30,1,23,22,23,22,21,20,7,6,7,6,7,6,35,
34,39,38,39,38,39,3,1,39,1,218,156,4,17,71,72,83,27,
39,33,33,34,25,26,15,15,19,20,48,24,21,70,51,16,19,7,
1,59,253,244,4,5,11,13,20,24,31,16,35,32,21,24,24,21,
18,16,9,9,42,68,20,18,13,1,171,167,7,17,28,28,32,44,
52,29,30,37,102,90,28,23,22,21,22,32,25,16,18,7,6,164,
8,58,169,51,38,42,35,33,22,21,59,9,34,18,21,10,10,20,
21,35,37,49,52,56,57,54,49,45,41,25,248,2,232,186,253,16,
5,138,47,17,82,53,54,7,6,18,19,26,28,43,44,54,66,44,
46,48,24,15,53,39,17,20,9,160,20,48,29,36,33,40,29,35,
31,16,28,25,15,16,20,17,20,18,20,21,24,43,42,17,15,42,
250,80,45,16,41,18,18,50,74,27,28,146,24,23,28,39,20,20,
12,13,18,16,43,21,153,11,12,25,23,46,43,56,84,53,7,30,
24,28,32,33,43,52,43,46,33,35,19,20,19,17,45,41,67,1,
221,2,91,77,253,168,0,0,0,3,0,31,255,28,3,250,6,117,
0,49,0,55,0,59,0,0,37,7,39,19,33,21,35,7,54,51,
50,23,22,23,22,21,20,7,14,1,35,34,39,38,39,46,1,39,
38,47,1,55,23,22,23,22,23,22,23,22,23,22,51,50,55,54,
52,38,35,34,1,35,55,51,17,35,19,1,39,1,2,163,9,157,
65,1,122,237,19,13,35,78,61,62,36,37,37,36,124,77,50,41,
44,29,31,44,14,13,6,4,172,4,2,4,4,9,10,10,11,16,
16,18,45,29,28,56,46,47,254,31,167,181,160,174,9,2,232,186,
253,16,121,9,55,1,131,160,98,2,31,32,61,63,75,76,63,61,
64,14,15,22,23,56,28,25,29,20,30,19,7,11,9,12,14,8,
9,6,6,29,28,92,62,5,64,165,253,0,254,65,2,91,77,253,
168,0,0,3,0,52,255,28,4,180,6,135,0,57,0,107,0,111,
0,0,19,39,55,54,55,54,51,50,23,22,23,22,23,22,23,22,
21,20,7,6,7,6,15,1,6,7,6,7,33,21,33,53,52,55,
54,55,54,55,54,55,54,55,54,55,54,55,54,55,54,55,54,53,
52,38,34,7,6,7,1,7,39,19,33,21,35,7,54,51,50,23,
22,23,22,21,20,7,14,1,35,34,39,38,39,46,1,39,38,47,
1,55,23,22,23,22,23,22,23,22,23,22,51,50,55,54,52,38,
35,34,9,1,39,1,218,156,4,17,71,72,83,27,39,33,33,34,
25,26,15,15,19,20,48,24,21,70,51,16,19,7,1,59,253,244,
4,5,11,13,20,24,31,16,35,32,21,24,24,21,18,16,9,9,
42,68,20,18,13,2,125,9,157,65,1,122,237,19,13,35,78,61,
62,36,37,37,36,124,77,50,41,44,29,31,44,14,13,6,4,172,
4,2,4,4,9,10,10,11,16,16,18,45,29,28,56,46,47,254,
40,2,232,186,253,16,5,138,47,17,82,53,54,7,6,18,19,26,
28,43,44,54,66,44,46,48,24,15,53,39,17,20,9,160,20,48,
29,36,33,40,29,35,31,16,28,25,15,16,20,17,20,18,20,21,
24,43,42,17,15,42,250,220,9,55,1,131,160,98,2,31,32,61,
63,75,76,63,61,64,14,15,22,23,56,28,25,29,20,30,19,7,
11,9,12,14,8,9,6,6,29,28,92,62,1,38,2,91,77,253,
168,0,0,0,0,3,0,51,255,28,4,150,6,148,0,63,0,113,
0,117,0,0,19,55,23,22,23,22,51,50,54,53,52,39,38,43,
1,53,51,50,55,54,53,52,39,38,35,34,7,6,15,1,39,55,
54,51,50,22,23,22,23,22,21,20,7,30,1,23,22,23,22,21,
20,7,6,7,6,7,6,35,34,39,38,39,38,39,1,7,39,19,
33,21,35,7,54,51,50,23,22,23,22,21,20,7,14,1,35,34,
39,38,39,46,1,39,38,47,1,55,23,22,23,22,23,22,23,22,
23,22,51,50,55,54,52,38,35,34,9,1,39,1,51,167,7,17,
28,28,32,44,52,29,28,39,102,90,28,23,22,21,23,31,24,17,
18,7,6,164,8,58,169,47,84,35,33,22,21,59,9,34,18,21,
10,10,20,21,35,37,49,52,56,57,54,49,45,41,25,3,4,9,
157,65,1,122,237,19,13,35,78,61,62,36,37,37,36,124,77,50,
41,44,29,31,44,14,13,6,4,172,4,2,4,4,9,10,10,11,
16,16,18,45,29,28,56,46,47,254,40,2,232,186,253,16,4,70,
45,16,41,18,18,50,38,36,27,27,146,25,23,28,40,19,21,13,
13,18,16,43,21,154,24,25,23,46,44,55,84,53,7,30,24,28,
32,33,42,53,43,46,33,35,19,20,19,17,45,41,67,252,71,9,
55,1,131,160,98,2,31,32,61,63,75,76,63,61,64,14,15,22,
23,56,28,25,29,20,30,19,7,11,9,12,14,8,9,6,6,29,
28,92,62,1,38,2,91,77,253,168,0,4,0,52,255,28,4,150,
6,117,0,10,0,13,0,63,0,67,0,0,1,51,21,35,21,35,
53,33,53,1,51,3,7,51,1,7,39,19,33,21,35,7,54,51,
50,23,22,23,22,21,20,7,14,1,35,34,39,38,39,46,1,39,
38,47,1,55,23,22,23,22,23,22,23,22,23,22,51,50,55,54,
52,38,35,34,9,1,39,1,2,6,70,70,174,254,220,1,35,175,
170,110,110,1,227,9,157,65,1,122,237,19,13,35,78,61,62,36,
37,37,36,124,77,50,41,44,29,31,44,14,13,6,4,172,4,2,
4,4,9,10,10,11,16,16,18,45,29,28,56,46,47,254,40,2,
232,186,253,16,4,194,159,174,174,128,1,210,254,249,171,251,182,9,
55,1,131,160,98,2,31,32,61,63,75,76,63,61,64,14,15,22,
23,56,28,25,29,20,30,19,7,11,9,12,14,8,9,6,6,29,
28,92,62,1,38,2,91,77,253,168,0,4,0,31,255,28,3,237,
6,117,0,15,0,44,0,50,0,54,0,0,37,52,39,38,35,34,
7,6,21,20,23,22,51,50,55,54,3,22,23,22,21,20,7,6,
7,6,7,6,35,34,39,38,39,38,53,52,55,54,55,54,55,54,
55,19,51,1,35,55,51,17,35,19,1,39,1,3,63,24,25,38,
36,24,24,25,26,34,37,25,24,76,110,68,72,19,19,34,33,50,
52,54,73,60,59,33,33,11,9,13,11,19,20,2,142,189,253,82,
167,181,160,174,9,2,232,186,253,16,20,41,27,28,28,28,38,41,
25,26,28,27,1,36,3,69,72,113,46,44,45,35,35,21,22,36,
36,56,57,65,40,46,37,30,24,36,37,5,1,21,3,166,165,253,
0,254,65,2,91,77,253,168,0,0,0,4,0,50,255,28,4,151,
6,130,0,50,0,66,0,95,0,99,0,0,1,7,39,19,33,21,
35,7,54,51,50,22,23,22,21,20,7,14,1,35,34,39,38,39,
46,1,39,38,47,1,55,23,22,23,22,23,22,23,22,23,22,51,
50,55,54,53,52,39,38,35,34,1,52,39,38,35,34,7,6,21,
20,23,22,51,50,55,54,3,22,23,22,21,20,7,6,7,6,7,
6,35,34,39,38,39,38,53,52,55,54,55,54,55,54,55,19,51,
5,1,39,1,1,1,9,157,65,1,122,237,19,20,28,77,124,36,
37,37,36,124,77,50,41,44,29,31,44,14,13,6,4,172,4,2,
4,4,9,10,10,11,16,17,17,45,29,28,28,29,45,46,2,209,
24,25,38,36,24,24,25,26,34,37,25,24,76,110,68,72,19,19,
34,33,50,52,54,73,60,59,33,33,11,9,13,11,19,20,2,142,
189,253,91,2,232,186,253,16,4,210,9,55,1,130,160,97,3,64,
61,63,76,75,63,61,64,14,15,22,23,56,28,25,29,20,30,19,
8,10,9,12,14,8,9,6,6,29,28,45,47,31,32,251,42,41,
27,28,28,28,38,41,25,26,28,27,1,36,3,69,72,113,46,44,
45,35,35,21,22,36,36,56,57,65,40,46,37,30,24,36,37,5,
1,21,116,2,91,77,253,168,0,5,0,31,255,28,4,3,6,117,
0,41,0,57,0,71,0,77,0,81,0,0,0,22,21,20,7,6,
7,6,15,1,6,15,1,22,23,22,21,20,7,6,7,6,7,6,
35,34,39,38,53,52,55,54,55,38,39,38,39,38,53,52,54,51,
7,20,23,22,51,50,55,54,53,52,39,38,35,34,7,6,18,50,
55,54,53,52,38,35,34,7,6,21,20,23,1,35,55,51,17,35,
19,1,39,1,3,88,142,4,5,5,7,5,18,13,13,3,28,30,
44,22,23,39,38,52,54,55,126,77,76,45,30,27,13,19,17,13,
11,138,113,77,19,18,41,39,19,20,19,21,39,40,19,18,28,100,
28,29,64,43,52,27,28,29,254,60,167,181,160,174,9,2,232,186,
253,16,2,59,122,95,23,17,20,12,16,6,22,15,10,2,17,40,
59,73,61,47,48,32,31,15,16,69,69,112,70,62,39,18,10,21,
19,30,27,36,97,120,217,35,16,15,16,17,33,30,18,19,19,18,
254,50,28,29,43,44,58,28,30,44,43,29,6,2,165,253,0,254,
65,2,91,77,253,168,0,0,0,5,0,51,255,28,4,195,6,148,
0,63,0,105,0,121,0,135,0,139,0,0,19,55,23,22,23,22,
51,50,54,53,52,39,38,43,1,53,51,50,55,54,53,52,39,38,
35,34,7,6,15,1,39,55,54,51,50,22,23,22,23,22,21,20,
7,30,1,23,22,23,22,21,20,7,6,7,6,7,6,35,34,39,
38,39,38,39,0,22,21,20,7,6,7,6,15,1,6,15,1,22,
23,22,21,20,7,6,7,6,7,6,35,34,39,38,53,52,55,54,
55,38,39,38,39,38,53,52,54,51,7,20,23,22,51,50,55,54,
53,52,39,38,35,34,7,6,18,50,55,54,53,52,38,35,34,7,
6,21,20,23,9,1,39,1,51,167,7,17,28,28,32,44,52,29,
28,39,102,90,28,23,22,21,23,31,24,17,18,7,6,164,8,58,
169,47,84,35,33,22,21,59,9,34,18,21,10,10,20,21,35,37,
49,52,56,57,54,49,45,41,25,3,221,142,4,5,5,7,5,18,
13,13,3,28,30,44,22,23,39,38,52,54,55,126,77,76,45,30,
27,13,19,17,13,11,138,113,77,19,18,41,39,19,20,19,21,39,
40,19,18,28,100,28,29,64,43,52,27,28,29,254,69,2,232,186,
253,16,4,70,45,16,41,18,18,50,38,36,27,27,146,25,23,28,
40,19,21,13,13,18,16,43,21,154,24,25,23,46,44,55,84,53,
7,30,24,28,32,33,42,53,43,46,33,35,19,20,19,17,45,41,
67,254,9,122,95,23,17,20,12,16,6,22,15,10,2,17,40,59,
73,61,47,48,32,31,15,16,69,69,112,70,62,39,18,10,21,19,
30,27,36,97,120,217,35,16,15,16,17,33,30,18,19,19,18,254,
50,28,29,43,44,58,28,30,44,43,29,1,232,2,91,77,253,168,
0,0,0,5,0,69,255,28,4,195,6,130,0,50,0,92,0,108,
0,122,0,126,0,0,1,7,39,19,33,21,35,7,54,51,50,22,
23,22,21,20,7,14,1,35,34,39,38,39,46,1,39,38,47,1,
55,23,22,23,22,23,22,23,22,23,22,51,50,55,54,53,52,39,
38,35,34,0,22,21,20,7,6,7,6,15,1,6,15,1,22,23,
22,21,20,7,6,7,6,7,6,35,34,39,38,53,52,55,54,55,
38,39,38,39,38,53,52,54,51,7,20,23,22,51,50,55,54,53,
52,39,38,35,34,7,6,18,50,55,54,53,52,38,35,34,7,6,
21,20,23,9,1,39,1,1,20,9,157,65,1,123,238,19,19,29,
77,124,36,37,37,36,124,77,50,41,44,29,31,44,14,13,6,4,
172,4,1,5,4,9,10,10,10,17,16,18,45,29,28,28,29,45,
47,2,238,142,4,5,5,7,5,18,13,13,3,28,30,44,22,23,
39,38,52,54,55,126,77,76,45,30,27,13,19,17,13,11,138,113,
77,19,18,41,39,19,20,19,21,39,40,19,18,28,100,28,29,64,
43,52,27,28,29,254,69,2,232,186,253,16,4,210,9,55,1,130,
160,97,3,64,61,63,76,75,63,61,64,14,15,22,23,56,28,25,
29,20,30,19,8,10,9,12,14,8,9,6,6,29,28,45,47,31,
32,253,81,122,95,23,17,20,12,16,6,22,15,10,2,17,40,59,
73,61,47,48,32,31,15,16,69,69,112,70,62,39,18,10,21,19,
30,27,36,97,120,217,35,16,15,16,17,33,30,18,19,19,18,254,
50,28,29,43,44,58,28,30,44,43,29,1,232,2,91,77,253,168,
0,5,0,66,255,28,4,195,6,117,0,5,0,47,0,63,0,77,
0,81,0,0,9,1,35,1,33,53,0,22,21,20,7,6,7,6,
15,1,6,15,1,22,23,22,21,20,7,6,7,6,7,6,35,34,
39,38,53,52,55,54,55,38,39,38,39,38,53,52,54,51,7,20,
23,22,51,50,55,54,53,52,39,38,35,34,7,6,18,50,55,54,
53,52,38,35,34,7,6,21,20,23,9,1,39,1,2,149,254,124,
207,1,47,254,223,3,200,142,4,5,5,7,5,18,13,13,3,28,
30,44,22,23,39,38,52,54,55,126,77,76,45,30,27,13,19,17,
13,11,138,113,77,19,18,41,39,19,20,19,21,39,40,19,18,28,
100,28,29,64,43,52,27,28,29,254,69,2,232,186,253,16,6,117,
253,0,2,89,167,251,198,122,95,23,17,20,12,16,6,22,15,10,
2,17,40,59,73,61,47,48,32,31,15,16,69,69,112,70,62,39,
18,10,21,19,30,27,36,97,120,217,35,16,15,16,17,33,30,18,
19,19,18,254,50,28,29,43,44,58,28,30,44,43,29,1,232,2,
91,77,253,168,0,2,0,31,1,182,3,201,6,117,0,5,0,9,
0,0,19,35,55,51,17,35,19,39,1,23,216,167,181,160,174,9,
194,2,240,186,5,208,165,253,0,254,65,80,2,88,77,0,0,1,
0,143,0,0,1,156,5,176,0,3,0,0,51,17,33,17,143,1,
13,5,176,250,80,0,0,0,0,2,0,143,0,0,3,56,5,176,
0,3,0,7,0,0,33,17,33,17,33,17,33,17,2,43,1,13,
253,87,1,13,5,176,250,80,5,176,250,80,0,3,0,143,0,0,
4,212,5,176,0,3,0,7,0,11,0,0,33,17,33,17,33,17,
33,17,33,17,33,17,3,199,1,13,253,87,1,13,253,87,1,13,
5,176,250,80,5,176,250,80,5,176,250,80,0,0,0,2,0,143,
0,0,6,180,5,176,0,6,0,10,0,0,1,33,1,33,1,33,
9,1,33,17,33,5,158,1,22,254,95,254,195,254,85,1,33,1,
39,252,28,1,13,254,243,5,176,250,80,5,176,251,235,254,101,5,
176,0,0,1,0,70,0,0,4,208,5,176,0,6,0,0,1,33,
1,33,1,33,1,3,186,1,22,254,94,254,196,254,84,1,34,1,
38,5,176,250,80,5,176,251,235,0,0,2,0,70,0,0,6,99,
5,176,0,3,0,10,0,0,33,17,33,17,1,33,1,33,1,33,
1,5,86,1,13,253,87,1,22,254,94,254,196,254,84,1,34,1,
38,5,176,250,80,5,176,250,80,5,176,251,235,0,0,0,0,3,
0,70,0,0,8,12,5,176,0,3,0,7,0,14,0,0,33,17,
33,17,33,17,33,17,1,33,1,33,1,33,1,6,255,1,13,253,
87,1,13,253,74,1,22,254,94,254,196,254,84,1,34,1,38,5,
176,250,80,5,176,250,80,5,176,250,80,5,176,251,235,0,0,4,
0,70,0,0,9,168,5,176,0,3,0,7,0,11,0,18,0,0,
33,17,33,17,33,17,33,17,33,17,33,17,1,33,1,33,1,33,
1,8,155,1,13,253,87,1,13,253,87,1,13,253,74,1,22,254,
94,254,196,254,84,1,34,1,38,5,176,250,80,5,176,250,80,5,
176,250,80,5,176,250,80,5,176,251,235,0,0,0,0,2,0,143,
0,0,6,185,5,176,0,11,0,15,0,0,1,33,9,1,33,9,
1,33,11,1,33,9,1,17,33,17,2,43,1,53,1,13,1,16,
1,54,254,88,1,174,254,175,251,247,254,175,1,171,252,191,1,13,
5,176,254,11,1,245,253,39,253,41,1,204,254,52,2,215,253,41,
5,176,250,80,0,1,0,53,0,0,4,201,5,176,0,11,0,0,
19,33,9,1,33,9,1,33,11,1,33,1,59,1,53,1,13,1,
16,1,54,254,88,1,174,254,175,251,247,254,175,1,171,5,176,254,
11,1,245,253,39,253,41,1,204,254,52,2,215,0,0,2,0,53,
0,0,6,95,5,176,0,3,0,15,0,0,33,17,33,17,1,33,
9,1,33,9,1,33,11,1,33,1,5,82,1,13,249,220,1,53,
1,13,1,16,1,54,254,88,1,174,254,175,251,247,254,175,1,171,
5,176,250,80,5,176,254,11,1,245,253,39,253,41,1,204,254,52,
2,215,0,0,0,3,0,53,0,0,7,251,5,176,0,3,0,7,
0,19,0,0,33,17,33,17,33,17,33,17,1,33,9,1,33,9,
1,33,11,1,33,1,6,238,1,13,253,87,1,13,249,220,1,53,
1,13,1,16,1,54,254,88,1,174,254,175,251,247,254,175,1,171,
5,176,250,80,5,176,250,80,5,176,254,11,1,245,253,39,253,41,
1,204,254,52,2,215,0,1,0,115,0,0,4,125,5,176,0,5,
0,0,19,33,17,33,21,33,115,1,12,2,254,251,246,5,176,251,
64,240,0,1,0,90,255,223,4,208,5,217,0,50,0,0,1,2,
33,34,39,38,39,38,39,38,39,38,53,52,55,54,55,54,55,54,
55,54,51,50,23,22,23,7,38,39,38,35,34,7,6,7,14,1,
7,6,21,20,23,22,23,22,23,22,51,50,55,4,208,159,254,164,
137,111,110,71,70,48,49,19,20,21,21,48,49,71,73,109,111,134,
177,130,129,57,255,41,66,68,63,79,62,63,39,38,52,10,11,21,
22,39,41,69,70,90,136,112,1,54,254,169,44,44,75,75,101,103,
111,114,120,119,105,107,95,98,68,70,40,41,91,90,129,89,66,46,
47,27,28,46,46,132,70,74,80,111,96,98,75,78,43,44,201,0,
0,2,0,115,0,0,4,172,5,176,0,9,0,24,0,0,1,52,
39,38,43,1,17,51,50,18,37,20,7,6,7,6,35,33,17,33,
50,23,22,23,22,3,145,93,92,146,199,199,145,186,1,27,77,78,
139,142,178,254,45,1,211,180,142,141,75,76,2,240,202,132,131,252,
47,1,26,230,212,172,174,96,98,5,176,95,95,160,163,0,0,1,
0,66,0,0,5,211,5,176,0,12,0,0,51,17,33,9,1,33,
17,33,17,1,33,1,17,66,1,104,1,93,1,101,1,103,254,250,
254,194,254,242,254,199,5,176,251,248,4,8,250,80,3,231,252,25,
3,220,252,36,0,2,0,121,0,0,1,159,5,214,0,11,0,15,
0,0,18,52,55,54,50,23,22,20,7,6,34,39,7,33,17,33,
121,43,44,120,44,43,43,44,120,44,25,1,2,254,254,4,245,130,
47,48,48,47,130,47,48,48,149,251,207,0,0,0,0,4,0,121,
0,0,3,42,5,214,0,11,0,15,0,27,0,31,0,0,0,52,
55,54,50,23,22,20,7,6,34,39,7,33,17,33,0,52,55,54,
50,23,22,20,7,6,34,39,7,33,17,33,2,4,44,44,118,44,
44,44,44,118,44,26,1,2,254,254,254,99,43,44,120,44,43,43,
44,120,44,25,1,2,254,254,4,247,126,49,48,48,49,126,49,48,
48,149,251,207,4,245,130,47,48,48,47,130,47,48,48,149,251,207,
0,6,0,121,0,0,4,181,5,214,0,11,0,15,0,27,0,31,
0,43,0,47,0,0,0,52,55,54,50,23,22,20,7,6,34,39,
7,33,17,33,0,52,55,54,50,23,22,20,7,6,34,39,7,33,
17,33,0,52,55,54,50,23,22,20,7,6,34,39,7,33,17,33,
3,143,43,44,120,44,43,43,44,120,44,25,1,2,254,254,254,99,
44,44,118,44,44,44,44,118,44,26,1,2,254,254,254,99,43,44,
120,44,43,43,44,120,44,25,1,2,254,254,4,245,130,47,48,48,
47,130,47,48,48,149,251,207,4,247,126,49,48,48,49,126,49,48,
48,149,251,207,4,245,130,47,48,48,47,130,47,48,48,149,251,207,
0,0,0,3,0,121,0,0,5,145,5,214,0,6,0,18,0,22,
0,0,33,1,33,27,1,51,1,0,52,55,54,50,23,22,20,7,
6,34,39,7,33,17,33,3,105,254,173,1,15,180,193,247,254,173,
252,59,43,44,120,44,43,43,44,120,44,25,1,2,254,254,4,49,
253,82,2,174,251,207,4,245,130,47,48,48,47,130,47,48,48,149,
251,207,0,0,0,1,0,72,0,0,3,195,4,49,0,6,0,0,
33,1,33,27,1,51,1,1,155,254,173,1,15,180,193,247,254,173,
4,49,253,82,2,174,251,207,0,3,0,72,0,0,5,96,5,214,
0,11,0,15,0,22,0,0,0,52,55,54,50,23,22,20,7,6,
34,39,7,33,17,41,1,1,33,27,1,51,1,4,58,44,44,118,
44,44,44,44,118,44,26,1,2,254,254,253,79,254,173,1,15,180,
193,247,254,173,4,247,126,49,48,48,49,126,49,48,48,149,251,207,
4,49,253,82,2,174,251,207,0,0,0,5,0,72,0,0,6,235,
5,214,0,11,0,15,0,27,0,31,0,38,0,0,0,52,55,54,
50,23,22,20,7,6,34,39,7,33,17,33,0,52,55,54,50,23,
22,20,7,6,34,39,7,33,17,41,1,1,33,27,1,51,1,5,
197,43,44,120,44,43,43,44,120,44,25,1,2,254,254,254,99,44,
44,118,44,44,44,44,118,44,26,1,2,254,254,253,79,254,173,1,
15,180,193,247,254,173,4,245,130,47,48,48,47,130,47,48,48,149,
251,207,4,247,126,49,48,48,49,126,49,48,48,149,251,207,4,49,
253,82,2,174,251,207,0,7,0,72,0,0,8,118,5,214,0,11,
0,15,0,27,0,31,0,43,0,47,0,54,0,0,0,52,55,54,
50,23,22,20,7,6,34,39,7,33,17,33,0,52,55,54,50,23,
22,20,7,6,34,39,7,33,17,33,0,52,55,54,50,23,22,20,
7,6,34,39,7,33,17,41,1,1,33,27,1,51,1,7,80,44,
44,118,44,44,44,44,118,44,26,1,2,254,254,254,99,43,44,120,
44,43,43,44,120,44,25,1,2,254,254,254,99,44,44,118,44,44,
44,44,118,44,26,1,2,254,254,253,79,254,173,1,15,180,193,247,
254,173,4,247,126,49,48,48,49,126,49,48,48,149,251,207,4,245,
130,47,48,48,47,130,47,48,48,149,251,207,4,247,126,49,48,48,
49,126,49,48,48,149,251,207,4,49,253,82,2,174,251,207,0,0,
0,3,0,121,0,0,5,235,5,214,0,11,0,23,0,27,0,0,
41,1,11,1,33,9,1,33,27,1,33,1,0,52,55,54,50,23,
22,20,7,6,34,39,7,33,17,33,5,230,254,205,190,190,254,205,
1,85,254,189,1,34,190,187,1,58,254,166,251,232,43,44,120,44,
43,43,44,120,44,25,1,2,254,254,1,79,254,177,2,24,2,25,
254,182,1,74,253,240,2,212,130,47,48,48,47,130,47,48,48,149,
251,207,0,0,0,1,0,27,0,0,4,2,4,49,0,11,0,0,
41,1,11,1,33,9,1,33,27,1,33,1,3,253,254,205,190,190,
254,205,1,85,254,189,1,34,190,187,1,58,254,166,1,79,254,177,
2,24,2,25,254,182,1,74,253,240,0,3,0,27,0,0,5,159,
5,214,0,11,0,15,0,27,0,0,0,52,55,54,50,23,22,20,
7,6,34,39,7,33,17,33,35,33,11,1,33,9,1,33,27,1,
33,1,4,121,43,44,120,44,43,43,44,120,44,25,1,2,254,254,
142,254,205,190,190,254,205,1,85,254,189,1,34,190,187,1,58,254,
166,4,245,130,47,48,48,47,130,47,48,48,149,251,207,1,79,254,
177,2,24,2,25,254,182,1,74,253,240,0,0,0,0,5,0,27,
0,0,7,42,5,214,0,11,0,15,0,27,0,31,0,43,0,0,
0,52,55,54,50,23,22,20,7,6,34,39,7,33,17,33,0,52,
55,54,50,23,22,20,7,6,34,39,7,33,17,33,35,33,11,1,
33,9,1,33,27,1,33,1,6,4,44,44,118,44,44,44,44,118,
44,26,1,2,254,254,254,99,43,44,120,44,43,43,44,120,44,25,
1,2,254,254,142,254,205,190,190,254,205,1,85,254,189,1,34,190,
187,1,58,254,166,4,247,126,49,48,48,49,126,49,48,48,149,251,
207,4,245,130,47,48,48,47,130,47,48,48,149,251,207,1,79,254,
177,2,24,2,25,254,182,1,74,253,240,0,0,1,0,139,255,227,
1,234,5,174,0,9,0,0,1,20,51,21,34,39,38,53,17,33,
1,141,93,186,82,83,1,2,1,25,87,223,67,68,170,4,154,0,
0,0,0,1,0,86,255,227,3,211,4,76,0,38,0,0,1,38,
35,34,7,6,21,20,23,22,51,50,55,54,55,62,1,55,23,6,
7,6,7,6,7,6,35,34,39,38,17,52,55,54,51,50,23,22,
23,2,254,64,116,99,69,70,74,75,109,40,26,28,14,12,28,8,
214,26,37,32,51,47,57,60,60,239,141,140,141,141,218,115,111,108,
59,2,244,114,96,97,145,148,90,91,10,11,15,13,46,17,111,43,
42,36,38,35,19,20,153,152,1,0,253,157,158,64,62,106,0,0,
0,2,0,74,255,228,3,250,5,174,0,27,0,59,0,0,33,53,
6,7,6,35,34,39,38,39,38,39,38,53,52,55,54,55,62,1,
51,50,23,22,23,17,33,17,1,20,23,22,23,22,23,22,51,50,
55,54,55,54,55,54,53,52,39,38,39,38,39,38,35,34,7,6,
7,6,7,6,2,248,52,84,86,85,97,72,75,44,45,23,23,22,
22,46,44,150,95,89,82,84,52,1,2,253,84,20,20,31,30,39,
36,36,40,36,35,36,34,21,20,20,21,34,34,37,36,40,38,36,
39,29,32,19,19,157,82,51,52,44,46,76,79,99,101,115,120,98,
99,81,78,92,50,51,82,2,25,250,82,2,25,77,68,66,39,37,
23,21,16,15,38,35,68,64,95,93,64,69,35,36,16,16,18,20,
34,38,65,64,0,1,0,119,0,0,5,190,4,78,0,55,0,0,
41,1,17,52,39,38,35,34,7,6,21,17,33,17,33,21,54,55,
54,55,54,55,54,51,50,23,22,23,22,23,22,23,48,31,1,54,
55,54,55,54,55,54,51,50,22,21,17,33,17,52,39,38,34,7,
6,21,3,156,254,254,32,32,81,82,31,31,254,254,1,2,14,27,
23,36,39,40,45,45,46,42,39,25,26,18,22,6,15,7,20,26,
30,36,37,48,47,46,132,156,254,254,32,32,160,32,32,2,27,162,
84,83,82,81,166,253,229,4,49,158,25,34,29,31,34,16,18,17,
16,25,26,29,35,20,48,24,41,36,41,36,37,25,24,224,210,253,
100,2,27,162,84,83,83,84,162,0,0,3,0,90,255,223,7,249,
5,217,0,38,0,52,0,76,0,0,1,20,7,6,7,6,35,33,
53,6,35,34,39,38,39,38,39,38,39,38,53,52,55,54,55,54,
55,54,55,54,51,50,23,53,33,50,4,23,22,5,52,39,38,43,
1,17,23,7,21,51,50,55,54,5,17,38,39,38,35,34,7,6,
7,14,1,7,6,21,20,23,22,23,22,23,22,51,50,7,249,77,
77,141,142,177,254,45,106,129,137,111,110,71,70,48,49,19,20,21,
21,48,49,71,73,109,111,134,129,104,1,211,180,1,28,75,75,254,
229,94,92,145,199,4,4,199,146,93,92,252,226,38,64,68,63,79,
62,63,39,38,52,10,11,21,22,39,41,69,70,90,127,2,240,212,
172,173,97,98,16,49,44,44,75,75,101,103,111,114,120,119,105,107,
95,98,68,70,40,41,48,7,190,160,160,194,201,133,131,252,119,2,
9,61,141,139,132,2,206,60,44,47,27,28,46,46,132,70,74,80,
111,96,98,75,78,43,44,0,0,2,0,115,0,0,4,172,5,176,
0,9,0,24,0,0,1,52,39,38,43,1,17,51,50,18,37,20,
7,6,7,6,35,33,17,33,50,23,22,23,22,3,145,93,92,146,
199,199,145,186,1,27,77,78,139,142,178,254,45,1,211,180,142,141,
75,76,2,240,202,132,131,252,47,1,26,230,212,172,174,96,98,5,
176,95,95,160,163,0,0,4,0,72,0,0,9,189,5,176,0,9,
0,24,0,35,0,49,0,0,1,20,18,59,1,17,35,34,7,6,
5,52,55,54,55,54,51,33,17,33,34,39,38,39,38,37,52,39,
38,43,1,17,51,50,55,54,37,20,7,6,7,6,35,33,17,33,
50,4,23,22,1,99,186,145,199,199,146,92,93,254,229,76,75,141,
142,180,1,211,254,45,178,142,139,78,77,8,90,94,92,145,199,199,
146,93,92,1,27,77,77,141,142,177,254,45,1,211,180,1,28,75,
75,2,240,230,254,230,3,209,131,132,202,191,163,160,95,95,250,80,
98,96,174,172,212,201,133,131,252,47,141,139,232,212,172,173,97,98,
5,176,190,160,160,0,0,0,0,1,0,90,255,223,4,208,5,217,
0,50,0,0,19,37,22,51,50,55,54,55,54,55,54,53,52,39,
46,1,39,38,39,38,35,34,7,6,7,39,54,55,54,51,50,23,
22,23,22,23,22,23,22,21,20,7,6,7,6,7,6,7,6,35,
32,90,1,3,113,135,90,70,69,41,39,22,21,11,10,52,38,39,
63,62,79,63,68,66,41,255,57,129,130,177,134,111,109,73,71,49,
48,21,21,20,19,49,48,70,71,110,111,137,254,164,1,54,100,201,
44,43,78,75,98,96,111,80,74,70,132,46,46,28,27,47,46,66,
89,129,90,91,41,40,70,68,98,95,107,105,119,120,114,111,103,101,
75,75,44,44,0,0,0,1,0,86,255,227,3,211,4,76,0,35,
0,0,1,39,54,55,54,51,50,0,21,20,0,35,34,39,38,39,
38,39,38,39,55,22,23,22,23,22,23,22,51,50,54,53,52,38,
35,34,1,43,213,58,110,111,114,218,1,26,254,230,238,60,60,59,
46,48,34,37,26,214,11,10,10,18,14,28,26,39,108,150,138,100,
115,2,244,112,105,63,64,254,196,252,255,254,206,20,19,35,35,39,
42,43,111,23,17,16,20,15,11,10,182,147,146,192,0,1,0,90,
255,27,4,196,5,217,0,53,0,0,5,35,53,6,35,34,39,38,
39,38,39,38,39,38,53,52,55,54,55,54,55,54,55,54,51,50,
23,22,23,7,38,39,38,35,34,7,6,7,14,1,7,6,21,20,
23,22,23,22,23,22,51,50,55,51,4,192,243,109,139,137,111,110,
71,70,48,49,19,20,21,21,48,49,71,73,109,111,134,177,130,129,
57,255,41,66,68,63,79,62,63,39,38,52,10,11,21,22,39,41,
69,70,90,136,112,243,229,251,55,44,44,75,75,101,103,111,114,120,
119,105,107,95,98,68,70,40,41,91,90,129,89,66,46,47,27,28,
46,46,132,70,74,80,111,96,98,75,78,43,44,201,0,0,0,1,
0,42,0,0,2,224,4,49,0,8,0,0,1,51,19,1,21,9,
1,53,1,1,45,173,1,1,5,254,166,254,164,1,7,4,49,252,
237,1,5,201,254,166,1,92,198,254,252,0,0,0,0,4,0,30,
255,28,3,246,6,148,0,20,0,46,0,110,0,114,0,0,19,54,
51,50,23,22,21,20,7,6,7,6,43,1,34,39,38,39,38,53,
52,23,20,23,22,23,22,23,22,23,22,51,50,55,54,55,54,55,
54,53,52,39,38,35,34,7,6,1,55,23,22,23,22,51,50,54,
52,39,38,43,1,53,51,50,55,54,53,52,39,38,35,34,7,6,
15,1,39,55,54,51,50,23,22,23,22,23,22,21,20,7,30,1,
23,22,23,22,21,20,7,6,7,6,7,6,35,34,39,38,39,38,
39,3,1,39,1,103,72,131,130,69,70,31,30,63,64,84,1,84,
64,63,30,31,174,4,3,7,8,10,10,18,16,22,28,19,18,12,
13,4,5,20,20,55,56,23,23,1,5,167,7,17,28,28,32,44,
52,29,30,37,102,90,28,23,22,21,22,32,25,16,18,7,6,164,
8,58,169,51,38,42,35,33,22,21,59,9,34,18,21,10,10,20,
21,35,37,49,52,56,57,54,49,45,41,25,248,2,232,186,253,16,
6,44,104,104,105,178,115,96,92,54,55,55,54,92,95,116,178,178,
42,52,43,28,32,18,17,10,9,14,14,31,33,45,52,62,131,48,
47,48,49,250,91,45,16,41,18,18,50,74,27,28,146,24,23,28,
39,20,20,12,13,18,16,43,21,153,11,12,25,23,46,43,56,84,
53,7,30,24,28,32,33,43,52,43,46,33,35,19,20,19,17,45,
41,67,1,221,2,91,77,253,168,0,0,0,0,1,0,49,0,39,
6,68,3,153,0,6,0,0,37,9,1,3,33,21,33,1,234,254,
71,1,185,109,4,199,251,57,39,1,185,1,185,254,185,228,0,1,
0,65,255,206,3,179,5,225,0,6,0,0,19,9,1,37,17,35,
17,65,1,185,1,185,254,185,228,4,40,1,185,254,71,109,251,57,
4,199,0,1,0,70,0,39,6,89,3,153,0,6,0,0,1,33,
53,33,3,9,1,5,13,251,57,4,199,109,1,185,254,71,1,110,
228,1,71,254,71,254,71,0,0,0,0,1,0,67,255,185,3,177,
5,204,0,6,0,0,1,17,51,17,37,9,1,1,136,228,1,69,
254,73,254,73,1,7,4,197,251,59,109,254,69,1,187,0,0,0,
0,1,0,49,0,39,6,89,3,153,0,9,0,0,1,19,9,1,
3,33,3,9,1,19,1,125,109,254,71,1,185,109,3,144,109,1,
185,254,71,109,1,110,254,185,1,185,1,185,254,185,1,71,254,71,
254,71,1,71,0,0,0,1,0,65,255,185,3,179,5,225,0,9,
0,0,1,37,9,1,5,17,5,9,1,37,2,108,1,69,254,73,
254,73,1,69,254,185,1,185,1,185,254,185,1,7,109,254,69,1,
187,109,3,142,109,1,185,254,71,109,0,0,0,1,1,2,0,118,
5,159,5,18,0,6,0,0,1,17,13,1,1,7,1,1,2,2,
109,254,207,3,97,163,252,160,2,158,2,116,3,153,252,160,160,3,
95,0,0,1,0,237,0,117,5,138,5,18,0,6,0,0,1,37,
11,1,1,39,1,3,24,2,114,3,153,252,160,161,3,96,5,15,
3,253,142,1,53,252,160,161,3,96,0,1,0,238,0,138,5,138,
5,39,0,6,0,0,9,1,55,1,27,1,33,4,77,252,161,160,
3,96,153,3,253,140,1,36,3,96,163,252,159,1,49,253,147,0,
0,1,1,2,0,138,5,159,5,39,0,6,0,0,9,1,23,1,
5,33,17,1,156,3,96,163,252,159,1,52,253,144,1,198,3,97,
163,252,160,154,2,112,0,0,0,1,0,49,0,38,6,68,3,154,
0,14,0,0,1,19,9,1,3,33,19,51,3,33,21,33,3,35,
19,1,125,109,254,71,1,185,109,1,121,108,233,108,2,101,253,80,
106,233,106,1,110,254,185,1,185,1,185,254,185,1,72,254,184,228,
254,184,1,72,0,1,0,70,0,38,6,89,3,154,0,14,0,0,
1,3,9,1,19,33,3,35,19,33,53,33,19,51,3,5,13,109,
1,185,254,71,109,254,135,106,233,106,253,155,2,176,108,233,108,2,
82,1,71,254,71,254,71,1,71,254,184,1,72,228,1,72,254,184,
0,1,0,145,0,40,6,2,3,37,0,22,0,0,37,3,37,5,
23,22,51,50,36,51,50,31,1,7,39,38,35,34,4,35,38,47,
1,1,51,162,2,89,254,255,73,70,63,85,1,8,188,83,67,156,
114,118,31,83,76,254,248,158,140,104,75,40,2,91,162,230,41,38,
216,32,92,199,70,19,210,10,56,44,0,0,0,1,0,138,0,40,
5,251,3,37,0,22,0,0,1,6,7,34,36,35,34,15,1,39,
55,54,51,50,4,51,50,63,1,37,5,11,1,4,200,102,140,158,
254,248,78,83,32,115,114,156,66,84,188,1,8,85,63,68,74,255,
0,2,89,162,68,1,78,56,10,210,19,71,200,92,32,216,38,41,
230,162,253,165,1,82,0,1,0,49,0,39,6,68,3,153,0,10,
0,0,1,23,9,1,7,55,3,33,21,33,19,1,153,81,254,71,
1,185,81,243,109,4,37,251,219,109,1,26,243,1,185,1,185,243,
243,254,185,228,254,185,0,0,0,1,0,65,255,206,3,179,5,225,
0,10,0,0,1,7,9,1,39,23,37,17,35,17,5,1,52,243,
1,185,1,185,243,243,254,185,228,254,185,4,121,81,1,185,254,71,
81,243,109,251,219,4,37,109,0,0,0,1,0,70,0,39,6,89,
3,153,0,10,0,0,1,39,9,1,55,7,19,33,53,33,3,4,
241,81,1,185,254,71,81,243,109,251,219,4,37,109,2,166,243,254,
71,254,71,243,243,1,71,228,1,71,0,0,0,1,0,65,255,185,
3,179,5,204,0,10,0,0,1,55,9,1,23,39,5,17,51,17,
37,2,192,243,254,71,254,71,243,243,1,71,228,1,71,1,33,81,
254,71,1,185,81,243,109,4,37,251,219,109,0,0,0,1,0,49,
0,39,6,163,3,153,0,11,0,0,1,19,9,1,3,33,55,33,
3,19,35,39,1,125,109,254,71,1,185,109,3,143,152,0,255,240,
239,254,152,1,110,254,185,1,185,1,185,254,185,192,254,208,254,204,
192,0,0,1,0,17,0,39,6,131,3,153,0,11,0,0,37,35,
19,3,33,23,33,3,9,1,19,33,1,16,254,239,240,0,255,152,
3,143,109,1,185,254,71,109,252,113,174,1,52,1,48,192,1,71,
254,71,254,71,1,71,0,0,0,1,0,49,0,39,6,68,3,153,
0,10,0,0,1,53,51,17,35,53,33,19,9,1,3,5,160,164,
164,251,221,109,254,71,1,185,109,2,82,128,254,28,128,254,185,1,
185,1,185,254,185,0,0,1,0,63,255,206,3,177,5,225,0,10,
0,0,37,51,21,33,53,51,17,5,9,1,37,2,106,128,254,28,
128,254,185,1,185,1,185,254,185,114,164,164,4,35,109,1,185,254,
71,109,0,0,0,1,0,49,0,39,6,68,3,153,0,10,0,0,
1,53,51,17,35,53,33,19,9,1,3,5,160,164,164,251,221,109,
254,71,1,185,109,2,82,128,254,28,128,254,185,1,185,1,185,254,
185,0,0,1,0,65,255,185,3,179,5,204,0,10,0,0,1,35,
53,33,21,35,17,37,9,1,5,1,136,128,1,228,128,1,71,254,
71,254,71,1,71,5,40,164,164,251,221,109,254,71,1,185,109,0,
0,1,0,65,255,206,3,179,5,225,0,14,0,0,1,37,1,33,
21,33,53,33,1,5,17,5,9,1,37,2,108,1,69,254,132,1,
113,252,160,1,121,254,132,1,69,254,185,1,185,1,185,254,185,1,
169,109,254,128,200,200,1,128,109,2,236,109,1,185,254,71,109,0,
0,1,0,49,255,206,3,144,6,81,0,8,0,0,1,19,9,1,
3,37,17,35,17,1,125,109,254,71,1,185,109,2,19,228,4,38,
254,185,1,185,1,185,254,185,2,250,194,4,88,0,0,0,0,1,
0,100,255,206,3,195,6,81,0,8,0,0,5,35,17,5,3,9,
1,19,33,1,72,228,2,19,109,1,185,254,71,109,254,209,50,5,
62,2,1,71,254,71,254,71,1,71,0,1,0,49,255,71,3,144,
5,202,0,8,0,0,1,51,17,33,19,9,1,3,33,2,172,228,
253,237,109,254,71,1,185,109,1,47,5,202,250,196,254,185,1,185,
1,185,254,185,0,1,0,100,255,71,3,195,5,202,0,8,0,0,
1,3,9,1,19,33,17,51,17,2,119,109,1,185,254,71,109,253,
237,228,1,114,1,71,254,71,254,71,1,71,5,60,251,168,0,1,
0,70,255,189,4,67,5,204,0,8,0,0,19,53,33,3,37,9,
1,5,17,70,2,184,2,1,71,254,71,254,71,1,71,4,232,228,
251,61,109,254,71,1,185,109,3,223,0,1,0,49,255,71,5,186,
5,202,0,8,0,0,1,51,17,33,19,9,1,3,33,4,214,228,
251,195,109,254,71,1,185,109,3,89,5,202,250,196,254,185,1,185,
1,185,254,185,0,1,255,227,2,121,6,117,5,224,0,34,0,0,
1,38,39,38,39,48,35,34,7,6,7,6,7,55,1,3,23,54,
55,54,55,54,51,50,23,22,23,22,23,22,31,1,35,39,38,5,
70,66,129,127,157,8,147,122,125,78,17,20,183,254,118,172,157,25,
37,115,179,176,211,42,74,112,180,178,97,93,5,1,232,1,3,3,
218,121,83,82,2,66,69,131,27,45,11,254,198,1,221,110,62,60,
186,100,96,1,2,115,115,173,168,211,51,49,147,0,0,0,0,1,
0,21,2,121,6,167,5,224,0,34,0,0,19,54,55,54,55,54,
51,50,23,22,23,22,23,55,3,1,23,38,39,38,39,38,35,48,
35,6,7,6,7,6,15,1,35,55,54,120,97,178,180,112,74,42,
211,176,179,115,37,25,157,172,254,118,183,20,17,78,125,122,147,8,
157,127,129,66,67,1,1,234,1,5,4,74,173,115,115,2,1,96,
100,186,60,62,110,254,35,1,58,11,45,27,131,69,66,2,82,83,
121,121,148,49,51,211,0,2,1,2,255,185,5,159,5,204,0,6,
0,10,0,0,1,17,33,5,1,7,1,3,33,21,33,1,2,2,
112,254,204,3,97,163,252,160,154,4,136,251,120,1,230,2,112,154,
252,160,163,3,97,2,178,228,0,2,0,70,255,73,6,68,4,181,
0,21,0,25,0,0,37,33,53,33,1,21,35,17,51,21,1,3,
33,21,33,1,53,51,17,35,53,9,1,33,3,33,4,121,251,205,
2,9,254,191,200,200,1,114,109,4,49,253,249,1,63,200,200,254,
144,254,100,2,9,93,253,247,144,228,1,65,237,2,100,233,1,114,
254,185,228,254,193,231,253,156,235,254,144,2,43,1,22,0,0,0,
0,1,0,40,255,187,6,77,5,146,0,50,0,0,1,22,23,22,
23,22,51,50,55,54,55,54,55,54,53,52,39,38,39,38,39,7,
3,33,7,22,23,22,23,22,21,20,7,6,7,6,7,6,35,34,
39,38,39,38,39,38,61,1,51,21,20,1,19,24,94,94,123,122,
98,47,39,132,125,122,45,45,6,24,96,24,31,54,160,1,245,152,
48,48,137,31,10,63,62,170,167,199,63,62,137,168,171,134,132,34,
11,228,2,116,142,119,120,42,42,6,22,94,92,124,125,99,42,39,
141,120,30,28,173,1,218,111,41,59,171,202,68,53,142,174,172,132,
130,30,10,58,59,170,168,204,69,59,50,50,49,0,0,0,0,1,
0,61,255,187,6,98,5,146,0,50,0,0,1,6,7,6,7,6,
35,34,39,38,39,38,39,38,53,52,55,54,55,54,55,39,33,3,
39,6,7,6,7,6,21,20,23,22,23,22,23,22,51,50,55,54,
55,54,55,54,61,1,51,21,20,6,87,34,132,134,171,168,137,62,
63,199,167,170,62,63,10,31,137,48,48,152,1,245,160,54,31,24,
96,24,6,45,45,122,125,132,39,47,98,122,123,94,94,24,7,228,
2,78,204,168,170,59,58,10,30,130,132,172,174,142,53,68,202,171,
59,41,111,254,38,173,28,30,120,141,39,42,99,125,124,92,94,22,
6,42,42,120,119,142,41,49,50,50,59,0,0,0,0,1,255,255,
1,238,6,68,4,25,0,4,0,0,3,1,3,33,21,1,2,43,
109,4,135,1,238,2,43,254,185,228,0,1,255,255,0,39,6,68,
2,82,0,4,0,0,1,21,33,19,1,6,68,251,121,109,253,213,
2,82,228,254,185,2,43,0,0,0,0,1,1,142,255,206,3,185,
6,19,0,4,0,0,9,1,37,17,35,1,142,2,43,254,185,228,
6,19,253,213,109,251,121,0,0,0,0,1,0,71,255,206,2,114,
6,19,0,4,0,0,19,1,17,35,17,71,2,43,228,3,232,2,
43,249,187,4,135,0,0,1,0,70,1,236,6,139,4,23,0,4,
0,0,19,53,33,3,1,70,4,135,109,2,43,1,236,228,1,71,
253,213,0,1,0,70,0,39,6,139,2,82,0,4,0,0,1,33,
53,33,1,4,205,251,121,6,69,253,213,1,110,228,253,213,0,1,
1,142,255,135,3,184,5,204,0,4,0,0,1,51,17,37,1,1,
142,228,1,70,253,214,5,204,251,123,109,253,211,0,0,0,0,1,
0,72,255,135,2,114,5,204,0,4,0,0,1,17,51,17,1,1,
142,228,253,214,1,71,4,133,249,187,2,45,0,2,0,49,255,61,
6,89,4,121,0,11,0,15,0,0,5,9,1,33,53,33,3,9,
1,33,21,33,37,55,33,7,1,234,254,71,1,88,254,189,4,199,
109,1,185,254,168,1,67,251,57,3,67,77,252,189,77,195,1,185,
1,88,228,1,71,254,71,254,168,228,228,230,230,0,0,0,0,2,
0,145,255,187,5,249,5,225,0,11,0,15,0,0,19,9,1,17,
51,17,37,9,1,17,35,17,19,5,17,37,145,1,185,1,132,228,
1,71,254,71,254,124,228,228,1,18,254,238,4,40,1,185,254,124,
1,113,251,57,109,254,71,1,132,254,143,4,199,252,206,92,3,50,
92,0,0,2,0,49,255,61,6,89,4,121,0,11,0,15,0,0,
37,33,53,33,9,1,3,33,21,33,9,1,19,33,23,33,5,13,
251,57,1,67,254,168,1,185,109,4,199,254,189,1,88,254,71,32,
252,189,77,3,67,132,228,1,88,1,185,254,185,228,254,168,254,71,
3,17,230,0,0,0,0,3,0,37,255,156,6,68,4,29,0,13,
0,16,0,19,0,0,1,33,21,33,7,23,33,21,33,23,1,45,
1,1,3,7,51,39,55,35,1,140,4,184,251,173,50,53,4,80,
251,72,102,254,51,1,49,254,207,1,209,81,25,99,74,74,99,3,
50,228,114,116,228,232,1,90,229,229,1,93,253,131,56,174,56,0,
0,3,1,6,255,206,5,135,5,237,0,13,0,16,0,19,0,0,
1,17,35,17,39,7,17,35,17,7,1,27,1,1,37,39,21,55,
23,53,4,156,228,114,116,228,232,1,90,229,229,1,93,253,131,56,
174,56,4,134,251,72,4,83,50,53,251,176,4,184,102,1,205,254,
207,1,49,254,47,81,25,99,74,74,99,0,0,3,0,70,255,156,
6,101,4,29,0,13,0,16,0,19,0,0,9,1,13,1,1,55,
33,53,33,55,39,33,53,33,7,23,55,15,1,51,4,148,1,209,
254,207,1,49,254,51,102,251,72,4,80,53,50,251,173,4,184,99,
74,25,25,74,99,4,29,254,163,229,229,254,166,232,228,116,114,228,
228,56,56,174,56,0,0,3,1,6,255,173,5,135,5,204,0,13,
0,16,0,19,0,0,9,1,11,1,1,23,17,51,17,23,55,17,
51,17,39,7,23,47,1,21,5,135,254,163,229,229,254,166,232,228,
116,114,228,228,56,56,174,56,1,126,254,47,1,49,254,207,1,205,
102,4,184,251,176,53,50,4,83,251,72,99,74,25,25,74,99,0,
0,2,255,255,255,231,6,139,4,239,0,4,0,9,0,0,9,1,
19,33,53,39,1,3,33,21,6,139,253,213,109,251,121,71,2,43,
109,4,135,2,18,253,213,1,71,228,178,2,43,254,185,228,0,2,
255,255,255,231,6,139,4,239,0,4,0,9,0,0,1,21,33,19,
1,55,53,33,3,1,6,68,251,121,109,253,213,71,4,135,109,2,
43,2,18,228,254,185,2,43,178,228,1,71,253,213,0,2,0,47,
0,0,5,94,5,176,0,2,0,10,0,0,1,19,33,39,33,19,
33,1,33,1,33,2,183,159,254,212,75,1,192,136,1,55,253,205,
255,0,254,4,1,51,1,152,1,167,246,1,123,250,80,5,176,0,
0,0,0,2,0,66,255,227,3,242,5,172,0,5,0,32,0,0,
1,16,32,17,16,32,3,16,55,54,51,50,23,38,39,37,0,17,
21,20,7,6,7,14,1,7,6,7,6,35,34,39,38,1,62,1,
188,254,68,252,124,125,224,81,66,96,200,1,80,1,28,6,12,41,
2,10,3,23,26,123,225,226,123,124,2,25,254,181,1,75,1,73,
254,183,1,4,151,152,19,135,233,3,254,96,254,33,20,56,51,126,
87,4,13,3,40,33,153,151,153,0,0,1,0,114,0,0,4,72,
5,176,0,11,0,0,41,1,53,33,17,33,53,33,17,33,53,33,
4,72,252,42,2,202,253,118,2,138,253,54,3,214,239,1,95,239,
1,131,240,0,0,3,0,38,255,175,4,156,4,151,0,39,0,55,
0,69,0,0,19,52,55,54,55,54,55,54,55,54,51,50,23,22,
23,55,51,7,22,23,22,21,20,7,6,7,6,35,34,39,38,39,
7,35,55,38,39,38,39,38,55,20,23,22,23,1,38,39,38,35,
34,6,7,6,7,6,37,1,23,22,50,55,54,55,62,1,53,52,
39,38,84,32,33,54,56,67,65,77,72,72,106,96,23,33,109,201,
184,62,37,42,77,76,120,119,133,72,77,60,46,109,210,187,13,12,
53,31,32,199,31,16,17,1,144,24,5,53,53,57,116,47,49,30,
30,2,77,254,117,21,57,114,57,55,49,48,60,32,10,2,30,113,
92,94,63,65,44,43,22,21,42,10,18,146,248,69,94,105,117,155,
127,126,67,67,22,18,26,147,249,13,15,64,88,91,103,83,70,35,
23,2,22,12,2,22,46,41,43,71,70,130,253,236,9,21,24,23,
43,42,132,80,90,70,22,0,0,2,0,108,0,0,5,160,5,176,
0,3,0,6,0,0,51,1,33,1,37,33,1,108,2,21,1,14,
2,17,252,91,2,30,254,238,5,176,250,80,240,3,24,0,0,2,
0,108,0,0,5,160,5,176,0,3,0,6,0,0,19,33,1,33,
3,9,1,108,5,52,253,239,254,242,134,1,12,1,18,5,176,250,
80,4,192,252,232,3,24,0,0,0,0,1,0,115,0,0,4,113,
5,176,0,7,0,0,19,33,17,33,17,33,17,33,115,3,254,254,
243,254,27,254,244,5,176,250,80,4,192,251,64,0,0,1,0,50,
0,0,4,128,5,145,0,11,0,0,41,1,17,9,1,17,33,17,
33,9,1,33,4,128,251,178,1,77,254,179,4,78,252,200,1,166,
254,100,3,46,1,104,1,93,1,101,1,103,254,250,254,57,254,66,
0,0,0,1,0,74,2,6,2,124,2,246,0,3,0,0,19,33,
21,33,74,2,50,253,206,2,246,240,0,0,0,1,0,0,0,0,
5,64,7,138,0,8,0,0,1,33,1,33,3,33,53,5,19,4,
42,1,22,253,238,254,195,158,254,173,2,43,99,7,138,248,118,2,
2,240,1,254,170,0,255,255,0,0,0,0,5,64,7,138,16,38,
3,49,0,0,16,7,0,116,0,140,255,252,255,255,0,0,0,0,
5,64,7,138,16,38,3,49,0,0,16,6,2,124,0,0,0,0,
0,3,0,63,255,255,8,38,3,176,0,28,0,37,0,43,0,0,
5,32,36,16,55,54,33,32,23,22,23,54,55,54,33,32,23,22,
16,7,6,33,32,39,38,39,6,7,6,37,32,16,33,32,7,29,
1,22,6,16,33,32,16,33,2,114,254,251,254,210,151,152,1,4,
1,5,153,12,21,17,18,152,1,4,1,5,153,152,151,153,254,250,
254,251,151,18,15,22,12,151,2,118,1,75,254,181,254,198,14,15,
250,254,181,254,183,1,73,1,248,1,194,123,123,123,10,21,17,15,
123,123,122,254,60,123,124,124,15,15,22,10,123,253,1,188,203,21,
19,201,1,1,188,254,68,0,0,1,0,64,254,91,3,190,5,209,
0,39,0,0,1,17,20,7,6,7,14,1,35,34,39,55,22,23,
22,51,50,55,54,53,17,53,52,55,54,55,62,1,51,50,23,7,
38,39,38,35,34,7,6,21,2,128,27,25,48,46,132,72,134,92,
148,15,28,26,19,44,19,19,27,25,48,46,132,72,134,92,148,15,
28,26,19,44,19,19,4,49,251,122,51,58,55,54,52,66,89,179,
18,11,10,21,20,46,4,154,80,51,58,55,54,52,66,89,179,18,
11,10,21,20,46,0,0,3,0,22,255,223,3,173,3,33,0,23,
0,47,0,58,0,0,1,38,39,38,53,52,55,54,55,54,51,50,
23,22,23,22,21,20,7,6,7,6,35,34,1,38,39,38,53,52,
55,54,55,54,51,50,23,22,23,22,21,20,7,6,7,6,35,34,
37,52,54,50,22,20,6,35,34,39,38,1,139,58,18,6,22,35,
65,23,20,41,40,60,17,6,22,34,66,23,21,43,254,183,58,18,
6,22,35,65,23,20,41,40,58,18,6,22,34,66,22,22,42,1,
215,96,136,96,96,68,67,49,48,1,238,34,66,22,23,42,37,59,
18,6,23,35,64,23,22,43,37,58,18,6,254,29,34,66,23,22,
42,37,59,18,6,23,34,65,22,23,43,37,58,18,6,164,68,96,
96,136,96,49,48,0,0,1,0,53,2,0,2,178,3,143,0,54,
0,0,19,54,55,54,55,54,55,54,55,54,51,50,23,22,23,30,
1,23,22,23,22,51,50,55,54,55,54,55,17,6,7,6,7,6,
7,6,35,34,39,38,39,38,39,38,35,34,7,6,7,14,2,7,
6,7,53,6,21,7,29,8,26,22,20,25,19,28,28,27,27,13,
26,13,27,28,30,29,31,39,38,18,17,35,7,23,15,27,16,31,
30,29,38,42,43,29,27,38,35,27,29,24,33,9,4,13,19,7,
29,13,3,40,4,20,6,23,7,16,14,6,7,15,14,24,11,24,
11,24,14,15,21,20,17,15,34,254,252,7,19,12,20,12,12,12,
24,25,27,25,27,24,10,13,7,3,10,16,5,22,11,0,0,1,
0,93,2,66,1,165,3,138,0,7,0,0,18,52,54,50,22,20,
6,34,93,96,136,96,96,136,2,162,136,96,96,136,96,0,0,2,
0,53,0,92,2,178,3,143,0,54,0,109,0,0,19,54,55,54,
55,54,55,54,55,54,51,50,23,22,23,30,1,23,22,23,22,51,
50,55,54,55,54,55,17,6,7,6,7,6,7,6,35,34,39,38,
39,38,39,38,35,34,7,6,7,14,2,7,6,7,17,54,55,54,
55,54,55,54,55,54,51,50,23,22,23,30,1,23,22,23,22,51,
50,55,54,55,54,55,17,6,7,6,7,6,7,6,35,34,39,38,
39,38,39,38,35,34,7,6,7,14,2,7,6,7,53,6,21,7,
29,8,26,22,20,24,20,28,28,27,27,13,26,13,27,28,30,29,
31,39,38,18,17,35,7,23,15,27,16,31,30,29,38,42,43,29,
27,38,35,27,29,24,33,9,4,13,19,7,29,13,6,21,7,29,
8,26,22,20,25,19,28,28,27,27,13,26,13,27,28,30,29,31,
39,38,18,17,35,7,23,15,27,16,31,30,29,38,42,43,29,27,
38,35,27,29,24,33,9,4,13,19,7,29,13,1,132,4,20,6,
23,7,16,14,6,7,15,14,24,11,24,11,24,14,15,21,20,17,
15,34,254,252,7,19,12,20,12,12,12,24,25,27,25,27,24,10,
13,7,3,10,16,5,22,11,2,149,4,20,6,23,7,16,14,6,
7,15,14,24,11,24,11,24,14,15,21,20,17,15,34,254,252,7,
19,12,20,12,12,12,24,25,27,25,27,24,10,13,7,3,10,16,
5,22,11,0,0,0,0,1,0,55,0,119,3,88,4,50,0,19,
0,0,37,35,55,35,53,33,55,33,53,33,55,51,7,51,21,33,
7,33,21,33,1,32,210,105,128,1,4,70,254,182,1,206,88,201,
86,136,254,246,69,1,79,254,47,119,190,240,127,239,159,159,239,127,
240,0,0,2,0,124,0,192,3,135,5,72,0,5,0,9,0,0,
1,37,9,1,33,1,19,33,21,33,2,80,1,19,254,43,1,210,
254,240,254,44,7,3,4,252,252,5,71,1,254,84,254,108,1,148,
254,20,240,0,0,2,0,124,0,192,3,135,5,72,0,3,0,9,
0,0,1,21,33,53,9,2,33,9,1,3,128,252,252,1,55,1,
212,254,44,254,240,1,210,254,43,1,176,240,240,3,151,254,85,254,
108,1,148,1,172,0,0,5,0,84,1,165,4,113,5,240,0,31,
0,40,0,48,0,56,0,64,0,0,19,52,55,62,1,55,54,55,
54,51,50,23,30,1,23,22,21,20,7,6,7,6,35,34,39,38,
39,38,39,38,39,38,23,30,1,23,22,23,22,23,53,23,54,55,
54,63,2,35,55,38,39,38,39,38,39,21,39,6,7,6,7,6,
7,51,84,32,33,108,69,68,74,69,75,106,96,97,142,42,42,77,
76,120,119,133,76,73,72,71,66,54,52,32,32,225,1,3,1,30,
49,50,50,239,55,43,46,32,1,1,178,195,7,14,33,51,45,44,
240,53,48,49,30,11,8,199,3,195,113,92,95,126,45,44,22,20,
42,42,146,104,105,118,155,127,126,67,67,21,20,47,43,65,63,90,
91,39,2,8,2,68,40,40,20,180,177,25,38,41,69,2,2,240,
32,28,72,42,37,20,231,236,22,42,43,70,27,32,0,0,0,5,
0,84,1,165,4,113,5,240,0,31,0,41,0,47,0,57,0,63,
0,0,19,52,55,62,1,55,54,55,54,51,50,23,30,1,23,22,
21,20,7,6,7,6,35,34,39,38,39,38,39,38,39,38,5,22,
23,22,51,50,55,54,55,39,37,54,53,52,39,7,3,38,39,38,
35,34,7,6,7,23,5,6,21,20,23,55,84,32,33,108,69,68,
74,69,75,106,96,97,142,42,42,77,76,120,119,133,76,73,72,71,
66,54,52,32,32,1,129,3,26,57,57,59,55,3,14,139,1,49,
29,22,143,15,7,33,53,53,59,56,24,20,151,254,210,19,23,129,
3,195,113,92,95,126,45,44,22,20,42,42,146,104,105,118,155,127,
126,67,67,21,20,47,43,65,63,90,91,209,1,11,21,23,1,7,
138,33,66,76,74,62,142,1,68,4,15,22,22,10,11,152,36,62,
66,73,61,129,0,1,0,93,2,66,1,165,3,138,0,7,0,0,
18,52,54,50,22,20,6,34,93,96,136,96,96,136,2,162,136,96,
96,136,96,0,0,2,1,27,0,0,3,255,5,178,0,5,0,9,
0,0,1,3,33,3,19,33,11,1,27,1,3,255,209,254,196,215,
215,1,60,160,90,90,90,2,216,253,40,2,216,2,218,254,100,254,
194,254,196,1,60,0,0,1,0,130,0,0,6,98,5,178,0,11,
0,0,19,33,17,51,33,21,17,33,21,33,17,33,130,1,12,202,
1,12,2,254,251,246,254,42,5,178,253,218,240,254,84,240,2,156,
0,2,0,137,0,1,3,71,5,172,0,9,0,19,0,0,1,20,
51,21,34,39,38,53,17,33,37,20,51,21,34,39,38,53,17,33,
2,234,93,186,82,83,1,2,254,161,93,189,79,83,1,2,1,55,
87,223,67,66,172,2,67,87,87,223,67,71,167,1,229,0,0,0,
0,1,0,115,255,241,4,73,5,176,0,29,0,0,19,33,21,33,
17,33,53,33,21,51,21,35,17,20,59,1,21,35,34,39,38,39,
38,39,38,53,17,33,17,33,115,3,214,253,54,1,45,1,2,155,
155,111,39,39,103,76,69,44,41,18,18,254,211,254,244,5,176,239,
254,161,207,207,239,254,182,95,217,19,17,41,38,56,52,85,1,78,
253,141,0,1,0,19,6,60,1,125,7,110,0,17,0,0,19,22,
23,22,51,50,55,54,55,21,6,7,6,35,34,39,38,39,19,46,
49,51,39,40,52,57,28,35,48,49,45,39,55,56,35,7,110,38,
26,27,28,31,28,226,29,23,24,26,26,30,0,2,0,74,254,47,
8,92,4,76,0,31,0,138,0,0,1,20,23,22,23,22,23,22,
51,50,55,54,55,54,55,54,53,52,39,38,39,38,39,38,35,34,
7,6,7,6,7,6,1,53,6,7,6,35,34,39,38,39,38,39,
38,53,52,55,54,55,62,1,51,50,23,22,23,53,33,17,20,23,
22,23,22,23,30,1,50,55,54,55,54,55,54,55,54,53,17,33,
17,21,20,7,6,7,6,7,6,35,34,39,38,39,55,22,23,22,
51,50,54,61,1,6,7,6,35,34,39,38,25,1,35,17,20,7,
6,7,6,7,6,35,34,38,39,38,39,38,39,38,39,55,22,23,
22,51,50,55,54,1,78,20,20,31,30,39,36,36,40,36,35,36,
34,21,20,20,21,34,34,37,36,40,38,36,39,29,32,19,19,1,
170,52,84,86,85,97,72,75,44,45,23,23,22,22,46,44,150,95,
89,82,84,52,2,231,11,12,18,17,25,22,52,48,27,25,27,26,
21,20,14,13,1,3,40,41,62,65,80,82,78,149,109,111,46,204,
20,53,54,78,84,112,45,87,89,96,149,85,86,227,30,29,57,54,
93,90,113,89,150,49,46,38,36,18,17,5,243,9,50,52,93,94,
57,58,2,25,77,68,66,39,37,23,21,16,15,38,35,68,64,95,
93,64,69,35,36,16,16,18,20,34,38,65,64,253,71,227,82,51,
52,44,46,76,79,99,101,115,120,98,99,81,78,92,50,51,82,156,
253,231,85,55,60,36,33,24,21,16,8,7,23,21,37,35,61,58,
81,2,24,251,236,58,80,79,81,59,62,37,38,70,71,100,112,56,
32,33,94,80,220,81,54,55,143,145,1,20,1,42,252,141,80,74,
71,60,57,35,34,48,37,35,52,49,47,44,50,11,68,40,41,45,
46,0,0,1,0,72,254,47,6,184,5,43,0,75,0,0,19,35,
53,51,53,33,21,33,17,20,23,22,23,22,23,30,1,50,55,54,
55,54,55,54,55,54,53,17,33,17,21,20,7,6,7,6,7,6,
35,34,39,38,39,55,22,23,22,51,50,54,61,1,6,7,6,35,
34,39,38,25,1,33,17,20,59,1,21,35,34,39,38,39,38,39,
38,53,213,141,141,1,2,2,100,11,12,18,17,25,22,52,48,27,
25,27,26,21,20,14,13,1,3,40,41,62,65,80,82,78,149,109,
111,46,204,20,53,54,78,84,112,45,87,89,96,149,85,86,254,158,
111,39,39,102,76,71,43,42,18,17,3,76,229,250,250,253,231,85,
55,60,36,33,24,21,16,8,7,23,21,37,35,61,58,81,2,24,
251,236,58,80,79,81,59,62,37,38,70,71,100,112,56,32,33,94,
80,220,81,54,55,143,145,1,20,1,53,253,221,95,217,19,18,40,
39,55,52,85,0,0,0,1,0,86,255,227,6,153,6,154,0,94,
0,0,1,35,53,51,53,38,39,38,39,38,35,34,7,6,7,6,
21,48,21,22,23,48,7,46,1,39,38,35,34,7,6,21,20,23,
22,51,50,55,54,55,62,1,55,23,6,7,6,7,6,7,6,35,
34,39,38,17,52,55,54,55,38,53,52,55,54,63,1,54,51,50,
23,22,23,22,23,22,23,21,51,21,35,17,20,59,1,21,35,34,
39,38,39,38,39,38,53,4,253,141,141,42,50,55,77,8,16,45,
54,91,11,12,28,135,213,10,36,10,53,71,99,69,70,74,75,109,
40,26,28,14,12,28,8,214,26,37,32,51,47,57,60,60,239,141,
140,141,140,214,6,43,42,150,4,53,118,30,36,137,111,103,47,64,
22,154,154,111,39,39,102,76,71,43,42,18,17,3,76,229,250,74,
36,38,8,1,15,66,50,57,88,37,160,139,112,11,46,12,45,96,
97,145,148,90,91,10,11,15,13,46,17,111,43,42,36,38,35,19,
20,153,152,1,0,253,157,157,1,38,40,109,130,126,107,3,37,3,
9,57,53,65,88,92,250,229,253,221,95,217,19,18,40,39,55,52,
85,0,0,0,0,2,0,215,255,236,3,194,4,58,0,17,0,43,
0,0,1,54,32,18,21,20,7,6,7,6,43,1,34,38,39,38,
53,52,23,20,23,22,23,22,23,22,23,22,51,50,55,54,55,54,
55,54,53,52,39,38,35,34,7,6,1,59,99,1,100,192,43,42,
85,86,117,1,118,170,42,43,228,4,5,10,11,16,17,24,25,33,
42,28,29,16,17,7,7,29,28,85,84,33,32,3,172,142,254,228,
249,161,131,127,75,75,150,127,131,161,247,247,83,49,58,44,47,25,
27,13,14,21,21,46,47,64,60,101,186,70,68,70,68,0,0,0,
0,1,0,202,0,0,3,208,4,49,0,11,0,0,51,53,33,17,
33,53,33,21,35,17,51,21,202,1,14,254,242,3,6,236,236,240,
2,81,240,240,253,175,240,0,0,1,0,229,0,0,3,180,4,60,
0,60,0,0,1,39,55,54,55,54,51,50,23,22,23,22,23,22,
23,22,21,20,6,7,6,15,1,6,7,6,29,1,37,21,33,53,
52,54,55,54,55,54,55,54,55,62,1,55,54,55,54,55,54,55,
53,52,39,38,39,38,35,34,7,6,7,1,228,238,3,22,99,98,
114,46,45,43,47,45,35,33,22,22,54,66,37,25,98,30,31,54,
1,167,253,49,12,16,15,32,29,46,37,33,47,56,24,12,30,22,
9,7,2,7,6,29,8,10,26,36,30,17,2,226,71,18,108,75,
74,9,9,24,23,38,36,62,63,71,89,124,66,37,18,74,17,27,
49,10,1,3,240,20,60,94,48,46,49,45,46,35,26,37,38,24,
12,32,23,41,31,42,8,21,44,32,12,4,30,26,57,0,0,1,
0,85,254,97,4,68,4,49,0,57,0,0,23,37,30,1,51,50,
55,54,53,52,39,38,43,1,53,51,50,54,53,52,38,35,34,6,
7,39,18,33,50,23,22,23,22,23,22,21,20,7,22,23,22,23,
30,1,21,20,7,6,7,6,7,6,35,34,39,38,39,38,85,1,
2,37,136,74,102,66,65,71,70,92,165,142,75,110,108,83,58,90,
19,250,108,1,52,91,75,77,63,63,38,37,145,54,30,33,39,37,
40,38,36,68,65,95,97,103,115,93,96,78,80,71,69,91,84,60,
59,91,89,65,64,209,116,70,93,102,66,43,65,1,20,22,23,43,
44,77,75,102,169,102,36,26,29,48,46,126,72,87,84,80,63,61,
36,37,34,35,78,80,0,0,0,2,0,92,254,129,4,60,4,49,
0,10,0,13,0,0,37,51,21,35,17,33,17,33,53,1,33,9,
1,33,3,179,137,137,254,243,253,182,2,54,1,33,254,251,254,176,
1,80,202,237,254,164,1,92,204,3,136,254,161,253,251,0,0,0,
0,1,0,82,254,103,4,70,4,49,0,46,0,0,0,34,7,37,
19,33,21,33,3,54,51,50,23,30,1,16,6,7,6,35,34,39,
38,39,38,39,38,39,38,39,37,22,23,22,23,22,23,22,23,22,
51,50,55,54,53,52,39,2,183,218,57,254,254,118,2,172,254,42,
54,37,109,144,114,116,134,134,116,114,144,90,79,82,53,57,41,46,
22,23,11,1,10,5,9,11,21,23,23,22,43,39,42,111,67,66,
67,1,80,59,90,2,194,239,254,221,22,59,60,224,254,224,224,60,
59,27,28,40,43,51,57,47,49,50,46,23,20,25,27,30,20,19,
17,15,70,69,106,108,74,0,0,2,0,110,255,228,4,43,5,176,
0,14,0,46,0,0,1,52,38,35,34,7,6,21,20,23,22,51,
50,55,54,1,54,51,50,0,21,20,7,6,7,6,7,6,35,34,
39,38,39,38,53,52,55,54,55,54,55,62,2,55,1,33,3,30,
120,94,93,56,57,60,61,87,95,59,58,254,250,5,49,213,1,8,
35,36,62,59,95,90,106,134,111,110,60,59,20,22,19,23,36,11,
20,11,2,1,18,1,30,1,173,95,136,68,69,90,98,63,64,68,
67,2,42,5,254,246,207,86,80,82,65,62,42,40,66,66,104,103,
120,84,79,88,40,50,67,20,39,23,3,2,20,0,0,0,0,1,
0,58,254,129,4,94,4,49,0,5,0,0,9,1,33,1,33,53,
4,94,253,32,254,188,2,94,253,164,4,49,250,80,4,178,254,0,
0,0,0,3,0,66,255,228,4,86,5,209,0,11,0,26,0,75,
0,0,36,50,54,53,52,39,38,35,34,6,21,20,19,20,23,22,
51,50,55,54,53,52,39,38,34,7,6,19,50,23,22,21,20,7,
6,7,6,7,14,1,7,6,7,6,7,6,7,22,23,22,21,20,
7,6,7,6,7,6,35,34,39,38,53,52,55,54,55,38,39,38,
39,46,1,53,52,54,1,218,228,140,76,78,100,118,136,58,52,54,
90,88,55,53,50,51,194,49,48,194,206,131,130,8,10,7,9,23,
7,21,4,10,28,27,4,3,26,87,79,78,40,39,75,70,96,94,
112,239,139,140,82,81,83,28,28,27,33,32,40,252,193,134,106,104,
69,70,136,107,106,3,0,87,42,43,43,41,88,80,47,48,49,48,
1,60,111,111,172,39,31,38,19,23,28,9,26,4,11,21,20,4,
3,17,22,108,106,133,113,87,86,59,56,30,30,127,128,206,126,112,
111,20,16,22,21,36,35,104,59,178,216,0,0,0,0,2,0,110,
254,101,4,44,4,49,0,15,0,43,0,0,1,20,23,22,51,50,
55,54,53,52,39,38,35,34,7,6,1,6,35,34,0,53,52,55,
62,1,55,54,51,50,22,23,22,21,20,7,6,7,6,7,6,7,
1,33,1,123,59,60,94,93,57,58,62,61,87,94,58,59,1,5,
5,49,212,254,248,35,36,122,93,90,106,137,218,61,60,21,22,19,
26,32,27,19,254,240,254,224,2,104,98,66,67,69,70,88,96,65,
64,67,68,253,214,5,1,10,207,86,80,82,128,41,40,130,106,105,
118,82,82,88,40,57,59,52,33,253,236,0,0,0,0,2,0,91,
255,224,3,211,4,74,0,17,0,23,0,0,1,33,25,1,33,53,
6,35,34,39,38,17,16,55,54,51,50,23,1,16,32,17,16,32,
2,209,1,2,254,254,91,122,171,123,123,124,125,196,101,84,254,134,
1,122,254,134,4,49,253,229,253,234,13,45,152,151,1,7,1,5,
151,152,41,253,245,254,181,1,75,1,74,0,255,255,0,91,255,224,
3,211,6,61,16,38,3,82,0,0,16,7,0,67,0,88,254,164,
255,255,0,91,255,224,3,211,6,61,16,38,3,82,0,0,16,7,
0,117,1,181,254,164,255,255,0,91,255,224,3,211,5,232,16,38,
3,82,0,0,16,7,1,74,255,58,254,82,255,255,0,91,255,224,
3,211,6,30,16,38,3,82,0,0,16,7,1,78,0,0,254,165,
255,255,0,91,255,224,3,211,5,234,16,38,3,82,0,0,16,7,
1,72,255,110,254,120,255,255,0,91,255,224,3,211,5,234,16,38,
3,82,0,0,16,7,0,105,0,72,254,105,255,255,0,91,254,168,
4,34,4,74,16,38,3,82,0,0,16,7,1,77,2,132,0,0,
255,255,0,91,255,224,3,211,6,60,16,38,3,82,0,0,16,7,
1,76,0,132,254,166,255,255,0,91,255,224,3,211,5,138,16,38,
3,82,0,0,16,7,0,112,0,84,254,117,0,1,0,27,0,0,
4,2,4,54,0,23,0,0,1,19,33,1,19,22,51,21,34,39,
38,47,1,3,33,1,3,38,39,53,50,23,22,23,2,13,187,1,
58,254,166,184,33,124,251,81,29,20,116,190,254,205,1,85,175,34,
131,251,81,29,20,2,231,1,74,253,240,254,217,27,223,68,23,39,
205,254,177,2,24,1,35,26,2,223,68,23,39,0,0,3,0,66,
255,254,5,212,8,115,0,15,0,45,0,58,0,0,1,52,55,54,
51,50,23,22,21,20,7,6,35,34,39,38,7,22,23,22,23,22,
51,50,55,54,55,21,55,51,6,7,6,7,6,7,6,35,34,39,
38,39,38,39,38,39,1,17,33,9,1,33,17,33,17,1,33,1,
17,2,95,84,35,45,97,46,21,84,33,47,97,47,20,23,16,15,
30,43,42,45,54,40,41,33,33,195,17,22,22,28,57,76,80,94,
84,81,78,58,25,26,21,25,254,201,1,104,1,93,1,103,1,102,
254,250,254,194,254,242,254,198,7,207,97,46,21,84,35,45,97,47,
20,84,33,89,44,15,53,25,24,22,23,51,2,65,41,46,45,36,
72,45,47,38,37,73,33,49,41,63,248,185,5,178,251,246,4,10,
250,78,3,232,252,22,3,222,252,36,0,0,0,3,0,119,0,0,
5,192,7,26,0,15,0,57,0,86,0,0,1,52,55,54,51,50,
23,22,21,20,7,6,35,34,39,38,1,33,17,52,38,39,34,7,
6,21,17,33,17,33,21,54,59,1,50,23,22,31,1,54,51,50,
19,22,23,22,21,17,33,17,52,39,38,39,34,7,6,21,1,22,
23,22,23,22,51,50,54,55,21,55,51,6,7,6,7,6,7,6,
35,34,39,38,39,38,39,38,39,2,124,84,33,47,96,47,21,85,
35,44,98,46,20,1,33,254,253,54,48,85,57,45,254,254,1,2,
83,98,9,107,66,71,34,4,112,210,235,50,10,3,3,254,254,28,
27,48,84,57,45,254,194,16,15,30,42,44,43,54,82,33,32,195,
17,22,23,26,57,76,80,95,84,81,78,58,23,27,21,25,6,118,
98,46,20,84,34,46,96,47,21,84,33,249,185,2,56,143,150,8,
94,72,98,253,163,4,50,117,146,36,38,72,8,154,254,219,47,62,
60,69,253,196,2,56,140,78,75,8,94,72,98,3,111,44,15,54,
24,25,46,51,2,65,40,47,48,33,72,45,47,38,37,73,29,53,
41,63,0,2,0,66,255,254,5,212,7,71,0,12,0,42,0,0,
51,17,33,9,1,33,17,33,17,1,33,1,17,1,22,23,22,23,
22,51,50,55,54,55,21,55,51,6,7,6,7,6,7,6,35,34,
39,38,39,38,39,38,39,66,1,104,1,93,1,103,1,102,254,250,
254,194,254,242,254,198,1,0,16,15,30,43,42,45,54,40,41,33,
33,195,17,22,22,28,57,76,80,94,84,81,78,58,25,26,21,25,
5,178,251,246,4,10,250,78,3,232,252,22,3,222,252,36,7,71,
44,15,53,25,24,22,23,51,2,65,41,46,45,36,72,45,47,38,
37,73,33,49,41,63,0,2,0,119,0,0,5,192,5,204,0,28,
0,70,0,0,1,22,23,22,23,22,51,50,54,55,21,55,51,6,
7,6,7,6,7,6,35,34,39,38,39,38,39,38,39,1,33,17,
52,38,39,34,7,6,21,17,33,17,33,21,54,59,1,50,23,22,
31,1,54,51,50,19,22,23,22,21,17,33,17,52,39,38,39,34,
7,6,21,2,95,16,15,30,42,44,43,54,82,33,32,195,17,22,
23,26,57,76,80,95,84,81,78,58,23,27,21,25,2,13,254,253,
54,48,85,57,45,254,254,1,2,83,98,9,107,66,71,34,4,112,
210,235,50,10,3,3,254,254,28,27,48,84,57,45,5,204,44,15,
54,24,25,46,51,2,65,40,47,48,33,72,45,47,38,37,73,29,
53,41,63,250,52,2,56,143,150,8,94,72,98,253,163,4,50,117,
146,36,38,72,8,154,254,219,47,62,60,69,253,196,2,56,140,78,
75,8,94,72,98,0,0,2,0,119,0,0,4,198,7,71,0,9,
0,38,0,0,51,17,33,1,17,33,17,33,1,17,19,22,23,30,
1,51,50,55,54,55,21,55,51,6,7,6,7,6,7,6,35,34,
39,38,39,38,39,38,39,119,1,4,2,62,1,13,254,247,253,198,
97,16,15,30,84,45,55,40,41,33,32,195,16,23,23,26,57,76,
80,95,84,81,78,58,23,27,21,25,5,178,252,83,3,173,250,78,
3,206,252,50,7,71,44,15,54,48,22,23,51,2,65,41,46,48,
33,72,45,47,38,37,73,29,53,41,63,0,0,2,0,119,0,0,
3,206,5,204,0,29,0,51,0,0,1,22,23,22,23,22,51,50,
55,54,55,21,55,51,6,7,6,7,6,7,6,35,34,39,38,39,
38,39,38,39,19,33,17,33,21,54,51,50,19,22,21,17,33,17,
52,39,38,35,34,7,6,21,1,101,17,13,30,43,44,43,54,41,
39,34,33,195,17,22,23,26,57,76,80,95,84,81,78,58,23,27,
21,25,227,254,254,1,2,93,204,200,69,31,254,253,69,27,35,74,
67,66,5,204,46,13,53,25,25,23,22,52,2,65,40,47,48,33,
72,45,47,38,37,73,29,53,41,63,250,52,4,50,92,121,254,252,
121,150,253,196,2,56,168,94,39,82,83,99,0,0,0,3,0,121,
0,0,4,140,7,71,0,29,0,44,0,63,0,0,1,22,23,22,
23,22,51,50,55,54,55,21,55,51,6,7,6,7,6,7,6,35,
34,39,38,39,38,39,38,39,19,51,32,55,54,53,48,53,52,39,
38,35,48,43,1,9,1,35,17,33,17,33,51,32,23,22,21,20,
7,6,7,6,7,1,1,129,16,15,30,43,42,45,54,40,41,33,
33,195,16,23,23,26,56,78,80,94,84,81,78,58,25,26,21,25,
212,98,1,24,23,2,233,22,12,38,98,1,213,254,127,84,254,243,
1,13,98,1,107,147,74,199,32,40,35,48,1,190,7,71,44,15,
53,25,24,22,23,51,2,65,41,46,48,33,71,46,47,38,37,73,
33,49,41,63,251,241,189,14,5,20,148,16,2,251,62,2,68,253,
188,5,178,185,94,127,222,129,21,19,17,11,253,135,0,0,0,2,
0,53,0,0,3,79,5,204,0,28,0,47,0,0,1,22,23,22,
23,22,51,50,54,55,21,55,51,6,7,6,7,6,7,6,35,34,
39,38,39,38,39,38,39,1,38,35,34,7,6,21,17,33,17,33,
21,54,51,50,23,22,31,1,1,4,16,15,30,43,44,43,53,82,
33,33,195,17,22,22,28,57,76,80,94,84,81,78,58,25,26,21,
25,2,169,107,30,100,73,47,254,254,1,2,99,110,93,106,9,16,
20,5,204,44,15,53,25,25,46,51,2,65,40,47,45,36,72,45,
47,38,37,73,33,49,41,63,253,92,61,115,73,66,253,153,4,50,
115,144,62,4,12,16,0,3,0,78,254,61,5,1,5,178,0,7,
0,23,0,39,0,0,19,33,21,33,17,33,17,33,1,52,55,54,
51,50,23,22,21,20,7,6,35,34,39,38,37,52,55,54,51,50,
23,22,21,20,7,6,35,34,39,38,78,4,179,254,55,254,244,254,
34,2,171,84,34,46,97,46,21,85,34,45,97,47,20,254,40,84,
35,45,97,47,20,84,34,46,97,46,21,5,178,240,251,62,4,194,
250,31,97,46,21,84,34,46,96,47,21,84,33,47,97,46,21,84,
33,47,97,46,21,84,35,0,0,3,255,221,254,61,2,253,5,44,
0,15,0,31,0,51,0,0,1,52,55,54,51,50,23,22,21,20,
7,6,35,34,39,38,37,52,55,54,51,50,23,22,21,20,7,6,
35,34,39,38,19,35,53,51,53,33,21,51,21,35,17,20,59,1,
21,35,32,39,38,53,1,181,84,35,45,97,46,21,84,35,45,97,
47,20,254,40,84,35,45,97,47,20,84,34,46,97,46,21,248,141,
141,1,3,153,153,110,39,39,254,248,72,33,254,225,97,46,21,84,
34,46,97,46,21,84,33,47,97,46,21,84,33,47,97,46,21,84,
35,4,153,229,250,250,229,253,206,94,218,134,63,111,0,0,0,3,
0,88,254,61,4,104,5,212,0,15,0,31,0,80,0,0,1,52,
55,54,51,50,23,22,21,20,7,6,35,34,39,38,37,52,55,54,
51,50,23,22,21,20,7,6,35,34,39,38,19,22,23,22,51,50,
55,54,53,52,39,38,39,38,39,36,39,38,53,52,55,54,51,32,
19,5,38,39,38,43,1,34,21,20,22,31,1,22,23,22,23,22,
21,20,7,6,35,32,3,2,185,84,35,45,96,47,21,84,35,45,
97,46,21,254,41,84,34,46,96,47,21,85,35,44,98,46,20,110,
69,75,56,85,173,46,13,199,21,26,30,21,254,138,57,10,213,121,
156,1,81,138,254,248,29,50,49,65,22,211,114,121,49,149,92,95,
50,68,187,140,180,254,140,161,254,225,97,46,21,84,34,46,97,46,
21,84,34,46,97,46,21,84,34,46,96,47,21,84,33,3,13,151,
46,37,127,36,38,140,82,10,8,9,5,99,235,44,45,234,108,59,
254,234,78,52,33,32,162,63,106,34,15,44,61,62,70,97,125,227,
125,91,1,138,0,3,0,78,254,61,3,109,4,77,0,15,0,31,
0,79,0,0,1,52,55,54,51,50,23,22,21,20,7,6,35,34,
39,38,37,52,55,54,51,50,23,22,21,20,7,6,35,34,39,38,
1,38,39,38,53,52,55,54,51,50,23,22,23,7,38,39,34,7,
6,21,20,31,1,22,23,22,21,16,7,6,35,32,39,38,39,38,
39,55,22,51,50,53,52,39,46,1,39,38,2,37,84,35,45,97,
47,20,84,35,45,97,46,21,254,41,84,35,45,96,47,21,84,34,
46,98,46,20,1,115,247,63,28,182,90,107,187,108,48,12,240,30,
83,101,8,2,84,37,181,93,93,236,67,90,254,251,102,11,9,9,
6,232,24,140,135,105,4,18,5,18,254,225,97,46,21,84,33,47,
97,46,21,84,34,46,97,46,21,84,34,46,97,46,21,84,33,3,
11,84,117,53,64,213,84,41,152,72,75,44,105,8,80,10,14,49,
46,14,69,77,76,114,254,251,69,21,213,26,26,28,27,37,127,119,
58,46,2,8,2,6,0,3,0,115,254,61,4,114,5,178,0,11,
0,27,0,43,0,0,19,33,17,33,17,33,17,33,17,33,17,33,
1,52,55,54,51,50,23,22,21,20,7,6,35,34,39,38,37,52,
55,54,51,50,23,22,21,20,7,6,35,34,39,38,115,1,12,1,
230,1,13,254,243,254,26,254,244,2,72,84,35,45,97,47,20,84,
35,45,97,46,21,254,41,84,34,46,96,47,21,84,34,46,98,46,
20,5,178,253,175,2,81,250,78,2,113,253,143,254,225,97,46,21,
84,33,47,97,46,21,84,34,46,97,46,21,84,34,46,97,46,21,
84,33,0,3,0,119,254,61,3,206,5,176,0,15,0,31,0,53,
0,0,1,52,55,54,51,50,23,22,21,20,7,6,35,34,39,38,
37,52,55,54,51,50,23,22,21,20,7,6,35,34,39,38,19,33,
17,33,17,54,51,50,19,22,21,17,33,17,52,39,38,35,34,7,
6,21,2,105,84,34,46,97,47,20,84,35,45,97,46,21,254,41,
84,34,46,96,47,21,84,34,46,98,46,20,231,254,254,1,2,83,
214,200,69,31,254,253,69,27,35,74,67,66,254,225,97,46,21,84,
33,47,97,46,21,84,34,46,97,46,21,84,34,46,97,46,21,84,
33,1,78,5,176,254,9,150,254,252,121,150,253,196,2,56,168,94,
39,82,83,99,0,2,0,115,254,137,4,114,5,178,0,3,0,15,
0,0,23,33,21,33,3,33,17,33,17,33,17,33,17,33,17,33,
238,3,5,252,251,123,1,12,1,230,1,13,254,243,254,26,254,244,
135,240,7,41,253,175,2,81,250,78,2,113,253,143,0,3,0,115,
253,71,4,126,5,178,0,15,0,31,0,37,0,0,1,20,23,22,
51,50,55,54,53,52,39,38,35,34,7,6,7,52,55,54,51,50,
23,22,21,20,7,6,35,34,39,38,3,33,17,33,21,33,1,191,
78,32,35,88,40,16,78,32,34,86,41,18,172,125,83,109,157,96,
65,125,85,108,156,96,65,160,1,12,2,255,251,245,254,127,93,41,
16,78,36,36,93,40,16,78,35,36,155,95,63,123,83,107,155,93,
64,121,83,7,159,251,62,240,0,3,255,225,253,71,2,93,5,176,
0,15,0,31,0,41,0,0,19,20,23,22,51,50,55,54,53,52,
39,38,35,34,7,6,7,52,55,54,51,50,23,22,21,20,7,6,
35,34,39,38,1,20,51,21,34,39,38,53,17,33,141,78,32,36,
87,40,16,77,32,34,87,40,19,172,125,82,111,156,96,66,125,85,
108,156,96,66,1,173,92,236,72,43,1,3,254,127,93,41,16,78,
36,36,93,40,16,78,36,35,155,95,63,123,84,106,155,93,64,121,
84,3,5,86,224,113,67,126,4,155,0,4,0,18,253,71,4,126,
7,0,0,3,0,19,0,35,0,41,0,0,19,33,21,33,1,20,
23,22,51,50,55,54,53,52,39,38,35,34,7,6,7,52,55,54,
51,50,23,22,21,20,7,6,35,34,39,38,3,33,17,33,21,33,
18,3,5,252,251,1,173,78,32,35,88,40,16,78,32,34,86,41,
18,172,125,83,109,157,96,65,125,85,108,156,96,65,160,1,12,2,
255,251,245,7,0,240,248,111,93,41,16,78,36,36,93,40,16,78,
35,36,155,95,63,123,83,107,155,93,64,121,83,7,159,251,62,240,
0,0,0,4,255,156,253,71,2,160,7,0,0,3,0,19,0,35,
0,45,0,0,3,33,21,33,19,20,23,22,51,50,55,54,53,52,
39,38,35,34,7,6,7,52,55,54,51,50,23,22,21,20,7,6,
35,34,39,38,1,20,51,21,34,39,38,53,17,33,100,3,4,252,
252,241,78,32,36,87,40,16,77,32,34,87,40,19,172,125,82,111,
156,96,66,125,85,108,156,96,66,1,173,92,236,72,43,1,3,7,
0,240,248,111,93,41,16,78,36,36,93,40,16,78,36,35,155,95,
63,123,84,106,155,93,64,121,84,3,5,86,224,113,67,126,4,155,
0,0,0,4,0,121,253,71,4,140,5,178,0,15,0,31,0,42,
0,60,0,0,1,20,23,22,51,50,55,54,53,52,39,38,35,34,
7,6,7,52,55,54,51,50,23,22,21,20,7,6,35,34,39,38,
19,51,32,55,54,53,52,39,38,43,1,9,1,48,35,17,33,17,
33,51,32,23,22,21,20,7,6,7,1,1,162,78,32,36,86,41,
16,78,32,33,86,41,19,172,125,83,110,156,96,66,126,85,107,156,
96,66,144,98,1,24,23,2,233,44,28,98,1,213,254,127,84,254,
243,1,13,98,1,107,147,74,199,69,86,1,190,254,127,93,41,16,
78,36,36,93,40,16,78,36,35,155,95,63,123,84,106,154,94,64,
121,84,5,36,189,24,15,148,16,2,251,62,2,68,253,188,5,178,
185,94,127,227,124,46,22,253,135,0,0,3,255,197,253,71,3,62,
4,79,0,15,0,31,0,49,0,0,19,20,23,22,51,50,55,54,
53,52,39,38,35,34,7,6,7,52,55,54,51,50,23,22,21,20,
7,6,35,34,39,38,1,38,35,34,7,6,21,17,33,17,33,21,
54,51,50,23,22,23,113,78,32,35,86,41,17,78,32,34,86,41,
18,172,125,82,110,156,96,66,125,85,108,156,96,65,3,25,107,30,
97,76,47,254,254,1,2,99,110,93,106,30,15,254,127,93,41,16,
78,39,33,93,40,16,78,35,36,155,95,63,123,84,106,155,93,64,
121,83,5,21,61,115,74,65,253,153,4,50,115,144,62,19,13,0,
0,5,0,121,253,71,4,140,7,0,0,3,0,19,0,35,0,46,
0,64,0,0,19,33,21,33,19,20,23,22,51,50,55,54,53,52,
39,38,35,34,7,6,7,52,55,54,51,50,23,22,21,20,7,6,
35,34,39,38,19,51,32,55,54,53,52,39,38,43,1,9,1,48,
35,17,33,17,33,51,32,23,22,21,20,7,6,7,1,178,3,5,
252,251,240,78,32,36,86,41,16,78,32,33,86,41,19,172,125,83,
110,156,96,66,126,85,107,156,96,66,144,98,1,24,23,2,233,44,
28,98,1,213,254,127,84,254,243,1,13,98,1,107,147,74,199,69,
86,1,190,7,0,240,248,111,93,41,16,78,36,36,93,40,16,78,
36,35,155,95,63,123,84,106,154,94,64,121,84,5,36,189,24,15,
148,16,2,251,62,2,68,253,188,5,178,185,94,127,227,124,46,22,
253,135,0,4,255,197,253,71,3,62,5,132,0,3,0,19,0,35,
0,53,0,0,19,33,21,33,19,20,23,22,51,50,55,54,53,52,
39,38,35,34,7,6,7,52,55,54,51,50,23,22,21,20,7,6,
35,34,39,38,1,38,35,34,7,6,21,17,33,17,33,21,54,51,
50,23,22,23,25,3,4,252,252,88,78,32,35,86,41,17,78,32,
34,86,41,18,172,125,82,110,156,96,66,125,85,108,156,96,65,3,
25,107,30,97,76,47,254,254,1,2,99,110,93,106,30,15,5,132,
239,249,234,93,41,16,78,39,33,93,40,16,78,35,36,155,95,63,
123,84,106,155,93,64,121,83,5,21,61,115,74,65,253,153,4,50,
115,144,62,19,13,0,0,0,0,1,255,20,254,80,1,141,4,49,
0,19,0,0,3,55,22,23,22,51,50,55,54,53,17,33,17,20,
14,1,35,34,39,38,236,169,12,26,28,24,51,32,33,1,2,110,
182,93,82,58,54,254,179,172,17,12,13,31,32,48,4,141,251,172,
101,184,112,20,18,0,0,0,0,1,0,93,2,66,1,165,3,138,
0,7,0,0,18,52,54,50,22,20,6,34,93,96,136,96,96,136,
2,162,136,96,96,136,96,0,0,2,0,98,2,154,3,102,6,58,
0,2,0,6,0,0,9,2,3,33,21,33,3,70,254,154,254,152,
22,3,4,252,252,6,58,253,50,2,206,253,43,203,0,0,0,3,
0,84,1,165,4,113,5,240,0,9,0,38,0,70,0,0,1,33,
21,33,21,51,21,35,21,35,3,20,23,22,23,22,23,22,51,50,
54,55,54,55,54,53,52,39,46,2,35,34,7,6,7,6,7,6,
7,52,55,62,1,55,54,55,54,51,50,23,30,1,23,22,21,20,
7,6,7,6,35,34,39,38,39,38,39,38,39,38,1,192,1,97,
254,255,234,234,96,165,31,30,49,52,53,57,57,59,110,49,46,32,
30,32,33,102,106,53,59,56,54,51,49,30,30,199,32,33,108,69,
68,74,69,75,106,96,97,142,42,42,77,76,120,119,133,76,73,72,
71,66,54,52,32,32,4,188,86,126,86,226,1,19,83,70,68,40,
42,20,21,46,43,41,69,66,79,89,70,72,84,44,22,21,45,43,
70,71,87,113,92,95,126,45,44,22,20,42,42,146,104,105,118,155,
127,126,67,67,21,20,47,43,65,63,90,91,0,2,0,120,1,104,
6,26,4,54,0,2,0,5,0,0,9,3,17,1,6,26,253,50,
2,206,250,94,2,206,1,104,1,102,1,104,253,50,2,206,254,152,
0,0,0,3,0,84,1,27,4,113,5,240,0,3,0,32,0,64,
0,0,19,33,21,33,19,20,23,22,23,22,23,22,51,50,54,55,
54,55,54,53,52,39,46,2,35,34,7,6,7,6,7,6,7,52,
55,62,1,55,54,55,54,51,50,23,30,1,23,22,21,20,7,6,
7,6,35,34,39,38,39,38,39,38,39,38,85,4,27,251,229,198,
31,30,49,52,53,57,57,59,110,49,46,32,30,32,33,102,106,53,
59,56,54,51,49,30,30,199,32,33,108,69,68,74,69,75,106,96,
97,142,42,42,77,76,120,119,133,76,73,72,71,66,54,52,32,32,
1,154,127,2,168,83,70,68,40,42,20,21,46,43,41,69,66,79,
89,70,72,84,44,22,21,45,43,70,71,87,113,92,95,126,45,44,
22,20,42,42,146,104,105,118,155,127,126,67,67,21,20,47,43,65,
63,90,91,0,0,0,0,1,0,0,0,224,0,1,0,35,0,192,
0,5,0,18,0,6,0,7,255,201,0,18,0,18,255,113,0,36,
0,38,255,176,0,36,0,55,255,158,0,36,0,57,255,43,0,36,
0,89,255,92,0,36,0,90,255,162,0,40,0,53,0,41,0,42,
0,55,255,188,0,46,0,50,255,147,0,50,0,36,255,158,0,50,
0,55,255,143,0,51,0,36,255,119,0,55,0,36,255,145,0,55,
0,88,255,121,0,57,0,36,255,12,0,57,0,40,255,186,0,57,
0,72,255,190,0,58,0,36,255,160,0,58,0,72,255,229,0,60,
0,36,255,66,0,60,0,68,255,129,0,63,0,63,255,113,0,68,
0,89,255,218,0,72,0,87,255,203,0,73,0,68,255,176,0,73,
0,81,255,188,0,73,0,82,255,215,0,73,0,87,255,186,0,73,
0,88,255,174,0,73,0,92,255,215,0,82,0,89,255,230,0,82,
0,91,255,203,0,85,0,72,255,223,0,89,0,72,255,211,0,0,
0,42,1,254,0,1,0,0,0,0,0,0,1,3,2,8,0,1,
0,0,0,0,0,1,0,5,3,24,0,1,0,0,0,0,0,2,
0,4,3,40,0,1,0,0,0,0,0,3,0,34,3,115,0,1,
0,0,0,0,0,4,0,10,3,172,0,1,0,0,0,0,0,5,
0,16,3,217,0,1,0,0,0,0,0,6,0,10,4,0,0,1,
0,0,0,0,0,9,0,46,4,105,0,1,0,0,0,0,0,11,
0,19,4,192,0,1,0,0,0,0,0,12,0,19,4,252,0,1,
0,0,0,0,0,13,0,14,5,46,0,1,0,0,0,0,1,0,
0,24,5,61,0,1,0,0,0,0,1,1,0,9,5,196,0,1,
0,0,0,0,1,2,0,17,5,245,0,1,0,0,0,0,1,3,
0,16,6,100,0,1,0,0,0,1,1,0,0,24,5,86,0,1,
0,0,0,1,1,1,0,9,5,206,0,1,0,0,0,1,1,2,
0,31,6,7,0,1,0,0,0,1,1,3,0,18,6,117,0,1,
0,0,0,2,1,0,0,33,5,111,0,1,0,0,0,2,1,1,
0,9,5,216,0,1,0,0,0,2,1,2,0,23,6,39,0,1,
0,0,0,2,1,3,0,17,6,136,0,1,0,0,0,3,1,0,
0,21,5,145,0,1,0,0,0,3,1,1,0,8,5,226,0,1,
0,0,0,3,1,2,0,17,6,63,0,1,0,0,0,3,1,3,
0,19,6,154,0,1,0,0,0,4,1,0,0,28,5,167,0,1,
0,0,0,4,1,1,0,9,5,235,0,1,0,0,0,4,1,2,
0,18,6,81,0,1,0,0,0,4,1,3,0,28,6,174,0,3,
0,1,4,9,0,0,2,6,0,0,0,3,0,1,4,9,0,1,
0,10,3,12,0,3,0,1,4,9,0,2,0,8,3,30,0,3,
0,1,4,9,0,3,0,68,3,45,0,3,0,1,4,9,0,4,
0,20,3,150,0,3,0,1,4,9,0,5,0,32,3,183,0,3,
0,1,4,9,0,6,0,20,3,234,0,3,0,1,4,9,0,9,
0,92,4,11,0,3,0,1,4,9,0,11,0,38,4,152,0,3,
0,1,4,9,0,12,0,38,4,212,0,3,0,1,4,9,0,13,
0,28,5,16,0,67,0,114,0,101,0,97,0,116,0,101,0,100,
0,32,0,98,0,121,0,32,0,84,0,104,0,97,0,116,0,99,
0,104,0,101,0,114,0,32,0,85,0,108,0,114,0,105,0,99,
0,104,0,32,0,40,0,104,0,116,0,116,0,112,0,58,0,47,
0,47,0,116,0,117,0,108,0,114,0,105,0,99,0,104,0,46,
0,99,0,111,0,109,0,41,0,44,0,32,0,75,0,97,0,114,
0,111,0,108,0,121,0,32,0,66,0,97,0,114,0,116,0,97,
0,32,0,40,0,98,0,97,0,114,0,116,0,97,0,107,0,97,
0,114,0,99,0,115,0,105,0,64,0,103,0,109,0,97,0,105,
0,108,0,46,0,99,0,111,0,109,0,41,0,32,0,97,0,110,
0,100,0,32,0,77,0,105,0,99,0,104,0,97,0,101,0,108,
0,32,0,69,0,118,0,101,0,114,0,115,0,111,0,110,0,32,
0,119,0,105,0,116,0,104,0,32,0,70,0,111,0,110,0,116,
0,70,0,111,0,114,0,103,0,101,0,32,0,32,0,40,0,104,
0,116,0,116,0,112,0,58,0,47,0,47,0,102,0,111,0,110,
0,116,0,102,0,111,0,114,0,103,0,101,0,46,0,115,0,102,
0,46,0,110,0,101,0,116,0,41,0,10,0,10,0,84,0,104,
0,105,0,115,0,32,0,102,0,111,0,110,0,116,0,44,0,32,
0,105,0,110,0,99,0,108,0,117,0,100,0,105,0,110,0,103,
0,32,0,104,0,105,0,110,0,116,0,32,0,105,0,110,0,115,
0,116,0,114,0,117,0,99,0,116,0,105,0,111,0,110,0,115,
0,44,0,32,0,104,0,97,0,115,0,32,0,98,0,101,0,101,
0,110,0,32,0,100,0,111,0,110,0,97,0,116,0,101,0,100,
0,32,0,116,0,111,0,32,0,116,0,104,0,101,0,32,0,80,
0,117,0,98,0,108,0,105,0,99,0,32,0,68,0,111,0,109,
0,97,0,105,0,110,0,46,0,32,0,32,0,68,0,111,0,32,
0,119,0,104,0,97,0,116,0,101,0,118,0,101,0,114,0,32,
0,121,0,111,0,117,0,32,0,119,0,97,0,110,0,116,0,32,
0,119,0,105,0,116,0,104,0,32,0,105,0,116,0,46,0,10,
0,0,67,114,101,97,116,101,100,32,98,121,32,84,104,97,116,99,
104,101,114,32,85,108,114,105,99,104,32,40,104,116,116,112,58,47,
47,116,117,108,114,105,99,104,46,99,111,109,41,44,32,75,97,114,
111,108,121,32,66,97,114,116,97,32,40,98,97,114,116,97,107,97,
114,99,115,105,64,103,109,97,105,108,46,99,111,109,41,32,97,110,
100,32,77,105,99,104,97,101,108,32,69,118,101,114,115,111,110,32,
119,105,116,104,32,70,111,110,116,70,111,114,103,101,32,32,40,104,
116,116,112,58,47,47,102,111,110,116,102,111,114,103,101,46,115,102,
46,110,101,116,41,10,10,84,104,105,115,32,102,111,110,116,44,32,
105,110,99,108,117,100,105,110,103,32,104,105,110,116,32,105,110,115,
116,114,117,99,116,105,111,110,115,44,32,104,97,115,32,98,101,101,
110,32,100,111,110,97,116,101,100,32,116,111,32,116,104,101,32,80,
117,98,108,105,99,32,68,111,109,97,105,110,46,32,32,68,111,32,
119,104,97,116,101,118,101,114,32,121,111,117,32,119,97,110,116,32,
119,105,116,104,32,105,116,46,10,0,0,84,0,117,0,102,0,102,
0,121,0,0,84,117,102,102,121,0,0,66,0,111,0,108,0,100,
0,0,66,111,108,100,0,0,70,0,111,0,110,0,116,0,70,0,
111,0,114,0,103,0,101,0,32,0,58,0,32,0,84,0,117,0,
102,0,102,0,121,0,32,0,66,0,111,0,108,0,100,0,32,0,
58,0,32,0,49,0,51,0,45,0,54,0,45,0,50,0,48,0,
49,0,50,0,0,70,111,110,116,70,111,114,103,101,32,58,32,84,
117,102,102,121,32,66,111,108,100,32,58,32,49,51,45,54,45,50,
48,49,50,0,0,84,0,117,0,102,0,102,0,121,0,32,0,66,
0,111,0,108,0,100,0,0,84,117,102,102,121,32,66,111,108,100,
0,0,86,0,101,0,114,0,115,0,105,0,111,0,110,0,32,0,
48,0,48,0,49,0,46,0,50,0,56,0,48,0,32,0,0,86,
101,114,115,105,111,110,32,48,48,49,46,50,56,48,32,0,0,84,
0,117,0,102,0,102,0,121,0,45,0,66,0,111,0,108,0,100,
0,0,84,117,102,102,121,45,66,111,108,100,0,0,84,0,104,0,
97,0,116,0,99,0,104,0,101,0,114,0,32,0,85,0,108,0,
114,0,105,0,99,0,104,0,44,0,32,0,75,0,97,0,114,0,
111,0,108,0,121,0,32,0,66,0,97,0,114,0,116,0,97,0,
44,0,32,0,77,0,105,0,99,0,104,0,97,0,101,0,108,0,
32,0,69,0,118,0,101,0,114,0,115,0,111,0,110,0,0,84,
104,97,116,99,104,101,114,32,85,108,114,105,99,104,44,32,75,97,
114,111,108,121,32,66,97,114,116,97,44,32,77,105,99,104,97,101,
108,32,69,118,101,114,115,111,110,0,0,104,0,116,0,116,0,112,
0,58,0,47,0,47,0,116,0,117,0,108,0,114,0,105,0,99,
0,104,0,46,0,99,0,111,0,109,0,10,0,0,104,116,116,112,
58,47,47,116,117,108,114,105,99,104,46,99,111,109,10,0,0,104,
0,116,0,116,0,112,0,58,0,47,0,47,0,116,0,117,0,108,
0,114,0,105,0,99,0,104,0,46,0,99,0,111,0,109,0,10,
0,0,104,116,116,112,58,47,47,116,117,108,114,105,99,104,46,99,
111,109,10,0,0,80,0,117,0,98,0,108,0,105,0,99,0,32,
0,68,0,111,0,109,0,97,0,105,0,110,0,10,0,0,80,117,
98,108,105,99,32,68,111,109,97,105,110,10,0,65,108,108,32,84,
121,112,111,103,114,97,112,104,105,99,32,70,101,97,116,117,114,101,
115,0,70,111,110,99,116,105,111,110,115,32,116,121,112,111,103,114,
97,112,104,105,113,117,101,115,0,65,108,108,101,32,116,121,112,111,
103,114,97,102,105,115,99,104,101,110,32,77,154,103,108,105,99,104,
107,101,105,116,101,110,0,70,117,110,122,105,111,110,105,32,84,105,
112,111,103,114,97,102,105,99,104,101,0,65,108,108,101,32,116,121,
112,111,103,114,97,102,105,115,99,104,101,32,107,101,110,109,101,114,
107,101,110,0,76,105,103,97,116,117,114,101,115,0,76,105,103,97,
116,117,114,101,115,0,76,105,103,97,116,117,114,101,110,0,76,101,
103,97,116,117,114,101,0,76,105,103,97,116,117,114,101,110,0,65,
108,108,32,84,121,112,101,32,70,101,97,116,117,114,101,115,0,84,
111,117,116,101,115,32,102,111,110,99,116,105,111,110,115,32,116,121,
112,111,103,114,97,112,104,105,113,117,101,115,0,65,108,108,101,32,
65,117,115,122,101,105,99,104,110,117,110,103,115,97,114,116,101,110,
0,84,117,116,116,101,32,108,101,32,70,117,110,122,105,111,110,105,
0,65,108,108,101,32,116,121,112,101,107,101,110,109,101,114,107,101,
110,0,67,111,109,109,111,110,32,76,105,103,97,116,117,114,101,115,
0,76,105,103,97,116,117,114,101,115,32,85,115,117,101,108,108,101,
115,0,78,111,114,109,97,108,101,32,76,105,103,97,116,117,114,101,
110,0,76,101,103,97,116,117,114,101,32,112,105,157,32,67,111,109,
117,110,105,0,71,101,109,101,101,110,115,99,104,97,112,112,101,108,
105,106,107,101,32,76,105,103,97,116,117,114,101,110,0,0,0,0,
0,2,0,0,0,0,0,0,255,1,0,102,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,122,0,0,
0,1,0,2,0,3,0,4,0,5,0,6,0,7,0,8,0,9,
0,10,0,11,0,12,0,13,0,14,0,15,0,16,0,17,0,18,
0,19,0,20,0,21,0,22,0,23,0,24,0,25,0,26,0,27,
0,28,0,29,0,30,0,31,0,32,0,33,0,34,0,35,0,36,
0,37,0,38,0,39,0,40,0,41,0,42,0,43,0,44,0,45,
0,46,0,47,0,48,0,49,0,50,0,51,0,52,0,53,0,54,
0,55,0,56,0,57,0,58,0,59,0,60,0,61,0,62,0,63,
0,64,0,65,0,66,0,67,0,68,0,69,0,70,0,71,0,72,
0,73,0,74,0,75,0,76,0,77,0,78,0,79,0,80,0,81,
0,82,0,83,0,84,0,85,0,86,0,87,0,88,0,89,0,90,
0,91,0,92,0,93,0,94,0,95,0,96,0,97,0,163,0,132,
0,133,0,189,0,150,0,232,0,134,0,142,0,139,0,157,0,169,
0,164,1,2,0,138,0,218,0,131,0,147,0,242,0,243,0,141,
1,3,0,136,0,195,0,222,0,241,0,158,0,170,0,245,0,244,
0,246,0,162,0,173,0,201,0,199,0,174,0,98,0,99,0,144,
0,100,0,203,0,101,0,200,0,202,0,207,0,204,0,205,0,206,
0,233,0,102,0,211,0,208,0,209,0,175,0,103,0,240,0,145,
0,214,0,212,0,213,0,104,0,235,0,237,0,137,0,106,0,105,
0,107,0,109,0,108,0,110,0,160,0,111,0,113,0,112,0,114,
0,115,0,117,0,116,0,118,0,119,0,234,0,120,0,122,0,121,
0,123,0,125,0,124,0,184,0,161,0,127,0,126,0,128,0,129,
0,236,0,238,0,186,1,4,1,5,1,6,1,7,1,8,1,9,
0,253,0,254,1,10,1,11,1,12,1,13,0,255,1,0,1,14,
1,15,1,16,1,1,1,17,1,18,1,19,1,20,1,21,1,22,
1,23,1,24,1,25,1,26,1,27,1,28,0,248,0,249,1,29,
1,30,1,31,1,32,1,33,1,34,1,35,1,36,1,37,1,38,
1,39,1,40,1,41,1,42,1,43,1,44,0,250,0,215,1,45,
1,46,1,47,1,48,1,49,1,50,1,51,1,52,1,53,1,54,
1,55,1,56,1,57,1,58,1,59,0,226,0,227,1,60,1,61,
1,62,1,63,1,64,1,65,1,66,1,67,1,68,1,69,1,70,
1,71,1,72,1,73,1,74,0,176,0,177,1,75,1,76,1,77,
1,78,1,79,1,80,1,81,1,82,1,83,1,84,0,251,0,252,
0,228,0,229,1,85,1,86,1,87,1,88,1,89,1,90,1,91,
1,92,1,93,1,94,1,95,1,96,1,97,1,98,1,99,1,100,
1,101,1,102,1,103,1,104,1,105,1,106,0,187,1,107,1,108,
1,109,1,110,0,230,0,231,1,111,0,166,1,112,1,113,1,114,
1,115,1,116,1,117,0,216,0,225,0,219,0,220,0,221,0,224,
0,217,0,223,1,118,1,119,1,120,1,121,1,122,1,123,1,124,
1,125,1,126,1,127,1,128,1,129,1,130,1,131,1,132,1,133,
1,134,1,135,1,136,1,137,1,138,1,139,1,140,1,141,1,142,
1,143,1,144,1,145,1,146,1,147,1,148,1,149,1,150,0,168,
1,151,1,152,1,153,1,154,1,155,1,156,1,157,1,158,1,159,
1,160,1,161,1,162,1,163,1,164,1,165,1,166,1,167,1,168,
1,169,0,159,1,170,1,171,1,172,1,173,1,174,1,175,1,176,
1,177,1,178,1,179,1,180,1,181,1,182,1,183,1,184,1,185,
1,186,1,187,0,151,1,188,1,189,1,190,0,155,1,191,1,192,
1,193,1,194,1,195,1,196,1,197,1,198,1,199,1,200,1,201,
1,202,1,203,1,204,1,205,1,206,1,207,1,208,1,209,1,210,
1,211,1,212,1,213,1,214,1,215,1,216,1,217,1,218,1,219,
1,220,1,221,1,222,1,223,1,224,1,225,1,226,1,227,1,228,
1,229,1,230,1,231,1,232,1,233,1,234,1,235,1,236,1,237,
1,238,1,239,1,240,1,241,1,242,1,243,1,244,1,245,1,246,
1,247,1,248,1,249,1,250,1,251,1,252,1,253,1,254,1,255,
2,0,2,1,2,2,2,3,2,4,2,5,2,6,2,7,2,8,
2,9,2,10,2,11,2,12,2,13,2,14,2,15,2,16,2,17,
2,18,2,19,2,20,2,21,2,22,2,23,2,24,2,25,2,26,
2,27,2,28,2,29,2,30,2,31,2,32,2,33,2,34,2,35,
2,36,2,37,2,38,2,39,2,40,2,41,2,42,2,43,2,44,
2,45,2,46,2,47,2,48,2,49,2,50,2,51,2,52,2,53,
2,54,2,55,2,56,2,57,2,58,2,59,2,60,2,61,2,62,
2,63,2,64,2,65,2,66,2,67,2,68,2,69,2,70,2,71,
2,72,2,73,2,74,2,75,2,76,2,77,2,78,2,79,2,80,
2,81,2,82,2,83,2,84,2,85,2,86,2,87,2,88,2,89,
2,90,2,91,2,92,2,93,2,94,2,95,2,96,2,97,2,98,
2,99,2,100,2,101,2,102,2,103,2,104,2,105,2,106,2,107,
2,108,2,109,2,110,2,111,0,178,0,179,2,112,0,182,0,183,
0,196,2,113,0,180,0,181,0,197,2,114,0,130,0,194,0,135,
2,115,2,116,2,117,0,171,0,198,2,118,0,190,0,191,2,119,
2,120,2,121,0,188,2,122,2,123,2,124,2,125,2,126,2,127,
2,128,2,129,2,130,2,131,2,132,2,133,2,134,2,135,2,136,
2,137,2,138,2,139,2,140,2,141,2,142,2,143,2,144,2,145,
2,146,2,147,2,148,2,149,2,150,2,151,2,152,2,153,2,154,
2,155,2,156,2,157,2,158,2,159,2,160,2,161,2,162,2,163,
2,164,2,165,2,166,2,167,2,168,2,169,2,170,2,171,2,172,
2,173,2,174,2,175,2,176,2,177,2,178,0,247,2,179,2,180,
2,181,2,182,2,183,2,184,2,185,2,186,2,187,2,188,2,189,
2,190,2,191,2,192,2,193,2,194,2,195,2,196,2,197,2,198,
2,199,2,200,2,201,2,202,0,140,2,203,2,204,2,205,2,206,
2,207,2,208,2,209,2,210,2,211,2,212,2,213,2,214,2,215,
2,216,2,217,2,218,2,219,2,220,2,221,2,222,2,223,2,224,
2,225,2,226,2,227,2,228,2,229,2,230,2,231,2,232,2,233,
2,234,2,235,2,236,2,237,2,238,2,239,2,240,2,241,2,242,
2,243,2,244,2,245,2,246,2,247,2,248,2,249,2,250,2,251,
2,252,2,253,2,254,2,255,3,0,3,1,3,2,3,3,3,4,
3,5,3,6,3,7,3,8,3,9,3,10,3,11,3,12,3,13,
3,14,3,15,3,16,3,17,3,18,3,19,3,20,3,21,3,22,
3,23,3,24,3,25,3,26,3,27,3,28,3,29,3,30,3,31,
3,32,3,33,3,34,3,35,3,36,3,37,3,38,3,39,3,40,
3,41,3,42,3,43,3,44,3,45,3,46,3,47,3,48,3,49,
3,50,3,51,3,52,3,53,3,54,3,55,3,56,0,152,3,57,
3,58,3,59,3,60,0,154,0,153,0,239,0,165,3,61,3,62,
0,146,0,156,3,63,3,64,3,65,0,167,0,143,0,148,0,149,
3,66,3,67,3,68,0,185,3,69,3,70,3,71,3,72,3,73,
3,74,3,75,3,76,3,77,3,78,3,79,3,80,3,81,3,82,
3,83,3,84,3,85,3,86,3,87,3,88,3,89,3,90,3,91,
3,92,3,93,3,94,3,95,3,96,3,97,3,98,3,99,3,100,
3,101,3,102,3,103,3,104,3,105,3,106,3,107,3,108,3,109,
3,110,3,111,3,112,3,113,3,114,3,115,3,116,3,117,3,118,
3,119,3,120,3,121,3,122,3,123,3,124,3,125,10,115,111,102,
116,104,121,112,104,101,110,9,109,105,99,114,111,115,105,103,110,7,
65,109,97,99,114,111,110,7,97,109,97,99,114,111,110,6,65,98,
114,101,118,101,6,97,98,114,101,118,101,7,65,111,103,111,110,101,
107,7,97,111,103,111,110,101,107,11,67,99,105,114,99,117,109,102,
108,101,120,11,99,99,105,114,99,117,109,102,108,101,120,10,67,100,
111,116,97,99,99,101,110,116,10,99,100,111,116,97,99,99,101,110,
116,6,68,99,97,114,111,110,6,100,99,97,114,111,110,6,68,99,
114,111,97,116,7,69,109,97,99,114,111,110,7,101,109,97,99,114,
111,110,6,69,98,114,101,118,101,6,101,98,114,101,118,101,10,69,
100,111,116,97,99,99,101,110,116,10,101,100,111,116,97,99,99,101,
110,116,7,69,111,103,111,110,101,107,7,101,111,103,111,110,101,107,
6,69,99,97,114,111,110,6,101,99,97,114,111,110,11,71,99,105,
114,99,117,109,102,108,101,120,11,103,99,105,114,99,117,109,102,108,
101,120,10,71,100,111,116,97,99,99,101,110,116,10,103,100,111,116,
97,99,99,101,110,116,12,71,99,111,109,109,97,97,99,99,101,110,
116,12,103,99,111,109,109,97,97,99,99,101,110,116,11,72,99,105,
114,99,117,109,102,108,101,120,11,104,99,105,114,99,117,109,102,108,
101,120,4,72,98,97,114,4,104,98,97,114,6,73,116,105,108,100,
101,6,105,116,105,108,100,101,7,73,109,97,99,114,111,110,7,105,
109,97,99,114,111,110,6,73,98,114,101,118,101,6,105,98,114,101,
118,101,7,73,111,103,111,110,101,107,7,105,111,103,111,110,101,107,
2,73,74,2,105,106,11,74,99,105,114,99,117,109,102,108,101,120,
11,106,99,105,114,99,117,109,102,108,101,120,12,75,99,111,109,109,
97,97,99,99,101,110,116,12,107,99,111,109,109,97,97,99,99,101,
110,116,12,107,103,114,101,101,110,108,97,110,100,105,99,6,76,97,
99,117,116,101,6,108,97,99,117,116,101,12,76,99,111,109,109,97,
97,99,99,101,110,116,12,108,99,111,109,109,97,97,99,99,101,110,
116,6,76,99,97,114,111,110,6,108,99,97,114,111,110,4,76,100,
111,116,4,108,100,111,116,6,78,97,99,117,116,101,6,110,97,99,
117,116,101,12,78,99,111,109,109,97,97,99,99,101,110,116,12,110,
99,111,109,109,97,97,99,99,101,110,116,6,78,99,97,114,111,110,
6,110,99,97,114,111,110,11,110,97,112,111,115,116,114,111,112,104,
101,3,69,110,103,3,101,110,103,7,79,109,97,99,114,111,110,7,
111,109,97,99,114,111,110,6,79,98,114,101,118,101,6,111,98,114,
101,118,101,13,79,104,117,110,103,97,114,117,109,108,97,117,116,13,
111,104,117,110,103,97,114,117,109,108,97,117,116,6,82,97,99,117,
116,101,6,114,97,99,117,116,101,12,82,99,111,109,109,97,97,99,
99,101,110,116,12,114,99,111,109,109,97,97,99,99,101,110,116,6,
82,99,97,114,111,110,6,114,99,97,114,111,110,6,83,97,99,117,
116,101,6,115,97,99,117,116,101,11,83,99,105,114,99,117,109,102,
108,101,120,11,115,99,105,114,99,117,109,102,108,101,120,12,84,99,
111,109,109,97,97,99,99,101,110,116,12,116,99,111,109,109,97,97,
99,99,101,110,116,6,84,99,97,114,111,110,6,116,99,97,114,111,
110,4,84,98,97,114,4,116,98,97,114,6,85,116,105,108,100,101,
6,117,116,105,108,100,101,7,85,109,97,99,114,111,110,7,117,109,
97,99,114,111,110,6,85,98,114,101,118,101,6,117,98,114,101,118,
101,5,85,114,105,110,103,5,117,114,105,110,103,13,85,104,117,110,
103,97,114,117,109,108,97,117,116,13,117,104,117,110,103,97,114,117,
109,108,97,117,116,7,85,111,103,111,110,101,107,7,117,111,103,111,
110,101,107,11,87,99,105,114,99,117,109,102,108,101,120,11,119,99,
105,114,99,117,109,102,108,101,120,11,89,99,105,114,99,117,109,102,
108,101,120,11,121,99,105,114,99,117,109,102,108,101,120,6,90,97,
99,117,116,101,6,122,97,99,117,116,101,10,90,100,111,116,97,99,
99,101,110,116,10,122,100,111,116,97,99,99,101,110,116,5,108,111,
110,103,115,7,117,110,105,48,49,69,50,7,117,110,105,48,49,69,
51,12,83,99,111,109,109,97,97,99,99,101,110,116,12,115,99,111,
109,109,97,97,99,99,101,110,116,7,117,110,105,48,50,49,65,7,
117,110,105,48,50,49,66,9,103,114,97,118,101,99,111,109,98,9,
97,99,117,116,101,99,111,109,98,7,117,110,105,48,51,48,50,9,
116,105,108,100,101,99,111,109,98,7,117,110,105,48,51,48,52,7,
117,110,105,48,51,48,53,7,117,110,105,48,51,48,54,7,117,110,
105,48,51,48,55,7,117,110,105,48,51,48,65,7,117,110,105,48,
51,48,66,7,117,110,105,48,51,48,67,7,117,110,105,48,51,49,
48,12,100,111,116,98,101,108,111,119,99,111,109,98,7,117,110,105,
48,51,50,52,7,117,110,105,48,51,50,53,7,117,110,105,48,51,
50,54,7,117,110,105,48,51,50,55,7,117,110,105,48,51,50,56,
7,117,110,105,48,51,51,49,7,117,110,105,48,51,55,65,5,116,
111,110,111,115,13,100,105,101,114,101,115,105,115,116,111,110,111,115,
10,65,108,112,104,97,116,111,110,111,115,12,69,112,115,105,108,111,
110,116,111,110,111,115,8,69,116,97,116,111,110,111,115,9,73,111,
116,97,116,111,110,111,115,12,79,109,105,99,114,111,110,116,111,110,
111,115,12,85,112,115,105,108,111,110,116,111,110,111,115,10,79,109,
101,103,97,116,111,110,111,115,17,105,111,116,97,100,105,101,114,101,
115,105,115,116,111,110,111,115,5,65,108,112,104,97,4,66,101,116,
97,5,71,97,109,109,97,7,69,112,115,105,108,111,110,4,90,101,
116,97,3,69,116,97,5,84,104,101,116,97,4,73,111,116,97,5,
75,97,112,112,97,6,76,97,109,98,100,97,2,77,117,2,78,117,
2,88,105,7,79,109,105,99,114,111,110,2,80,105,3,82,104,111,
5,83,105,103,109,97,3,84,97,117,7,85,112,115,105,108,111,110,
3,80,104,105,3,67,104,105,3,80,115,105,12,73,111,116,97,100,
105,101,114,101,115,105,115,15,85,112,115,105,108,111,110,100,105,101,
114,101,115,105,115,10,97,108,112,104,97,116,111,110,111,115,12,101,
112,115,105,108,111,110,116,111,110,111,115,8,101,116,97,116,111,110,
111,115,9,105,111,116,97,116,111,110,111,115,20,117,112,115,105,108,
111,110,100,105,101,114,101,115,105,115,116,111,110,111,115,5,97,108,
112,104,97,4,98,101,116,97,5,103,97,109,109,97,5,100,101,108,
116,97,7,101,112,115,105,108,111,110,4,122,101,116,97,3,101,116,
97,5,116,104,101,116,97,4,105,111,116,97,5,107,97,112,112,97,
6,108,97,109,98,100,97,2,110,117,2,120,105,7,111,109,105,99,
114,111,110,3,114,104,111,6,115,105,103,109,97,49,5,115,105,103,
109,97,3,116,97,117,7,117,112,115,105,108,111,110,3,112,104,105,
3,99,104,105,3,112,115,105,5,111,109,101,103,97,12,105,111,116,
97,100,105,101,114,101,115,105,115,15,117,112,115,105,108,111,110,100,
105,101,114,101,115,105,115,12,111,109,105,99,114,111,110,116,111,110,
111,115,12,117,112,115,105,108,111,110,116,111,110,111,115,10,111,109,
101,103,97,116,111,110,111,115,6,116,104,101,116,97,49,4,112,104,
105,49,6,111,109,101,103,97,49,9,97,102,105,105,49,48,48,50,
51,9,97,102,105,105,49,48,48,53,49,9,97,102,105,105,49,48,
48,53,50,9,97,102,105,105,49,48,48,53,51,9,97,102,105,105,
49,48,48,53,52,9,97,102,105,105,49,48,48,53,53,9,97,102,
105,105,49,48,48,53,54,9,97,102,105,105,49,48,48,53,55,9,
97,102,105,105,49,48,48,53,56,9,97,102,105,105,49,48,48,53,
57,9,97,102,105,105,49,48,48,54,48,9,97,102,105,105,49,48,
48,54,49,9,97,102,105,105,49,48,48,54,50,9,97,102,105,105,
49,48,49,52,53,9,97,102,105,105,49,48,48,49,55,9,97,102,
105,105,49,48,48,49,56,9,97,102,105,105,49,48,48,49,57,9,
97,102,105,105,49,48,48,50,48,9,97,102,105,105,49,48,48,50,
49,9,97,102,105,105,49,48,48,50,50,9,97,102,105,105,49,48,
48,50,52,9,97,102,105,105,49,48,48,50,53,9,97,102,105,105,
49,48,48,50,54,9,97,102,105,105,49,48,48,50,55,9,97,102,
105,105,49,48,48,50,56,9,97,102,105,105,49,48,48,50,57,9,
97,102,105,105,49,48,48,51,48,9,97,102,105,105,49,48,48,51,
49,9,97,102,105,105,49,48,48,51,50,9,97,102,105,105,49,48,
48,51,51,9,97,102,105,105,49,48,48,51,52,9,97,102,105,105,
49,48,48,51,53,9,97,102,105,105,49,48,48,51,54,9,97,102,
105,105,49,48,48,51,55,9,97,102,105,105,49,48,48,51,56,9,
97,102,105,105,49,48,48,51,57,9,97,102,105,105,49,48,48,52,
48,9,97,102,105,105,49,48,48,52,49,9,97,102,105,105,49,48,
48,52,50,9,97,102,105,105,49,48,48,52,51,9,97,102,105,105,
49,48,48,52,52,9,97,102,105,105,49,48,48,52,53,9,97,102,
105,105,49,48,48,52,54,9,97,102,105,105,49,48,48,52,55,9,
97,102,105,105,49,48,48,52,56,9,97,102,105,105,49,48,48,52,
57,9,97,102,105,105,49,48,48,54,53,9,97,102,105,105,49,48,
48,54,54,9,97,102,105,105,49,48,48,54,55,9,97,102,105,105,
49,48,48,54,56,9,97,102,105,105,49,48,48,54,57,9,97,102,
105,105,49,48,48,55,48,9,97,102,105,105,49,48,48,55,50,9,
97,102,105,105,49,48,48,55,51,9,97,102,105,105,49,48,48,55,
52,9,97,102,105,105,49,48,48,55,53,9,97,102,105,105,49,48,
48,55,54,9,97,102,105,105,49,48,48,55,55,9,97,102,105,105,
49,48,48,55,56,9,97,102,105,105,49,48,48,55,57,9,97,102,
105,105,49,48,48,56,48,9,97,102,105,105,49,48,48,56,49,9,
97,102,105,105,49,48,48,56,50,9,97,102,105,105,49,48,48,56,
51,9,97,102,105,105,49,48,48,56,52,9,97,102,105,105,49,48,
48,56,53,9,97,102,105,105,49,48,48,56,54,9,97,102,105,105,
49,48,48,56,55,9,97,102,105,105,49,48,48,56,56,9,97,102,
105,105,49,48,48,56,57,9,97,102,105,105,49,48,48,57,48,9,
97,102,105,105,49,48,48,57,49,9,97,102,105,105,49,48,48,57,
50,9,97,102,105,105,49,48,48,57,51,9,97,102,105,105,49,48,
48,57,52,9,97,102,105,105,49,48,48,57,53,9,97,102,105,105,
49,48,48,57,54,9,97,102,105,105,49,48,48,57,55,9,97,102,
105,105,49,48,48,55,49,9,97,102,105,105,49,48,48,57,57,9,
97,102,105,105,49,48,49,48,48,9,97,102,105,105,49,48,49,48,
49,9,97,102,105,105,49,48,49,48,50,9,97,102,105,105,49,48,
49,48,51,9,97,102,105,105,49,48,49,48,52,9,97,102,105,105,
49,48,49,48,53,9,97,102,105,105,49,48,49,48,54,9,97,102,
105,105,49,48,49,48,55,9,97,102,105,105,49,48,49,48,56,9,
97,102,105,105,49,48,49,48,57,9,97,102,105,105,49,48,49,49,
48,9,97,102,105,105,49,48,49,57,51,10,66,100,111,116,97,99,
99,101,110,116,10,98,100,111,116,97,99,99,101,110,116,10,68,100,
111,116,97,99,99,101,110,116,10,100,100,111,116,97,99,99,101,110,
116,7,117,110,105,49,69,48,67,7,117,110,105,49,69,48,68,10,
70,100,111,116,97,99,99,101,110,116,10,102,100,111,116,97,99,99,
101,110,116,7,117,110,105,49,69,50,52,7,117,110,105,49,69,50,
53,7,117,110,105,49,69,51,52,7,117,110,105,49,69,51,53,7,
117,110,105,49,69,51,54,7,117,110,105,49,69,51,55,7,117,110,
105,49,69,51,56,7,117,110,105,49,69,51,57,7,117,110,105,49,
69,51,65,7,117,110,105,49,69,51,66,10,77,100,111,116,97,99,
99,101,110,116,10,109,100,111,116,97,99,99,101,110,116,7,117,110,
105,49,69,52,50,7,117,110,105,49,69,52,51,7,117,110,105,49,
69,52,52,7,117,110,105,49,69,52,53,7,117,110,105,49,69,52,
54,7,117,110,105,49,69,52,55,7,117,110,105,49,69,52,56,7,
117,110,105,49,69,52,57,10,80,100,111,116,97,99,99,101,110,116,
10,112,100,111,116,97,99,99,101,110,116,7,117,110,105,49,69,53,
65,7,117,110,105,49,69,53,66,7,117,110,105,49,69,53,67,7,
117,110,105,49,69,53,68,7,117,110,105,49,69,53,69,7,117,110,
105,49,69,53,70,10,83,100,111,116,97,99,99,101,110,116,10,115,
100,111,116,97,99,99,101,110,116,7,117,110,105,49,69,54,50,7,
117,110,105,49,69,54,51,10,84,100,111,116,97,99,99,101,110,116,
10,116,100,111,116,97,99,99,101,110,116,7,117,110,105,49,69,54,
67,7,117,110,105,49,69,54,68,7,117,110,105,49,69,54,69,7,
117,110,105,49,69,54,70,6,87,103,114,97,118,101,6,119,103,114,
97,118,101,6,87,97,99,117,116,101,6,119,97,99,117,116,101,9,
87,100,105,101,114,101,115,105,115,9,119,100,105,101,114,101,115,105,
115,7,117,110,105,49,69,56,69,7,117,110,105,49,69,56,70,7,
117,110,105,49,69,57,54,7,117,110,105,49,69,57,69,6,89,103,
114,97,118,101,6,121,103,114,97,118,101,7,117,110,105,49,69,70,
65,7,117,110,105,49,69,70,66,7,117,110,105,50,48,48,51,7,
117,110,105,50,48,48,52,7,117,110,105,50,48,48,53,7,117,110,
105,50,48,48,57,7,117,110,105,50,48,48,65,7,117,110,105,50,
48,49,48,7,117,110,105,50,48,49,49,10,102,105,103,117,114,101,
100,97,115,104,13,104,111,114,105,122,111,110,116,97,108,98,97,114,
13,113,117,111,116,101,114,101,118,101,114,115,101,100,7,117,110,105,
50,48,49,70,7,117,110,105,50,48,50,51,14,111,110,101,100,111,
116,101,110,108,101,97,100,101,114,14,116,119,111,100,111,116,101,110,
108,101,97,100,101,114,7,117,110,105,50,48,51,49,9,101,120,99,
108,97,109,100,98,108,7,117,110,105,50,48,51,68,7,117,110,105,
50,48,52,51,7,117,110,105,50,48,52,55,7,117,110,105,50,48,
52,56,7,117,110,105,50,48,52,57,7,117,110,105,50,48,52,66,
7,117,110,105,50,48,52,67,7,117,110,105,50,48,52,68,7,117,
110,105,50,48,52,70,7,117,110,105,50,48,53,50,7,117,110,105,
50,48,53,51,7,117,110,105,50,48,53,54,7,117,110,105,50,48,
53,56,7,117,110,105,50,48,53,57,7,117,110,105,50,48,53,65,
7,117,110,105,50,48,53,66,7,117,110,105,50,48,53,68,7,117,
110,105,50,48,53,69,7,117,110,105,50,48,55,48,7,117,110,105,
50,48,55,49,7,117,110,105,50,48,55,50,7,117,110,105,50,48,
55,51,7,117,110,105,50,48,55,52,7,117,110,105,50,48,55,53,
7,117,110,105,50,48,55,54,7,117,110,105,50,48,55,55,7,117,
110,105,50,48,55,56,7,117,110,105,50,48,55,57,7,117,110,105,
50,48,55,65,7,117,110,105,50,48,55,66,7,117,110,105,50,48,
55,67,7,117,110,105,50,48,55,68,7,117,110,105,50,48,55,69,
7,117,110,105,50,48,55,70,7,117,110,105,50,48,56,48,7,117,
110,105,50,48,56,49,7,117,110,105,50,48,56,50,7,117,110,105,
50,48,56,51,7,117,110,105,50,48,56,52,7,117,110,105,50,48,
56,53,7,117,110,105,50,48,56,54,7,117,110,105,50,48,56,55,
7,117,110,105,50,48,56,56,7,117,110,105,50,48,56,57,7,117,
110,105,50,48,56,65,7,117,110,105,50,48,56,66,7,117,110,105,
50,48,56,67,7,117,110,105,50,48,56,68,7,117,110,105,50,48,
56,69,7,117,110,105,50,48,57,48,7,117,110,105,50,48,57,49,
7,117,110,105,50,48,57,50,7,117,110,105,50,48,57,51,7,117,
110,105,50,48,57,52,7,117,110,105,50,48,57,56,7,117,110,105,
50,48,57,57,7,117,110,105,50,48,65,48,13,99,111,108,111,110,
109,111,110,101,116,97,114,121,7,117,110,105,50,48,65,50,4,108,
105,114,97,7,117,110,105,50,48,65,53,7,117,110,105,50,48,65,
54,6,112,101,115,101,116,97,7,117,110,105,50,48,65,56,7,117,
110,105,50,48,65,57,9,97,102,105,105,53,55,54,51,54,4,100,
111,110,103,4,69,117,114,111,7,117,110,105,50,48,65,68,7,117,
110,105,50,48,65,69,7,117,110,105,50,48,65,70,7,117,110,105,
50,48,66,48,7,117,110,105,50,48,66,49,7,117,110,105,50,48,
66,50,7,117,110,105,50,48,66,51,7,117,110,105,50,48,66,52,
7,117,110,105,50,48,66,53,7,117,110,105,50,48,66,54,7,117,
110,105,50,48,66,55,7,117,110,105,50,48,66,56,7,117,110,105,
50,48,66,57,7,117,110,105,50,49,48,51,9,97,102,105,105,54,
49,51,53,50,7,117,110,105,50,49,50,54,9,101,115,116,105,109,
97,116,101,100,8,111,110,101,116,104,105,114,100,9,116,119,111,116,
104,105,114,100,115,7,117,110,105,50,49,53,53,7,117,110,105,50,
49,53,54,7,117,110,105,50,49,53,55,7,117,110,105,50,49,53,
56,7,117,110,105,50,49,53,57,7,117,110,105,50,49,53,65,9,
111,110,101,101,105,103,104,116,104,12,116,104,114,101,101,101,105,103,
104,116,104,115,11,102,105,118,101,101,105,103,104,116,104,115,12,115,
101,118,101,110,101,105,103,104,116,104,115,7,117,110,105,50,49,53,
70,7,117,110,105,50,49,54,48,7,117,110,105,50,49,54,49,7,
117,110,105,50,49,54,50,7,117,110,105,50,49,54,51,7,117,110,
105,50,49,54,52,7,117,110,105,50,49,54,53,7,117,110,105,50,
49,54,54,7,117,110,105,50,49,54,55,7,117,110,105,50,49,54,
56,7,117,110,105,50,49,54,57,7,117,110,105,50,49,54,65,7,
117,110,105,50,49,54,66,7,117,110,105,50,49,54,67,7,117,110,
105,50,49,54,68,7,117,110,105,50,49,54,69,7,117,110,105,50,
49,54,70,7,117,110,105,50,49,55,48,7,117,110,105,50,49,55,
49,7,117,110,105,50,49,55,50,7,117,110,105,50,49,55,51,7,
117,110,105,50,49,55,52,7,117,110,105,50,49,55,53,7,117,110,
105,50,49,55,54,7,117,110,105,50,49,55,55,7,117,110,105,50,
49,55,56,7,117,110,105,50,49,55,57,7,117,110,105,50,49,55,
65,7,117,110,105,50,49,55,66,7,117,110,105,50,49,55,67,7,
117,110,105,50,49,55,68,7,117,110,105,50,49,55,69,7,117,110,
105,50,49,55,70,7,117,110,105,50,49,56,48,7,117,110,105,50,
49,56,49,7,117,110,105,50,49,56,50,7,117,110,105,50,49,56,
51,7,117,110,105,50,49,56,52,7,117,110,105,50,49,56,53,7,
117,110,105,50,49,56,54,7,117,110,105,50,49,56,57,9,97,114,
114,111,119,108,101,102,116,7,97,114,114,111,119,117,112,10,97,114,
114,111,119,114,105,103,104,116,9,97,114,114,111,119,100,111,119,110,
9,97,114,114,111,119,98,111,116,104,9,97,114,114,111,119,117,112,
100,110,7,117,110,105,50,49,57,54,7,117,110,105,50,49,57,55,
7,117,110,105,50,49,57,56,7,117,110,105,50,49,57,57,7,117,
110,105,50,49,57,65,7,117,110,105,50,49,57,66,7,117,110,105,
50,49,57,67,7,117,110,105,50,49,57,68,7,117,110,105,50,49,
57,69,7,117,110,105,50,49,57,70,7,117,110,105,50,49,65,48,
7,117,110,105,50,49,65,49,7,117,110,105,50,49,65,50,7,117,
110,105,50,49,65,51,7,117,110,105,50,49,65,52,7,117,110,105,
50,49,65,53,7,117,110,105,50,49,65,54,7,117,110,105,50,49,
65,55,12,97,114,114,111,119,117,112,100,110,98,115,101,7,117,110,
105,50,49,66,48,7,117,110,105,50,49,66,49,7,117,110,105,50,
49,66,50,7,117,110,105,50,49,66,51,7,117,110,105,50,49,66,
52,14,99,97,114,114,105,97,103,101,114,101,116,117,114,110,7,117,
110,105,50,49,66,54,7,117,110,105,50,49,66,55,7,117,110,105,
50,49,66,56,7,117,110,105,50,49,66,57,7,117,110,105,50,49,
66,65,7,117,110,105,50,49,66,66,7,117,110,105,50,49,66,67,
7,117,110,105,50,49,66,68,7,117,110,105,50,49,66,69,7,117,
110,105,50,49,66,70,7,117,110,105,50,49,67,48,7,117,110,105,
50,49,67,49,7,117,110,105,50,49,67,50,7,117,110,105,50,49,
67,51,7,117,110,105,50,49,67,52,7,117,110,105,50,49,67,53,
7,117,110,105,50,49,67,54,7,117,110,105,50,49,67,55,7,117,
110,105,50,49,67,56,7,117,110,105,50,49,67,57,7,117,110,105,
50,49,67,65,7,117,110,105,50,49,67,66,7,117,110,105,50,49,
67,67,9,117,110,105,118,101,114,115,97,108,11,101,120,105,115,116,
101,110,116,105,97,108,8,101,109,112,116,121,115,101,116,7,117,110,
105,50,50,48,54,8,103,114,97,100,105,101,110,116,7,117,110,105,
50,50,49,66,7,117,110,105,50,50,49,67,9,116,104,101,114,101,
102,111,114,101,7,115,105,109,105,108,97,114,9,99,111,110,103,114,
117,101,110,116,10,99,105,114,99,108,101,112,108,117,115,14,99,105,
114,99,108,101,109,117,108,116,105,112,108,121,7,117,110,105,50,50,
67,52,7,117,110,105,65,55,52,54,7,117,110,105,65,55,52,55,
7,117,110,105,69,48,57,53,7,117,110,105,69,48,57,54,7,117,
110,105,69,49,48,52,7,117,110,105,69,49,48,53,7,117,110,105,
69,49,48,54,7,117,110,105,69,49,49,56,7,117,110,105,69,49,
49,57,7,117,110,105,69,49,49,65,7,117,110,105,69,49,49,66,
7,117,110,105,69,49,49,67,7,117,110,105,69,49,49,68,7,117,
110,105,69,49,49,69,7,117,110,105,69,49,49,70,7,117,110,105,
69,49,50,48,7,117,110,105,69,49,50,49,7,117,110,105,69,50,
53,48,7,117,110,105,69,50,53,49,7,117,110,105,69,50,53,50,
7,117,110,105,69,50,53,51,7,117,110,105,69,50,53,52,7,117,
110,105,69,50,53,53,7,117,110,105,69,50,53,54,7,117,110,105,
69,50,53,55,7,117,110,105,69,50,53,56,7,117,110,105,69,50,
53,57,7,117,110,105,69,50,54,56,7,117,110,105,69,70,65,48,
7,117,110,105,69,70,65,49,7,117,110,105,69,70,65,50,7,117,
110,105,69,70,65,51,7,117,110,105,69,70,65,52,7,117,110,105,
69,70,65,53,7,117,110,105,69,70,65,54,7,117,110,105,69,70,
65,55,7,117,110,105,69,70,65,56,7,117,110,105,69,70,65,57,
7,117,110,105,69,70,65,65,7,117,110,105,69,70,65,66,7,117,
110,105,69,70,65,67,7,117,110,105,69,70,65,68,7,117,110,105,
69,70,66,48,7,117,110,105,69,70,66,49,7,117,110,105,69,70,
66,50,7,117,110,105,69,70,66,51,7,117,110,105,69,70,66,52,
7,117,110,105,69,70,66,53,7,117,110,105,69,70,66,54,7,117,
110,105,69,70,66,55,7,117,110,105,69,70,66,56,9,106,46,100,
111,116,108,101,115,115,7,117,110,105,70,56,69,53,7,117,110,105,
70,56,69,54,7,117,110,105,70,56,69,55,7,117,110,105,70,56,
70,49,7,117,110,105,70,56,70,51,0,0,0,0,0,1,255,255,
0,2,0,2,0,0,0,1,0,0,0,2,0,6,0,70,1,128,
0,6,0,36,0,0,0,0,0,11,0,3,0,3,0,10,0,5,
0,4,0,11,0,8,0,6,0,5,0,10,0,9,0,11,0,11,
0,11,17,11,0,12,0,12,31,11,0,13,0,13,0,11,0,14,
0,14,0,4,0,15,0,15,0,7,0,16,0,16,0,4,0,18,
0,17,0,7,0,28,0,19,0,3,0,29,0,29,0,7,0,30,
0,30,0,11,0,31,0,31,18,11,0,32,0,32,0,11,0,33,
0,33,30,11,0,35,0,34,0,11,0,62,0,62,18,11,0,63,
0,63,0,11,0,64,0,64,30,11,0,67,0,65,0,11,0,94,
0,94,18,11,0,95,0,95,0,11,0,96,0,96,30,11,0,98,
0,97,0,11,0,102,0,99,0,5,0,106,0,103,0,11,0,112,
0,108,0,11,0,114,0,113,0,5,0,116,0,115,0,3,0,117,
0,117,0,11,0,121,0,119,0,11,0,122,0,122,0,3,0,128,
0,124,0,11,0,152,0,152,0,11,0,184,0,184,0,11,1,79,
1,72,0,11,1,94,1,80,128,11,1,95,1,95,0,11,1,98,
1,96,128,11,1,101,1,100,0,11,2,74,2,70,0,10,2,95,
2,75,0,11,2,97,2,96,0,5,2,98,2,98,17,11,2,99,
2,99,31,11,2,102,2,100,0,11,2,103,2,103,0,7,2,119,
2,104,0,11,2,120,2,120,0,3,2,123,2,122,0,11,2,129,
2,124,0,3,2,131,2,130,0,4,2,132,2,132,0,11,2,133,
2,133,17,11,2,134,2,134,31,11,2,145,2,136,0,3,2,147,
2,146,0,4,2,148,2,148,0,11,2,149,2,149,17,11,2,150,
2,150,31,11,2,183,2,158,0,5,2,186,2,184,0,11,2,188,
2,188,0,5,2,201,2,189,0,11,3,47,2,241,0,11,3,48,
3,48,0,4,3,64,3,49,0,11,255,255,255,255,0,0,0,0,
0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,1,0,0,
0,36,0,0,1,0,0,1,0,1,0,0,0,40,0,0,1,1,
0,0,1,2,0,2,1,3,0,2,0,0,0,0,0,1,0,0,
0,1,0,0,1,8,0,0,0,4,0,0,0,1,0,1,0,2,
0,0,0,1,255,255,255,255,0,1,0,3,0,0,0,0,255,255,
255,254,0,0,0,0,255,255,255,255,255,255,255,255,0,0,0,1,
0,0,0,0,0,0,0,0,0,0,0,200,0,0,0,2,0,0,
0,1,0,0,0,8,0,0,0,28,0,0,0,66,0,0,0,130,
0,0,0,160,0,0,0,176,0,0,0,184,0,4,0,6,0,2,
0,12,0,1,0,0,0,45,0,44,0,30,0,77,0,76,0,34,
255,255,255,255,0,0,0,4,0,5,0,6,0,7,0,0,0,0,
0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,
0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,
0,1,0,3,0,2,0,0,0,0,0,0,0,0,0,0,0,1,
0,0,0,2,0,4,0,0,0,0,0,0,0,2,128,0,0,0,
0,3,128,0,0,0,0,0,160,0,0,0,0,0,160,0,0,2,
63,255,255,211,191,255,255,213,63,255,255,181,191,255,255,183,0,0,
0,0,0,0,0,1,0,243,0,244,0,0,0,1,0,0,0,0,
201,137,111,49,0,0,0,0,193,173,138,185,0,0,0,0,203,255,
3,53,
};
#define NFONTS 3
static fontdef_t fontdefs[NFONTS]= {
{ fontdata0, 16 },
{ fontdata1, 16 },
{ fontdata1, 54 },
};


static font_t fonts[NFONTS];

/*****************
  Scale has to be computed in a very careful way. A font may contain a
  lot of characters from different languages, all of which may not be 
  of our concern. For example, if a font contains mathematical symbols,
  the tall integral sign affects the whole font. And if you specify that
  all glyphs should fit in a given height, the system will fit the
  integral sign to that height and normal characters will be much smaller.
  A better way to find the scale is to look at some typical characters.
  For example, the descent of jpgyq can be combined with ascent of 
  M1KTF. The total of these two values can be scaled to fit within a
  certain height. 
 *****************/

static void compute_chr_vmetrics
   (stbtt_fontinfo *info, int chr, int *rA, int *rD)
{
  int x0, y0, x1, y1;
  int A, D;
  x0= y0= x1= y1= 0; // shut up the compiler about possible uninitval
  stbtt_GetCodepointBox(info, chr, &x0,&y0,&x1,&y1);
  if (y0<0) A= -y0; else A= 0;
  if (y1<0) D=   0; else D= y1;
  if (rA) *rA= A;
  if (rD) *rD= D;
}

static void compute_str_vmetrics
  (stbtt_fontinfo *info, char *str, int *RmaxA, int *RmaxD)
{
  int maxA, maxD, A,D;
  maxA= maxD= 0;
  while(*str)
  {
    compute_chr_vmetrics(info, str[0], &A, &D);
    maxA= imax2(maxA, A);
    maxD= imax2(maxD, D);
    str++;
  }
  if (RmaxA) *RmaxA= maxA;
  if (RmaxD) *RmaxD= maxD;
}

static float compute_font_scale(stbtt_fontinfo *info,int pix)
{
  int A,D,H;
  compute_str_vmetrics(info, "ygqPMK1TFQpj",&A,&D);
  H= A + D;
  return  pix / (float) H;
}

static void fonts_init()
{
  int i;
  if (fonts[0].cache) return ;
  for(i=0;i<NFONTS;i++)
  {
    fonts[i].cache= womap_new();
    stbtt_InitFont(&fonts[i].finfo, fontdefs[i].data,
                   stbtt_GetFontOffsetForIndex(fontdefs[i].data,0));
    fonts[i].height= fontdefs[i].size * getdpi()/86;
    fonts[i].scale= compute_font_scale(&fonts[i].finfo,  fonts[i].height);
  }
  static int* htargets[]= { &font1height, &font2height, &font3height,
                            &font4height, &font5height, NULL };
  for(i=0;htargets[i];i++)
    if (i>=NFONTS) htargets[i][0]= fonts[0].height;
             else  htargets[i][0]= fonts[i].height;
}

/***********************************************************
  Implementing correct rendering in the general case is a 
  really complicated issue. All I will do is to ignore the
  case where the glyph extend outside its own box. For example,
  italics do this. I will implement something better later.
  For now, I need to do this as soon as possible. 

  I will render each character as individually, and then simply
  copy the whole thing into the combined buffer. The buffer
  will also hold the necessary spaces. 
 ***********************************************************/

static fchr_t* font_render_char(font_t *F, int chr)
{
  fchr_t *CC;
  int gindex; 
  int bw, bh,x,y,xoff,yoff,advance,lbearing, w,h;
  unsigned char *bmap, *big;
  CC= womap_find(F->cache, chr);
  if (CC) return CC;
  gindex= stbtt_FindGlyphIndex(&F->finfo, chr);
  if (!gindex) gindex= stbtt_FindGlyphIndex(&F->finfo, 'A');
  if (!gindex) gindex= 1; // I don't know man..
  xoff= yoff= w= h= 0; // shut the compiler up
  bmap= stbtt_GetGlyphBitmap(&F->finfo,0,F->scale, gindex, &w,&h, &xoff, &yoff);
  stbtt_GetGlyphHMetrics(&F->finfo,gindex,&advance, &lbearing);

  bw= 0;
  if (xoff<0) { bw= -xoff; xoff= 0;}

  bw= imax2(bw,imax2(xoff+w,advance*F->scale));
  bh= h;
  big= calloc(bw*bh,sizeof(big[0]));
  for(y=0;y<h;y++)
    for(x=0;x<w;x++)
      big[(x+xoff)+y*bw]= bmap[x+y*w];
  stbtt_FreeBitmap(bmap,NULL);
  
  CC= malloc(sizeof(*CC));
  CC->chr= chr;
  CC->width= bw; CC->height= bh;
  CC->data= big;
  CC->ascent= -yoff;
  CC->descent= h+yoff;
  womap_insert(F->cache, chr, CC);
  return CC;
}


static void font_render
        (font_t *F, uint32_t *str, size_t L,
        int *RW, int *RH, int *RA,
        unsigned char **Rdata)
{                                       
  fchr_t **chars;
  int i, x, y, maxA, maxD, w,h, cw, ch, ca, xx, yy;
  unsigned char *data, *cd;

  fonts_init();

  chars= alloca(L*sizeof(chars[0]));
  for(i=0;i<L;i++)
    chars[i]= font_render_char(F, str[i]);

  maxA= maxD= 0;
  w= 0;
  for(i=0;i<L;i++)
  {
    maxA= imax2(maxA, chars[i]->ascent);
    maxD= imax2(maxD, chars[i]->descent);
    w+= chars[i]->width;
  }
  h= maxA+maxD;

  if (RW) *RW= w;
  if (RH) *RH= h;
  if (RA) *RA= maxA;
  if (!Rdata) return ;

  *Rdata= data= calloc(w*h,sizeof(data[0]));
  xx= 0; yy= maxA;
  for(i=0;i<L;i++)
  {
    cw= chars[i]->width; ch= chars[i]->height; 
    ca= chars[i]->ascent; cd= chars[i]->data;
    for(y=0;y<ch;y++)
       for(x=0;x<cw;x++)
          data[ (xx+x) + (yy-ca+y)*w ]= cd[x+y*cw];
    xx+= cw;
  }
}

void* __unused_freetype_lib[]= {
stbtt_BakeFontBitmap, stbtt_GetBakedQuad, stbtt_GetScaledFontVMetrics,
stbtt_PackBegin, stbtt_PackEnd , stbtt_PackFontRange,
stbtt_PackSetOversampling, stbtt_PackSetSkipMissingCodepoints,
stbtt_GetPackedQuad, stbtt_GetNumberOfFonts, stbtt_GetFontVMetricsOS2,
stbtt_GetFontBoundingBox, stbtt_GetCodepointHMetrics,
stbtt_GetCodepointKernAdvance, stbtt_IsGlyphEmpty,
stbtt_GetCodepointShape, stbtt_FreeShape, stbtt_GetCodepointBitmap,
stbtt_MakeCodepointBitmap, stbtt_MakeCodepointBitmapSubpixelPrefilter,
stbtt_GetCodepointBitmapBox, stbtt_FreeSDF, stbtt_GetCodepointSDF,
stbtt_FindMatchingFont, stbtt_CompareUTF8toUTF16_bigendian,
stbtt_GetFontNameString,
};

static unsigned int *radio_on, *radio_off;

RES_COLOR(radio_bg,0xffededed, "Radio Button background");
RES_COLOR(radio_fg,0x00000000, "Radio Button foreground");
RES_INT(radio_pad_left,  2, "Radio Button left padding");
RES_INT(radio_pad_mid, 2, "Radio Button middle padding");

RES_GRAYIMG(Gradio_on, "Radio button ON image")
   15, 15,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0d,
    0x43,0x65,0x71,0x65,0x43,0x0d,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x38,0x89,0xc8,0xf0,0xff,0xf0,0xc8,
    0x89,0x38,0x00,0x00,0x00,0x00,0x00,0x38,0xa1,0xff,
    0xb4,0x82,0x71,0x82,0xb4,0xff,0xa1,0x38,0x00,0x00,
    0x00,0x0d,0x89,0xff,0x93,0x1b,0x5a,0x71,0x5a,0x1b,
    0x93,0xff,0x89,0x0d,0x00,0x00,0x43,0xc8,0xb4,0x1b,
    0x89,0xdd,0xff,0xdd,0x89,0x1b,0xb4,0xc8,0x43,0x00,
    0x00,0x65,0xf0,0x82,0x5a,0xdd,0xff,0xff,0xff,0xdd,
    0x5a,0x82,0xf0,0x65,0x00,0x00,0x71,0xff,0x71,0x71,
    0xff,0xff,0xff,0xff,0xff,0x71,0x71,0xff,0x71,0x00,
    0x00,0x65,0xf0,0x82,0x5a,0xdd,0xff,0xff,0xff,0xdd,
    0x5a,0x82,0xf0,0x65,0x00,0x00,0x43,0xc8,0xb4,0x1b,
    0x89,0xdd,0xff,0xdd,0x89,0x1b,0xb4,0xc8,0x43,0x00,
    0x00,0x0d,0x89,0xff,0x93,0x1b,0x5a,0x71,0x5a,0x1b,
    0x93,0xff,0x89,0x0d,0x00,0x00,0x00,0x38,0xa1,0xff,
    0xb4,0x82,0x71,0x82,0xb4,0xff,0xa1,0x38,0x00,0x00,
    0x00,0x00,0x00,0x38,0x89,0xc8,0xf0,0xff,0xf0,0xc8,
    0x89,0x38,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0d,
    0x43,0x65,0x71,0x65,0x43,0x0d,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,
RES_END

RES_GRAYIMG(Gradio_off,"Radio button OFF image")
   15, 15,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0d,
    0x43,0x65,0x71,0x65,0x43,0x0d,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x38,0x89,0xc8,0xf0,0xff,0xf0,0xc8,
    0x89,0x38,0x00,0x00,0x00,0x00,0x00,0x38,0xa1,0xff,
    0xb4,0x82,0x71,0x82,0xb4,0xff,0xa1,0x38,0x00,0x00,
    0x00,0x0d,0x89,0xff,0x93,0x39,0x00,0x00,0x00,0x39,
    0x93,0xff,0x89,0x0d,0x00,0x00,0x43,0xc8,0xb4,0x39,
    0x00,0x00,0x00,0x00,0x00,0x39,0xb4,0xc8,0x43,0x00,
    0x00,0x65,0xf0,0x82,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x82,0xf0,0x65,0x00,0x00,0x71,0xff,0x71,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x71,0xff,0x71,0x00,
    0x00,0x65,0xf0,0x82,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x82,0xf0,0x65,0x00,0x00,0x43,0xc8,0xb4,0x39,
    0x00,0x00,0x00,0x00,0x00,0x39,0xb4,0xc8,0x43,0x00,
    0x00,0x0d,0x89,0xff,0x93,0x39,0x00,0x00,0x00,0x39,
    0x93,0xff,0x89,0x0d,0x00,0x00,0x00,0x38,0xa1,0xff,
    0xb4,0x82,0x71,0x82,0xb4,0xff,0xa1,0x38,0x00,0x00,
    0x00,0x00,0x00,0x38,0x89,0xc8,0xf0,0xff,0xf0,0xc8,
    0x89,0x38,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0d,
    0x43,0x65,0x71,0x65,0x43,0x0d,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,
RES_END

static unsigned int  gfx_radio_width, gfx_radio_height;


static unsigned int *checkbox_ok, *checkbox_nok;

RES_COLOR(checkbox_bg,0xffededed, "Checkbox background");
RES_COLOR(checkbox_fg,0x00000000, "Checkbox foreground");
RES_INT(checkbox_pad_left,  2, "Checkbox left padding");
RES_INT(checkbox_pad_mid, 2, "Checkbox middle padding");

RES_GRAYIMG(Gcheckbox_ok, "Checkbox ON image")
   18, 18,
    0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
    0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0xff,0x00,0xff,0xff,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xdd,
    0x00,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xdd,0x00,0xff,
    0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0xff,0xff,0xdd,0xdd,0x00,0xff,0xff,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,
    0xff,0xff,0xdd,0x00,0x00,0xff,0xff,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0xdd,0xff,0xff,0xdd,
    0x00,0x00,0x00,0xff,0xff,0x00,0xff,0x00,0x00,0x00,
    0x00,0x00,0x00,0xdd,0xff,0xff,0xdd,0x00,0x00,0x00,
    0x00,0xff,0xff,0x00,0xff,0xff,0x00,0x00,0x00,0x00,
    0xdd,0xff,0xff,0xdd,0x00,0x00,0x00,0x00,0x00,0xff,
    0xff,0x00,0xdd,0xff,0xdd,0x00,0x00,0xdd,0xff,0xff,
    0xdd,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x00,
    0xdd,0xdd,0xff,0xdd,0xdd,0xff,0xff,0xff,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x00,0x00,0xdd,
    0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,0xdd,0xff,
    0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0xff,0xff,0x00,0x00,0x00,0x00,0xdd,0xff,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,
    0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,
    0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
    0xff,0xff,0xff,0xff,
RES_END

RES_GRAYIMG(Gcheckbox_nok,"Checkbox OFF image")
   18, 18,
    0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
    0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,
    0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,
    0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,
    0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,
    0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
    0xff,0xff,0xff,0xff,
RES_END

static unsigned int  gfx_checkbox_width, gfx_checkbox_height;


RES_COLORIMG(Hscroll_ind_left, "Left part of the scroll indicator (H)")
  2 | (1<<31), 15,
    0xff9a9694,0xff9a9694,0xff9a9694,0xffffffff,0xff9a9694,0xffffffff,
    0xff9a9694,0xffffffff,0xff9a9694,0xffffffff,0xff9a9694,0xffffffff,
    0xff9a9694,0xffffffff,0xff9a9694,0xffffffff,0xff9a9694,0xffffffff,
    0xff9a9694,0xffffffff,0xff9a9694,0xffffffff,0xff9a9694,0xffffffff,
    0xff9a9694,0xffffffff,0xff9a9694,0xffcdcbca,0xff9a9694,0xff9a9694,
RES_END
RES_COLORIMG(Hscroll_ind_mid, "Mid part of the scroll indicator (H)")
  1 | (1<<31), 15,
    0xff9a9694,0xffffffff,0xffe7e6e5,0xffe4e3e2,0xffe1e0df,0xffdedddc,
    0xffdcdad9,0xffd9d7d6,0xffd6d4d3,0xffd3d1d0,0xffd1cecd,0xffcecbca,
    0xffcbc9c7,0xffcdcbca,0xff9a9694,
RES_END
RES_COLORIMG(Hscroll_ind_right, "Right part of the scroll indicator (H)")
  2 | (1<<31), 15,
    0xff9a9694,0xff9a9694,0xffcdcbca,0xff9a9694,0xffcdcbca,0xff9a9694,
    0xffcdcbca,0xff9a9694,0xffcdcbca,0xff9a9694,0xffcdcbca,0xff9a9694,
    0xffcdcbca,0xff9a9694,0xffcdcbca,0xff9a9694,0xffcdcbca,0xff9a9694,
    0xffcdcbca,0xff9a9694,0xffcdcbca,0xff9a9694,0xffcdcbca,0xff9a9694,
    0xffcdcbca,0xff9a9694,0xffcdcbca,0xff9a9694,0xff9a9694,0xff9a9694,
RES_END
RES_COLORIMG(Hscroll_trough, "Gradient for horizontal scroll trough")
  1 | (1<<31), 15,
    0xffd9d7d6,0xffd6d6d3,0xffd9d9d6,0xffdcdcd9,0xffdfdfdc,0xffe2e2df,
    0xffe5e5e2,0xffe8e8e6,0xffebebe9,0xffeeeeec,0xfff1f1ef,0xfff4f4f2,
    0xfff7f7f5,0xfffafaf9,0xffd9d7d6,
RES_END
RES_COLORIMG(Vscroll_ind_top, "Top part of the scroll indicator (V)")
  15 | (1<<31), 2,
    0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,
    0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,
    0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffcdcbca,0xff9a9694,
RES_END
RES_COLORIMG(Vscroll_ind_mid, "Mid part of the scroll indicator (V)")
  15 | (1<<31), 1,
    0xff9a9694,0xffffffff,0xffe7e6e5,0xffe4e3e2,0xffe1e0df,0xffdedddc,
    0xffdcdad9,0xffd9d7d6,0xffd6d4d3,0xffd3d1d0,0xffd1cecd,0xffcecbca,
    0xffcbc9c7,0xffcdcbca,0xff9a9694,
RES_END
RES_COLORIMG(Vscroll_ind_bot, "Bottom part of the scroll indicator (V)")
  15 | (1<<31), 2,
    0xff9a9694,0xffcdcbca,0xffcdcbca,0xffcdcbca,0xffcdcbca,0xffcdcbca,
    0xffcdcbca,0xffcdcbca,0xffcdcbca,0xffcdcbca,0xffcdcbca,0xffcdcbca,
    0xffcdcbca,0xffcdcbca,0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,
    0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,
    0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,
RES_END
RES_COLORIMG(Vscroll_trough, "Gradient for vertical scroll trough")
  15 | (1<<31), 1,
    0xffd9d7d6,0xffd6d6d3,0xffd9d9d6,0xffdcdcd9,0xffdfdfdc,0xffe2e2df,
    0xffe5e5e2,0xffe8e8e6,0xffebebe9,0xffeeeeec,0xfff1f1ef,0xfff4f4f2,
    0xfff7f7f5,0xfffafaf9,0xffd9d7d6,
RES_END

RES_COLORIMG(scroll_nor_up, "Scroll bar normal up button")
  15 | (1<<31), 15,
    0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,
    0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,
    0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffcdcbca,0xff9a9694,
    0xff9a9694,0xffffffff,0xffe7e6e5,0xffe4e3e2,0xffe1e0df,0xffdedddb,
    0xffdbdad9,0xffd9d7d6,0xffd6d4d3,0xffd3d1d0,0xffd0cecd,0xffcdcbca,
    0xffcbc9c7,0xffcdcbca,0xff9a9694,0xff9a9694,0xffffffff,0xffe7e6e5,
    0xffe4e3e2,0xffe1e0df,0xffdedddb,0xffdbdad9,0xffd9d7d6,0xffd6d4d3,
    0xffd3d1d0,0xffd0cecd,0xffcdcbca,0xffcbc9c7,0xffcdcbca,0xff9a9694,
    0xff9a9694,0xffffffff,0xffe7e6e5,0xffe4e3e2,0xffe1e0df,0xffdedddb,
    0xffdbdad9,0xffd9d7d6,0xffd6d4d3,0xffd3d1d0,0xffd0cecd,0xffcdcbca,
    0xffcbc9c7,0xffcdcbca,0xff9a9694,0xff9a9694,0xffffffff,0xffe7e6e5,
    0xffe4e3e2,0xffe1e0df,0xffdedddb,0xffdbdad9,0xff444444,0xffd6d4d3,
    0xffd3d1d0,0xffd0cecd,0xffcdcbca,0xffcbc9c7,0xffcdcbca,0xff9a9694,
    0xff9a9694,0xffffffff,0xffe7e6e5,0xffe4e3e2,0xffe1e0df,0xffdedddc,
    0xff444444,0xff000000,0xff444444,0xffd3d1d0,0xffd0cecd,0xffcdcbca,
    0xffcbc9c7,0xffcdcbca,0xff9a9694,0xff9a9694,0xffffffff,0xffe7e6e5,
    0xffe4e3e2,0xffe1e0df,0xff444444,0xff000000,0xff000000,0xff000000,
    0xff444444,0xffd0cecd,0xffcdcbca,0xffcbc9c7,0xffcdcbca,0xff9a9694,
    0xff9a9694,0xffffffff,0xffe7e6e5,0xffe4e3e2,0xff444444,0xff000000,
    0xff000000,0xff000000,0xff000000,0xff000000,0xff444444,0xffcdcbca,
    0xffcbc9c7,0xffcdcbca,0xff9a9694,0xff9a9694,0xffffffff,0xffe7e6e5,
    0xffe4e3e2,0xffe1e0df,0xffdedddc,0xffdbdad9,0xffd9d7d6,0xffd6d4d3,
    0xffd3d1d0,0xffd0cecd,0xffcdcbca,0xffcbc9c7,0xffcdcbca,0xff9a9694,
    0xff9a9694,0xffffffff,0xffe7e6e5,0xffe4e3e2,0xffe1e0df,0xffdedddb,
    0xffdbdad9,0xffd9d7d6,0xffd6d4d3,0xffd3d1d0,0xffd0cecd,0xffcdcbca,
    0xffcbc9c7,0xffcdcbca,0xff9a9694,0xff9a9694,0xffffffff,0xffe7e6e5,
    0xffe4e3e2,0xffe1e0df,0xffdedddb,0xffdbdad9,0xffd9d7d6,0xffd6d4d3,
    0xffd3d1d0,0xffd0cecd,0xffcdcbca,0xffcbc9c7,0xffcdcbca,0xff9a9694,
    0xff9a9694,0xffffffff,0xffe7e6e5,0xffe4e3e2,0xffe1e0df,0xffdedddb,
    0xffdbdad9,0xffd9d7d6,0xffd6d4d3,0xffd3d1d0,0xffd0cecd,0xffcdcbca,
    0xffcbc9c7,0xffcdcaca,0xff9a9694,0xff9a9694,0xffcdcbca,0xffcdcaca,
    0xffcdcbca,0xffcdcbca,0xffcdcbca,0xffcdcbca,0xffcdcbca,0xffcdcbca,
    0xffcdcbca,0xffcdcbca,0xffcdcbca,0xffcdcbca,0xffcdcbca,0xff9a9694,
    0xff9a9694,0xff9a9694,0xff9a9594,0xff9a9694,0xff9a9694,0xff9a9694,
    0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,
    0xff9a9694,0xff9a9694,0xff9a9694,
RES_END
RES_COLORIMG(scroll_nor_down, "Scroll bar normal down button")
  15 | (1<<31), 15,
    0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,
    0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,
    0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffcdcbca,0xff9a9694,
    0xff9a9694,0xffffffff,0xffe7e6e5,0xffe4e3e2,0xffe1e0df,0xffdedddb,
    0xffdbdad9,0xffd9d7d6,0xffd6d4d3,0xffd3d1d0,0xffd0cecd,0xffcdcbca,
    0xffcbc9c7,0xffcdcbca,0xff9a9694,0xff9a9694,0xffffffff,0xffe7e6e5,
    0xffe4e3e2,0xffe1e0df,0xffdedddb,0xffdbdad9,0xffd9d7d6,0xffd6d4d3,
    0xffd3d1d0,0xffd0cecd,0xffcdcbca,0xffcbc9c7,0xffcdcbca,0xff9a9694,
    0xff9a9694,0xffffffff,0xffe7e6e5,0xffe4e3e2,0xffe1e0df,0xffdedddb,
    0xffdbdad9,0xffd9d7d6,0xffd6d4d3,0xffd3d1d0,0xffd0cecd,0xffcdcbca,
    0xffcbc9c7,0xffcdcbca,0xff9a9694,0xff9a9694,0xffffffff,0xffe7e6e5,
    0xffe4e3e2,0xffe1e0df,0xffdedddb,0xffdbdad9,0xffd9d7d6,0xffd6d4d3,
    0xffd3d1d0,0xffd0cecd,0xffcdcbca,0xffcbc9c7,0xffcdcbca,0xff9a9694,
    0xff9a9694,0xffffffff,0xffe7e6e5,0xffe4e3e2,0xff444444,0xff000000,
    0xff000000,0xff000000,0xff000000,0xff000000,0xff444444,0xffcdcbca,
    0xffcbc9c7,0xffcdcbca,0xff9a9694,0xff9a9694,0xffffffff,0xffe7e6e5,
    0xffe4e3e2,0xffe1e0df,0xff444444,0xff000000,0xff000000,0xff000000,
    0xff444444,0xffd0cecd,0xffcdcbca,0xffcbc9c7,0xffcdcbca,0xff9a9694,
    0xff9a9694,0xffffffff,0xffe7e6e5,0xffe4e3e2,0xffe1e0df,0xffdedddc,
    0xff444444,0xff000000,0xff444444,0xffd3d1d0,0xffd0cecd,0xffcdcbca,
    0xffcbc9c7,0xffcdcbca,0xff9a9694,0xff9a9694,0xffffffff,0xffe7e6e5,
    0xffe4e3e2,0xffe1e0df,0xffdedddc,0xffdbdad9,0xff444444,0xffd6d4d3,
    0xffd3d1d0,0xffd0cecd,0xffcdcbca,0xffcbc9c7,0xffcdcbca,0xff9a9694,
    0xff9a9694,0xffffffff,0xffe7e6e5,0xffe4e3e2,0xffe1e0df,0xffdedddb,
    0xffdbdad9,0xffd9d7d6,0xffd6d4d3,0xffd3d1d0,0xffd0cecd,0xffcdcbca,
    0xffcbc9c7,0xffcdcbca,0xff9a9694,0xff9a9694,0xffffffff,0xffe7e6e5,
    0xffe4e3e2,0xffe1e0df,0xffdedddb,0xffdbdad9,0xffd9d7d6,0xffd6d4d3,
    0xffd3d1d0,0xffd0cecd,0xffcdcbca,0xffcbc9c7,0xffcdcbca,0xff9a9694,
    0xff9a9694,0xffffffff,0xffe7e6e5,0xffe4e3e2,0xffe1e0df,0xffdedddb,
    0xffdbdad9,0xffd9d7d6,0xffd6d4d3,0xffd3d1d0,0xffd0cecd,0xffcdcbca,
    0xffcbc9c7,0xffcdcaca,0xff9a9694,0xff9a9694,0xffcdcbca,0xffcdcaca,
    0xffcdcbca,0xffcdcbca,0xffcdcbca,0xffcdcbca,0xffcdcbca,0xffcdcbca,
    0xffcdcbca,0xffcdcbca,0xffcdcbca,0xffcdcbca,0xffcdcbca,0xff9a9694,
    0xff9a9694,0xff9a9694,0xff9a9594,0xff9a9694,0xff9a9694,0xff9a9694,
    0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,
    0xff9a9694,0xff9a9694,0xff9a9694,
RES_END
RES_COLORIMG(scroll_dpd_up, "Scroll bar depressed up button")
  15 | (1<<31), 15,
    0xffd2d2cf,0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,
    0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,
    0xffa5a59f,0xffa5a59f,0xffd2d2cf,0xffa5a59f,0xffd2d2cf,0xffd2d2cf,
    0xffd2d2cf,0xffd2d2cf,0xffd2d2cf,0xffd2d2cf,0xffd2d2cf,0xffd2d2cf,
    0xffd2d2cf,0xffd2d2cf,0xffd2d2cf,0xffd2d2cf,0xffd2d2cf,0xffa5a59f,
    0xffa5a59f,0xffd2d2cf,0xffd9d9d6,0xffdcdcd9,0xffdfdfdc,0xffe2e2df,
    0xffe5e5e2,0xffe8e8e6,0xffebebe9,0xffeeeeec,0xfff1f1ef,0xfff4f4f2,
    0xfff7f7f6,0xffffffff,0xffa5a59f,0xffa5a59f,0xffd2d2cf,0xffd9d9d6,
    0xffdcdcd9,0xffdfdfdc,0xffe2e2df,0xffe5e5e2,0xffe8e8e6,0xffebebe9,
    0xffeeeeec,0xfff1f1ef,0xfff4f4f2,0xfff7f7f6,0xffffffff,0xffa5a59f,
    0xffa5a59f,0xffd2d2cf,0xffd9d9d6,0xffdcdcd9,0xffdfdfdc,0xffe2e2df,
    0xffe5e5e2,0xffe8e8e6,0xffebebe9,0xffeeeeec,0xfff1f1ef,0xfff4f4f2,
    0xfff7f7f6,0xffffffff,0xffa5a59f,0xffa5a59f,0xffd2d2cf,0xffd9d9d6,
    0xffdcdcd9,0xffdfdfdc,0xffe2e2df,0xffe5e5e2,0xff444444,0xffebebe9,
    0xffeeeeec,0xfff1f1ef,0xfff4f4f2,0xfff7f7f6,0xffffffff,0xffa5a59f,
    0xffa5a59f,0xffd2d2cf,0xffd9d9d6,0xffdcdcd9,0xffdfdfdc,0xffe2e2df,
    0xff444444,0xff000000,0xff444444,0xffeeeeec,0xfff1f1ef,0xfff4f4f2,
    0xfff7f7f6,0xffffffff,0xffa5a59f,0xffa5a59f,0xffd2d2cf,0xffd9d9d6,
    0xffdcdcd9,0xffdfdfdc,0xff444444,0xff000000,0xff000000,0xff000000,
    0xff444444,0xfff1f1ef,0xfff4f4f2,0xfff7f7f6,0xffffffff,0xffa5a59f,
    0xffa5a59f,0xffd2d2cf,0xffd9d9d6,0xffdcdcd9,0xff444444,0xff000000,
    0xff000000,0xff000000,0xff000000,0xff000000,0xff444444,0xfff4f4f2,
    0xfff7f7f6,0xffffffff,0xffa5a59f,0xffa5a59f,0xffd2d2cf,0xffd9d9d6,
    0xffdcdcd9,0xffdfdfdc,0xffe2e2df,0xffe5e5e2,0xffe8e8e6,0xffebebe9,
    0xffeeeeec,0xfff1f1ef,0xfff4f4f2,0xfff7f7f6,0xffffffff,0xffa5a59f,
    0xffa5a59f,0xffd2d2cf,0xffd9d9d6,0xffdcdcd9,0xffdfdfdc,0xffe2e2df,
    0xffe5e5e2,0xffe8e8e6,0xffebebe9,0xffeeeeec,0xfff1f1ef,0xfff4f4f2,
    0xfff7f7f6,0xffffffff,0xffa5a59f,0xffa5a59f,0xffd2d2cf,0xffd9d9d6,
    0xffdcdcd9,0xffdfdfdc,0xffe2e2df,0xffe5e5e2,0xffe8e8e6,0xffebebe9,
    0xffeeeeec,0xfff1f1ef,0xfff4f4f2,0xfff7f7f6,0xffffffff,0xffa5a59f,
    0xffa5a59f,0xffd2d2cf,0xffd9d9d6,0xffdcdcd9,0xffdfdfdc,0xffe2e2df,
    0xffe5e5e2,0xffe8e8e6,0xffebebe9,0xffeeeeec,0xfff1f1ef,0xfff4f4f2,
    0xfff7f7f6,0xffffffff,0xffa5a59f,0xffa5a59f,0xffd2d2cf,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffa5a59f,
    0xffd2d2cf,0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,
    0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,
    0xffa5a59f,0xffa5a59f,0xffd2d2cf,
RES_END
RES_COLORIMG(scroll_dpd_down, "Scroll bar depressed down button")
  15 | (1<<31), 15,
    0xffd2d2cf,0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,
    0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,
    0xffa5a59f,0xffa5a59f,0xffd2d2cf,0xffa5a59f,0xffd2d2cf,0xffd2d2cf,
    0xffd2d2cf,0xffd2d2cf,0xffd2d2cf,0xffd2d2cf,0xffd2d2cf,0xffd2d2cf,
    0xffd2d2cf,0xffd2d2cf,0xffd2d2cf,0xffd2d2cf,0xffd2d2cf,0xffa5a59f,
    0xffa5a59f,0xffd2d2cf,0xffd9d9d6,0xffdcdcd9,0xffdfdfdc,0xffe2e2df,
    0xffe5e5e2,0xffe8e8e6,0xffebebe9,0xffeeeeec,0xfff1f1ef,0xfff4f4f2,
    0xfff7f7f6,0xffffffff,0xffa5a59f,0xffa5a59f,0xffd2d2cf,0xffd9d9d6,
    0xffdcdcd9,0xffdfdfdc,0xffe2e2df,0xffe5e5e2,0xffe8e8e6,0xffebebe9,
    0xffeeeeec,0xfff1f1ef,0xfff4f4f2,0xfff7f7f6,0xffffffff,0xffa5a59f,
    0xffa5a59f,0xffd2d2cf,0xffd9d9d6,0xffdcdcd9,0xffdfdfdc,0xffe2e2df,
    0xffe5e5e2,0xffe8e8e6,0xffebebe9,0xffeeeeec,0xfff1f1ef,0xfff4f4f2,
    0xfff7f7f6,0xffffffff,0xffa5a59f,0xffa5a59f,0xffd2d2cf,0xffd9d9d6,
    0xffdcdcd9,0xffdfdfdc,0xffe2e2df,0xffe5e5e2,0xffe8e8e6,0xffebebe9,
    0xffeeeeec,0xfff1f1ef,0xfff4f4f2,0xfff7f7f6,0xffffffff,0xffa5a59f,
    0xffa5a59f,0xffd2d2cf,0xffd9d9d6,0xffdcdcd9,0xff444444,0xff000000,
    0xff000000,0xff000000,0xff000000,0xff000000,0xff444444,0xfff4f4f2,
    0xfff7f7f6,0xffffffff,0xffa5a59f,0xffa5a59f,0xffd2d2cf,0xffd9d9d6,
    0xffdcdcd9,0xffdfdfdc,0xff444444,0xff000000,0xff000000,0xff000000,
    0xff444444,0xfff1f1ef,0xfff4f4f2,0xfff7f7f6,0xffffffff,0xffa5a59f,
    0xffa5a59f,0xffd2d2cf,0xffd9d9d6,0xffdcdcd9,0xffdfdfdc,0xffe2e2df,
    0xff444444,0xff000000,0xff444444,0xffeeeeec,0xfff1f1ef,0xfff4f4f2,
    0xfff7f7f6,0xffffffff,0xffa5a59f,0xffa5a59f,0xffd2d2cf,0xffd9d9d6,
    0xffdcdcd9,0xffdfdfdc,0xffe2e2df,0xffe5e5e2,0xff444444,0xffebebe9,
    0xffeeeeec,0xfff1f1ef,0xfff4f4f2,0xfff7f7f6,0xffffffff,0xffa5a59f,
    0xffa5a59f,0xffd2d2cf,0xffd9d9d6,0xffdcdcd9,0xffdfdfdc,0xffe2e2df,
    0xffe5e5e2,0xffe8e8e6,0xffebebe9,0xffeeeeec,0xfff1f1ef,0xfff4f4f2,
    0xfff7f7f6,0xffffffff,0xffa5a59f,0xffa5a59f,0xffd2d2cf,0xffd9d9d6,
    0xffdcdcd9,0xffdfdfdc,0xffe2e2df,0xffe5e5e2,0xffe8e8e6,0xffebebe9,
    0xffeeeeec,0xfff1f1ef,0xfff4f4f2,0xfff7f7f6,0xffffffff,0xffa5a59f,
    0xffa5a59f,0xffd2d2cf,0xffd9d9d6,0xffdcdcd9,0xffdfdfdc,0xffe2e2df,
    0xffe5e5e2,0xffe8e8e6,0xffebebe9,0xffeeeeec,0xfff1f1ef,0xfff4f4f2,
    0xfff7f7f6,0xffffffff,0xffa5a59f,0xffa5a59f,0xffd2d2cf,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffa5a59f,
    0xffd2d2cf,0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,
    0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,
    0xffa5a59f,0xffa5a59f,0xffd2d2cf,
RES_END
RES_COLORIMG(scroll_nor_left, "Scroll bar normal left button")
  15 | (1<<31), 15,
    0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,
    0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,
    0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffcdcbca,0xff9a9694,
    0xff9a9694,0xffffffff,0xffe7e6e5,0xffe4e3e2,0xffe1e0df,0xffdedddb,
    0xffdbdad9,0xffd9d7d6,0xffd6d4d3,0xffd3d1d0,0xffd0cecd,0xffcdcbca,
    0xffcbc9c7,0xffcdcbca,0xff9a9694,0xff9a9694,0xffffffff,0xffe7e6e5,
    0xffe4e3e2,0xffe1e0df,0xffdedddb,0xffdbdad9,0xffd9d7d6,0xffd6d4d3,
    0xffd3d1d0,0xffd0cecd,0xffcdcbca,0xffcbc9c7,0xffcdcbca,0xff9a9694,
    0xff9a9694,0xffffffff,0xffe7e6e5,0xffe4e3e2,0xffe1e0df,0xffdedddb,
    0xffdbdad9,0xffd9d7d6,0xff444444,0xffd3d1d0,0xffd0cecd,0xffcdcbca,
    0xffcbc9c7,0xffcdcbca,0xff9a9694,0xff9a9694,0xffffffff,0xffe7e6e5,
    0xffe4e3e2,0xffe1e0df,0xffdedddb,0xffdbdad9,0xff444444,0xff000000,
    0xffd3d1d0,0xffd0cecd,0xffcdcbca,0xffcbc9c7,0xffcdcbca,0xff9a9694,
    0xff9a9694,0xffffffff,0xffe7e6e5,0xffe4e3e2,0xffe1e0df,0xffdedddc,
    0xff444444,0xff000000,0xff000000,0xffd3d1d0,0xffd0cecd,0xffcdcbca,
    0xffcbc9c7,0xffcdcbca,0xff9a9694,0xff9a9694,0xffffffff,0xffe7e6e5,
    0xffe4e3e2,0xffe1e0df,0xff444444,0xff000000,0xff000000,0xff000000,
    0xffd3d1d0,0xffd0cecd,0xffcdcbca,0xffcbc9c7,0xffcdcbca,0xff9a9694,
    0xff9a9694,0xffffffff,0xffe7e6e5,0xffe4e3e2,0xffe1e0df,0xffdedddc,
    0xff444444,0xff000000,0xff000000,0xffd3d1d0,0xffd0cecd,0xffcdcbca,
    0xffcbc9c7,0xffcdcbca,0xff9a9694,0xff9a9694,0xffffffff,0xffe7e6e5,
    0xffe4e3e2,0xffe1e0df,0xffdedddc,0xffdbdad9,0xff444444,0xff000000,
    0xffd3d1d0,0xffd0cecd,0xffcdcbca,0xffcbc9c7,0xffcdcbca,0xff9a9694,
    0xff9a9694,0xffffffff,0xffe7e6e5,0xffe4e3e2,0xffe1e0df,0xffdedddb,
    0xffdbdad9,0xffd9d7d6,0xff444444,0xffd3d1d0,0xffd0cecd,0xffcdcbca,
    0xffcbc9c7,0xffcdcbca,0xff9a9694,0xff9a9694,0xffffffff,0xffe7e6e5,
    0xffe4e3e2,0xffe1e0df,0xffdedddb,0xffdbdad9,0xffd9d7d6,0xffd6d4d3,
    0xffd3d1d0,0xffd0cecd,0xffcdcbca,0xffcbc9c7,0xffcdcbca,0xff9a9694,
    0xff9a9694,0xffffffff,0xffe7e6e5,0xffe4e3e2,0xffe1e0df,0xffdedddb,
    0xffdbdad9,0xffd9d7d6,0xffd6d4d3,0xffd3d1d0,0xffd0cecd,0xffcdcbca,
    0xffcbc9c7,0xffcdcaca,0xff9a9694,0xff9a9694,0xffcdcbca,0xffcdcaca,
    0xffcdcbca,0xffcdcbca,0xffcdcbca,0xffcdcbca,0xffcdcbca,0xffcdcbca,
    0xffcdcbca,0xffcdcbca,0xffcdcbca,0xffcdcbca,0xffcdcbca,0xff9a9694,
    0xff9a9694,0xff9a9694,0xff9a9594,0xff9a9694,0xff9a9694,0xff9a9694,
    0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,
    0xff9a9694,0xff9a9694,0xff9a9694,
RES_END
RES_COLORIMG(scroll_nor_right, "Scroll bar normal right button")
  15 | (1<<31), 15,
    0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,
    0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,
    0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffcdcbca,0xff9a9694,
    0xff9a9694,0xffffffff,0xffe7e6e5,0xffe4e3e2,0xffe1e0df,0xffdedddb,
    0xffdbdad9,0xffd9d7d6,0xffd6d4d3,0xffd3d1d0,0xffd0cecd,0xffcdcbca,
    0xffcbc9c7,0xffcdcbca,0xff9a9694,0xff9a9694,0xffffffff,0xffe7e6e5,
    0xffe4e3e2,0xffe1e0df,0xffdedddb,0xffdbdad9,0xffd9d7d6,0xffd6d4d3,
    0xffd3d1d0,0xffd0cecd,0xffcdcbca,0xffcbc9c7,0xffcdcbca,0xff9a9694,
    0xff9a9694,0xffffffff,0xffe7e6e5,0xffe4e3e2,0xffe1e0df,0xffdedddb,
    0xff444444,0xffd9d7d6,0xffd6d4d3,0xffd3d1d0,0xffd0cecd,0xffcdcbca,
    0xffcbc9c7,0xffcdcbca,0xff9a9694,0xff9a9694,0xffffffff,0xffe7e6e5,
    0xffe4e3e2,0xffe1e0df,0xffdedddb,0xff000000,0xff444444,0xffd6d4d3,
    0xffd3d1d0,0xffd0cecd,0xffcdcbca,0xffcbc9c7,0xffcdcbca,0xff9a9694,
    0xff9a9694,0xffffffff,0xffe7e6e5,0xffe4e3e2,0xffe1e0df,0xffdedddc,
    0xff000000,0xff000000,0xff444444,0xffd3d1d0,0xffd0cecd,0xffcdcbca,
    0xffcbc9c7,0xffcdcbca,0xff9a9694,0xff9a9694,0xffffffff,0xffe7e6e5,
    0xffe4e3e2,0xffe1e0df,0xffdedddc,0xff000000,0xff000000,0xff000000,
    0xff444444,0xffd0cecd,0xffcdcbca,0xffcbc9c7,0xffcdcbca,0xff9a9694,
    0xff9a9694,0xffffffff,0xffe7e6e5,0xffe4e3e2,0xffe1e0df,0xffdedddc,
    0xff000000,0xff000000,0xff444444,0xffd3d1d0,0xffd0cecd,0xffcdcbca,
    0xffcbc9c7,0xffcdcbca,0xff9a9694,0xff9a9694,0xffffffff,0xffe7e6e5,
    0xffe4e3e2,0xffe1e0df,0xffdedddc,0xff000000,0xff444444,0xffd6d4d3,
    0xffd3d1d0,0xffd0cecd,0xffcdcbca,0xffcbc9c7,0xffcdcbca,0xff9a9694,
    0xff9a9694,0xffffffff,0xffe7e6e5,0xffe4e3e2,0xffe1e0df,0xffdedddb,
    0xff444444,0xffd9d7d6,0xffd6d4d3,0xffd3d1d0,0xffd0cecd,0xffcdcbca,
    0xffcbc9c7,0xffcdcbca,0xff9a9694,0xff9a9694,0xffffffff,0xffe7e6e5,
    0xffe4e3e2,0xffe1e0df,0xffdedddb,0xffdbdad9,0xffd9d7d6,0xffd6d4d3,
    0xffd3d1d0,0xffd0cecd,0xffcdcbca,0xffcbc9c7,0xffcdcbca,0xff9a9694,
    0xff9a9694,0xffffffff,0xffe7e6e5,0xffe4e3e2,0xffe1e0df,0xffdedddb,
    0xffdbdad9,0xffd9d7d6,0xffd6d4d3,0xffd3d1d0,0xffd0cecd,0xffcdcbca,
    0xffcbc9c7,0xffcdcaca,0xff9a9694,0xff9a9694,0xffcdcbca,0xffcdcaca,
    0xffcdcbca,0xffcdcbca,0xffcdcbca,0xffcdcbca,0xffcdcbca,0xffcdcbca,
    0xffcdcbca,0xffcdcbca,0xffcdcbca,0xffcdcbca,0xffcdcbca,0xff9a9694,
    0xff9a9694,0xff9a9694,0xff9a9594,0xff9a9694,0xff9a9694,0xff9a9694,
    0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,
    0xff9a9694,0xff9a9694,0xff9a9694,
RES_END
RES_COLORIMG(scroll_dpd_left, "Scroll bar depressed left button")
  15 | (1<<31), 15,
    0xffd2d2cf,0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,
    0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,
    0xffa5a59f,0xffa5a59f,0xffd2d2cf,0xffa5a59f,0xffd2d2cf,0xffd2d2cf,
    0xffd2d2cf,0xffd2d2cf,0xffd2d2cf,0xffd2d2cf,0xffd2d2cf,0xffd2d2cf,
    0xffd2d2cf,0xffd2d2cf,0xffd2d2cf,0xffd2d2cf,0xffd2d2cf,0xffa5a59f,
    0xffa5a59f,0xffd2d2cf,0xffd9d9d6,0xffdcdcd9,0xffdfdfdc,0xffe2e2df,
    0xffe5e5e2,0xffe8e8e6,0xffebebe9,0xffeeeeec,0xfff1f1ef,0xfff4f4f2,
    0xfff7f7f6,0xffffffff,0xffa5a59f,0xffa5a59f,0xffd2d2cf,0xffd9d9d6,
    0xffdcdcd9,0xffdfdfdc,0xffe2e2df,0xffe5e5e2,0xffe8e8e6,0xffebebe9,
    0xffeeeeec,0xfff1f1ef,0xfff4f4f2,0xfff7f7f6,0xffffffff,0xffa5a59f,
    0xffa5a59f,0xffd2d2cf,0xffd9d9d6,0xffdcdcd9,0xffdfdfdc,0xffe2e2df,
    0xffe5e5e2,0xffe8e8e6,0xff444444,0xffeeeeec,0xfff1f1ef,0xfff4f4f2,
    0xfff7f7f6,0xffffffff,0xffa5a59f,0xffa5a59f,0xffd2d2cf,0xffd9d9d6,
    0xffdcdcd9,0xffdfdfdc,0xffe2e2df,0xffe5e5e2,0xff444444,0xff000000,
    0xffeeeeec,0xfff1f1ef,0xfff4f4f2,0xfff7f7f6,0xffffffff,0xffa5a59f,
    0xffa5a59f,0xffd2d2cf,0xffd9d9d6,0xffdcdcd9,0xffdfdfdc,0xffe2e2df,
    0xff444444,0xff000000,0xff000000,0xffeeeeec,0xfff1f1ef,0xfff4f4f2,
    0xfff7f7f6,0xffffffff,0xffa5a59f,0xffa5a59f,0xffd2d2cf,0xffd9d9d6,
    0xffdcdcd9,0xffdfdfdc,0xff444444,0xff000000,0xff000000,0xff000000,
    0xffeeeeec,0xfff1f1ef,0xfff4f4f2,0xfff7f7f6,0xffffffff,0xffa5a59f,
    0xffa5a59f,0xffd2d2cf,0xffd9d9d6,0xffdcdcd9,0xffdfdfdc,0xffe2e2df,
    0xff444444,0xff000000,0xff000000,0xffeeeeec,0xfff1f1ef,0xfff4f4f2,
    0xfff7f7f6,0xffffffff,0xffa5a59f,0xffa5a59f,0xffd2d2cf,0xffd9d9d6,
    0xffdcdcd9,0xffdfdfdc,0xffe2e2df,0xffe5e5e2,0xff444444,0xff000000,
    0xffeeeeec,0xfff1f1ef,0xfff4f4f2,0xfff7f7f6,0xffffffff,0xffa5a59f,
    0xffa5a59f,0xffd2d2cf,0xffd9d9d6,0xffdcdcd9,0xffdfdfdc,0xffe2e2df,
    0xffe5e5e2,0xffe8e8e6,0xff444444,0xffeeeeec,0xfff1f1ef,0xfff4f4f2,
    0xfff7f7f6,0xffffffff,0xffa5a59f,0xffa5a59f,0xffd2d2cf,0xffd9d9d6,
    0xffdcdcd9,0xffdfdfdc,0xffe2e2df,0xffe5e5e2,0xffe8e8e6,0xffebebe9,
    0xffeeeeec,0xfff1f1ef,0xfff4f4f2,0xfff7f7f6,0xffffffff,0xffa5a59f,
    0xffa5a59f,0xffd2d2cf,0xffd9d9d6,0xffdcdcd9,0xffdfdfdc,0xffe2e2df,
    0xffe5e5e2,0xffe8e8e6,0xffebebe9,0xffeeeeec,0xfff1f1ef,0xfff4f4f2,
    0xfff7f7f6,0xffffffff,0xffa5a59f,0xffa5a59f,0xffd2d2cf,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffa5a59f,
    0xffd2d2cf,0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,
    0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,
    0xffa5a59f,0xffa5a59f,0xffd2d2cf,
RES_END
RES_COLORIMG(scroll_dpd_right, "Scroll bar depressed right button")
  15 | (1<<31), 15,
    0xffd2d2cf,0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,
    0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,
    0xffa5a59f,0xffa5a59f,0xffd2d2cf,0xffa5a59f,0xffd2d2cf,0xffd2d2cf,
    0xffd2d2cf,0xffd2d2cf,0xffd2d2cf,0xffd2d2cf,0xffd2d2cf,0xffd2d2cf,
    0xffd2d2cf,0xffd2d2cf,0xffd2d2cf,0xffd2d2cf,0xffd2d2cf,0xffa5a59f,
    0xffa5a59f,0xffd2d2cf,0xffd9d9d6,0xffdcdcd9,0xffdfdfdc,0xffe2e2df,
    0xffe5e5e2,0xffe8e8e6,0xffebebe9,0xffeeeeec,0xfff1f1ef,0xfff4f4f2,
    0xfff7f7f6,0xffffffff,0xffa5a59f,0xffa5a59f,0xffd2d2cf,0xffd9d9d6,
    0xffdcdcd9,0xffdfdfdc,0xffe2e2df,0xffe5e5e2,0xffe8e8e6,0xffebebe9,
    0xffeeeeec,0xfff1f1ef,0xfff4f4f2,0xfff7f7f6,0xffffffff,0xffa5a59f,
    0xffa5a59f,0xffd2d2cf,0xffd9d9d6,0xffdcdcd9,0xffdfdfdc,0xffe2e2df,
    0xff444444,0xffe8e8e6,0xffebebe9,0xffeeeeec,0xfff1f1ef,0xfff4f4f2,
    0xfff7f7f6,0xffffffff,0xffa5a59f,0xffa5a59f,0xffd2d2cf,0xffd9d9d6,
    0xffdcdcd9,0xffdfdfdc,0xffe2e2df,0xff000000,0xff444444,0xffebebe9,
    0xffeeeeec,0xfff1f1ef,0xfff4f4f2,0xfff7f7f6,0xffffffff,0xffa5a59f,
    0xffa5a59f,0xffd2d2cf,0xffd9d9d6,0xffdcdcd9,0xffdfdfdc,0xffe2e2df,
    0xff000000,0xff000000,0xff444444,0xffeeeeec,0xfff1f1ef,0xfff4f4f2,
    0xfff7f7f6,0xffffffff,0xffa5a59f,0xffa5a59f,0xffd2d2cf,0xffd9d9d6,
    0xffdcdcd9,0xffdfdfdc,0xffe2e2df,0xff000000,0xff000000,0xff000000,
    0xff444444,0xfff1f1ef,0xfff4f4f2,0xfff7f7f6,0xffffffff,0xffa5a59f,
    0xffa5a59f,0xffd2d2cf,0xffd9d9d6,0xffdcdcd9,0xffdfdfdc,0xffe2e2df,
    0xff000000,0xff000000,0xff444444,0xffeeeeec,0xfff1f1ef,0xfff4f4f2,
    0xfff7f7f6,0xffffffff,0xffa5a59f,0xffa5a59f,0xffd2d2cf,0xffd9d9d6,
    0xffdcdcd9,0xffdfdfdc,0xffe2e2df,0xff000000,0xff444444,0xffebebe9,
    0xffeeeeec,0xfff1f1ef,0xfff4f4f2,0xfff7f7f6,0xffffffff,0xffa5a59f,
    0xffa5a59f,0xffd2d2cf,0xffd9d9d6,0xffdcdcd9,0xffdfdfdc,0xffe2e2df,
    0xff444444,0xffe8e8e6,0xffebebe9,0xffeeeeec,0xfff1f1ef,0xfff4f4f2,
    0xfff7f7f6,0xffffffff,0xffa5a59f,0xffa5a59f,0xffd2d2cf,0xffd9d9d6,
    0xffdcdcd9,0xffdfdfdc,0xffe2e2df,0xffe5e5e2,0xffe8e8e6,0xffebebe9,
    0xffeeeeec,0xfff1f1ef,0xfff4f4f2,0xfff7f7f6,0xffffffff,0xffa5a59f,
    0xffa5a59f,0xffd2d2cf,0xffd9d9d6,0xffdcdcd9,0xffdfdfdc,0xffe2e2df,
    0xffe5e5e2,0xffe8e8e6,0xffebebe9,0xffeeeeec,0xfff1f1ef,0xfff4f4f2,
    0xfff7f7f6,0xffffffff,0xffa5a59f,0xffa5a59f,0xffd2d2cf,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffa5a59f,
    0xffd2d2cf,0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,
    0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,
    0xffa5a59f,0xffa5a59f,0xffd2d2cf,
RES_END

/* The following has two functions: when called with a NULL scrollbar,
   it sets the gui_scrollbar_width/_height variables so that the layout
   engines can do their stuff. If SB is not NULL, then it assigns the
   images to the scrollbar, depending on the orientation */

static unsigned int gui_scrollbar_width;
static unsigned int gui_scrollbar_height;


RES_INT(dropdown_list_padv, 2, "");
RES_INT(dropdown_list_spc, 2, "");
RES_COLOR(dropdown_list_hcolor, 0xFF0088ff, "");
RES_COLOR(dropdown_list_border, 0xcccac9, "");


static int gui_list_pad_horz= 2,
           gui_list_pad_vert= 2,
           gui_list_icontext_sep= 2,
           gui_list_spacing= 2,
           gui_list_border= 0x888888;


static uint32_t TE_fg        = 0;
static uint32_t TE_bg        = 0xffffff;
static uint32_t TE_cfg       = 0xffffff;
static uint32_t TE_cbg       = 0x000088;


RES_COLOR(confirm_bg, 0xcece88, "background color for confirmation dialog");
RES_COLOR(confirm_fg, 0x000000, "foreground color for confirmation dialog");
RES_INT(dialog_spacing, 10, 
                      "Padding between widgets in the confirmation dialog");


RES_INT(filesel_pad,10,"Padding between widgets in file selector");
RES_INT(filesel_ipad,6,"Internal padding for buttons in file selector");
RES_COLOR(filesel_bg, 0xbcbcbc, "Background color for file selector dialog");
RES_COLOR(filesel_fg, 0x000000, "Foreground color for file selector title");

RES_STRING(filesel_lbl_ok,"OK","Label for OK button");

RES_STRING(filesel_lbl_cancel, "Cancel", "Label for Cancel button");
RES_STRING(filesel_lbl_refresh, "Refresh", "Label for Refresh button");
RES_STRING(filesel_lbl_home, "Home", "Label for Home button");
RES_STRING(filesel_lbl_load, "Select File to Load", "File selector load mode title");
RES_STRING(filesel_lbl_save, "Select File to Save", "File selector write mode title");

RES_INT(filesel_dirst_pad , 6, "File selector padding between directory stack buttons");
RES_INT(filesel_dirst_ipad, 6, "File selector internal padding for directory stack buttons");
RES_INT(filesel_dirst_left, 10, "File selector directory stack left padding");


static int spinner_lessb_width, spinner_moreb_width;

RES_COLORIMG(RESspinLESS,"Spinner: Icon for the less button")
  16 | (1<<31), 16,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0xff000000,0xff000000,0xff000000,0xff000000,
    0xff000000,0xff000000,0xff000000,0xff000000,0xff000000,0xff000000,
    0xff000000,0xff000000,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0xff000000,0xff000000,0xff000000,0xff000000,0xff000000,0xff000000,
    0xff000000,0xff000000,0xff000000,0xff000000,0xff000000,0xff000000,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0xff000000,0xff000000,
    0xff000000,0xff000000,0xff000000,0xff000000,0xff000000,0xff000000,
    0xff000000,0xff000000,0xff000000,0xff000000,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0xff000000,0xff000000,0xff000000,0xff000000,
    0xff000000,0xff000000,0xff000000,0xff000000,0xff000000,0xff000000,
    0xff000000,0xff000000,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
RES_END


RES_COLORIMG(RESspinMORE,"Spinner: Icon for the more button")
  16 | (1<<31), 16,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0xff000000,0xff000000,0xff000000,0xff000000,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0xff000000,0xff000000,0xff000000,0xff000000,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0xff000000,0xff000000,
    0xff000000,0xff000000,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0xff000000,0xff000000,0xff000000,0xff000000,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0xff000000,0xff000000,0xff000000,0xff000000,
    0xff000000,0xff000000,0xff000000,0xff000000,0xff000000,0xff000000,
    0xff000000,0xff000000,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0xff000000,0xff000000,0xff000000,0xff000000,0xff000000,0xff000000,
    0xff000000,0xff000000,0xff000000,0xff000000,0xff000000,0xff000000,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0xff000000,0xff000000,
    0xff000000,0xff000000,0xff000000,0xff000000,0xff000000,0xff000000,
    0xff000000,0xff000000,0xff000000,0xff000000,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0xff000000,0xff000000,0xff000000,0xff000000,
    0xff000000,0xff000000,0xff000000,0xff000000,0xff000000,0xff000000,
    0xff000000,0xff000000,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0xff000000,0xff000000,
    0xff000000,0xff000000,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0xff000000,0xff000000,0xff000000,0xff000000,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0xff000000,0xff000000,0xff000000,0xff000000,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0xff000000,0xff000000,
    0xff000000,0xff000000,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
RES_END


RES_COLOR(logview_background,0xffffff,"Background color for logview");
RES_INT(logview_pad, 4, "Padding around content for logview");
RES_COLOR(logview_foreground,0x00,"Foreground color for logview");


static int logwidget= -1;


RES_COLORIMG(Hslider_tro_left, "Slider trough:left")
1 | (1<<31), 4,0xff9c9c9c,0xffb0b0b0,0xffb0b0b0,0xffeeefef,
RES_END
RES_COLORIMG(Hslider_tro_right, "Slider trough:right")
1 | (1<<31), 4,0xffeeefef,0xfffdfddd,0xfffdfddd,0xfffdfddd,
RES_END
RES_COLORIMG(Hslider_tro_mid, "Horizontal slider trough:hmid")
1 | (1<<31), 4,0xffb0b0b0,0xffe7eaea,0xffe7eaea,0xffffffff,
RES_END

RES_COLORIMG(Hslider_button, "Horizontal slider button")
11 | (1<<31), 19,0xff707070,0xff707070,0xff707070,0xff707070,0xff707070,0xff707070,0xff707070,0xff707070,0xff707070,0xff707070,0xff707070,0xff707070,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xff707070,0xff707070,0xffffffff,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffffffff,0xff707070,0xff707070,0xffffffff,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffffffff,0xff707070,0xff707070,0xffffffff,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffffffff,0xff707070,0xff707070,0xffffffff,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffffffff,0xff707070,0xff707070,0xffffffff,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffffffff,0xff707070,0xff707070,0xffffffff,0xffeeeeee,0xffeeeeee,0xffd6d6d6,0xffeeeeee,0xffd6d6d6,0xffeeeeee,0xffeeeeee,0xffffffff,0xff707070,0xff707070,0xffffffff,0xffeeeeee,0xffd6d6d6,0xffeeeeee,0xffd6d6d6,0xffeeeeee,0xffd6d6d6,0xffeeeeee,0xffffffff,0xff707070,0xff707070,0xffffffff,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffffffff,0xff707070,0xff707070,0xffffffff,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffffffff,0xff707070,0xff707070,0xffffffff,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffffffff,0xff707070,0xff707070,0xffffffff,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffffffff,0xff707070,0xff707070,0xffffffff,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffffffff,0xff707070,0xffb6b6b6,0xff707070,0xffffffff,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffffffff,0xff707070,0xffb6b6b6,0x00000000,0xffb2b2b2,0xff707070,0xffffffff,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffffffff,0xff707070,0xffb2b2b2,0x00000000,0x00000000,0x00000000,0xffb2b2b2,0xff707070,0xffffffff,0xffd6d6d6,0xffffffff,0xff707070,0xffb2b2b2,0x00000000,0x00000000,0x00000000,0x00000000,0x00000000,0xffb2b2b2,0xff707070,0xffffffff,0xff707070,0xffb2b2b2,0x00000000,0x00000000,0x00000000,0x00000000,0x00000000,0x00000000,0x00000000,0xffb2b2b2,0xff707070,0xffb2b2b2,0x00000000,0x00000000,0x00000000,0x00000000,
RES_END
RES_COLORIMG(Hslider_button_depressed, "Horizontal slider button-depressed")
11 | (1<<31), 19,0xff707070,0xff707070,0xff707070,0xff707070,0xff707070,0xff707070,0xff707070,0xff707070,0xff707070,0xff707070,0xff707070,0xff707070,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xff707070,0xff707070,0xffffffff,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffffffff,0xff707070,0xff707070,0xffffffff,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffffffff,0xff707070,0xff707070,0xffffffff,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffffffff,0xff707070,0xff707070,0xffffffff,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffffffff,0xff707070,0xff707070,0xffffffff,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffffffff,0xff707070,0xff707070,0xffffffff,0xffd6d6d6,0xffd6d6d6,0xffeeeeee,0xffd6d6d6,0xffeeeeee,0xffd6d6d6,0xffd6d6d6,0xffffffff,0xff707070,0xff707070,0xffffffff,0xffd6d6d6,0xffeeeeee,0xffd6d6d6,0xffeeeeee,0xffd6d6d6,0xffeeeeee,0xffd6d6d6,0xffffffff,0xff707070,0xff707070,0xffffffff,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffffffff,0xff707070,0xff707070,0xffffffff,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffffffff,0xff707070,0xff707070,0xffffffff,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffffffff,0xff707070,0xff707070,0xffffffff,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffffffff,0xff707070,0xff707070,0xffffffff,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffffffff,0xff707070,0xffb6b6b6,0xff707070,0xffffffff,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffffffff,0xff707070,0xffb6b6b6,0x00000000,0xffb2b2b2,0xff707070,0xffffffff,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffffffff,0xff707070,0xffb2b2b2,0x00000000,0x00000000,0x00000000,0xffb2b2b2,0xff707070,0xffffffff,0xffeeeeee,0xffffffff,0xff707070,0xffb2b2b2,0x00000000,0x00000000,0x00000000,0x00000000,0x00000000,0xffb2b2b2,0xff707070,0xffffffff,0xff707070,0xffb2b2b2,0x00000000,0x00000000,0x00000000,0x00000000,0x00000000,0x00000000,0x00000000,0xffb2b2b2,0xff707070,0xffb2b2b2,0x00000000,0x00000000,0x00000000,0x00000000,
RES_END

RES_COLORIMG(Vslider_tro_top, "Slider trough:top")
4 | (1<<31), 1,0xff9c9c9c,0xffb0b0b0,0xffb0b0b0,0xffeeefef,
RES_END
RES_COLORIMG(Vslider_tro_bot, "Slider trough:bot")
4 | (1<<31), 1,0xffeeefef,0xfffdfddd,0xfffdfddd,0xfffdfddd,
RES_END
RES_COLORIMG(Vslider_tro_mid, "Vertical slider trough:mid")
4 | (1<<31), 1,0xffb0b0b0,0xffe7eaea,0xffe7eaea,0xffffffff,
RES_END
RES_COLORIMG(Vslider_button, "Vertical slider button")
19 | (1<<31), 11,0xff707070,0xff707070,0xff707070,0xff707070,0xff707070,0xff707070,0xff707070,0xff707070,0xff707070,0xff707070,0xff707070,0xff707070,0xff707070,0xff707070,0xffb6b6b6,0x00000000,0x00000000,0x00000000,0x00000000,0xff707070,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xff707070,0xffb2b2b2,0x00000000,0x00000000,0x00000000,0xff707070,0xffffffff,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffffffff,0xff707070,0xffb2b2b2,0x00000000,0x00000000,0xff707070,0xffffffff,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffffffff,0xff707070,0xffb2b2b2,0x00000000,0xff707070,0xffffffff,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffd6d6d6,0xffeeeeee,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffffffff,0xff707070,0xffb2b2b2,0xff707070,0xffffffff,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffffffff,0xff707070,0xff707070,0xffffffff,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffd6d6d6,0xffeeeeee,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffffffff,0xff707070,0xffb2b2b2,0xff707070,0xffffffff,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffffffff,0xff707070,0xffb2b2b2,0x00000000,0xff707070,0xffffffff,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffffffff,0xff707070,0xffb2b2b2,0x00000000,0x00000000,0xff707070,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xff707070,0xffb2b2b2,0x00000000,0x00000000,0x00000000,0xff707070,0xff707070,0xff707070,0xff707070,0xff707070,0xff707070,0xff707070,0xff707070,0xff707070,0xff707070,0xff707070,0xff707070,0xff707070,0xff707070,0xffb6b6b6,0x00000000,0x00000000,0x00000000,0x00000000,
RES_END
RES_COLORIMG(Vslider_button_depressed, "Vertical slider button-depressed")
19 | (1<<31), 11,0xff707070,0xff707070,0xff707070,0xff707070,0xff707070,0xff707070,0xff707070,0xff707070,0xff707070,0xff707070,0xff707070,0xff707070,0xff707070,0xff707070,0xffb6b6b6,0x00000000,0x00000000,0x00000000,0x00000000,0xff707070,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xff707070,0xffb2b2b2,0x00000000,0x00000000,0x00000000,0xff707070,0xffffffff,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffffffff,0xff707070,0xffb2b2b2,0x00000000,0x00000000,0xff707070,0xffffffff,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffffffff,0xff707070,0xffb2b2b2,0x00000000,0xff707070,0xffffffff,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffeeeeee,0xffd6d6d6,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffffffff,0xff707070,0xffb2b2b2,0xff707070,0xffffffff,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffffffff,0xff707070,0xff707070,0xffffffff,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffeeeeee,0xffd6d6d6,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffffffff,0xff707070,0xffb2b2b2,0xff707070,0xffffffff,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffffffff,0xff707070,0xffb2b2b2,0x00000000,0xff707070,0xffffffff,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffd6d6d6,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffeeeeee,0xffffffff,0xff707070,0xffb2b2b2,0x00000000,0x00000000,0xff707070,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xff707070,0xffb2b2b2,0x00000000,0x00000000,0x00000000,0xff707070,0xff707070,0xff707070,0xff707070,0xff707070,0xff707070,0xff707070,0xff707070,0xff707070,0xff707070,0xff707070,0xff707070,0xff707070,0xff707070,0xffb6b6b6,0x00000000,0x00000000,0x00000000,0x00000000,
RES_END


static usr_timer_t *usrtimers;
static int susrtimers, nusrtimers;


static womap_t *gfx_objid_map;
RES_INT(vkey_hspacing, 5, "Virtual keyboard horizontal spacing");
RES_INT(vkey_vspacing, 5, "Virtual keyboard vertical spacing");
RES_INT(vkey_vpadding, 12, "Virtual keyboard vertical padding");
RES_INT(vkey_hpadding, 12, "Virtual keyboard maximum horizontal padding");
static vkb_t *active_vk;


  RES_COLOR(buttonNOR_SHDlight, 0xffffff, 
                                "Button normal view shadow, light line");
  RES_COLOR(buttonNOR_SHDdark, 0xd5d5d1, "");
  RES_COLOR(buttonDPD_SHDlight, 0xd5d5d1,
                                "Button depressed view shadow, light line");
  RES_COLOR(buttonDPD_SHDdark, 0xffffff, "");
  RES_COLOR(buttonNOR_BRD, 0xaaaaa3, "Button border");
  RES_COLOR(buttonDPD_BRD, 0xaaaaa3, "");
  RES_COLOR(buttonNOR_GRDstart, 0xfcfcfb, "Button normal view, gradient start");
  RES_COLOR(buttonNOR_GRDend, 0xdbdbd7, "");
  RES_COLOR(buttonDPD_GRDstart,0xcccac9,"");
  RES_COLOR(buttonDPD_GRDend, 0xe9e8e7, "");
  RES_COLOR(button_FG, 0x000000, "");
  RES_INT(button_iconspc, 4, "Space between the icon and the text");

void *__gfx_library__unused_symbol_holder__[]= 
  { gui_canvas_new, gui_spinner, gui_logview, gfx_pixgrid, 
    dropdown_new, panel_new, gui_checkbox_new, radio_new,
    gui_slider_new, womap_destroy,
// imported utilities that could be removed
   buffer_append, mprintf, fdprintf, 
   path_child, path_relative, path_dir,
  gui_progressbar_new,

  gui_iconlist_new,


 gui_filelist_new,

  have_user_timer,
  elapsed_user_timer,

   graypix_sub, 
   clip_rrect,
   obj_put, obj_get, obj_remove,
  };
   // updates can be turned on and off, this can prevent flickering
   // situations
static int updates_on= 1;

  // This variable makes sense only for the Android platform.
  // However, it's used in layout code which is platform
  // independent. Therefore, it must exist no matter what the
  // platform is. On X11, it's defined to be 0 so that it
  // doesn't affect the layout there.
#ifdef GFX_ANDROID
static int gui_sysbar_height = 25;
#else
static int gui_sysbar_height = 0;
#endif
  //below comment is a MARK, do not remove
/** USER RESOURCES **/

/***********************************************************************
 *                                                                     *
 *                                CODE                                 *
 *                                                                     *
 ***********************************************************************/
#ifdef GFX_X11

/***********************************************************************
  In order to create images etc, we need to find a suitable visual 
  with depth==24 or depth==32.
 ***********************************************************************/
static uint32_t trailing_zero_bits(uint32_t Y)
{
  uint32_t shif;
  for(shif=0;Y%2==0;shif++) Y= Y>>1;
  return shif;
}

static int get_x_visual()
{
  int depth, ndepths, i;
  int *depths;
  XVisualInfo xvinfo;

  depths= XListDepths(x_display, x_screen_number, &ndepths);
  if (!depths) 
  {
    fprintf(stderr,"can't get depth list for display\n");
    return 1;
  }

  depth=0;
  for(i=0;i<ndepths;i++)
    if (depths[i]==32 || depths[i]==24)
    {
      depth= depths[i];
      break;
    }
  XFree(depths);

  if (!depth)
  {
    fprintf(stderr, "display doesn't support 24 or 32 bit depth.\n");
    return 1;
  }

  x_depth= depth;
  x_visual= NULL;
  if (XMatchVisualInfo(x_display, x_screen_number, depth, TrueColor,&xvinfo))
     x_visual= xvinfo.visual;
  else if (XMatchVisualInfo(x_display, x_screen_number,
                                       depth, DirectColor,&xvinfo))
     x_visual= xvinfo.visual;
  else
  {
    fprintf(stderr,"can't find a 24 or 32 bit TrueColor/DirectColor visual\n");
    return 1;
  }
  x_red_mask= x_visual->red_mask;
  x_red_shift= trailing_zero_bits(x_red_mask);
  x_green_mask= x_visual->green_mask;
  x_green_shift= trailing_zero_bits(x_green_mask);
  x_blue_mask= x_visual->blue_mask;
  x_blue_shift= trailing_zero_bits(x_blue_mask);
  return 0;
}

static Window create_window(char *title,int width, int height)
{
  int                  x,y;
  Window               window;
  XSetWindowAttributes attribs;
  XTextProperty        title_prop;
  XSizeHints          *size;

  x= (x_root_width-width)/2;
  y= (x_root_height-height)/2;

  attribs.background_pixmap= None;

  window= XCreateWindow(x_display, x_root_window,
                        x, y, width, height,
                        1, x_depth, InputOutput, x_visual, 
                        CWBackPixmap, &attribs);

  if (XStringListToTextProperty(&title, 1, &title_prop))
  {
    XSetWMName(x_display, window, &title_prop);
  }
  size= XAllocSizeHints();
  size->flags= PMinSize | PMaxSize;
  size->min_width= size->max_width= width;
  size->min_height= size->max_height= height;
  XSetWMNormalHints(x_display,window, size);

  unsigned long protos[4];

  wm_protocols= XInternAtom(x_display, "WM_PROTOCOLS", False);
  wm_delete_window= XInternAtom(x_display, "WM_DELETE_WINDOW", False);
  protos[0]= wm_delete_window;
  protos[1]= 0;
 
  XChangeProperty(x_display, window, wm_protocols, XA_ATOM, 32,
                  PropModeReplace, (unsigned char*)protos, 1);

  XFlush(x_display);
  XFree(size);

  return window;
}

static void get_root_attribs()
{
  x_screen_number= DefaultScreen(x_display);
  x_root_window= DefaultRootWindow(x_display);
  x_root_width= DisplayWidth(x_display, x_screen_number);
  x_root_height= DisplayHeight(x_display, x_screen_number);
}

int gfx_init(char *name, int width, int height, char *title)
{
  int y;

  x_display= XOpenDisplay(name);

  if (!x_display) 
  {
    //FIXME: log this
    fprintf(stderr,"can't open display\n");
    return 1;
  }
  get_root_attribs();
  if (get_x_visual())
  {
    XCloseDisplay(x_display);
    x_display= NULL;
    return 1;
  }
  x_window= create_window(title,width, height);
  XSelectInput(x_display, x_window, PointerMotionMask | KeyPressMask |
                                    ButtonPressMask |
                                    ButtonReleaseMask | ExposureMask );
                                    // StructureNotifyMask);

  x_pixmap= XCreatePixmap(x_display, x_window, width, height, x_depth);
  x_image= create_image(width, height);

  x_image_data= malloc(sizeof(uint32_t*) * height);
  for(y=0;y<height;y++)
    x_image_data[y]= (uint32_t*) ((char*) x_image->data + y*x_image->bpl);
  checker_pattern(x_image, 17);

  x_window_width= width;
  x_window_height= height;
   gfx_radio_width= Gradio_on[0];
   gfx_radio_height= Gradio_on[1];

   gfx_checkbox_width= Gcheckbox_ok[0];
   gfx_checkbox_height= Gcheckbox_ok[1];

  fonts_init();

  gfx_update_all();
#ifdef GFX_X11
  x_keyboard= x_keyboard_init(x_window);
#endif


  scrollbar_init_buttons(NULL);

  XMapWindow(x_display, x_window);
  return 0;
}


/***********************************************************************
 *                                                                     *
 *                           Image Functions                           *
 *                                                                     *
 ***********************************************************************/

static ximage_t *create_image(uint32_t width, uint32_t height)
{
  ximage_t *image;
  size_t data_size;
  struct shmid_ds dummy_shmid_ds;

  if (!can_use_shared_images()) goto fail_nolib;

  image= calloc(1,sizeof(*image));
  image->width= width;
  image->height= height;
  image->shared= 1;

  // Create the image on the server
  //
  image->x11image= XShmCreateImage(x_display,x_visual, x_depth, ZPixmap,
                                   NULL, &image->shminfo, width, height);
  if (!image->x11image) goto fail_create;

  image->bpl= image->x11image->bytes_per_line;
  data_size= height*image->bpl;

  // Create the shared memory area
  //
  image->shminfo.shmid= shmget(IPC_PRIVATE, data_size, IPC_CREAT | 0777);
  if (image->shminfo.shmid <0)
  {
    fprintf(stderr,"can't shmget shared memory\n");
    goto fail_shmcreate;
  }
  
  image->shminfo.shmaddr= shmat(image->shminfo.shmid,0,0);
   // we remove the ID now, so that when the program exits, the memory
   // will be automatically freed
   //
  shmctl(image->shminfo.shmid, IPC_RMID, &dummy_shmid_ds); 
  if (image->shminfo.shmaddr==(char*) -1) 
  {
    fprintf(stderr,"can't attach shared memory\n");
    goto fail_shmat;
  }

  // bind the area to the image 
  //
  image->data= (uint32_t*) image->shminfo.shmaddr;
  image->x11image->data= (char*) image->shminfo.shmaddr;
  if (!XShmAttach(x_display, &image->shminfo)) 
  {
    fprintf(stderr,"couldn't attach shared memory to the ximage\n");
    goto fail_attach_x;
  }

  return image;

fail_attach_x:
  shmdt(image->shminfo.shmaddr);
fail_shmat:      // We have already removed the ID
fail_shmcreate:
  XDestroyImage(image->x11image);
fail_create:
  free(image);
fail_nolib:
  return ximage_create_simple(width,height);
}

static ximage_t *ximage_create_simple(uint32_t width,uint32_t height)
{
  ximage_t *image;

  image= calloc(1,sizeof(*image));
  image->width= width;
  image->height= height;
  image->data= malloc(sizeof(uint32_t)*width*height);

  image->x11image= XCreateImage(x_display, x_visual, x_depth,
                                ZPixmap, 0, (char*) image->data,
                                width, height, 32, width*sizeof(uint32_t));
      // FIXME: error checking??
  image->bpl= image->x11image->bytes_per_line;
  image->shared= 0;
  return image;
}

static void destroy_image(ximage_t *image)
{
  XSync(x_display, False);
  if (image->shared) 
    XShmDetach(x_display, &image->shminfo);
  XDestroyImage(image->x11image);
  if (image->shared)
    shmdt(image->shminfo.shmaddr);
  free(image);
}


/************************************************************
  Putting an image on the screen is also handled differently
  for shared and non-shared images.
 ***********************************************************/

static void put_image(Drawable draw, int dest_x, int dest_y,
               ximage_t *image, int src_x, int src_y,
               int width, int height)
{
  if (src_x >= image->width ) return ;
  if (src_y >= image->height ) return ;
  if (src_x<0) { width+= src_x; src_x= 0; }
  if (src_y<0) { height+= src_y; src_y= 0; }
  
  if (width + src_x> image->width)  width= image->width-src_x;
  if (height+ src_y> image->height) height= image->height-src_y;

  if (image->shared)
    XShmPutImage(x_display, draw, DefaultGC(x_display,0),
      image->x11image, src_x, src_y, dest_x, dest_y,
      width, height, False);
  else
    XPutImage(x_display, draw, DefaultGC(x_display,0),
      image->x11image, src_x, src_y, dest_x, dest_y,
      width, height);
}

/*******************************************************
  Images in X11 can be in shared memory if the server 
  supports the "MIT-SHM" extension.
 ******************************************************/
static int can_use_shared_images()
{
  static int tried;
  static int can;
  if (!tried)
  {
    int ignore, major, minor;
    Bool pixmaps;
    tried= 1;
    can= XQueryExtension(x_display, "MIT-SHM", &ignore, &ignore, &ignore)
         && XShmQueryVersion(x_display, &major, &minor, &pixmaps);
  }
  return can;
}

static void gfx_update(int x,int y,int width,int height)
{
  clip_for_rect(&x, &width, x_window_width);
  clip_for_rect(&y, &height, x_window_height);
  if (width<=0 || height<=0) return ;
  put_image(x_pixmap, x, y, x_image, x,y, width, height); 
  XClearArea(x_display, x_window, x,y, width, height, True);
}

void gfx_close()
{
#ifdef GFX_X11
  x_keyboard_free(x_keyboard);
  x_keyboard= NULL;
#endif

  if (x_image) destroy_image(x_image);
  XDestroyWindow(x_display, x_window);
  XFreePixmap(x_display, x_pixmap);

  x_display= NULL;
  x_window= None;
  x_pixmap= None;
  x_image= NULL;
}

static void checker_pattern(ximage_t *img,int N)
{
  int x,y;
  uint32_t all_mask;
  if (N<=0) N= 4;
  all_mask= x_red_mask | x_green_mask | x_blue_mask;
  for(y=0;y<img->height;y++)
   for(x=0;x<img->width;x++)
     *(uint32_t*)  ((unsigned char*) img->data + y*img->bpl + 4*x)= 
            (x%(2*N)/N ^ y%(2*N)/N)  ? all_mask : 0;
}

static int getdpi()
{
   // FIXME: X can provide this info, look it up, maybe.
  return 86;
}


static x_keyboard_t *x_keyboard_init(Window window)
{
  x_keyboard_t *xk;

  xk= calloc(1,sizeof(*xk));

  xk->method= 'S';
  xk->window= window;
  xk->sbuf= 20;   xk->buf= malloc(xk->sbuf);
  xk->swbuf= 20;  xk->wbuf= malloc(sizeof(uint32_t)*xk->swbuf);
  get_xim();

  if (xim)
  {
    xk->ic= XCreateIC(xim, XNInputStyle, xim_style, 
                      XNClientWindow, window, 
                      XNFocusWindow, window, 
                      NULL);
    if (xk->ic!=NULL)
       xk->method= 'M'; 
  }
  return xk;
}

static void x_keyboard_free(x_keyboard_t *xk)
{
  free(xk->buf);
  free(xk->wbuf);
  if (xk->method=='M') XDestroyIC(xk->ic);
  free(xk);
}

static void get_xim()
{
  int i;
  XIMStyles *xim_styles;
  XIMStyle simple_style;
  char *failed_param;

  if (xim_tried) return ;
  xim_tried= 1;

  xim_styles= NULL;
  
  xim= XOpenIM(x_display, NULL, NULL, NULL);
  if (xim==NULL) return ;

  failed_param= XGetIMValues (xim, XNQueryInputStyle, &xim_styles, NULL);
  if (failed_param || !xim_styles)
     goto fail_no_styles;

  simple_style= (XIMPreeditNothing | XIMStatusNothing);
  for(i=0;i<xim_styles->count_styles;i++) 
    if (xim_styles->supported_styles[i] == simple_style)
       break;

  if (i==xim_styles->count_styles)
     goto fail_no_styles;

  xim_style= simple_style;
  XFree(xim_styles);

  return ;

fail_no_styles:
  if (xim_styles) XFree(xim_styles);
  
  XCloseIM(xim);
  xim= NULL;
}


static int x_keyboard_event
             (x_keyboard_t *xk, XEvent *ev, gfx_event_t *Revent)
{
  Status status;
  KeySym sym;
  int lk;

  sym= NoSymbol;

  Revent->type= GFXEV_KEY_PRESS;

  if (xk->method=='S') goto simple;
  if (XFilterEvent(ev, xk->window)) return 1;
  if (ev->type!=KeyPress) return 0;


retry:
  lk= Xutf8LookupString(xk->ic, (XKeyPressedEvent *) ev,
                        xk->buf, xk->sbuf-1, &sym, &status);
  switch(status)
  {
    case XBufferOverflow:
      free(xk->buf);
      xk->sbuf= lk+lk/2;
      xk->buf= malloc(xk->sbuf);
      goto retry;
    case XLookupBoth:
      if ((Revent->key=lookup_key(sym,ev->xkey.state))) return 1;
      Revent->key= GFX_K_PRT;
      Revent->string= xk->buf;
      Revent->string[lk]= 0;
      Revent->wide= utf8_decode_single_char(Revent->string);
      return 1;
    case XLookupChars: 
      if (xk->buf[0]>0 && xk->buf[0]<0x20) // control character
      { // I don't know what to do here.
        return -1;
      }
      Revent->key= GFX_K_PRT;
      Revent->string= xk->buf;
      Revent->string[lk]= 0;
      Revent->wide= utf8_decode_single_char(Revent->string);
      return 1;
      
    case XLookupKeySym:
      if ((Revent->key=lookup_key(sym,ev->xkey.state))) return 1;
      if ((Revent->wide= keysym2ucs(sym)))
      {
        utf8_encode_single_char(Revent->wide, xk->buf);
        Revent->string= xk->buf;
        Revent->string[lk]= 0;
        Revent->key= GFX_K_PRT;
        return 1;
      }
  }

  return -1;

simple:
  sym= NoSymbol;
  lk= XLookupString(&ev->xkey, xk->buf, xk->sbuf-1, &sym, NULL);
  if ((Revent->key=lookup_key(sym,ev->xkey.state))) return 1;
  if (lk>0) 
  {
    Revent->string= xk->buf;
    Revent->string[lk]= 0;
    Revent->wide= utf8_decode_single_char(Revent->string);
    Revent->key= GFX_K_PRT; 
    return 1;
  } 
  return -1;
}


static uint32_t keysym2ucs(KeySym keysym)
{
    int min = 0;
    int max = sizeof(keysymtab) / sizeof(struct codepair);
    int mid;

    if (keysym<=0xff) return keysym;

    if (keysym & 0x1000000) return keysym ^0x1000000;

    /* binary search */
    while (max > min) {
        mid = (min + max) / 2;
        if (keysymtab[mid].keysym < keysym)
            min = mid + 1;
        else if (keysymtab[mid].keysym > keysym)
            max = mid - 1;
        else {
            /* found it */
            return keysymtab[mid].ucs;
        }
    }

    /* no matching Unicode value found */
    return 0;
} 


static int lookup_key(KeySym sym, unsigned int modifiers)
{
   static const struct { KeySym sym; int meaning; } all[]=
   {
     { XK_BackSpace , GFX_K_BACKSPACE },
     { XK_Tab,        GFX_K_TAB },
     { XK_Linefeed,   GFX_K_RETURN },
     { XK_Return,     GFX_K_RETURN },
     { XK_Escape,     GFX_K_ESCAPE },
     { XK_Insert,     GFX_K_INSERT },
     { XK_Delete,     GFX_K_DELETE }, 
     { XK_Home,       GFX_K_HOME },
     { XK_End,        GFX_K_END },
     { XK_Page_Up,    GFX_K_PAGEUP },
     { XK_Page_Down,  GFX_K_PAGEDOWN },
     { XK_Left,       GFX_K_LEFT },
     { XK_Right,      GFX_K_RIGHT },
     { XK_Down,       GFX_K_DOWN },
     { XK_Up,         GFX_K_UP },
     { XK_VoidSymbol, 0 }
   };
   int i,B;
   B= 0;
   if (sym>=0x20 && sym<=0x7e && (modifiers&ControlMask))
      return sym | GFX_K_CONTROL; 
   for(i=0;all[i].sym!=XK_VoidSymbol;i++)
      if (all[i].sym==sym) 
       {
         B= all[i].meaning; 
         if (modifiers & ControlMask) B |= GFX_K_CONTROL;
         if (modifiers & ShiftMask) B |= GFX_K_SHIFT;
         return B;
       }
   return 0;
}



static void tv2msecs(struct timeval *tv, unsigned int* msecs)
{
  if (!msecs) return ;
  *msecs= tv->tv_sec*1000 + tv->tv_usec/1000;
}

static int event_noprocess(unsigned int *msecs,gfx_event_t *Revent)
{
  int x,R,maxfd;
  XEvent event;
  fd_set rfd, xfd, wfd;
  XExposeEvent *expose;

  struct timeval tv,*tvp;
  unsigned int delay,remaining,elapsed;
  unsigned int user_delay, sys_delay;
  int have_sys_delay, have_user_delay;

  user_delay= sys_delay= 0; // warnUNINVAR

  if (msecs && *msecs) { have_user_delay= 1; user_delay= *msecs; }
                else     have_user_delay= 0;

  XSync(x_display,False);
again:
      // no time has passed. no timers will fire and the user delay
      // is unaffected.
  if (XPending(x_display)) goto have_event; 

  have_sys_delay= gui_timer_get(&sys_delay); 

     // FIXME: should this be above XPending??
  if (have_sys_delay && sys_delay==0 && gui_timer_elapsed(0,Revent))
  {
    //printf("emitting timer left over\n");
    goto done;
  }

  tvp= &tv;
  switch(flag2(have_user_delay,have_sys_delay))
  {
  case 0: tvp= NULL; break;
  case 1: delay= sys_delay; break;
  case 2: delay= user_delay; break;
  case 3: delay= user_delay<sys_delay ? user_delay : sys_delay; break;
  }

  if (tvp)
  {
    tv.tv_sec= delay/1000;
    tv.tv_usec= (delay%1000)*1000;
  }   

  x= ConnectionNumber(x_display);

  FD_ZERO(&rfd); FD_ZERO(&xfd); FD_ZERO(&wfd);
  FD_SET(x, &rfd); FD_SET(x, &xfd);
  maxfd= x;

  populate_select_set(&maxfd, &rfd, &wfd, &xfd);

  //if (tvp)
  //printf("waiting for event: secs= %d usecs= %d\n",tvp->tv_sec,tvp->tv_usec);

  R= select(maxfd+1, &rfd, &wfd, &xfd, tvp);
  if (R<0)
  {
    if (errno==EINTR)
    {
       usleep(1000);
       tv2msecs(&tv, msecs);
       goto again;
    }
    return -1; // FIXME: log this stuff.
  }
  if (tvp)
  {
    tv2msecs(&tv, &remaining);
    elapsed= delay-remaining;
    if (have_user_delay) { if (elapsed>user_delay) user_delay= 0;
                                          else     user_delay-= elapsed; }
    if (have_sys_delay && gui_timer_elapsed(elapsed,Revent)) 
    { //printf("timer resulted in event. elapsed= %d sys_delay=%d\n",
       //elapsed, sys_delay);
      goto done; }
  }
  if (get_file_monitor_event(&rfd,&wfd,&xfd,Revent))
    goto done;
  if (FD_ISSET(x, &xfd)) return -1; // FIXME: log this stuff.

  if (!FD_ISSET(x, &rfd)) 
  {
    if (have_user_delay && user_delay==0) { *msecs=0; return 0; }
    goto again;
  }

have_event:
  XNextEvent(x_display, &event);

  switch(x_keyboard_event(x_keyboard,&event,Revent))
  {
  case 0: break;
  case 1: goto done;
  case -1: goto again;
  }

  switch(event.type)
  {
   case Expose:
     expose= &event.xexpose;
                                                  // FIXME: This zero should be
                                                  // something else
     XCopyArea(x_display, x_pixmap, x_window, DefaultGC(x_display,0), 
               expose->x, expose->y, expose->width, expose->height,
               expose->x, expose->y);
     goto again; 
   case MotionNotify:
     // if (gfx_recsel_event(&event)) goto again;
     Revent->type= GFXEV_POINTER_MOVE; 
     Revent->x= event.xmotion.x; 
     Revent->y= event.xmotion.y; 
     Revent->modifiers= event.xmotion.state; 
     break;
   case ButtonPress:
     Revent->type= GFXEV_BUTTON_PRESS; 
     Revent->x= event.xbutton.x; 
     Revent->y= event.xbutton.y; 
     Revent->modifiers= event.xbutton.state; 
     Revent->button= event.xbutton.button;
     Revent->time= event.xbutton.time;
     break;
   case ButtonRelease:
     Revent->type= GFXEV_BUTTON_RELEASE; 
     Revent->x= event.xbutton.x; 
     Revent->y= event.xbutton.y; 
     Revent->modifiers= event.xbutton.state; 
     Revent->button= event.xbutton.button;
     Revent->time= event.xbutton.time;
     break;
   case ClientMessage: 
     if (event.xclient.message_type!=wm_protocols) goto again;
     if (event.xclient.data.l[0]!=wm_delete_window) goto again;
     Revent->type= GFXEV_QUIT;
     break;
   default:
//     printf("unknown event type: %d\n", event.type);
     goto again;
  }
done:

  if (have_user_delay) *msecs= user_delay;

  return 1; 
}

#endif
#ifdef GFX_FB

static uint32_t all_ones(uint32_t S,uint32_t L)
{
  uint32_t i;
  S= (1<<S);
  for(i=0;i<L-1;i++) S|= (S<<1);
  return S;
}

int gfx_init(char *DUMMYname, int DUMMYwidth, int DUMMYheight, char *DUMMYtitle)
{
  int y;
 
  struct fb_fix_screeninfo finfo;
  struct fb_var_screeninfo vinfo;

  gfrot= atoi(getenvd("GFX_ROTATION","0"));
  gfrot= imax2(0,imin2(3,gfrot));

  fb_fd = open(getenvd("GFX_VIDEO","/dev/fb0"),O_RDWR);
  if (fb_fd<0) return 1;
  if (ioctl(fb_fd, FBIOGET_VSCREENINFO, &vinfo)<0) return 1;
  if (vinfo.grayscale || vinfo.bits_per_pixel!=32)
  {
    vinfo.grayscale=0;
    vinfo.bits_per_pixel=32;
    if (ioctl(fb_fd, FBIOPUT_VSCREENINFO, &vinfo)<0) return 1;
    if (ioctl(fb_fd, FBIOGET_VSCREENINFO, &vinfo)<0) return 1;
    if (vinfo.grayscale || vinfo.bits_per_pixel!=32)
       return 1;
  }
  if (vinfo.xoffset!=0 || vinfo.yoffset!=0)
  {
    vinfo.xoffset= 0;
    vinfo.yoffset= 0;
    if (ioctl(fb_fd, FBIOPAN_DISPLAY, &vinfo)<0) return 1;
  }
  if (ioctl(fb_fd, FBIOGET_FSCREENINFO, &finfo)<0) return 1;

  switch(gfrot)
  {
  case 0:
  case 2:
    x_window_width= vinfo.xres;
    x_window_height= vinfo.yres;
    break;
  case 1:
  case 3:
    x_window_width= vinfo.yres;
    x_window_height= vinfo.xres;
    break;
  }

  x_red_shift= vinfo.red.offset;
  x_green_shift= vinfo.green.offset;
  x_blue_shift= vinfo.blue.offset;

  x_red_mask= all_ones(x_red_shift,vinfo.red.length);
  x_green_mask= all_ones(x_green_shift,vinfo.green.length);
  x_blue_mask= all_ones(x_blue_shift,vinfo.blue.length);
  
  x_bpl= finfo.line_length;

  fb_mem= mmap(0, vinfo.yres*x_bpl, PROT_READ | PROT_WRITE, MAP_SHARED,
                fb_fd, (off_t)0);

  if (!fb_mem) return 1;


  x_image= malloc(sizeof(uint32_t)*x_window_width*x_window_height);

  x_image_data= malloc(sizeof(uint32_t*) * x_window_height);
  for(y=0;y<x_window_height;y++)
    x_image_data[y]= x_image + y*x_window_width;
  checker_pattern(17);

  rawinput_init();

  struct termios ttynew;
  // now we're confident that everything will be fine, we can disable
  // the echo etc.
  if (tcgetattr(0, &tty_settings)) goto failterm;
  tty_settings_valid= 1;
  ttynew = tty_settings;
  ttynew.c_iflag = 0;
  ttynew.c_oflag = 0;
  ttynew.c_lflag &= ~ICANON;
  ttynew.c_lflag &= ~ECHO;
  ttynew.c_cc[VMIN] = 1;
  ttynew.c_cc[VTIME] = 1;
  tcsetattr(0, TCSANOW, &ttynew);

  //printf("\033[?25l\033[100B\033[100C\033[2J");
  printf("\033[?25l\033[2J"); // hide cursor, erase display
  fflush(0);
failterm:

   gfx_radio_width= Gradio_on[0];
   gfx_radio_height= Gradio_on[1];

   gfx_checkbox_width= Gcheckbox_ok[0];
   gfx_checkbox_height= Gcheckbox_ok[1];


  gfx_update_all();
#ifdef GFX_X11
  x_keyboard= x_keyboard_init(x_window);
#endif


  scrollbar_init_buttons(NULL);

  return 0;
}

static void destroy_image()
{
}

static void gfx_update(int x,int y,int width,int height)
{
  int xx,yy;
  int sx,sy;
  clip_for_rect(&x, &width, x_window_width);
  clip_for_rect(&y, &height, x_window_height);
  if (width<=0 || height<=0) return ;

  switch(gfrot)
  {
  case 0:
  for(xx=0;xx<width;xx++)
    for(yy=0;yy<height;yy++)
    {
      uint32_t *D;
      D= (uint32_t*) (fb_mem + (y+yy)*x_bpl + (xx+x)*4);
      D[0]= x_image_data[y+yy][x+xx];
    }
  break;
  case 3:
  for(xx=0;xx<width;xx++)
    for(yy=0;yy<height;yy++)
    {
      uint32_t *D;
      sx= (y+yy); sy= x_window_width-1 - (x+xx);
      D= (uint32_t*) (fb_mem + sy*x_bpl + sx*4);
      D[0]= x_image_data[y+yy][x+xx];
    }
  break;
  case 2:
  for(xx=0;xx<width;xx++)
    for(yy=0;yy<height;yy++)
    {
      uint32_t *D;
      sy= x_window_height-1-(y+yy); sx= x_window_width-1 - (x+xx);
      D= (uint32_t*) (fb_mem + sy*x_bpl + sx*4);
      D[0]= x_image_data[y+yy][x+xx];
    }
  break;
  case 1:
  for(xx=0;xx<width;xx++)
    for(yy=0;yy<height;yy++)
    {
      uint32_t *D;
      sx= x_window_height-1-(y+yy); sy= (x+xx);
      D= (uint32_t*) (fb_mem + sy*x_bpl + sx*4);
      D[0]= x_image_data[y+yy][x+xx];
    }
  break;
  }
#ifdef GFX_FB
  if (mouse_proto=='M')
#endif
    draw_cursor(x,y,width,height);
}

void gfx_close()
{
  if (tty_settings_valid)
    tcsetattr(0, TCSANOW, &tty_settings);

  printf("\033[?25h\033[2J"); // show cursor, erase display
  fflush(0);
#ifdef GFX_X11
  x_keyboard_free(x_keyboard);
  x_keyboard= NULL;
#endif

}

static void checker_pattern(int N)
{
  int x,y;
  uint32_t all_mask;
  if (N<=0) N= 4;
  all_mask= x_red_mask | x_green_mask | x_blue_mask;
  for(y=0;y<x_window_height;y++)
   for(x=0;x<x_window_width;x++)
     x_image_data[y][x]= (x%(2*N)/N ^ y%(2*N)/N)  ? all_mask : 0;
}



static void draw_cursor(int ux,int uy,int uw,int uh)
{
  static const unsigned char cursor[]= {
  0x92,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
  0xff,0x93,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
  0xff,0xeb,0x87,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
  0xff,0x33,0xef,0x78,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
  0xff,0x0e,0x40,0xf2,0x68,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
  0xff,0x09,0x15,0x4b,0xf4,0x5a,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
  0xff,0x04,0x10,0x1d,0x56,0xf6,0x4e,0x00,0x00,0x00,0x00,0x00,0x00,
  0xff,0x00,0x0b,0x17,0x24,0x61,0xf7,0x42,0x00,0x00,0x00,0x00,0x00,
  0xff,0x00,0x05,0x12,0x1f,0x2b,0x6d,0xf8,0x36,0x00,0x00,0x00,0x00,
  0xff,0x00,0x00,0x0d,0x19,0x26,0x32,0x77,0xf8,0x2d,0x00,0x00,0x00,
  0xff,0x00,0x00,0x07,0x14,0x20,0x2d,0x3a,0x83,0xf8,0x24,0x00,0x00,
  0xff,0x00,0x00,0x02,0x0f,0x1b,0x28,0x34,0x41,0x8b,0xf6,0x1d,0x00,
  0xff,0x00,0x00,0x00,0x09,0x18,0xd9,0xf8,0xf8,0xf9,0xfe,0xf9,0x12,
  0xff,0x00,0x00,0x18,0x5f,0x11,0x7e,0xde,0x0f,0x0d,0x0d,0x0c,0x03,
  0xff,0x00,0x1b,0xe2,0xf2,0x17,0x21,0xf2,0x25,0x00,0x00,0x00,0x00,
  0xff,0x1d,0xe4,0x97,0xcd,0x7d,0x13,0x8d,0xc7,0x00,0x00,0x00,0x00,
  0xff,0xe7,0x8e,0x00,0x20,0xf1,0x17,0x28,0xf6,0x14,0x00,0x00,0x00,
  0xff,0x82,0x00,0x00,0x00,0xcd,0x7b,0x14,0xc9,0x59,0x00,0x00,0x00,
  0x6e,0x00,0x00,0x00,0x00,0x1f,0xf6,0xbf,0xf3,0x23,0x00,0x00,0x00,
  0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x66,0x15,0x00,0x00,0x00,0x00,
  };
  static const uint16_t mask[]={
  0x0001, 0x0003, 0x0007, 0x000f, 
  0x001f, 0x003f, 0x007f, 0x00ff, 
  0x01ff, 0x03ff, 0x07ff, 0x0fff, 
  0x1fff, 0x1fff, 0x01ff, 0x01ff, 
  0x03f7, 0x03e3, 0x03e1, 0x01c0, 
  };
  const int cursorW= 13, cursorH= 20;
  int ux_e, uy_e;
  int mx_e, my_e,mx,my,dx,dy;
  int ccx_s, ccx_e, ccy_s, ccy_e;
  uint32_t *D,V;
  int xx,yy;

  mx= McursorX; my= McursorY;
  mx_e= mx+cursorW; my_e= my+cursorH;
  ux_e= ux+uw; uy_e= uy+uh;

  if (ux_e<=mx || uy_e<=my || mx_e<=ux || my_e<=uy) return ;

  if (ux>mx) ccx_s= ux-mx;
        else ccx_s= 0;

  if (mx_e>ux_e) ccx_e= cursorW - (mx_e-ux_e);
            else ccx_e= cursorW - ccx_s;

  if (uy>my) ccy_s= uy-my;
        else ccy_s= 0;

  if (my_e>uy_e) ccy_e= cursorH - (my_e-uy_e);
            else ccy_e= cursorH - ccy_s;

 switch(gfrot)
 {
 case 0:
  for(yy=ccy_s;yy<ccy_e;yy++)
    for(xx=ccx_s;xx<ccx_e;xx++)
    {
      if ((mask[yy]&(1<<xx))==0) continue;
      dx= mx+xx;
      dy= my+yy;

      D= (uint32_t*) (fb_mem + dy*x_bpl + dx*4);
      V=  cursor[yy*cursorW+xx];
      D[0]= (V<<x_red_shift) | (V<<x_green_shift) | (V<<x_blue_shift);
    }
  break;
 case 1:
  for(yy=ccy_s;yy<ccy_e;yy++)
    for(xx=ccx_s;xx<ccx_e;xx++)
    {
      if ((mask[yy]&(1<<xx))==0) continue;
      dx= x_window_height-1-(my+yy); dy= (mx+xx);

      D= (uint32_t*) (fb_mem + dy*x_bpl + dx*4);
      V=  cursor[yy*cursorW+xx];
      D[0]= (V<<x_red_shift) | (V<<x_green_shift) | (V<<x_blue_shift);
    }
  break;
 case 2:
  for(yy=ccy_s;yy<ccy_e;yy++)
    for(xx=ccx_s;xx<ccx_e;xx++)
    {
      if ((mask[yy]&(1<<xx))==0) continue;
      dy= x_window_height-1-(my+yy); dx= x_window_width-1 - (mx+xx);
      D= (uint32_t*) (fb_mem + dy*x_bpl + dx*4);
      V=  cursor[yy*cursorW+xx];
      D[0]= (V<<x_red_shift) | (V<<x_green_shift) | (V<<x_blue_shift);
    }
  break;
 case 3:
  for(yy=ccy_s;yy<ccy_e;yy++)
    for(xx=ccx_s;xx<ccx_e;xx++)
    {
      if ((mask[yy]&(1<<xx))==0) continue;
      dx= (my+yy); dy= x_window_width-1 - (mx+xx);
      D= (uint32_t*) (fb_mem + dy*x_bpl + dx*4);
      V=  cursor[yy*cursorW+xx];
      D[0]= (V<<x_red_shift) | (V<<x_green_shift) | (V<<x_blue_shift);
    }
  break;
 }
}

static void move_cursor(int cx,int cy)
{
  int ox,oy;
  if (cx==McursorX && cy==McursorY) return ;
  ox= McursorX;
  oy= McursorY;
  McursorX= cx;
  McursorY= cy;
  gfx_update(ox,oy,13,20);
  gfx_update(McursorX,McursorY,13,20);
}

static void prt_key(int key,char *lo,char *hi)
{
  kbmap[key].type= 'P';
  kbmap[key].lo= lo;
  kbmap[key].hi= hi;
}

static void prt_keys(int SK,int EK, char *lo,char *hi)
{
  int i,k;
  for(i=0,k=SK;k<=EK;i++,k++)
  {
    kbmap[k].ss[0]= lo[i];
    kbmap[k].ss[2]= hi[i];
    prt_key(k, kbmap[k].ss,kbmap[k].ss+2);
  }
}

static void prt_keys_upper(int SK,int EK,char *inp)
{
  int i,k;
  for(i=0,k=SK;k<=EK;i++,k++)
  {
    kbmap[k].ss[0]= inp[i];
    kbmap[k].ss[2]= toupper(inp[i]);
    prt_key(k, kbmap[k].ss,kbmap[k].ss+2);
  }
}

static void ctl_key(int raw,int gf)
{
  kbmap[raw].type= 'C';
  kbmap[raw].value= gf;
}

static void mod_key(int raw,int gf)
{
  kbmap[raw].type= 'M';
  kbmap[raw].value= gf;
}


static char *getenvd(char *name,char *def)
{
  char *S;
  S= getenv(name);
  if (!S) S= def;
  return S;
}

static void read_environ_vars()
{
  char *S;
  S= getenvd("GFX_MOUSE_PROTO",NULL);
  mouse_proto= 'M';
  if (S)
  {
    if (!strcmp(S,"ft5x06")) mouse_proto= 'F';
    if (!strcmp(S,"absolute")) mouse_proto= 'A';
  }

  mo_device= strdup(getenvd("GFX_MOUSE_FILE", 
                             mouse_proto=='F' ? "/dev/hidraw2" :
                                                "/dev/input/mice"));
  if (mouse_proto=='F')
  {
    gfx_m_minx= atoi(getenvd("GFX_MOUSE_MINX", "0"));
    gfx_m_maxx= atoi(getenvd("GFX_MOUSE_MAXX", "1000"));
    gfx_m_miny= atoi(getenvd("GFX_MOUSE_MINY", "0"));
    gfx_m_maxy= atoi(getenvd("GFX_MOUSE_MAXY", "1000"));
    gfx_m_xresol= atoi(getenvd("GFX_MOUSE_XRESOL","1000"));
    gfx_m_yresol= atoi(getenvd("GFX_MOUSE_YRESOL","1000"));
  }

  kb_device= strdup(getenvd("GFX_KB_FILE", "/dev/input/event10"));
}

static void rawinput_init()
{
  read_environ_vars();
  RAWIfd_kb= open(kb_device,O_RDWR);
  RAWIfd_mo= open(mo_device,mouse_proto=='F' ? O_RDONLY : O_RDWR);
  if (RAWIfd_kb<0 && RAWIfd_mo<0) exit(1);
  if (RAWIfd_mo>=0 && mouse_proto=='M')
  {
    static const unsigned char mousedev_imps_seq[]=
        {0xf3, 0xc8, 0xf3, 0x64, 0xf3, 0x50};
    write(RAWIfd_mo, mousedev_imps_seq, sizeof(mousedev_imps_seq));
  }

  prt_keys_upper(KEY_Q,KEY_P,"qwertyuiop");
  prt_keys_upper(KEY_A,KEY_L,"asdfghjkl");
  prt_keys_upper(KEY_Z,KEY_M,"zxcvbnm");
  prt_keys(KEY_1,KEY_EQUAL,"1234567890-=","!@#$%^&*()_+");
  prt_key(KEY_LEFTBRACE,"[","{");
  prt_key(KEY_RIGHTBRACE,"]","}");
  prt_key(KEY_SEMICOLON,";",":");
  prt_key(KEY_APOSTROPHE,"'","\"");
  prt_key(KEY_BACKSLASH, "\\", "|");
  prt_keys(KEY_COMMA,KEY_SLASH,",./","<>?");
  prt_key(KEY_SPACE," "," ");

  ctl_key(KEY_ESC, GFX_K_ESCAPE);
  ctl_key(KEY_TAB, GFX_K_TAB);
  ctl_key(KEY_BACKSPACE, GFX_K_BACKSPACE);
  ctl_key(KEY_ENTER, GFX_K_RETURN);
  ctl_key(KEY_KPENTER, GFX_K_RETURN);
  ctl_key(KEY_UP, GFX_K_UP);
  ctl_key(KEY_DOWN, GFX_K_DOWN);
  ctl_key(KEY_RIGHT, GFX_K_RIGHT);
  ctl_key(KEY_LEFT, GFX_K_LEFT);
  ctl_key(KEY_HOME, GFX_K_HOME);
  ctl_key(KEY_END, GFX_K_END);
  ctl_key(KEY_INSERT, GFX_K_INSERT);
  ctl_key(KEY_DELETE, GFX_K_DELETE);
  ctl_key(KEY_PAGEUP, GFX_K_PAGEUP);
  ctl_key(KEY_PAGEDOWN, GFX_K_PAGEDOWN);

  mod_key(KEY_LEFTSHIFT, GFX_K_SHIFT);
  mod_key(KEY_RIGHTSHIFT, GFX_K_SHIFT);
  mod_key(KEY_LEFTALT, GFX_K_ALT);
  mod_key(KEY_RIGHTALT, GFX_K_ALT);
  mod_key(KEY_LEFTCTRL, GFX_K_CONTROL);
  mod_key(KEY_RIGHTCTRL, GFX_K_CONTROL);
}

static int event_noprocess(unsigned int *msecs, gfx_event_t *Revent)
{
  fd_set rset,wset,xset;
  int nfd;
  int R;
  static int modifiers;
  static int buttons;
  static int mX,mY;

again:
  nfd= 0;
  FD_ZERO(&rset); FD_ZERO(&wset); FD_ZERO(&xset);
  if (RAWIfd_kb>=0) { FD_SET(RAWIfd_kb, &rset); nfd=imax2(nfd,RAWIfd_kb); }
  if (RAWIfd_mo>=0) { FD_SET(RAWIfd_mo, &rset); nfd=imax2(nfd,RAWIfd_mo); }
  populate_select_set(&nfd,&rset,&wset,&xset);

  R= select(nfd+1, &rset, &wset,&xset,NULL);
  if (R<0) { if (errno==EINTR) goto again; exit(1); }
  if (get_file_monitor_event(&rset,&wset,&xset,Revent)) return 1;
  if (RAWIfd_kb>=0 && FD_ISSET(RAWIfd_kb, &rset))
  {
    struct input_event EV;
    unsigned int code;
    read(RAWIfd_kb, &EV, sizeof(EV));
    // I don't check the return value, I want weird things to happen
    // if our basic assumptions fail.
    if (EV.type!=EV_KEY) goto again;

    code= EV.code;
    if (code>255) goto again;
    switch(kbmap[code].type)
    {
    case 'M':
      modifiers= (modifiers&~kbmap[code].value);
      if (EV.value) modifiers |= kbmap[code].value;
      goto again;
    case 'P': 
         // we don't report release of printable chars, only of ctl chars
      if (!EV.value) goto again;
      Revent->type= GFXEV_KEY_PRESS;
      Revent->key= GFX_K_PRT;
      Revent->modifiers= modifiers;
      Revent->string= modifiers&GFX_K_SHIFT? kbmap[code].hi : kbmap[code].lo;
      Revent->wide= Revent->string[0];
      return 1;
    case 'C':
          // it turns out, we don't report release of control chars
          // either :P
      if (!EV.value) goto again;
      Revent->type= GFXEV_KEY_PRESS;
      Revent->key= kbmap[code].value | modifiers;
      Revent->modifiers= modifiers;
      return 1;
    }
    goto again;
  }
  if (mouse_proto=='M' && RAWIfd_mo>=0 && FD_ISSET(RAWIfd_mo, &rset))
  {
    unsigned char buf[4],BB;
    int aX,aY,dx,dy;
    R= read(RAWIfd_mo,buf,4);
    if (R<3) goto again;

    dx= (buf[0]&(1<<4))? buf[1]-256:buf[1];
    dy= (buf[0]&(1<<5))? 256-buf[2]:-buf[2];
    aX= imax2(0,imin2(x_window_width,mX+dx));
    aY= imax2(0,imin2(x_window_height,mY+dy));

    move_cursor(aX,aY);

    BB= buf[0] & 7;
    if (R==4)
    { 
      if (buf[3]==1) BB|= (1<<3);
      if (buf[3]==0xff) BB|= (1<<4);
    }
    if (BB^buttons || aY!=mY || aX!=mX)
    {
      Revent->modifiers= modifiers;
      Revent->x= mX= aX; Revent->y= mY= aY;

      if (BB^buttons)
      {
        unsigned char K= BB^buttons,B;
        for(B=0;B<5;B++) if (K&(1<<B)) break;
        buttons= BB;
        Revent->type= (buttons&(1<<B)) ? GFXEV_BUTTON_PRESS:GFXEV_BUTTON_RELEASE;
        Revent->button= B+1;
      }
      else
        Revent->type= GFXEV_POINTER_MOVE;
      return 1;
    }
  }
  if (mouse_proto=='F' && RAWIfd_mo>=0 && FD_ISSET(RAWIfd_mo, &rset))
  {
    unsigned char buf[22],BB;
    int rx,ry;
    int aX,aY,dx,dy;
    R= read(RAWIfd_mo,buf,22);
    if (R<6) goto again;

    if (buf[1]==0) BB= 0;
              else BB= 1;

    if (BB)
    {
      rx= ((buf[2]&0x0f)<<8) | buf[3];
      ry= ((buf[4]&0x0f)<<8) | buf[5];

      rx= (rx - gfx_m_minx)*gfx_m_xresol / (gfx_m_maxx-gfx_m_minx);
      ry= (ry - gfx_m_miny)*gfx_m_yresol / (gfx_m_maxy-gfx_m_miny);

      switch(gfrot)
      {
       case 0: aX= rx; aY= ry; break;
       case 3: aX= gfx_m_yresol-1-ry; aY= rx; break;
       case 2: aX= gfx_m_xresol-1-rx; aY= gfx_m_yresol-1-ry; break;
       case 1: aX= ry; aY= gfx_m_xresol-1-rx; break;
      }
      aX= imax2(0,imin2(x_window_width-1,aX));
      aY= imax2(0,imin2(x_window_height-1,aY));
    }
    else
    {
      aX= mX;
      aY= mY;
    }

    if (BB^buttons || aY!=mY || aX!=mX)
    {
      Revent->modifiers= modifiers;
      Revent->x= mX= aX; Revent->y= mY= aY;

      if (BB^buttons)
      {
        buttons= BB;
        Revent->type= (buttons&1) ? GFXEV_BUTTON_PRESS:GFXEV_BUTTON_RELEASE;
        Revent->button= 1;
      }
      else
        Revent->type= GFXEV_POINTER_MOVE;
      return 1;
    }
  }
  if (mouse_proto=='A' && RAWIfd_mo>=0 && FD_ISSET(RAWIfd_mo, &rset))
  {
    struct input_event iev;
    static int have_pos,is_down;
    static int pos_x,pos_y;
    int aX,aY;

    R= read(RAWIfd_mo,&iev,sizeof(iev));
    if (R<sizeof(iev)) goto again;

    if (iev.type==EV_SYN && iev.code==SYN_MT_REPORT)
    {
      if (have_pos)
      {
        have_pos= 0;
        Revent->type= is_down ? GFXEV_BUTTON_PRESS : GFXEV_POINTER_MOVE;
        is_down= 1;
        goto have_abs_event;
      }
      else
      {
        Revent->type= GFXEV_BUTTON_RELEASE;
        is_down= 0;
        goto have_abs_event;
      }
    }
    if (iev.type==EV_ABS && iev.code==ABS_MT_POSITION_X)
    {
       pos_x= iev.value;
       have_pos= 1;
       goto again;
    }
    if (iev.type==EV_ABS && iev.code==ABS_MT_POSITION_Y)
    {
       pos_y= iev.value;
       have_pos= 1;
       goto again;
    }
    goto again;
have_abs_event:
    switch(gfrot)
    {
     case 0: aX= pos_x; aY= pos_y; break;
          // we subtrack pos_y from window_WIDTH, because it's actually
          // height but was switched around because of the rotation.
     case 3: aX= x_window_width-1-pos_y; aY= pos_x; break;
          // here, width and height are correct, since they were not
          // switched around
     case 2: aX= x_window_width-1-pos_x; aY= x_window_height-1-pos_y; break;
          // again, subtract from HEIGHT because of the rotation.
     case 1: aX= pos_y; aY= x_window_height-1-pos_x; break;
    }
    aX= imax2(0,imin2(x_window_width-1,aX));
    aY= imax2(0,imin2(x_window_height-1,aY));

    Revent->button= 1;
    Revent->modifiers= modifiers;
    Revent->x= mX= aX; Revent->y= mY= aY;

    return 1;
  }
  goto again;
}

#endif
#ifdef GFX_ANDROID

void ANativeActivity_onCreate
      (ANativeActivity* activity, void* state, size_t state_size)
{
  int cmdpipe[2];
  pthread_attr_t attr; 
  app_t *app;

  LOGV("Creating: %p\n", activity);

  // #C.1: Activity callback installation
  activity->callbacks->onDestroy = onDestroy;
  activity->callbacks->onStart = onStart;
  activity->callbacks->onResume = onResume;
  activity->callbacks->onPause = onPause;
  activity->callbacks->onStop = onStop;
  activity->callbacks->onNativeWindowCreated = onNativeWindowCreated;
  activity->callbacks->onNativeWindowDestroyed = onNativeWindowDestroyed;
  activity->callbacks->onInputQueueCreated = onInputQueueCreated;
  activity->callbacks->onInputQueueDestroyed = onInputQueueDestroyed;
  activity->callbacks->onSaveInstanceState = onSaveInstanceState;
  activity->callbacks->onWindowFocusChanged = onWindowFocusChanged;
  activity->callbacks->onLowMemory = onLowMemory;
  activity->callbacks->onConfigurationChanged = onConfigurationChanged;

  ANativeActivity_setWindowFormat(activity, WINDOW_FORMAT_RGBX_8888);

  activity->instance= my_app= app= calloc(1,sizeof(*app));
  app->activity= activity;
  app->last_pointer_id= -1;

  if (state && state_size)
  {
    app->init_state= malloc(state_size);
    memcpy(app->init_state, state, state_size);
    app->init_state_size= state_size;
  }

  pthread_mutex_init(&app->mutex, NULL);
  pthread_cond_init(&app->cond,NULL);

  if (pipe(cmdpipe))
  {
    LOGE("Couldn't create pipe: %s\n",strerror(errno));
    return ;
  }
  app->cmdpipe_r= cmdpipe[0];
  app->cmdpipe_w= cmdpipe[1];

  pthread_attr_init(&attr);
  pthread_attr_setdetachstate(&attr, PTHREAD_CREATE_DETACHED);
  pthread_create(&app->worker_thread, &attr, worker_entry, app);

  
  pthread_mutex_lock(&app->mutex); 
  while(!app->running) pthread_cond_wait(&app->cond, &app->mutex); 
  pthread_mutex_unlock(&app->mutex);
}

  // #C.2 Worker Function
static void* worker_entry(void* arg)
{
  app_t *app;

  app= arg;

  app->config= AConfiguration_new();
  AConfiguration_fromAssetManager(app->config, app->activity->assetManager);

  app->looper= ALooper_prepare(ALOOPER_PREPARE_ALLOW_NON_CALLBACKS);
  ALooper_addFd(app->looper, app->cmdpipe_r,
                PIPE_CMD, ALOOPER_EVENT_INPUT, NULL, app);
  
  pthread_mutex_lock(&app->mutex); 
  app->running=1; 
  pthread_cond_broadcast(&app->cond);
  pthread_mutex_unlock(&app->mutex);

  while(!app->inputq || !app->window)
    if (execute_commands(app)) goto done;

   gfx_radio_width= Gradio_on[0];
   gfx_radio_height= Gradio_on[1];

   gfx_checkbox_width= Gcheckbox_ok[0];
   gfx_checkbox_height= Gcheckbox_ok[1];

#ifdef GFX_X11
  x_keyboard= x_keyboard_init(x_window);
#endif


  scrollbar_init_buttons(NULL);

  fonts_init();
  android_main(app->init_state, app->init_state_size);

  while(!app->quit_request)
     if (execute_commands(app))
       break;

done:
  //free_saved_state(A);
  if (app->inputq) 
      { AInputQueue_detachLooper(app->inputq); app->inputq= NULL; }
  AConfiguration_delete(app->config);
  app->config= NULL;

  if (app->quit_request)
     complete_request(app, app->quit_request);
  return NULL;
}


static void make_request(app_t *A, request_t *R)
{
   R->complete= 0;
   if (write(A->cmdpipe_w, &R, sizeof(R))!=sizeof(R))
   {
     LOGE("Couldn't write to command pipe: %s\n", strerror(errno));
     return ;
   }
   
   pthread_mutex_lock(&A->mutex); 
   while(!R->complete) pthread_cond_wait(&A->cond, &A->mutex); 
   pthread_mutex_unlock(&A->mutex); 
}

static int get_request(app_t *A,request_t **R)
{
   request_t *T;
   if (read(A->cmdpipe_r, &T, sizeof(T))!=sizeof(T))
   {
     LOGE("Couldn't read from command pipe: %s\n", strerror(errno));
     return 1;
   }
   *R= T;
   return 0;
}

static void complete_request(app_t *A, request_t *R)
{
   pthread_mutex_lock(&A->mutex); 
   R->complete= 1;
   pthread_cond_broadcast(&A->cond);
   pthread_mutex_unlock(&A->mutex); 
}


static void simple_command(ANativeActivity *ac, int cmd)
{
   request_t R;
   R.type= cmd;
   make_request(ac->instance, &R);
}

static void onStart(ANativeActivity* activity)
{
   LOGV("Start: %p\n", activity);
   simple_command(activity, CMD_APP_START);
}

static void onResume(ANativeActivity* activity)
{
   LOGV("Resume: %p\n", activity);
   simple_command(activity, CMD_APP_RESUME);
}

static void onPause(ANativeActivity* activity)
{
   LOGV("Pause: %p\n", activity);
   simple_command(activity, CMD_APP_PAUSE);
}

static void onStop(ANativeActivity* activity)
{
   LOGV("Stop: %p\n", activity);
   simple_command(activity, CMD_APP_STOP);
}


static void onNativeWindowCreated
   (ANativeActivity* activity, ANativeWindow* window)
{
  request_t R;
  LOGV("NativeWindowCreated: %p -- %p\n", activity, window);
  R.type= CMD_WINDOW_CREATED;
  R.d.window= window;
  make_request(activity->instance, &R);
}

static void onNativeWindowDestroyed
   (ANativeActivity* activity, ANativeWindow* window)
{
  request_t R;
  LOGV("NativeWindowDestroyed: %p -- %p\n", activity, window);
  R.type= CMD_WINDOW_DESTROYED;
  R.d.window= window;
  make_request(activity->instance, &R);
}

static void onNativeWindowRedrawNeeded
              (ANativeActivity* activity, ANativeWindow* window)
{
  request_t R;
  LOGV("NativeWindowRedraw: %p -- %p\n", activity, window);
  R.type= CMD_WINDOW_REDRAW;
  R.d.window= window;
  make_request(activity->instance, &R);
}

static void onInputQueueCreated
   (ANativeActivity* activity, AInputQueue* queue)
{
  request_t R;
  LOGV("InputQueueCreated: %p -- %p\n", activity, queue);
  R.type= CMD_INPUTQ_CREATED;
  R.d.inputq= queue;
  make_request(activity->instance, &R);
}

static void onInputQueueDestroyed
   (ANativeActivity* activity, AInputQueue* queue)
{
  request_t R;
  LOGV("InputQueueDestroyed: %p -- %p\n", activity, queue);
  R.type= CMD_INPUTQ_DESTROYED;
  R.d.inputq= queue;
  make_request(activity->instance, &R);
}

static void* onSaveInstanceState
   (ANativeActivity* activity, size_t* outLen)
{
  request_t R;
  LOGV("SaveInstanceState: %p\n", activity);
  R.type= CMD_SAVE_STATE;
  R.d.buffer.ptr= NULL;
  R.d.buffer.size= 0;
  make_request(activity->instance, &R);
  if (R.d.buffer.ptr)
    *outLen= R.d.buffer.size;
  return R.d.buffer.ptr;
}

static void onWindowFocusChanged
   (ANativeActivity* activity, int focused)
{
  request_t R;
  LOGV("WindowFocusChanged: %p -- %d\n", activity, focused);
  R.type= CMD_FOCUS_CHANGE;
  R.d.intv= focused;
  make_request(activity->instance, &R);
}

static void onLowMemory(ANativeActivity* activity)
{
  request_t R;
  LOGV("LowMemory: %p\n", activity);
  R.type= CMD_LOW_MEMORY;
  make_request(activity->instance, &R);
}

static void onConfigurationChanged(ANativeActivity* activity)
{
  request_t R;
  LOGV("ConfigurationChanged: %p\n", activity);
  R.type= CMD_CONFIG_CHANGE;
  make_request(activity->instance, &R);
}


static int handle_command(app_t *A,int *Rvalue)
{

  request_t *R;
  if (get_request(A, &R)) return 0;
  switch(R->type)
  {
  case CMD_APP_STOP:
     if (gfx_app_stop) (*gfx_app_stop)();
     complete_request(A,R);
     break;
  case CMD_APP_START:
  case CMD_APP_PAUSE:
  case CMD_APP_RESUME:
     // FIXME: inform the client, maybe??
     complete_request(A,R);
     break;
  case CMD_WINDOW_DESTROYED:
     graphics_window_destroyed(A, R->d.window);
     complete_request(A,R);
     break;
  case CMD_WINDOW_CREATED:
     graphics_window_created(A, R->d.window);
     complete_request(A,R);
     gfx_update_all();
     break;
  case CMD_WINDOW_REDRAW:
     gfx_update_all();
     break;
  case CMD_FOCUS_CHANGE:
  case CMD_LOW_MEMORY:
     complete_request(A,R);
     break;
  case CMD_CONFIG_CHANGE:
     LOGV("APP_CMD_CONFIG_CHANGED\n");
     AConfiguration_fromAssetManager(A->config, A->activity->assetManager);
     complete_request(A,R);
     break;
  case CMD_INPUTQ_DESTROYED:
     if (A->inputq!=R->d.inputq)
     {
       complete_request(A,R);
       break;
     }
     AInputQueue_detachLooper(A->inputq);
     A->inputq= NULL;
     complete_request(A,R);
     break;
  case CMD_INPUTQ_CREATED:
     if (A->inputq!=NULL)
        AInputQueue_detachLooper(A->inputq);
     A->inputq= R->d.inputq;
     AInputQueue_attachLooper(A->inputq, A->looper, PIPE_EVENT, NULL,A);
     complete_request(A,R);
     break;
  case CMD_QUIT:
     // FIXME: when do we get this?
     LOGV("APP_CMD_QUIT\n");
     A->quit_request= R;
     return 1;
  case CMD_SAVE_STATE:
     // This request gets completed when the save_state function gets
     // called. it MUST be called otherwise the main thread will hang 
     A->save_request= R;
     return 2;
  case CMD_JAVARESULT:
     if (Rvalue) *Rvalue= R->d.intv;
     complete_request(A,R);
     return 3;
  }
  return 0;
}


static int execute_commands(app_t *app)
{
   int ident;
   int dFD, dEV;
   void *dPTR;

again:
   ident= ALooper_pollAll(-1,  &dFD, &dEV,  &dPTR);

   switch(ident)
   {
     // somebody might have woke us up because the looper
     // has changed and we need to poll again.
   case ALOOPER_POLL_WAKE:
      goto again;
   case PIPE_CMD:
      if (handle_command(app,NULL)==1) return 1;
      return 0;
   case PIPE_EVENT:
     handle_input(app, NULL);
     goto again;
   }

   // other things are not possible. maybe I can add some
   // sort of a time-out later.
   // so, unhandled stuff corresponds to an error, which
   // makes the application quit. I think it's OK.
   return 1;
}


static void onDestroy(ANativeActivity* activity)
{
  request_t R;
  app_t *A;

  LOGV("Destroy: %p\n", activity);

  A= activity->instance;
  R.type= CMD_QUIT;
  make_request(A, &R);

  close(A->cmdpipe_r);
  close(A->cmdpipe_w);
  pthread_cond_destroy(&A->cond);
  pthread_mutex_destroy(&A->mutex);
  free(A);
}

static void graphics_window_destroyed(app_t *A, ANativeWindow *window)
{
  if (A->window!=window) return ;
  A->window= NULL;
}

static void graphics_window_created(app_t *A, ANativeWindow *window)
{
   int W,H;
   A->window= window;
   W= ANativeWindow_getWidth(A->window);
   H= ANativeWindow_getHeight(A->window);
   if (W<=0) W= 1;
   if (H<=0) H= 1;

   if (W!=x_window_width || H!=x_window_height || !Gpixels)
   {
     int y;
     if (Gpixels) free(Gpixels);
     Gpixels= malloc(sizeof(uint32_t)*W*H);
     if (x_image_data) free(x_image_data);
     x_image_data= malloc(sizeof(x_image_data[0])*H);
     for(y=0;y<H;y++)
       x_image_data[y]= y*W + Gpixels;
     x_window_width= W;
     x_window_height= H;
   }
}


static void gfx_update(int x,int y,int w,int h)
{
   ARect rect;
   ANativeWindow_Buffer buffer;
   int R;
   uint32_t *spixels;
   uint16_t *wpixels;
   int eX, eY;

   if (!updates_on) return ;
   if (!Gpixels) return ; // display not initialized yet
   if (!my_app->window) return ;

   eX= x+w; eY= y+h;

   if (x>=x_window_width || eX<=0 || y>=x_window_height || eY<=0) return ;

   eX= imin2(eX, x_window_width); eY= imin2(eY, x_window_height);
   x= imax2(x, 0); y= imax2(y,0);

   rect.left= x; rect.top= y;
   rect.right= eX; rect.bottom= eY;

   R= ANativeWindow_lock(my_app->window, &buffer, &rect);
   if (R<0)
   {
      LOGV("Unable to lock buffer: %d\n", R);
      return ;
   }

   // LOGV("GFX::Buffer width=%d height=%d stride=%d format=%d\n", buffer.width, buffer.height,  buffer.stride, buffer.format);

   // LOGV("GFX::Rect left=%d top=%d right=%d bottom=%d\n", rect.left,
           // rect.top, rect.right, rect.bottom);
   
  switch(buffer.format)
  {
   case WINDOW_FORMAT_RGBX_8888:
     spixels= buffer.bits;
     for(y=rect.top;y<rect.bottom;y++)
       for(x=rect.left;x<rect.right;x++)
         spixels[y*buffer.stride+x]= Gpixels[x+ y*x_window_width];
     break;
   case WINDOW_FORMAT_RGBA_8888:
     spixels= buffer.bits;
     for(y=rect.top;y<rect.bottom;y++)
       for(x=rect.left;x<rect.right;x++)
         spixels[y*buffer.stride+x]= Gpixels[x+ y*x_window_width] | 0xff000000;
     break;
   case WINDOW_FORMAT_RGB_565:
     wpixels= buffer.bits;
     for(y=rect.top;y<rect.bottom;y++)
       for(x=rect.left;x<rect.right;x++)
       {
         uint32_t P,R,G,B;
         P= x_image_data[y][x];
         R= (P>>16)&0xff;  R>>= 3;
         G= (P>>8) &0xff;  G>>= 2;
         B= P&0xff;        B>>= 3;
         wpixels[y*buffer.stride+x]= (R<<11) | (G<<5) | B;
       }
      break;
    default:
      LOGV("unknown buffer format %d",buffer.format);
      break;
  }
  ANativeWindow_unlockAndPost(my_app->window);
}

static int getdpi()
{
  if (display_dpi) return display_dpi;
#ifdef GFX_ANDROID_ACTIVITY
  JNIEnv* J;
  JavaVM *vm;
  ANativeActivity* activity;
  int R, att;
  int result;

  jobject jo_activity;
 
  activity= my_app->activity;
   // fuck this shit. clazz is actually a pointer to the
   // activity object.
  vm= my_app->activity->vm;
  
  att= 0;
  R= (*vm)->GetEnv(vm, (void**) &J, JNI_VERSION_1_6); 
  if (R==JNI_EDETACHED)
  {
    R= (*vm)->AttachCurrentThread(vm, &J, NULL);
    if (R) goto fail;
    att= 1;
  }

  jo_activity= activity->clazz;

  result= JmethodI(J, jo_activity, "getDisplayDPI");

  if (att) (*vm)->DetachCurrentThread(vm);
  return display_dpi=result;
fail:
  return display_dpi=86;
#else
  return display_dpi=86;
#endif
}



static int millitime()
{
  struct timespec tv;
  clock_gettime(CLOCK_MONOTONIC, &tv);
  return tv.tv_sec*1000+tv.tv_nsec/1000/1000;
}

static int handle_input(app_t *A, gfx_event_t *ev)
{
  AInputEvent* event;
  int type;
  uint32_t action,index, i, npointers;
  gfx_event_t dummy;
  event = NULL;
  if (!ev) ev= &dummy;
again:
     // Is this an error? should I log it or somehow
     // return an indication? FIXME

  if (AInputQueue_getEvent(A->inputq, &event)<0) return 1;

  type= AInputEvent_getType(event);
  // LOGV("New input event: type=%d\n", type);

  if (AInputQueue_preDispatchEvent(A->inputq, event)) goto again;

  switch(type)
  {
  case AINPUT_EVENT_TYPE_KEY: goto next_event;
  case AINPUT_EVENT_TYPE_MOTION: goto touch_event;
  }

next_event:
  AInputQueue_finishEvent(A->inputq, event, 1);
  goto again;

touch_event:
  action= AMotionEvent_getAction(event);
  index= (action & AMOTION_EVENT_ACTION_POINTER_INDEX_MASK)
              >>AMOTION_EVENT_ACTION_POINTER_INDEX_SHIFT;
  action= (action & AMOTION_EVENT_ACTION_MASK);

  switch(action)
  {
  case AMOTION_EVENT_ACTION_UP:
     ev->type= GFXEV_BUTTON_RELEASE;
     ev->button= 1;
     ev->x= AMotionEvent_getX(event,index);
     ev->y= AMotionEvent_getY(event,index);
          ev->key= AMotionEvent_getTouchMajor(event,index);
          ev->wide= AMotionEvent_getTouchMinor(event,index);
     A->last_pointer_id= -1;
     break;
  case AMOTION_EVENT_ACTION_DOWN:
     ev->type= GFXEV_BUTTON_PRESS;
     ev->x= AMotionEvent_getX(event,index);
     ev->y= AMotionEvent_getY(event,index);
          ev->key= AMotionEvent_getTouchMajor(event,index);
          ev->wide= AMotionEvent_getTouchMinor(event,index);
     ev->button= 1;
     A->last_pointer_id= AMotionEvent_getPointerId(event, index);    
     break;
  case AMOTION_EVENT_ACTION_MOVE:
     npointers= AMotionEvent_getPointerCount(event);
     for(i=0;i<npointers;i++)
        if (AMotionEvent_getPointerId(event, i)==A->last_pointer_id)
        { 
          ev->type= GFXEV_POINTER_MOVE;
          ev->x= AMotionEvent_getX(event,i);
          ev->y= AMotionEvent_getY(event,i);
          ev->key= AMotionEvent_getTouchMajor(event,i);
          ev->wide= AMotionEvent_getTouchMinor(event,i);
          goto done;
        }
  default:
     goto next_event;
  }

done:
  AInputQueue_finishEvent(A->inputq, event, 1);
  return 0;
}


static int get_event(unsigned int *msecs, gfx_event_t *E)
{
   int ident;
   int value;
   int dFD, dEV;
   app_t *app;
   int elapsed, have_event;
   int have_timer, initime, delay;

again:
   have_timer= have_user_timer(&delay);
   if (delay<0) have_timer= 0;
   if (have_timer&&(delay==0))
     return elapsed_user_timer(0, 1, E);
   if (have_timer) initime= millitime();

   ident= ALooper_pollAll(have_timer? delay: -1,  &dFD, &dEV, (void**) &app);

   have_event= 0;

   switch(ident)
   {
     // somebody might have woke us up because the looper
     // has changed and we need to poll again.
   case ALOOPER_POLL_WAKE:
      break;
   case PIPE_CMD:
      switch(handle_command(app, &value))
      {
      case 1: E->type= GFXEV_QUIT; have_event=1;   break;
      case 2: E->type= GFXEV_SAVE_STATE; have_event=1; break;
      case 3: E->type= GFXEV(value,JAVARESULT); have_event= 1; break;
      }
      break;
   case PIPE_EVENT:
      if (!handle_input(app, E) && app->window)
        have_event= 1;
      break;
   case ALOOPER_POLL_TIMEOUT:
      // the timeout has elapsed completely
      // this should always return 1, because we got the
      // delay from there..
      if (elapsed_user_timer(delay, 1, E)) return 1;
      goto again;
   default:
      if ((ident&0xffff0000)==0x00010000)
      {
        ident ^= 0x00010000;
        E->key= ident; E->wide= dFD;
        if (dEV&(ALOOPER_EVENT_HANGUP|ALOOPER_EVENT_ERROR|
                 ALOOPER_EVENT_INVALID))
           E->type= GFXEV_READY_EXCEPT;
        else if (dEV&ALOOPER_EVENT_INPUT)
           E->type= GFXEV_READY_READ;
        else if (dEV&ALOOPER_EVENT_OUTPUT)
           E->type= GFXEV_READY_WRITE;
        else 
           E->type= GFXEV_READY_EXCEPT;
        have_event= 1;
        break;
      }
   }

   elapsed= millitime()- initime;
   if (have_event)
   {
     if (have_timer)
        elapsed_user_timer(elapsed, 0, NULL);
     return 1;
   }
   if (have_timer && elapsed_user_timer(elapsed,1,E))
     return 1;
   goto again;
}

int gfx_event (unsigned int *msecs, gfx_event_t *E)
{
retry:
  if (!get_event(msecs,E)) return 0;
  if (vkey_event(E)) goto retry;
  switch(E->type)
  {
  case GFXEV_POINTER_MOVE:
     if (handle_motion_event(E)==2) goto retry;
     break;
  case GFXEV_BUTTON_PRESS:
     if (handle_click_event(E)==2) goto retry;
     break;
  case GFXEV_BUTTON_RELEASE:
     if (handle_release_event(E)==2) goto retry;
     break;
  }
  if (focusable_event(E)) goto retry;
  return 1;
}

static int event_noprocess(unsigned int *msecs,gfx_event_t *E)
{
  return get_event(msecs,E);
}


JavaVM *gfx_get_javavm()
{
  return my_app->activity->vm;
}

ANativeActivity* gfx_get_activity()
{
  return my_app->activity;
}

void gfx_save_state(uint32_t len, uint8_t *data)
{
  if (!my_app->save_request) return ;
  my_app->save_request->d.buffer.size= len;
  my_app->save_request->d.buffer.ptr= data;
  complete_request(my_app, my_app->save_request);
}


#ifdef GFX_ANDROID_ACTIVITY

static void have_java_result(JNIEnv* env, jobject thiz, jint rcode)
{
  request_t R;
  R.type= CMD_JAVARESULT;
  R.d.intv= rcode;
  make_request(my_app, &R);
}


jint JNI_OnLoad(JavaVM *vm, void *reserved)
{
  static JNINativeMethod methods[]=
  {
   { "haveresult", "(I)V", (void*) have_java_result },
  };
  JNIEnv* env;
  int R,att;
  att= 0;
  R= (*vm)->GetEnv(vm, (void**) &env, JNI_VERSION_1_6); 
  if (R==JNI_EDETACHED)
  {
    R= (*vm)->AttachCurrentThread(vm, &env, NULL);
    if (R) return -1;
    att= 1;
  }

  jclass cls= (*env)->FindClass(env, GFX_ANDROID_ACTIVITY);
  (*env)->RegisterNatives(env, cls, methods,
                          sizeof(methods)/sizeof(methods[0]));
  return JNI_VERSION_1_6;
}
#endif


static jclass Jcls(JNIEnv *env, const char *name)
{
  return (*env)->FindClass(env, name);
}

static jclass JclsO(JNIEnv *env, jobject obj)
{
  return (*env)->GetObjectClass(env, obj);
}

static jobject JstaticfieldO
    (JNIEnv *env, jclass cls, const char *name,const char *type)
{
  jfieldID fid;
  fid= (*env)->GetStaticFieldID(env, cls, name, type);
  return (*env)->GetStaticObjectField(env, cls, fid);
}

  // returns and object (O) and takes an object (o)
static jobject JmethodO_o
  (JNIEnv *env, jobject obj, 
   const char *name, const char *proto,
   jobject arg1)
{
  jmethodID mid;
  jclass cls;

  cls= (*env)->GetObjectClass(env, obj);
  mid= (*env)->GetMethodID(env, cls, name, proto);
  return (*env)->CallObjectMethod(env, obj, mid, arg1);
}

  // returns and object (O) and takes no arguments
static jobject JmethodO
  (JNIEnv *env, jobject obj, const char *name, const char *proto)
{
  jmethodID mid;
  jclass cls;

  cls= (*env)->GetObjectClass(env, obj);
  mid= (*env)->GetMethodID(env, cls, name, proto);
  return (*env)->CallObjectMethod(env, obj, mid);
}

  // returns a boolean (B) and takes an object (o) and an integer (i)
static jboolean JmethodB_oi
  (JNIEnv *env, jobject obj, 
   const char *name, const char *proto,
   jobject arg1, int arg2)
{
  jmethodID mid;
  jclass cls;
  cls= (*env)->GetObjectClass(env, obj);
  mid= (*env)->GetMethodID(env, cls, name, proto);
  return (*env)->CallBooleanMethod(env, obj, mid, arg1, arg2);
}

static jint JmethodI
  (JNIEnv *env, jobject obj, const char *name) 
{
  jmethodID mid;
  jclass cls;
  cls= (*env)->GetObjectClass(env, obj);
  mid= (*env)->GetMethodID(env, cls, name, "()I");
  return (*env)->CallIntMethod(env, obj, mid);
}
 

void gfx_soft_keyboard(int show)
{
  JNIEnv* J;
  JavaVM *vm;
  ANativeActivity* activity;
  int R, att;
  int flags;

  jobject jo_activity;
  jobject jo_imm;
  jobject jo_decorview;
  jboolean result;
 
  activity= my_app->activity;
   // fuck this shit. clazz is actually a pointer to the
   // activity object.
  vm= my_app->activity->vm;
  
  att= 0;
  R= (*vm)->GetEnv(vm, (void**) &J, JNI_VERSION_1_6); 
  if (R==JNI_EDETACHED)
  {
    R= (*vm)->AttachCurrentThread(vm, &J, NULL);
    if (R) return ;
    att= 1;
  }

  jo_activity= activity->clazz;
  flags= 0;

  jo_imm= JmethodO_o(J, jo_activity, 
             "getSystemService", "(Ljava/lang/String;)Ljava/lang/Object;",
             JstaticfieldO(J, 
               Jcls(J,"android/content/Context"),
               "INPUT_METHOD_SERVICE", "Ljava/lang/String;"));

  jo_decorview= JmethodO(J,
                  JmethodO(J, jo_activity,
                    "getWindow", "()Landroid/view/Window;"),
                  "getDecorView", "()Landroid/view/View;"); 
  if (show) 
     result= JmethodB_oi(J, jo_imm, 
               "showSoftInput", "(Landroid/view/View;I)Z",
               jo_decorview, flags);
  else 
     result= JmethodB_oi(J, jo_imm,
               "hideSoftInputFromWindow", "(Landroid/os/IBinder;I)Z",
               JmethodO(J, jo_decorview,  
                 "getWindowToken", "()Landroid/os/IBinder;"),
               flags);
  if (att) (*vm)->DetachCurrentThread(vm);
}



/**************
This is from:

https://groups.google.com/forum/?fromgroups=#!topic/android-ndk/Tk3g00wLKhk

It uses the C++ interface. The corresponding Java code is this:

  imm= activity.getSystemService(Context.INPUT_METHOD_SERVICE);
  decorview= activity.getWindow().getDecorView();

  if (show) 
      result= imm.showSoftInput(decorview, 0);
  else 
      result= imm.hideSoftInputFromWindow(decorview.getWindowToken(), 0);

void displayKeyboard(bool pShow) 
{
    // Attaches the current thread to the JVM.
    jint lResult;
    jint lFlags = 0;

    JavaVM* lJavaVM = mApplication->activity->vm;
    JNIEnv* lJNIEnv = mApplication->activity->env;

    JavaVMAttachArgs lJavaVMAttachArgs;
    lJavaVMAttachArgs.version = JNI_VERSION_1_6;
    lJavaVMAttachArgs.name = "NativeThread";
    lJavaVMAttachArgs.group = NULL;

    lResult=lJavaVM->AttachCurrentThread(&lJNIEnv,
&lJavaVMAttachArgs);
    if (lResult == JNI_ERR) {
        return;
    }

    // Retrieves NativeActivity.
    jobject lNativeActivity = mApplication->activity->clazz;
    jclass ClassNativeActivity = lJNIEnv->GetObjectClass(lNativeActivity);

    // Retrieves Context.INPUT_METHOD_SERVICE.
    jclass ClassContext = lJNIEnv->FindClass("android/content/
Context");
    jfieldID FieldINPUT_METHOD_SERVICE =
        lJNIEnv->GetStaticFieldID(ClassContext,
            "INPUT_METHOD_SERVICE", "Ljava/lang/String;");
    jobject INPUT_METHOD_SERVICE =
        lJNIEnv->GetStaticObjectField(ClassContext,
            FieldINPUT_METHOD_SERVICE);
    jniCheck(INPUT_METHOD_SERVICE);

    // Runs getSystemService(Context.INPUT_METHOD_SERVICE).
    jclass ClassInputMethodManager = lJNIEnv->FindClass(
        "android/view/inputmethod/InputMethodManager");
    jmethodID MethodGetSystemService = lJNIEnv->GetMethodID(
        ClassNativeActivity, "getSystemService",
        "(Ljava/lang/String;)Ljava/lang/Object;");
    jobject lInputMethodManager = lJNIEnv->CallObjectMethod(
        lNativeActivity, MethodGetSystemService,
        INPUT_METHOD_SERVICE);

    // Runs getWindow().getDecorView().
    jmethodID MethodGetWindow = lJNIEnv->GetMethodID(
        ClassNativeActivity, "getWindow",
        "()Landroid/view/Window;");
    jobject lWindow = lJNIEnv->CallObjectMethod(lNativeActivity,
        MethodGetWindow);
    jclass ClassWindow = lJNIEnv->FindClass(
        "android/view/Window");
    jmethodID MethodGetDecorView = lJNIEnv->GetMethodID(
        ClassWindow, "getDecorView", "()Landroid/view/View;");
    jobject lDecorView = lJNIEnv->CallObjectMethod(lWindow,
        MethodGetDecorView);

    if (pShow) {
        // Runs lInputMethodManager.showSoftInput(...).
        jmethodID MethodShowSoftInput = lJNIEnv->GetMethodID(
            ClassInputMethodManager, "showSoftInput",
            "(Landroid/view/View;I)Z");
        jboolean lResult = lJNIEnv->CallBooleanMethod(
            lInputMethodManager, MethodShowSoftInput,
            lDecorView, lFlags);
    } else {
        // Runs lWindow.getViewToken()
        jclass ClassView = lJNIEnv->FindClass(
            "android/view/View");
        jmethodID MethodGetWindowToken = lJNIEnv->GetMethodID(
            ClassView, "getWindowToken", "()Landroid/os/IBinder;");
        jobject lBinder = lJNIEnv->CallObjectMethod(lDecorView,
            MethodGetWindowToken);

        // lInputMethodManager.hideSoftInput(...).
        jmethodID MethodHideSoftInput = lJNIEnv->GetMethodID(
            ClassInputMethodManager, "hideSoftInputFromWindow",
            "(Landroid/os/IBinder;I)Z");
        jboolean lRes = lJNIEnv->CallBooleanMethod(
            lInputMethodManager, MethodHideSoftInput,
            lBinder, lFlags);
    }

    // Finished with the JVM.
    lJavaVM->DetachCurrentThread(); 
}

 **************/

#endif

#ifndef GFX_ANDROID
/* The event routine returns an event from the queue. It waits a maximum
   of 'msecs' milliseconds for the event. If msecs is zero, it waits 
   until an event is received. 

   The return value is one if an event is returned. It's zero if the
   return was due to timeout.

   In case of an event, *msecs is updated to reflect the remaining
   wait time.  */
   
int gfx_event(unsigned int *msecs,gfx_event_t *Revent)
{
  int K;

again:
  K= event_noprocess(msecs, Revent);
  if (!K) return 0;
  
  if (vkey_event(Revent)) goto again;
  switch(Revent->type)
  {
  case GFXEV_BUTTON_PRESS:
  case GFXEV_BUTTON_RELEASE:
  case GFXEV_POINTER_MOVE:
    if (handle_grabbed_event(Revent)) goto again; break;
  }

  switch(Revent->type)
  {
  case GFXEV_BUTTON_PRESS:
     if (handle_click_event(Revent)) goto again; break;
  case GFXEV_BUTTON_RELEASE:
     if (handle_release_event(Revent)) goto again; break;
  case GFXEV_POINTER_MOVE:
     if (handle_motion_event(Revent)) goto again; break;
  }

  if (focusable_event(Revent)) goto again;

  return 1; 
}

#endif


/***********************************************************************
 Here are some utility functions for graypix and whatnot.
 ***********************************************************************/
static graypix_t graypix_sub(graypix_t src, int ofx, int ofy)
{
  if (ofx>=src.w)  src.w= 0; 
  else if (ofx>0)  { src.w-= ofx; src.data+= ofx; }

  if (ofy>=src.h)  src.h= 0; 
  else if (ofy>0)  { src.h-= ofy; src.data+= ofy*src.stride; }

  return src; 
}

static colorpix_t pix_sub(colorpix_t src, int ofx, int ofy)
{
  if (ofx>=src.w)  src.w= 0; 
  else if (ofx>0)  { src.w-= ofx; src.data+= ofx; }

  if (ofy>=src.h)  src.h= 0; 
  else if (ofy>0)  { src.h-= ofy; src.data+= ofy*src.stride; }

  return src; 
}

static void gfx_update_all()
{
  gfx_update(0,0,x_window_width, x_window_height);
}

static uint32_t *get_server_pix(int src_x,int src_y,int w,int h)
{
  uint32_t *D; int dw;
  int x,y;
  D= calloc(1,sizeof(uint32_t*)*w*h);
  dw= w;
  clip_for_rect(&src_x, &w, x_window_width);
  clip_for_rect(&src_y, &h, x_window_height);

  for(y=0;y<h;y++)
    for(x=0;x<w;x++)
      D[x+y*dw]= x_image_data[y+src_y][x+src_x];
  return D;
}

static void put_server_pix(uint32_t *D,int dst_x,int dst_y,int w, int h)
{
  int dw;
  int x,y;
  dw= w;
  clip_for_rect(&dst_x, &w, x_window_width);
  clip_for_rect(&dst_y, &h, x_window_height);

  for(y=0;y<h;y++)
    for(x=0;x<w;x++)
      x_image_data[y+dst_y][x+dst_x]= D[x+y*dw];
}

static void extract_resource_image_mask(uint32_t *D, uint8_t **Rmask)
{
  unsigned int W,H,sz,i;
  uint8_t *m;
  if (*Rmask) return ;
  W= D[0] & ~(1<<31);
  H= D[1];
  D+= 2;
  sz= W*H;
  m= malloc(sz);
  *Rmask= m;
  for(i=0;i<sz;i++) m[i]= D[i]>>24;
}

static void put_server_pix_alphamask
   (uint32_t *D,uint8_t *mask,int dst_x,int dst_y,int w, int h)
{
  int dw;
  int x,y;

  dw= w;
  clip_for_rect(&dst_x, &w, x_window_width);
  clip_for_rect(&dst_y, &h, x_window_height);

  for(y=0;y<h;y++)
    for(x=0;x<w;x++)
      if (mask[x+y*dw])
         x_image_data[y+dst_y][x+dst_x]= D[x+y*dw];
}


static void populate_select_set
  (int *Rmaxfd, fd_set *rfd, fd_set *wfd, fd_set *xfd)
{
  int maxfd;
  int i;
  maxfd= *Rmaxfd;
  for(i=0;i<n_fmon;i++)
  {
    if (fmon[i].events&1) FD_SET(fmon[i].fd, rfd);
    if (fmon[i].events&2) FD_SET(fmon[i].fd, wfd);
    if (fmon[i].events&4) FD_SET(fmon[i].fd, xfd);
    maxfd= imax2(maxfd, fmon[i].fd);
  }
  *Rmaxfd= maxfd;
}

static int get_file_monitor_event
  (fd_set *rfd, fd_set *wfd, fd_set *xfd, gfx_event_t *Revent)
{
  static int last_pos;
  file_monitor_t *F;
  int i;

  if (!n_fmon) return 0;
  if (last_pos>=n_fmon) last_pos%=n_fmon;
  for(i=0;i<n_fmon;i++)
  {
     F= fmon + (i+last_pos)%n_fmon;
     if ((F->events&4) && FD_ISSET(F->fd, xfd)) 
          { Revent->type= GFXEV_READY_EXCEPT; goto found; }
     if ((F->events&2) && FD_ISSET(F->fd, wfd)) 
          { Revent->type= GFXEV_READY_WRITE; goto found; }
     if ((F->events&1) && FD_ISSET(F->fd, rfd)) 
          { Revent->type= GFXEV_READY_READ; goto found; }
  }
  return 0;
found:
  Revent->key= F->ident;
  Revent->wide= F->fd;
  last_pos= (last_pos+1)%n_fmon;
  return 1;
}


static char *nstrdup(const char *k)
{
  if (k) return strdup(k);
    else return NULL;
}

static int flag2(int a,int b)
{
  int S= 0;
  if (a) S|= 2;
  if (b) S|= 1;
  return S;
}
static int range_test(int v, int s, int w) { return v>=s && v<(s+w); }


static int imin2(int a,int b) { return a < b ? a : b; }
static int imax2(int a,int b) { return a > b ? a : b; }


static double dmin2(double a,double b) { return a<b?a:b; }
static double dmax2(double a,double b) { return a>b?a:b; }

static int utf8_encode_string
    (const uint32_t* wstr,size_t wlen, uint8_t *dst, size_t *dlen)
{
/*
  This is all from
  http://www.cl.cam.ac.uk/~mgk25/unicode.html

  TODO: what to do if the input has invalid
  unicode chars such as unassigned chars etc?
  pass them thru?
*/

/* Encoding Table
                  Start-Byte    
 Min Value    8421 8421   hex     Length
0x04000000    1111 110x   fc        6
0x00200000    1111 10xx   f8        5
0x00010000    1111 0xxx   f0        4
0x00000800    1110 xxxx   e0        3
0x00000080    110x xxxx   c0        2 */
  int i,k,len;
  uint32_t chr;
  unsigned char *odst;

  static const unsigned int lowerlimit[]=
    { 0x04000000, 0x00200000, 0x00010000, 0x00000800, 0x00000080 };
  static const unsigned char topbits []= { 0xfc, 0xf8, 0xf0, 0xe0, 0xc0 };
  const unsigned char lower6=  0x3f; // binary 0011 1111
  const unsigned char seventh= 0x80; // binary 1000 0000
  const unsigned int bit31=    0x80000000; 

  odst= dst;

  while(wlen)
  {
    chr= *(wstr++); wlen--;
    if (chr<=0x7f)   { *(dst++)= chr; continue; }
    if (chr & bit31) { *(dst++)= chr & ~bit31; continue; }

    for(i=0;i<4;i++) if (chr >= lowerlimit[i]) break;
    len= 4-i+2;

    for(k=len-1;k>0;k--)
    {
      dst[k]= seventh | (chr & lower6);
      chr >>= 6;
    }
    dst[k]= chr | topbits[i];
    dst+= len;
  }

  *dlen= dst-odst;
  return 0;
}


/*
UTF-8 Table
8421 8421
110x xxxx   2 bytes    mask= e0  result= c0   min= 80       vmask= 1f
1110 xxxx   3 bytes    mask= f0  result= e0   min= 800      vmask= 0f
1111 0xxx   4 bytes    mask= f8  result= f0   min= 10000    vmask= 07
1111 10xx   5 bytes    mask= fc  result= f8   min= 200000   vmask= 03
1111 110x   6 bytes    mask= fe  result= fc   min= 4000000  vmask= 01

10xx xxxx   cont. byte mask= c0  result= 80   vmask= 3f
*/
static int utf8_decode_string
  (const uint8_t *input, size_t ilen, uint32_t *output, size_t *olen)
{
   const uint8_t *end,*start;
   static const uint32_t bit31= (1<<31);
   size_t L;
   int have_errors;
   int i, contb;
   uint8_t C;
   uint32_t outc; uint32_t min;

   end= input+ilen;
   L= 0;
   have_errors= 0;

   if (ilen==0) goto done;

again:
   C= input[0];
   if ( (C&0x80) ==0)    { outc= C; input++; goto out; }
   if ( (C&0xe0) ==0xc0) goto seq2; 
   if ( (C&0xf0) ==0xe0) goto seq3;
   if ( (C&0xf8) ==0xf0) goto seq4;

   // Here, we don't care about the seq5 and seq6 stuff.
   // they are invalid anyway, either overlong or greater
   // then the unicode limit. We just treat them as unrecognized
   // bytes and output them.
invalid_byte:
   outc= input[0] | bit31;
   input++;
   have_errors= 1;
   goto out;

seq2: outc= C & 0x1f;  min=    0x80; contb= 1; goto do_cont;
seq3: outc= C & 0x0f;  min=   0x800; contb= 2; goto do_cont;
seq4: outc= C & 0x07;  min= 0x10000; contb= 3; goto do_cont;

do_cont:
   start= input;
   input++;
   for(i=0;i<contb;i++)
   {
     if ((input==end) || ( (input[0]&0xc0) !=0x80)) goto reject;
     outc= (outc << 6) | (input[0]&0x3f);
     input++;
   }

   if (outc<min || outc>0x10ffff) goto reject; 
   if (outc>=0xd800 && outc<=0xdfff) goto reject;
   if (outc==0xffff || outc==0xfffe) goto reject;

out:
   output[L++]= outc;
   if (input<end) goto again;
done:
   *olen= L;
   return have_errors;
reject:
   input= start;
   goto invalid_byte; 
}


static uint32_t utf8_decode_single_char(char *src)
{
  uint32_t *dst;
  size_t L;
  L= strlen(src);
  dst= alloca(sizeof(*dst)*(L+1));
  utf8_decode_string((uint8_t*) src, L, dst, &L);
  if (L==0) return ' ';
  return dst[0];
}


static void utf8_encode_single_char(uint32_t wide, char *dst)
{
  /* This assumes that dst is big enough, at least 6 bytes. */
  size_t L;
  L= 6;
  utf8_encode_string(&wide,1, (uint8_t*) dst, &L);
}

static void utf8_decode_alloc(char *str, uint32_t **Rwstr, uint32_t *Rwlen)
{
  uint32_t *S;
  size_t L,SL;
  L= strlen(str);
  S= malloc((L+1)*sizeof(uint32_t));
  utf8_decode_string((uint8_t*)str, L, S, &SL);
  *Rwstr= S;
  *Rwlen= SL;
}


static int clip_for_rect(int *start, int *amount, int max)
{
  int end, am;
  am= *amount;
  if (am<=0) return 1;
  end= *start + am;
  if (end>max) end= max;
  if (*start<0) *start= 0;
  *amount= am= end - *start;
  return am<=0;
}

static void freeNnull(void *A)
{
  if (A) free(A);
}

static void *array_make1space
      (int pos,void **Rarray,int n, int *Rs, int eltsize)
{
  void *src, *dst;
  int cp;
  int s;

  src= *Rarray;
  s= *Rs;
  if (n<s)
  {
    dst= src;
  }
  else
  {
    if (s==0) s= 50;
         else s+= s/2;
    dst= malloc(s*eltsize);
  }

  if (dst!=src && src && pos)
    memcpy(dst, src, pos*eltsize);
  cp= n - pos;
  if (src && cp)
    memmove(dst+(pos+1)*eltsize, src+pos*eltsize, cp*eltsize);

  if (src && src!=dst) free(src);
  *Rarray= dst;
  *Rs= s;
  return dst+pos*eltsize;
}

static int clip_rrect(rrect_t *D, rrect_t *S)
{
  int XsE, YsE, XdE, YdE;
  XsE= S->x+S->w;   XdE= D->x+D->w;
  YsE= S->y+S->h;   YdE= D->y+D->h;

  if (XsE>XdE) S->w -= XsE-XdE; 
  if (YsE>YdE) S->h -= YsE-YdE; 

  if (S->x < D->x) { S->w -= D->x - S->x; S->x= D->x; }
  if (S->y < D->y) { S->h -= D->y - S->y; S->y= D->y; }

  if (S->w<=0 || S->h<=0) return 1;
  return 0;
}



#ifdef PATH_DEBUG
#define PRT printf
#else
#define PRT if (0) printf
#endif

static void strmove(char *dst,char *src)
{
  memmove(dst, src, strlen(src)+1);
}

static int remove_mid(char *path, char *pattern, int keep)
{
  char *k;
  k= strstr(path, pattern);
  if (!k) return 0;
  strmove(k+keep, k+strlen(pattern));
PRT("  (%s)\n",path);
  return 1;
}

static int remove_prefix(char *path, char *pattern, int keep)
{
  int i;
  for(i=0;pattern[i];i++)
   if (path[i]!=pattern[i]) return 0;
  strmove(path+keep,path+i);
PRT("  (%s)\n",path);
  return 1;
  
}

static char *has_suffix(char *path, char *sfx)
{
  int sL, pL,i;
  sL= strlen(sfx);
  pL= strlen(path);
  if (pL<sL) return NULL;
  path+= pL-sL;
  for(i=0;path[i];i++)
    if (path[i]!=sfx[i]) return NULL;
  return path;
}

static int remove_suffix(char *path,char *sfx,int keep)
{
  if (!(path=has_suffix(path,sfx))) return 0;
  path[keep]= 0;
PRT("  (%s)\n",path);
  return 1;
}


__PATH_PROTO char *path_file(char *path)
{
  char *G;
  if (!path || !path[0]) return strdup("");
  path= strdup(path);
  while(0
    || remove_mid(path,"/./",1) 
    || remove_mid(path,"//",1)  
    || remove_suffix(path,"/.",1)
    || remove_suffix(path,"/..",1)
       );
  G= strrchr(path,'/');
  if (G)
    strmove(path, G+1);
  return path;
}

static int dotdotlast(char *path)
{
  char *k, *u,*z;
  k= has_suffix(path,"/..");
  if (!k) return 0;

  z= NULL;
  for(u=path;u<k;u++)
    if (u[0]=='/') z= u;
  if (!z) return 0;
  z[1]= 0;
  return 1;
}

static int dotdot(char *path)
{
  char *k, *u,*z;
  k= strstr(path,"/../");
  if (k==NULL) return 0;
  if (k==path) return remove_prefix(path,"/../",1);
  z= NULL;
  for(u=path;u<k;u++)
   if (u[0]=='/') z= u;
  if (!z) strmove(path, k+4); 
     else strmove(z+1, k+4);
PRT("  (%s)\n",path);
  return 1;
}

__PATH_PROTO char *path_dir(char *path)
{
  char *G;
  if (!path || !path[0]) return strdup("");
  path= strdup(path);
  while(0
    || remove_mid(path,"/./",1) 
    || remove_mid(path,"//",1) 
    || remove_prefix(path,"/../",1)
    || remove_suffix(path,"/.", 1)
    || dotdot(path)
    || dotdotlast(path)
       );
  
  G= strrchr(path,'/');
  if (!G)           path[0]= 0; 
  else if (G==path) path[1]= 0; 
  else              G[0]= 0; 
  return path;
}

__PATH_PROTO char *path_wd()
{
  char *buf,*ret;
  size_t siz;
  siz= 1000;
again:
  buf= malloc(siz);
  if (getcwd(buf,siz)==NULL) 
  {
     if (errno==ERANGE) { siz+= siz/2; free(buf); goto again; }
     strcpy(buf,"/");
  }
  ret= strdup(buf);
  free(buf);
  return ret;
}

static char *pacom_fk(char *a,char* b)
{
  char *R;
  R= malloc(strlen(a)+strlen(b)+2);
  sprintf(R,"%s/%s",a,b);
  free(a);
  return R;
}

__PATH_PROTO char* path_absolute(char *path)
{
  if (!path || !path[0]) return strdup("");

  if (path[0]=='/') path= strdup(path);
              else  path= pacom_fk(path_wd(), path);

  while(0
    || remove_mid(path,"/./",1) 
    || remove_mid(path,"//",1) 
    || remove_prefix(path,"/../",1)
    || remove_suffix(path,"/.",1)
    || dotdot(path)
    || dotdotlast(path)
       );

  return path;
}

__PATH_PROTO char *path_relative(char *path, char *pivot)
{
  int i,j,k;
  int count;
  char *result;

  path= path_absolute(path);
  pivot= path_absolute(pivot);

  for(i=0;path[i];i++)
    if (path[i]!=pivot[i]) break;

  if (!path[i]) 
  {
    result= path_file(path);
    goto done;
  }

  count= 1;
  for(j=i-1;j>0;j--) if (path[j]=='/') break;

  /* from j to end, count how many directories you have.. */

  count= 0;
  for(k=j+1;path[k];k++) if (path[k]=='/') count++;

  result= malloc(strlen(path+j) + count*3 + 1);
  result[0]= 0;
  for(i=0;i<count;i++) strcat(result,"../");
  strcat(result,path+j+1);

done:
  free(path);
  free(pivot);
  return result;
}

__PATH_PROTO char *path_child(char *path,char *child)
{
  char *R;
  R= malloc(strlen(path) + strlen(child) + 2);
  sprintf(R,"%s/%s",path,child);
  return R;
}



WOMAP_PROTO void* womap_find(womap_t *map,uint32_t key)
{
  womap_node_t *node;

  node= map->root;
  if (!node) return NULL;

  while(node->internal) node= Q_CHLD(node, womap_dir(key,node));

  if (Q_KEY(node)==key) return Q_DATA(node);
                          else return NULL;
}


WOMAP_PROTO void* womap_insert(womap_t* map, uint32_t key, void *data)
{
  womap_node_t *node_elt;

  if (!map->root)
  {
     map->root= womap_leaf_node(key,data);
     return 0;
  }

  node_elt= map->root;
  while(node_elt->internal)
    node_elt= Q_CHLD(node_elt, womap_dir(key,node_elt));

  
  uint32_t elt;
  int dir_elt;
  uint8_t bit;
  womap_node_t *node_key;

  elt= Q_KEY(node_elt);

  if (elt==key) return Q_DATA(node_elt);

  bit= womap_crit_bit(elt,key);

  dir_elt= (elt>>bit)&1;

  node_key= womap_internal_node(bit);
  Q_CHLD(node_key,1-dir_elt)= womap_leaf_node(key,data);

  womap_node_t *parent;
  womap_node_t *node;

  parent= 0;
  node= map->root;

  while(node->internal)
  {
     if (node->bit>bit) break;
     parent= node;
     node= Q_CHLD(node, womap_dir(key,node));
  }

  Q_CHLD(node_key,dir_elt)= node;
  if (parent) { if (Q_CHLD(parent,0)==node)  Q_CHLD(parent,0)= node_key;
                                       else  Q_CHLD(parent,1)= node_key; }
  else map->root= node_key;
  return 0;
}

WOMAP_PROTO void *womap_remove(womap_t* map, uint32_t key)
{
  void *retv;

  if (!map->root) return NULL;

   
  womap_node_t *node;
  womap_node_t *sibling;
  womap_node_t *parent;
  womap_node_t *gparent;

  node= map->root;
  gparent= 0;
  sibling= 0;
  parent= 0;

  while(node->internal)
  {
    int dir;
    dir= womap_dir(key, node);
    gparent= parent;
    parent= node;
    sibling= Q_CHLD(node, 1-dir);
    node= Q_CHLD(node, dir);
  }

  if (Q_KEY(node)!=key) return NULL;
  retv= Q_DATA(node);
  free(node);

  if (!gparent)
  {
     map->root= sibling;
     if (parent) free(parent);
     return retv;
  }

  if (Q_CHLD(gparent,0)==parent) Q_CHLD(gparent,0)= sibling;
                            else Q_CHLD(gparent,1)= sibling;
  free(parent);

  return retv;
}

WOMAP_PROTO void *womap_destroy(womap_t *map)
{
  womap_node_t *node;
  womap_node_t *parent;
  womap_node_t *gparent;
  womap_node_t *sibling;
  void *retv;

  if (!map->root) return 0;

  parent= 0;
  gparent= 0;
  sibling= 0;
  node= map->root;
  while(node->internal)
  {
    gparent= parent;
    parent= node;
    sibling= Q_CHLD(node, 1);
    node= Q_CHLD(node,0);
  }
  retv= Q_DATA(node);
  free(node);
  if (!gparent) 
  {
    map->root= sibling;
    if (parent) free(parent);
    return retv;
  }
  if (Q_CHLD(gparent,0)==parent)
    Q_CHLD(gparent,0)= sibling;
  else
    Q_CHLD(gparent,1)= sibling;

  free(parent);

  return retv;
}

WOMAP_PROTO womap_t  *womap_new()
{
  womap_t *s;
  s= malloc(sizeof(*s));
  s->root= 0;
  return s;
}

static inline int womap_dir(uint32_t key,womap_node_t *node)
{
  return (key >> node->bit)&1;
}

static inline womap_node_t* womap_leaf_node(uint32_t key, void *data)
{
  womap_node_t *N;
  N= malloc(sizeof(*N));
  N->internal= 0;
  Q_KEY(N)= key;
  Q_DATA(N)= data; 
  return N;
}

static inline womap_node_t* womap_internal_node(uint32_t bit)
{
  womap_node_t *N;
  N= malloc(sizeof(*N));
  N->internal= 1;
  N->bit= bit;
  return N;
}

static uint8_t womap_crit_bit(uint32_t X, uint32_t Y)
{
  uint32_t i,j;
  static const uint32_t B[]=
  {
    0x55555555,
    0x33333333,
    0x0f0f0f0f,
    0x00ff00ff,
    0x0000ffff,
  };
  uint32_t A;
  A= X ^ Y;
  
  for(i=1;i<32;i<<=1) A |= (A<<i);
  A = ~A;
  for(j=0,i=1;i<32;i<<=1,j++) A= (A&B[j]) + ((A>>i)&B[j]);
  return A;
}



static void screen_store_contents()
{
  if (!screen) return ;

  screen->backstore= get_server_pix(0,0,x_window_width,x_window_height);
  screen->back_w= x_window_width;
  screen->back_h= x_window_height;
}

static void screen_restore_contents(screen_t *S)
{
  if (!S || !S->backstore) return ;
  put_server_pix(S->backstore, 0,0,S->back_w,S->back_h);
  gfx_update(0,0,x_window_width,x_window_height);
  free(S->backstore);
  S->backstore= NULL;
}

static void enter_screen
   (int n_widgets, int *widgets,int *co)
{
  screen_t *S;

  screen_op_count++;

  if (screen)
  {
    widget_t *W;
    W= screen->focus_widget;
    if (W && W->focus && W->has_focus)
    {
      (*W->focus)(W,0);
      W->has_focus= 0; 
    }
  }
  gfx_hide_virtual_keyboard();

  screen_store_contents();

  S= calloc(1,sizeof(*S));
  S->down= screen;
  if (screen) screen->up= S;
  screen= S;

  if (co[0]<0) co[0]= 0;
  if (co[1]<0) co[1]= 0;
  if (co[2]<=0) co[2]= x_window_width;
  if (co[3]<=0) co[3]= x_window_height;

  S->x= co[0]; S->y= co[1];
  S->w= co[2]; S->h= co[3]; 

  if (S->x>=x_window_width) S->x= 0;
  if (S->y>=x_window_height) S->y= 0;
  if (S->x+S->w>x_window_width) S->w= x_window_width-S->x;
  if (S->y+S->h>x_window_height) S->h= x_window_height-S->y;

  S->n_widgets= n_widgets;
  S->widgets= widgets;

  gfx_fill_rect(0,S->x,S->y,S->w,S->h,0xededed);
  if (S->x>0 || S->y>0)
    gfx_draw_rect(0, S->x-1,S->y-1,S->w+2,S->h+2, 0x00);
}


static int install_click_handler
        (int x,int y,int w,int h,int *enabled,
         void *arg, int (*func)(void*,gfx_event_t*),int button)
{
  click_handler_t *C;
  int R;
  if (!screen) return 0;

  if (screen->n_click_handlers==screen->s_click_handlers)
  {
    int delta;
    if (screen->s_click_handlers) delta= 1+screen->s_click_handlers/2;
                             else delta= 1+screen->n_widgets;
    screen->s_click_handlers+= delta;
    screen->click_handlers= realloc(screen->click_handlers, 
                                    sizeof(click_handler_t)*
                                       screen->s_click_handlers);
  }
  R= screen->n_click_handlers;
  screen->n_click_handlers++;
  C= screen->click_handlers + R;
  C->x= x;
  C->y= y;
  C->w= w;
  C->h= h;
  C->enabled= enabled;
  C->arg= arg;
  C->func= func;
  C->button= button;
  return R;
}

static void install_release_handler
        (void *arg, int (*func)(void*,gfx_event_t*))
{
  if (!screen) return ;
  screen->release_handler.func= func;
  screen->release_handler.arg= arg;
}

static void install_motion_handler(void *arg,int (*func)(void *,gfx_event_t*))
{
  if (!screen) return ;
  screen->motion_handler.func= func;
  screen->motion_handler.arg= arg;
}

static void uninstall_motion_handler()
{
  if (!screen) return ;
  screen->motion_handler.func= NULL;
  screen->motion_handler.arg= NULL;
}

/***************
Now we have yet another handler for mouse events. Sometimes, it's necessary
to grab all mouse events. For example, the dropdown widget does this. If
the user clicks outside the dropdown list, the list gets hidden.
***************/

static int handle_grabbed_event(gfx_event_t *event)
{
  if (!screen || !screen->grabber.func) return 0;
  return (*screen->grabber.func)(screen->grabber.arg, event);
}

static void grab_mouse(int (*func)(void*,gfx_event_t*), void *arg)
{
  if (!screen) return ;
  screen->grabber.func= func;
  screen->grabber.arg= arg;
}

static void ungrab_mouse()
{
  if (!screen) return ;
  screen->grabber.func= NULL;
  screen->grabber.arg= NULL;
}


static int handle_click_event(gfx_event_t *event)
{
  int i;
  click_handler_t *C;

  if (!screen || event->type!=GFXEV_BUTTON_PRESS) return 0;
  for(i=0;i<screen->n_click_handlers;i++)
  {
    C= screen->click_handlers+i;
    if (C->button!=event->button) continue;
    if (range_test(event->x,C->x, C->w) && range_test(event->y,C->y, C->h))
    {
             // if the widget was disabled, look for something else
      if ((!C->enabled || C->enabled[0])&& C->func)
           return (*C->func)(C->arg, event);
    }
  }
  return 0;
}

static void remove_click_handler(int H)
{
  int i;
  if (!screen) return;
  if (H<0 || H>=screen->n_click_handlers) return ;
  screen->click_handlers[H].func= NULL;
  for(i=H;i<screen->n_click_handlers;i++)
    if (screen->click_handlers[i].func!=NULL) return ;
  screen->n_click_handlers= H;
}


static int handle_release_event(gfx_event_t *event)
{
  void *A; int (*F)(void *,gfx_event_t*);
  if (!screen || event->type!=GFXEV_BUTTON_RELEASE || event->button!=1)
      return 0;
  if (screen->release_handler.func)
  {
    A= screen->release_handler.arg;
    F= screen->release_handler.func;
    screen->release_handler.arg= NULL;
    screen->release_handler.func= NULL;
    return (*F)(A, event);
  }
  return 0;
}

static int handle_motion_event(gfx_event_t *event)
{
  if (!screen || event->type!=GFXEV_POINTER_MOVE) return 0;
  if (screen->motion_handler.func)
     return (*screen->motion_handler.func)(screen->motion_handler.arg,event);
  return 0;
}


static void widget_destroy(widget_t* W)
{
  if (!W) return ;
  if (W->destroy) 
   { (*W->destroy)(W); widgets[W->number]= NULL; free(W); return ; }
  switch(W->klass)
  {
case GFXCLASS_RADIO:
  { radio_t *R= (void*) W;
    if (R->text) free(R->text);
    remove_click_handler(R->click); break; }

case GFXCLASS_SCROLLBAR: scrollbar_destroy((scrollbar_t*)W); break;
 case GFXCLASS_TEXTENTRY: textentry_free((text_entry_t*)W); break;

case GFXCLASS_PIXGRID: 
{
  gui_pixgrid_t *G;
  G= (gui_pixgrid_t*) W;
  remove_click_handler(G->click_handler);
  break;
}


case GFXCLASS_CANVAS: 
  { gui_canvas_t *CC= (void*) W;
    if (CC->buffer) free(CC->buffer);
    if (CC->scrollh) { scrollbar_destroy(CC->scrollh); free(CC->scrollh); }
    if (CC->scrollv) { scrollbar_destroy(CC->scrollv); free(CC->scrollv); }
    break;
  }


case GFXCLASS_SPINNER: gui_spinner_destroy((gui_spinner_t*) W); break;

    default: break;
  }
  widgets[W->number]= NULL;
  free(W);
}

static void widget_move(widget_t *W,int x,int y,int w,int h)
{
  if (!W) return ;
  if (W->position) { (*W->position)(W,x,y,w,h); return ; }
  switch(W->klass)
  {

case GFXCLASS_BUTTON:
case GFXCLASS_TOGGLE:
  button_set_position( (gui_button_t*) W, x,y,w,h);
  break;

case GFXCLASS_LABEL: gui_label_set_position((gui_label_t*)W, x,y,w,h); break; 

case GFXCLASS_RADIO:
  { radio_t *R; R= (void *)W;
    W->x= x; W->y= y; W->w= w; W->h= h;
    if (R->click!=-1) set_click_handler(R->click, x,y,w,h);
  radio_draw((radio_t*)W);
  break; }

case GFXCLASS_CHECKBOX:
  { checkbox_t *R; R= (void *)W;
    W->x= x; W->y= y; W->w= w; W->h= h;
    if (R->click!=-1) set_click_handler(R->click, x,y,w,h);
  checkbox_draw((checkbox_t*)W);
  break; }

case GFXCLASS_SCROLLBAR: 
  scrollbar_position((scrollbar_t*)W, x,y,w,h);
  break;
case GFXCLASS_PANEL: panel_position((panel_t *)W,x,y,w,h); break;
 case GFXCLASS_DROPDOWN: dropdown_position((dropdown_t*)W,x,y,w,h); break;

 case GFXCLASS_LIST:
  { gui_list_set_position((gui_list_t*)W, x,y,w,h); break; }


  case GFXCLASS_TEXTENTRY: textentry_position((text_entry_t*)W,x,y,w,h); break;


case GFXCLASS_PIXGRID:
{
  gui_pixgrid_t *G;
  G= (gui_pixgrid_t*) W;

  W->x= x;
  W->y= y;
  W->w= w;
  W->h= h;

  set_click_handler(G->click_handler,x,y,w,h);
  break;
}

 case GFXCLASS_SPINNER:
  gui_spinner_set_position((gui_spinner_t*)W, x,y,w,h); break; 

    default: break;
  }
}

static void widget_show(widget_t *W, int show)
{
  if (!W) return ;
  if (show) show= 1;

  if (W->show)
  {
    if (W->shown==show) return ;
    W->shown= show;
    if (W->shown) { (*W->show)(W); }
             else { if (W->hide) (*W->hide)(W); }
    return ;
  }

  switch(W->klass)
  {
case GFXCLASS_BUTTON:
case GFXCLASS_TOGGLE:
{
  gui_button_show((gui_button_t*) W, show);
  break;
}

case GFXCLASS_RADIO:
  radio_show((radio_t*) W,show);
  break;

case GFXCLASS_CHECKBOX:
  checkbox_show((checkbox_t*) W,show);
  break;

case GFXCLASS_SCROLLBAR: scrollbar_show((scrollbar_t*)W, show); break;
case GFXCLASS_PANEL: panel_show((panel_t*)W,show); break;
 case GFXCLASS_DROPDOWN: dropdown_show((dropdown_t*)W,show); break;

 case GFXCLASS_LIST: gfx_list_show((gui_list_t*) W,show); break;

case GFXCLASS_PIXGRID:
{
  gui_pixgrid_t *B;
  B= (gui_pixgrid_t*) W;
  if (B->enabled==show) break ;
  B->enabled= show;
  break;
}

case GFXCLASS_CANVAS: 
  { gui_canvas_t *CC= (void*) W;
    if (CC->enabled==show) break;
    CC->enabled= show;
    if (CC->enabled)
    {
      gui_canvas_draw_all(CC);
      gui_canvas_update_click_handlers(CC);
    }
    break;
  } 

 case GFXCLASS_SPINNER: gui_spinner_show((gui_spinner_t*) W,show); break;

    default: break;
  }
}

static void widget_set_text(widget_t *W, char *str)
{
  if (!W) return ;
  switch(W->klass)
  {
case GFXCLASS_TOGGLE:
case GFXCLASS_BUTTON:
  gui_button_set_text((gui_button_t*) W, str);
  break;

case GFXCLASS_LABEL: gui_label_set_text( (gui_label_t*) W,str); break;

case GFXCLASS_TEXTENTRY: text_entry_set((text_entry_t*)W,str); break;

    default: break;
  }
}

static char* widget_get_text(widget_t *W)
{
  char *str;
  if (!W) return strdup("");
  switch(W->klass)
  {
  case GFXCLASS_TEXTENTRY: str= textentry_get_text((text_entry_t*)W); break;

  default: str= strdup("");
  }
  return str;
}

static widget_t *get_widget(int wno)
{
  if (wno<=_XX_WIDGETS_START || wno>=_XX_WIDGETS_END) return NULL;
  return widgets[wno];
}

static void *get_widgetk(int wno,int klass)
{
  widget_t *W;
  W= get_widget(wno);
  if (!W) return NULL;
  if (W->klass!=klass) return NULL;
  return W;
}

static void widget_set_state(widget_t *W, int state)
{
  if (!W) return ;
  switch(W->klass)
  {
case GFXCLASS_TOGGLE:
{
  gui_button_t *B;
  B= (gui_button_t*) W;
  if (state) state= 1;
  button_set_state(B,state);
  break;
}

case GFXCLASS_RADIO:
  { radio_t *R; R= (void*) W;
    if (R->state==state) break;
    if (R->state) { R->state= 0; radio_draw_button(R,R->state,1,1); }
    else radio_set(R);
    break; }

case GFXCLASS_CHECKBOX:
  checkbox_set((checkbox_t *)W, state); 
  break;

  }
}

static int widget_get_state(widget_t *W)
{
  int result;
  if (!W) return 0;
  result= 0;
  switch(W->klass)
  {
case GFXCLASS_TOGGLE:
{
  gui_button_t *B;
  B= (gui_button_t*) W;
  result= B->state;
  if (result) result= 1;
  break;
}
case GFXCLASS_RADIO:
  { radio_t *R; R= (void*) W;
    result= R->state; break; }

case GFXCLASS_CHECKBOX:
  { checkbox_t *R; R= (void*) W;
    result= R->state; break; }

  }
  return result;
}

static int widget_get_selected(widget_t *W)
{
  int result;
  if (!W) return -1;
  result= -1;
  switch(W->klass)
  {
case GFXCLASS_RADIO:
  { radio_t *R; R= (void*) W;
    if (R->group==-1) return -1;
    return radio_group_get_selected(R->group); }

case GFXCLASS_DROPDOWN: 
  {
    dropdown_t* DD;
    DD= (dropdown_t *) W;
    result= DD->selected;
    break;
  }

 case GFXCLASS_LIST: result= gfx_list_selected((gui_list_t *)W); break;


  case GFXCLASS_ICONLIST:
    { gui_iconlist_t *IC= (gui_iconlist_t*)W;
      result= IC->sel; }
    break;

  }
  return result;
}

static void widget_set_selected(widget_t *W,int sel)
{
  if (!W) return ;
  switch(W->klass)
  {
case GFXCLASS_PANEL: panel_activate((panel_t *)W,sel); break;
case GFXCLASS_DROPDOWN: gfx_dropdown_select((dropdown_t*)W, sel); break;

 case GFXCLASS_LIST: gfx_list_select((gui_list_t*)W,sel); break;


  case GFXCLASS_ICONLIST:
    gui_iconlist_select_item((gui_iconlist_t*)W, sel);
    break;

  }
}

static void widget_set_fgbg(widget_t *W,int fg,int bg)
{
  if (!W) return ;
  switch(W->klass)
  {
case GFXCLASS_LABEL: label_set_fgbg((gui_label_t*) W, fg, bg); break;

  }
}

static void widget_insert
  (widget_t *W,int pos, char *text, void *user, uint32_t *icon)
{
  if (!W) return ;
  switch(W->klass)
  {
case GFXCLASS_DROPDOWN: dropdown_insert((dropdown_t*)W, pos, text, user); break;

case GFXCLASS_LIST:
  gfx_list_insert((gui_list_t*) W, pos, text, user, icon);
  break;

  }
}

static void widget_remove(widget_t *W,int pos, void **Ruser)
{
  if (!W) return ;
  switch(W->klass)
  {
case GFXCLASS_DROPDOWN: dropdown_remove((dropdown_t*)W,pos,Ruser); break;

 case GFXCLASS_LIST: gfx_list_delete((gui_list_t*)W,pos,Ruser); break;


  case GFXCLASS_ICONLIST:
    gui_iconlist_remove((gui_iconlist_t*)W, pos, Ruser);
    break;

  }
}

static void widget_clear(widget_t *W)
{
  if (!W) return ;
  switch(W->klass)
  {
case GFXCLASS_DROPDOWN: gui_dropdown_clear((dropdown_t*) W); break;

case GFXCLASS_LIST:
  gfx_list_clear((gui_list_t*) W);
  break;
 
  case GFXCLASS_ICONLIST:
    gui_iconlist_clear((gui_iconlist_t*) W);
    break;

  }
}


static void set_focus(widget_t *N)
{
  widget_t *W;
  if (!screen || !N) return ;
  if (!N->can_focus || N->has_focus) return ;

  W= screen->focus_widget;
  if (W && W->can_focus && W->has_focus)
  {
    if (W->focus) (*W->focus)(W, 0);
    W->has_focus= 0;
  }

  if (N->focus) (*N->focus)(N,1);
  N->has_focus= 1;
  screen->focus_widget= N;
}

static void remove_focus()
{
  widget_t *W;
  if (!screen) return ;

  W= screen->focus_widget;
  if (W && W->can_focus && W->has_focus)
  {
    if (W->focus) (*W->focus)(W, 0);
    W->has_focus= 0;
  }
  screen->focus_widget= NULL;
}

 // returns zero if successful
static int make_focus_event(gfx_event_t *E)
{
  widget_t *W;
  if (!screen) return 2;
  W= screen->focus_widget;
  if (!W) return 2;
  if (W->number<GFXEV_LAST+GFXRESERVED) return 2;
  E->type= GFXEV(W->number,FOCUS);
  return 0;
}


static int tabs_before(widget_t *A,widget_t *B)
{
  if (A->y<B->y) return 1;
  if (A->y==B->y && A->x<B->x) return 1;
  return 0;
}

static int focusable_event(gfx_event_t *event)
{
  int i;
  widget_t *W;
  W= NULL; // warnUNINVAR

  if (!screen) return 0; 
  if (event->type==GFXEV_BUTTON_PRESS) 
  { 
    // FIXME: check for modifiers
    if (event->button!=1) return 0;
    for(i=0;i<screen->n_widgets;i++)
    {
      W= widgets[screen->widgets[i]];
      if (!W) continue;
      if (W->can_focus &&
          range_test(event->x, W->x, W->w) &&
          range_test(event->y, W->y, W->h)) break;
    }
    if (i==screen->n_widgets || W==screen->focus_widget) return 0;
    screen->focus_clicked= W;
    return 1;
  }
  if (event->type==GFXEV_BUTTON_RELEASE)
  {
    // FIXME: check for modifiers
    if (event->button!=1 || !screen->focus_clicked) return 0;
    set_focus(screen->focus_clicked);
    screen->focus_clicked= NULL;
    return make_focus_event(event);
  }
  if (event->type==GFXEV_KEY_PRESS)
  {
    widget_t *target, *minpos,*current;

    W= screen->focus_widget;
    if (!W) return 0;
    if (W->handle_key && (*W->handle_key)(W, event)) return 1;

    // FIXME: handle shift-tab
    if (event->key!=GFX_K_TAB)  return 0;
    
    for(i=0;i<screen->n_widgets;i++)
      if (W->number==screen->widgets[i]) break;

    if (i==screen->n_widgets) return 0;
    target= NULL;
    minpos= NULL;
    current= widgets[screen->widgets[i]];
  
    for(i=0;i<screen->n_widgets;i++)
    {
      W= widgets[screen->widgets[i]];
      if (W==current || !W || !W->can_focus) continue;

                   // FIXME: check for visibility also..
      if (!minpos) minpos= W;
      else if (tabs_before(W,minpos)) minpos= W; 

      if (tabs_before(W,current)) continue;
      if (target && tabs_before(target,W)) continue;
      target= W;
    }
    if (!target) target= minpos;
    if (target)
    {
      set_focus(target);
      return make_focus_event(event);
    }
  }
  return 0;
}

static void focus_lost()
{
  if (!screen) return ;
  screen->focus_widget= NULL;
}

static void set_click_handler(int click,int x,int y,int w,int h)
{
  click_handler_t *C;
  if (!screen) return ;
  if (click<0 || click>=screen->n_click_handlers) return ;
  C= screen->click_handlers+click;
  C->x= x;
  C->y= y;
  C->w= w;
  C->h= h;
}


static int install_or_modify_click
  (int ch, int *enabled, int (*func)(void*,gfx_event_t*), void* arg,
   int x,int y,int w,int h,int button)
{
  if (ch==-1)
   return install_click_handler(x,y,w,h,enabled,arg, func,button);

  set_click_handler(ch, x,y,w,h);
  return ch;
}

static void widgetpos(widget_t *W,int x,int y,int w,int h)
{
  W->x= x; W->y= y; W->w= w; W->h= h;
}


static void get_screen_rect(screen_t *S, rect_t *A)
{
  A->top= S->y; A->bottom= S->y+S->h-1;
  A->left= S->x; A->right= S->x+S->w-1;
}

static void screen_compute_visible_parts(screen_t *S)
{
  rect_t A, B, D[4];
  rectque_t *Q;
  int i,N,L;
  screen_t *K;

  if (S->visible_parts_time==screen_op_count) return ;
  S->visible_parts_time= screen_op_count;

  if (S->visible_parts) free(S->visible_parts);

  Q= rectque_new();
  get_screen_rect(S, &A);
  rectque_put(Q, &A);
  
  for(K=S->up;K;K=K->up)
  {
    get_screen_rect(K,&B);
    L= rectque_len(Q);
    for(i=0;i<L;i++)
    {
      rectque_get(Q, &A);
      N= subtract_rectangle(&A, &B, D);
      rectque_putn(Q, D, N);
    }
  }

  rectque_get_data(Q, &S->visible_parts, &S->n_visible_parts);
  rectque_free(Q);
}


static colorpix_t get_screen_pix(screen_t *S)
{
  colorpix_t P;
  if (S->up)
  {
    P.w= S->back_w;
    P.h= S->back_h;
    P.stride= S->back_w;
    P.data= S->backstore;
  }
  else
  {
    P.w= x_window_width;
    P.h= x_window_height;
    P.stride= x_window_width;
    P.data= x_image_data[0];
  }
  return P;
}

static void screen_update_display(screen_t *S, int x,int y,int w, int h)
{
  int xx,yy;
  clip_for_rect(&x,&w, x_window_width);
  clip_for_rect(&y,&h, x_window_height);
  if (w<=0 || h<=0) return ;
  for(yy=y;yy<y+h;yy++)
    for(xx=x;xx<x+w;xx++)
      x_image_data[yy][xx]= S->backstore[xx+yy*S->back_w];
  gfx_update(x,y,w,h);
}

static int rectangle_intersect(rect_t *A, rect_t *B, rect_t *K)
{
  int N;
  *K= *A;
  N= 0;
  if (B->left>=A->left && B->left<=A->right) { K->left= B->left; N++; }
  if (B->right>=A->left && B->right<=A->right) { K->right= B->right; N++; }
  if (B->top>=A->top && B->top<=A->bottom) { K->top= B->top; N++; }
  if (B->bottom>=A->top && B->bottom<=A->bottom) { K->bottom= B->bottom; N++; }
  return N;
}

static void update_screen_pixels(screen_t *S, int x,int y, int w, int h)
{
  rect_t K, E;
  int i;
  if (!S->up)
  {
    gfx_update(x,y,w,h);
    return ;
  }
  screen_compute_visible_parts(S);
  E.top= y; E.bottom= y+h-1;
  E.left= x; E.right= x+w-1;
  for(i=0;i<S->n_visible_parts;i++)
  {
    if (rectangle_intersect(S->visible_parts+i, &E, &K))
      screen_update_display(S, K.left, K.top, 
                                K.right-K.left+1, K.bottom-K.top+1);
  }
}

static void generic_dummy_hide(widget_t *W) { }
static uint32_t blend_usr_usr(uint32_t alpha, uint32_t fg, uint32_t bg)
{
  uint32_t fR, fG, fB; 
  uint32_t bR, bG, bB; 
  uint32_t pR, pG, pB; 
  double A,B;

  fR= (fg>>16)&0xff; fG= (fg>>8)&0xff; fB= fg&0xff;

  if (alpha==0xff) { pR= fR; pG= fG; pB= fB; goto OK;}

  bR= (bg>>16)&0xff; bG= (bg>>8)&0xff; bB= bg&0xff;
  if (alpha==0) { pR= bR; pG= bG; pB= bB; goto OK; }

  A= (double) alpha / 255.0;
  B= 1.0-A;

  pR= A*fR + B*bR;
  pG= A*fG + B*bG;
  pB= A*fB + B*bB;

OK:
  return   ((pR<<x_red_shift)&x_red_mask)
         | ((pG<<x_green_shift)&x_green_mask)
         | ((pB<<x_blue_shift)&x_blue_mask);
}

static uint32_t blend_usr_usr_usr(uint32_t alpha, uint32_t fg, uint32_t bg)
{
  uint32_t fR, fG, fB; 
  uint32_t bR, bG, bB; 
  uint32_t pR, pG, pB; 
  double A,B;

  if (alpha==0xff)  return fg; 
  if (alpha==0)    return bg;  

  fR= (fg>>16)&0xff; fG= (fg>>8)&0xff; fB= fg&0xff;


  bR= (bg>>16)&0xff; bG= (bg>>8)&0xff; bB= bg&0xff;

  A= (double) alpha / 255.0;
  B= 1.0-A;

  pR= A*fR + B*bR;
  pG= A*fG + B*bG;
  pB= A*fB + B*bB;

  return  (pR<<16) | (pG<<8) | (pB<<0);
}

static uint32_t blend_usr_svr(uint32_t alpha, uint32_t fg, uint32_t bg)
{
  uint32_t fR, fG, fB; 
  uint32_t bR, bG, bB; 
  uint32_t pR, pG, pB; 
  double A,B;

  if (alpha==0) return bg;

  fR= (fg>>16)&0xff; fG= (fg>>8)&0xff; fB= fg&0xff;

  if (alpha==0xff) { pR= fR; pG= fG; pB= fB; goto OK;}

  bR= (bg&x_red_mask)>>x_red_shift; 
  bG= (bg&x_green_mask)>>x_green_shift;
  bB= (bg&x_blue_mask)>>x_blue_shift;

  A= (double) alpha / 255.0;
  B= 1.0-A;

  pR= A*fR + B*bR;
  pG= A*fG + B*bG;
  pB= A*fB + B*bB;

OK:
  return   ((pR<<x_red_shift)&x_red_mask)
         | ((pG<<x_green_shift)&x_green_mask)
         | ((pB<<x_blue_shift)&x_blue_mask);
}

static void blend_graypix_bg
   (int fg, int bg, graypix_t src, 
    colorpix_t dst, int posx, int posy)
{
  int x,y;

  clip_for_rect( &posx, &src.w, dst.w);
  clip_for_rect( &posy, &src.h, dst.h);
  if (src.w<=0 || src.h<=0) return ;

  for(y=0;y<src.h;y++)
    for(x=0;x<src.w;x++)   
      PIX(dst,x+posx,y+posy)= blend_usr_usr(PIX(src,x,y),fg, bg);
}

static void blend_graypix
   (int fg, graypix_t src, 
    colorpix_t dst, int posx, int posy)
{
  int x,y;

  clip_for_rect( &posx, &src.w, dst.w);
  clip_for_rect( &posy, &src.h, dst.h);
  if (src.w<=0 || src.h<=0) return ;

  for(y=0;y<src.h;y++)
    for(x=0;x<src.w;x++) 
      PIX(dst,x+posx,y+posy)= blend_usr_svr(PIX(src,x,y),fg, 
                                            PIX(dst,x+posx,y+posy));
}

static void colorpix_fill_rect
       (colorpix_t dst, int x,int y, int w, int h, int color)
{
  int xx,yy;
  clip_for_rect(&x, &w, dst.w);
  clip_for_rect(&y, &h, dst.h);
  if (w<=0 || h<=0) return ;
  color= color_u_to_s(color);
  for(yy=0;yy<h;yy++)
   for(xx=0;xx<w;xx++)
     PIX(dst, x+xx,y+yy)= color;
}

static void blend_graymap(int flags, int fg, int bg,
                          const unsigned char *src, int src_w, int src_h,
                          int src_x, int src_y,
                          int dst_x, int dst_y, int width, int height)
{
  int x,y;
  uint32_t A;

  clip_for_rect( &src_x, &width, src_w);
  clip_for_rect( &src_y, &height, src_h);
  clip_for_rect( &dst_x, &width, x_window_width);
  clip_for_rect( &dst_y, &height, x_window_height);
  if (width<=0 || height<=0) return ;

  if (flags&GFX_BACKGND) // blend with fg,bg pair
  {
    for(y=0;y<height;y++)
      for(x=0;x<width;x++)   
      {
        A= src[(x+src_x) + (y+src_y)*src_w];
        x_image_data[y+dst_y][x+dst_x]= blend_usr_usr(A,fg, bg);
      }
  } 
  else
  {
    for(y=0;y<height;y++)
      for(x=0;x<width;x++)   
      {
        A= src[(x+src_x) + (y+src_y)*src_w];
        x_image_data[y+dst_y][x+dst_x]= 
             blend_usr_svr(A,fg, x_image_data[y+dst_y][x+dst_x]);
      }
  } 

  if (flags&GFX_UPDATE)
    gfx_update(dst_x, dst_y, width, height);
}

static uint32_t color_s(uint32_t uR, uint32_t uG, uint32_t uB)
{
  return ((uR<<x_red_shift)&x_red_mask)
        |((uG<<x_green_shift)&x_green_mask)
        |((uB<<x_blue_shift)&x_blue_mask);
}

static uint32_t u_red(uint32_t C) { return (C>>16)&0xff; }
static uint32_t u_green(uint32_t C) { return (C>>8)&0xff; }
static uint32_t u_blue(uint32_t C) { return (C)&0xff; }

static uint32_t color_u_to_s(uint32_t U)
{
  return color_s(u_red(U), u_green(U), u_blue(U));
}

static unsigned int blend_chan(unsigned int F, double A, unsigned int B)
{
  return  (unsigned int) ((F&0xff)*A + (B&0xff)*(1-A));
}


static unsigned int blend(uint32_t F, double A, uint32_t B)
{
  return color_s(
            blend_chan( u_red(F), A, u_red(B)),
            blend_chan( u_green(F), A, u_green(B)),
            blend_chan( u_blue(F), A, u_blue(B))
                );
}


static void grad_fill(int x,int y, int w, int h, uint32_t start, uint32_t end)
{
  int fx, fy, fw, fh,x0,y0,dx,dy;
  fx= x; fy= y; fw= w; fh= h;

  clip_for_rect(&x, &w, x_window_width);
  clip_for_rect(&y, &h, x_window_height);
  if (w<=0 || h<=0) return;

  for(y0=0;y0<h;y0++)
    for(x0=0;x0<w;x0++)
    {
      dx= (x0+x)-fx; dy= (y0+y)-fy;
      x_image_data[y0+y][x0+x]= blend(start, 1.0-(double)(dx+dy)/(fw+fh), end);
    }
}

static void hline(int x1,int x2, int y,uint32_t color)
{
  if (y<0 || y>=x_window_height || x1>x2 || x1>=x_window_width) return ;
  if (x1<0) x1= 0;
  if (x2>=x_window_width) x2= x_window_width-1;

  for(;x1<=x2;x1++)
    x_image_data[y][x1]= color;
}

static void vline(int x,int y1, int y2,uint32_t color)
{
  if (x<0 || x>=x_window_width || y1>y2 || y1>=x_window_height) return ;
  if (y1<0) y1= 0;
  if (y2>=x_window_height) y2= x_window_height-1;

  for(;y1<=y2;y1++)
    x_image_data[y1][x]= color;
}




static void gfx_fill_rect(int flags, int dst_x,int dst_y,
                   int w,int h, unsigned int color)
{
  int x,y;
  uint32_t sv;
  clip_for_rect(&dst_x, &w, x_window_width);
  clip_for_rect(&dst_y, &h, x_window_height);
  if (w<=0 || h<=0) return ;
  sv= color_u_to_s(color);
  for(y=0;y<h;y++)
   for(x=0;x<w;x++)
     x_image_data[y+dst_y][x+dst_x]= sv;
  if (flags&GFX_UPDATE) gfx_update(dst_x, dst_y, w,h);
}


void gfx_draw_rect(int flags, int dst_x,int dst_y,
                   int w,int h, unsigned int color)
{
  uint32_t sv;
  sv= color_u_to_s(color);
  hline(dst_x, dst_x+w-1, dst_y, sv);
  hline(dst_x, dst_x+w-1, dst_y+h-1, sv);
  vline(dst_x, dst_y, dst_y+h-1, sv);
  vline(dst_x+w-1, dst_y, dst_y+h-1, sv);
  if (flags&GFX_UPDATE) gfx_update(dst_x, dst_y, w,h);
}

static void blend_graymap_buffer
        (unsigned int fg, const unsigned char *src, int src_w, int src_h,
                          int src_x, int src_y,
                          unsigned int *dst, int dst_w, int dst_h,
                          int dst_x, int dst_y, int width, int height)
{
  int x,y;
  uint32_t A,D;

  clip_for_rect( &src_x, &width, src_w);
  clip_for_rect( &src_y, &height, src_h);
  clip_for_rect( &dst_x, &width, dst_w);
  clip_for_rect( &dst_y, &height, dst_h);
  if (width<=0 || height<=0) return ;

  for(y=0;y<height;y++)
  {
    for(x=0;x<width;x++)   
    {
       A= src[(x+src_x) + (y+src_y)*src_w];
       D= (y+dst_y)*dst_w + (x+dst_x);
       dst[D]= blend_usr_usr_usr(A,fg, dst[D]);
    }
  }
}



static void gfx_put(int flags,
             const unsigned int *buffer, int src_w, int src_h,
             int src_x, int src_y,
             int dst_x, int dst_y,
             int width, int height)
{
  int x,y;

  clip_for_rect( &src_x, &width, src_w);
  clip_for_rect( &src_y, &height, src_h);
  clip_for_rect( &dst_x, &width, x_window_width);
  clip_for_rect( &dst_y, &height, x_window_height);
  if (width<=0 || height<=0) return ;

  if (!(flags&GFX_ALPHA)) 
  {
    for(y=0;y<height;y++)
      for(x=0;x<width;x++)
      {
         uint32_t sR, sG, sB, sP;
         uint32_t dP;
         sP= buffer[ (x+src_x) + (y+src_y)*src_w ];
         sR= (sP >> 16)&0xff;
         sG= (sP >> 8 )&0xff;
         sB= (sP      )&0xff;

         dP= (sR << x_red_shift)&x_red_mask;
         dP|= (sG << x_green_shift)&x_green_mask;
         dP|= (sB << x_blue_shift)&x_blue_mask;

         x_image_data[y+dst_y][x+dst_x]= dP;
       }
  }
  else
  {
    for(y=0;y<height;y++)
      for(x=0;x<width;x++)
    {
        uint32_t sA, sR, sG, sB, sP;
        uint32_t     dR, dG, dB, dP;

        sP= buffer[ (x+src_x) + (y+src_y)*src_w ];
        sA= (sP >> 24)&0xff;
        if (!sA) continue;

        sR= (sP >> 16)&0xff;
        sG= (sP >> 8 )&0xff;
        sB= (sP      )&0xff;

        if (sA==0xff)
        {
           dR= sR;
           dG= sG;
           dB= sB;
        }
        else 
        {
            double R,V;

            dP= x_image_data[y+dst_y][x+dst_x];

            dR= (dP & x_red_mask)>>x_red_shift;
            dG= (dP & x_green_mask)>>x_green_shift;
            dB= (dP & x_blue_mask)>>x_blue_shift;

            V= sA/255.0; R= 1.0 - V;

            dR=  dR*R + sR*V;
            dG=  dG*R + sG*V;
            dB=  dB*R + sB*V;
         }

         dP= (dR << x_red_shift)&x_red_mask;
         dP|= (dG << x_green_shift)&x_green_mask;
         dP|= (dB << x_blue_shift)&x_blue_mask;

         x_image_data[y+dst_y][x+dst_x]= dP;
     }
  }

  if (flags & GFX_UPDATE)
      gfx_update(dst_x,dst_y,width,height);
}


static unsigned int* convert_graymap_to_color
        (unsigned int fg, unsigned int bg, const unsigned char *src)
{
  unsigned int *buffer;
  int i;
  int w,h;
  w= src[0]; 
  h= src[1];
  src+= 2;
  buffer= malloc(sizeof(*buffer)*(w*h+2));
  for(i=0;i<w*h;i++) buffer[i+2]= bg;

  blend_graymap_buffer(fg, src, w,h, 0,0, buffer+2, w,h, 0,0, w,h);
  buffer[0]= w;
  buffer[1]= h;
  return buffer;
}


static void gfx_draw_3dbox(int x,int y,int w,int h, 
                        int light, int dark, int border,
                        int start, int end)
{
  int sX,sY,eX,eY;

  light= color_u_to_s(light);
  dark= color_u_to_s(dark);
  border= color_u_to_s(border);

  sX= x; eX= x + w - 1;
  sY= y; eY= y + h - 1;

  hline(sX, eX, sY,     border);
  hline(sX, eX, eY,     border);
  vline(sX, sY+1, eY-1, border);
  vline(eX, sY+1, eY-1, border);

  hline(sX+1, eX-2, sY+1, light);
  vline(sX+1, sY+1, eY-2, light);
  hline(sX+1, eX-1, eY-1, dark);
  vline(eX-1, sY+1, eY-1, dark);

  grad_fill(sX+2, sY+2, w-4, h-4, start, end);
}


static void convert_images_to_server(uint32_t **images)
{
  int i;
  for(i=0;images[i];i++)
  {
    convert_image_to_server(images[i]);
    images[i]= NULL;
  }
}

static void convert_image_to_server(uint32_t *IMG)
{
  int W,H,i;
  W= IMG[0];
  if (W&(1<<31))
  {
    H= IMG[1];
    W&= ~(1<<31);
    IMG+= 2;
    for(i=0;i<W*H;i++)
      IMG[i]= color_u_to_s(IMG[i]);
    IMG[-2] = W;
  }
}

static void draw_icon_and_text
                 (int x,int y,int w,int h,
                  int iconpos, uint32_t *icon,
                  int space,
                  uint32_t text_fg, char *text)
{
  int iw,ih,tw,th,ix,iy,tx,ty,total_w,total_h;
  total_w= total_h= 0; // warnUNINVAR
  if (!icon) 
  {
    if (text) goto text_only;
    return ;
  }
  if (!text)
  {
     draw_icon_centered(x,y,w,h,icon);
     return ;
  }
  // convert_image_to_server(icon);

  iw= icon[0] & ~(1<<31);
  ih= icon[1];
  get_text_data(1, text, &tw, &th,NULL,NULL);

  switch(iconpos)
  {
  case 'L': case 'R':
     total_w= iw+tw; 
     if (total_w>w) goto text_only;
     
     if (w-total_w<space) space= w-total_w;
     total_w+= space;
     break;
  case 'T': 
  case 'B': 
  default:
     total_h= ih+th;
     if (total_h>h) goto text_only;
     if (h-total_h<space) space= h-total_h;
     total_h+= space;
     break;
  }
  switch(iconpos)
  {
   case 'L':
     ix= (w - total_w)/2;
     tx= ix+iw+space;
     goto horz_render;
   case 'R':
     tx= (w - total_w)/2;
     ix= tx+tw+space;
     goto horz_render;
   case 'T':
     iy= (h-total_h)/2;
     ty= iy+ih+space;
     break;
   default:
   case 'B':
     iy= (h-total_h)/2;
     ty= iy+ih+space;
     break;
  }
  draw_icon_centered(x, y+iy, w, ih, icon);
  txt_print_fit("C.", "L>", x, y+ty, w, th, 1,1, text_fg,0xFFffFF, text);
  return ;

text_only:
  txt_print_fit("C.","C.",x,y,w,h,1,1,text_fg, 0xffffff, text);
  return ;
horz_render:
  draw_icon_centered(x+ix, y, iw, h, icon);
  txt_print_fit("L>", "C.", x+tx, y, tw, h, 1,1,text_fg,0xffFFff,text);
  return ;
}

static void draw_icon_centered(int x,int y,int w,int h, uint32_t *icon)
{
  int iw,ih, copy_w, copy_h, src_x, src_y, dst_x, dst_y;
  iw= icon[0];
  ih= icon[1];
  iw&=~(1<<31);
  if (iw<=w)
  {
    src_x= 0;
    dst_x= (w-iw)/2;
    copy_w= iw;
  }
  else
  {
    src_x= (iw-w)/2;
    dst_x= 0;
    copy_w= w;
  }
  if (ih<=h)
  {
    src_y= 0;
    dst_y= (h-ih)/2;
    copy_h= ih;
  }
  else
  {
    src_y= (ih-h)/2;
    dst_y= 0;
    copy_h= h;
  }
  gfx_put(GFX_ALPHA, icon+2, iw, ih, src_x, src_y, x+dst_x,y+dst_y,
                                            copy_w, copy_h);
}

static void put_pix_in_area
    (colorpix_t pix, int x, int y, int Ax, int Ay, int Aw, int Ah)
{
  int ux,uy;
  if (clip_for_rect(&Ax, &Aw, x_window_width)) return ;
  if (clip_for_rect(&Ay, &Ah, x_window_height)) return ;

  if (x<Ax) { pix= pix_sub(pix, Ax-x, 0); x= Ax; }
  if (y<Ay) { pix= pix_sub(pix, 0, Ay-y); y= Ay; }
  if (pix.w<=0 || pix.h<=0) return ;
  
  if (x+pix.w>Ax+Aw) { pix.w= Ax+Aw-x; }
  if (y+pix.h>Ay+Ah) { pix.h= Ay+Ah-y; }
  
  if (pix.w<=0 || pix.h<=0) return ;

  for(uy=0;uy<pix.h;uy++)
    for(ux=0;ux<pix.w;ux++)
     x_image_data[uy+y][ux+x]= pix.data[ux+uy*pix.stride];
}

static void gfx_draw_rect_in
   (unsigned int color, int x,int y, int w,int h,
     int Ax, int Ay, int Aw, int Ah)
{
  if (clip_for_rect(&Ax, &Aw, x_window_width)) return ;
  if (clip_for_rect(&Ay, &Ah, x_window_height)) return ;
  color= color_u_to_s(color);

  if (x<Ax) { w -= Ax- x; x= Ax; }
  if (y<Ay) { h -= Ay -y; y= Ay; }
  if (w<=0 || h<=0) return ;
  if (x+w>Ax+Aw) w= Ax+Aw-x; 
  if (y+h>Ay+Ah) h= Ay+Ah-y; 
  if (w<=0 || h<=0) return ;
  hline(    x, x+w-1,     y, color);
  hline(    x, x+w-1, y+h-1, color);
  vline(    x,     y, y+h-1, color);
  vline(x+w-1,     y, y+h-1, color);
}


static void colorpix_hline(colorpix_t *P,int x1,int x2, int y,uint32_t color)
{
  if (x1<0) x1= 0; 
  if (x2>=P->w) x2= P->w-1;
  if (y<0 || y>=P->h || x1>x2) return ;
  for(;x1<=x2;x1++) PIX(*P,x1,y)= color;
}

static void colorpix_vline(colorpix_t *P,int x,int y1, int y2,uint32_t color)
{
  if (y1<0) y1= 0;
  if (y2>=P->h) y2= P->h-1;
  if (x<0 || x>=P->w || y1>y2) return ;
  for(;y1<=y2;y1++) PIX(*P,x,y1)= color;
}

static unsigned int s_red(unsigned int V)
   { return (V&x_red_mask)>>x_red_shift; }
static unsigned int s_green(unsigned int V)
   { return (V&x_green_mask)>>x_green_shift; }
static unsigned int s_blue(unsigned int V)
   { return (V&x_blue_mask)>>x_blue_shift; }

static unsigned int blend_s(uint32_t F, double A, uint32_t B)
{
  return color_s(
            blend_chan( s_red(F), A, s_red(B)),
            blend_chan( s_green(F), A, s_green(B)),
            blend_chan( s_blue(F), A, s_blue(B))
                );
}

static void colorpix_gradfill
   (colorpix_t *P,int x0,int y0, int w, int h, uint32_t start, uint32_t end)
{
  int D, dx, dy;
  D= (w+h);
  if (!D) D= 1;

  if (clip_for_rect(&x0, &w, P->w) || clip_for_rect(&y0, &h, P->h)) return ;

  for(dy=0;dy<h;dy++)
    for(dx=0;dx<w;dx++)
      PIX(*P,dx+x0,dy+y0)= blend(start, 1.0-(double)(dx+dy)/D, end);
}

static void colorpix_3dbox
      (colorpix_t *P, int light, int dark, int border, int start, int end)
{
  int sX,sY,eX,eY;

  sX= 0; eX= P->w-1;
  sY= 0; eY= P->h-1;
                                
  colorpix_hline(P,sX, eX, sY,     border);
  colorpix_hline(P,sX, eX, eY,     border);
  colorpix_vline(P,sX, sY+1, eY-1, border);
  colorpix_vline(P,eX, sY+1, eY-1, border);

  colorpix_hline(P,sX+1, eX-2, sY+1, light);
  colorpix_vline(P,sX+1, sY+1, eY-2, light);
  colorpix_hline(P,sX+1, eX-1, eY-1, dark);
  colorpix_vline(P,eX-1, sY+1, eY-1, dark);

  colorpix_gradfill(P,sX+2, sY+2, P->w-4, P->h-4, start, end);   
}

static void colorpix_put_graypix_centered
   (colorpix_t *P, graypix_t *G, int fg)
{
  int sx, sy, dx, dy, cw, ch, cx, cy;
  int cc;
  cc= (G->w-P->w)/2;
  if (cc>=0) { sx= cc; dx= 0; cw= P->w; }
        else { sx= 0; dx= -cc; cw= G->w; }
  cc= (G->h-P->h)/2;
  if (cc>=0) { sy= cc; dy= 0; ch= P->h; }
        else { sy= 0; dy= -cc; ch= G->h; }

  for(cy=0;cy<ch;cy++)
  for(cx=0;cx<cw;cx++)
    PIX(*P, cx+dx, cy+dy)= blend_s(PIX(*P,cx+dx,cy+dy), 
                                  1-PIX(*G,cx+sx,cy+sy)/255.0,fg);
}


static void get_text_data(int font, const char *str, 
                          int *Rw, int *Rh,int *Ra,unsigned char **Rd)
{
  uint32_t *wtr;
  size_t L= strlen(str);
  wtr= alloca((L+1)*sizeof(uint32_t));
  utf8_decode_string((uint8_t*) str, L, wtr, &L);

  if (font<1) font=1;
  if (font>NFONTS) font=NFONTS;
  font_render(fonts+font-1, wtr, L, Rw, Rh, Ra, Rd);
}

static void text_to_graypix(int font, const char *str, graypix_t *gp, int *Ra)
{
  get_text_data(font, str, &gp->w, &gp->h, Ra, &gp->data);
  gp->stride= gp->w;
}


static void gfx_text_size(int font, char *str, int *W, int *H)
{
  get_text_data(font, str, W, H, NULL, NULL);
}

void txt_print(int flags, int font, int fg, int bg, int x, int y, 
               char *str,int *Rw, int *Rh)
{
  int w,h; unsigned char *data;
  get_text_data(font, str, &w, &h, NULL, &data);

  blend_graymap(flags, fg, bg, data, w,h, 0,0, x,y,w,h);
  if (data) free(data);
  if (Rw) *Rw= w;
  if (Rh) *Rh= h;
}


static int max_text_width(int font, ...)
{
  char *str;
  va_list ap;
  int mw, tw;
  va_start(ap,font);
  mw= 0;
  while((str=va_arg(ap,char*)))
  {
    get_text_data(font,str,&tw, NULL,NULL,NULL);
    if (tw>mw) mw= tw;
  }
  va_end(ap);
  return mw;
}


static void txt_print_fit(const char *horz,const char *vert,
                   int x,int y, int w, int h,
                   int font, int alpha, int fg, int bg,
                   const char *str)
{
  int tw,th; unsigned char *data;
  int src_x, src_y, dst_x, dst_y, cp_w, cp_h;
  int flags;

  get_text_data(font, str, &tw, &th, NULL, &data);

  if (!horz) horz= "C.";
  if (!vert) vert= "C.";

  if (tw>w)
  {
    if (strchr(horz,'<'))       src_x= tw-w;
    else if (strchr(horz,'>'))  src_x= 0;
    else                        src_x= (tw-w)/2; 
    cp_w= w;
    dst_x= x;
  }
  else
  {
    src_x= 0;
    cp_w= tw;
    if (strchr(horz,'B'))       dst_x= x;
    else if (strchr(horz,'E'))  dst_x= x+w-tw;
    else                        dst_x= x+(w-tw)/2;
  }

  if (th>h)
  {
    if (strchr(vert,'<'))       src_y= th-h;
    else if (strchr(vert,'>'))  src_y= 0;
    else                        src_y= (th-h)/2;
    cp_h= h;
    dst_y= y;
  }
  else
  {
    src_y= 0;
    cp_h= th;
    if (strchr(vert,'B'))       dst_y= y;
    else if (strchr(vert,'E'))  dst_y= y+h-th;
    else                        dst_y= y+(h-th)/2;
  }

  if (alpha) flags= GFX_ALPHA;
        else flags= 0;
  blend_graymap(flags, fg, bg, data, tw,th, src_x,src_y, dst_x,dst_y,cp_w,cp_h);
  if (data) free(data);
}


static void gui_button_set_text(gui_button_t *B, char *text)
{
  if (B->text) free(B->text);
  B->text= strdup(text);
  button_render(B);
}

static void button_render(gui_button_t *B)
{
  int x,y,w,h;

  if (!B->enabled) return ;

  x= B->widget.x; y= B->widget.y; w= B->widget.w; h= B->widget.h;

  gfx_draw_3dbox(x,y,w,h, 
    B->state ? buttonDPD_SHDlight : buttonNOR_SHDlight,
    B->state ? buttonDPD_SHDdark  : buttonNOR_SHDdark,
    B->state ? buttonDPD_BRD      : buttonNOR_BRD,
    B->state ? buttonDPD_GRDstart : buttonNOR_GRDstart,
    B->state ? buttonDPD_GRDend   : buttonNOR_GRDend);

  draw_icon_and_text(x,y,w,h, B->iconpos, B->icon, button_iconspc, 
                     button_FG, B->text);
  gfx_update(x,y,w,h);
}

static gui_button_t *gui_button_new
  (const char *txt, int iconpos, uint32_t* icon, int klass)
{
  // this one is for internal use only. it doesn't
  // register the click handler
  gui_button_t *B;

  B= calloc(1,sizeof(*B));
  B->state= 0;
  B->enabled= 0;
  B->iconpos= iconpos;
  B->icon= icon;

  if (txt) B->text= strdup(txt);

  B->click_handler= -1;
  B->widget.klass= klass;
  B->widget.destroy= gui_button_destroy;
  return B;
}


static widget_t* gfx_button
     (const char *txt,int iconpos, uint32_t *icon,int klass)
{
  gui_button_t *B;
  B= gui_button_new(txt,iconpos,icon,klass);
  B->click_handler= install_click_handler(0,0,0,0, &B->enabled, 
                                           B, gui_button_click,1);
  return &B->widget;
}


static void button_set_state(gui_button_t *B, int state)
{
  if (state) state= 1;
  B->state= state;
  button_render(B);
}


static int gui_button_click(void *arg, gfx_event_t *event)
{
  gui_button_t *B;
  B= arg;
  if (!B->enabled) return 0; // shouldn't happen, but you never know
  if (B->widget.klass==GFXCLASS_BUTTON)
    button_set_state(B, 1);
  else
    button_set_state(B,B->state^1);
  install_release_handler(arg, gui_button_release);
  if (B->click_func)
     return (*B->click_func)(B->click_arg,event); 
  return 1;
}

static int gui_button_release(void *arg, gfx_event_t *event)
{
  gui_button_t *B;
  B= arg;
  event->type= B->widget.number;
  if (B->widget.klass==GFXCLASS_BUTTON)
    button_set_state(B,0);
  else
    event->key= B->state;
  if (B->release_func)
    return (*B->release_func)(B->click_arg,event);
  return 0;
}


static void gui_button_destroy(widget_t *W)
{
  gui_button_t *B;
  B= (void*) W;
  if (B->text) free(B->text);
  remove_click_handler(B->click_handler);
}


static void button_set_position( gui_button_t *B, int x,int y,int w,int h)
{
  set_click_handler(B->click_handler, x,y,w,h);
  B->widget.x= x;
  B->widget.y= y;
  B->widget.w= w;
  B->widget.h= h;
}

static void gui_button_activate(widget_t *W, int x,int y,int w,int h)
{
  gui_button_t *B;
  B= (gui_button_t *)W;
  // this is again for internal use. it sets the position,
  // installs the click handler and then shows the button
  B->widget.x= x;
  B->widget.y= y;
  B->widget.w= w;
  B->widget.h= h;
 
  B->click_handler= install_click_handler(x,y,w,h, &B->enabled, 
                                           B, gui_button_click,1);
  B->enabled= 1;
  button_render(B);
}


static void gui_button_show(gui_button_t *B,int show)
{
  if (show) show= 1;
  if (B->enabled==show) return ;
  B->enabled= show;
  if (B->enabled) button_render(B);
}


static void gui_button_init
  (gui_button_t *B,const char *txt, int iconpos, uint32_t* icon, 
   int (*click_func)(void *,gfx_event_t*), 
   int (*release_func)(void *,gfx_event_t*), void *click_arg)
{
  memset(B,0,sizeof(*B));
  B->state= 0;
  B->enabled= 0;
  if (txt) B->text= strdup(txt);
  B->iconpos= iconpos;
  B->icon= icon;

  B->click_func= click_func;
  B->release_func= release_func;
  B->click_arg= click_arg;

  B->widget.klass= GFXCLASS_BUTTON;
  
  B->click_handler= install_click_handler(0,0,0,0, &B->enabled, 
                                           B, gui_button_click,1);
}

static void label_render(gui_label_t *G)
{
  int tw, th; unsigned char *td;
  int dst_x, dst_y, copy_w, copy_h, src_x, src_y;

  int x,y,w,h;

  if (!G->widget.shown) return ;

  x= G->widget.x; y= G->widget.y; w= G->widget.w; h= G->widget.h;
  
  get_text_data(G->font, G->text, &tw, &th, NULL, &td);
  gfx_fill_rect(0, x, y, w, h, G->bg);

  if (th<=h)
  {
    src_y= 0; dst_y= y + (h-th)/2; copy_h= th;
  }
  else
  {
    src_y= (th-h)/2; dst_y= y; copy_h= h;
  }

  if (tw<w)
  {
    src_x= 0; copy_w= tw;
    if (G->just=='C')
      dst_x= x+(w-tw)/2;
    else if (G->just=='R')
      dst_x= x+w-tw;
    else
      dst_x= x;
  }
  else
  {
    dst_x= x; copy_w= w;
#if 0
    if (G->flags&GFX_CUT_LEFT)
      src_x= tw - G->h;
    else
#endif
    src_x= 0;
  }

  blend_graymap(GFX_BACKGND, G->fg, G->bg, td, tw, th,
                src_x, src_y, dst_x, dst_y, copy_w, copy_h);
  free(td);
  gfx_update(x,y,w,h);
}


static widget_t* gfx_label(int font, int fg, int bg, int just, char *str)
{
  gui_label_t *G;
  G= calloc(1,sizeof(*G));
  G->font= font;
  G->fg= fg;
  G->bg= bg;
  G->just= just;
  G->text= strdup(str ? str:"");

  G->widget.klass= GFXCLASS_LABEL;
  G->widget.show= gui_label_show;
  G->widget.destroy= gui_label_destroy;
  return &G->widget;
}


static void gui_label_show(widget_t *W)
{
  label_render((gui_label_t*) W);
}

static void gui_label_set_position(gui_label_t *L,int x,int y,int w,int h)
{
  widget_t *W;
  W= &L->widget;
  W->x= x; W->y= y; W->w= w; W->h= h;
  label_render(L);
}

static void gui_label_destroy(widget_t *W)
{
  gui_label_t *G;
  G= (void*) W;
  if (G->text)
   free(G->text);
}




static void gui_label_set_text(gui_label_t *G,const char *str)
{
  if (G->text) free(G->text);
  G->text= str ? strdup(str) : NULL;
  label_render(G);
}


static void label_set_fgbg(gui_label_t *G, int fg,int bg)
{
  if (G->fg==fg && G->bg==bg) return ;
  G->fg= fg;
  G->bg= bg;
  label_render(G);
}


static void init_radio_images()
{
  if (radio_on) return ;
  radio_on= convert_graymap_to_color(radio_fg, radio_bg,Gradio_on);
  radio_off= convert_graymap_to_color(radio_fg, radio_bg,Gradio_off);
}

static void radio_draw_button(radio_t *R,int state,int bg, int upd)
{
  int w,h,x,y;
  unsigned int *img;

  if (!R->enabled) return ;
  init_radio_images();
  img= state ? radio_on : radio_off;
  w= img[0];
  h= img[1];

  x= R->widget.x+radio_pad_left;
  y= R->widget.y;
  if (R->widget.h>h) y+= (R->widget.h-h)/2;

  if (bg) gfx_fill_rect(0, x,y,w,h, radio_bg);
  gfx_put(upd? GFX_UPDATE :0, img+2,w,h, 0,0, x,y,w,h);
}



static void radio_show(radio_t *R, int show)
{
  if (show)
  {
    if (R->enabled) return ;
    R->enabled= 1;
    if (R->click==-1)
      R->click= install_click_handler
          (R->widget.x,R->widget.y, R->widget.w, R->widget.h,
             &R->enabled, R, radio_click, 1);
    radio_draw(R);
  }
  else
  {
    if (!R->enabled) return ;
    // disable the click handler
    R->enabled= 0;
  }
}

static void radio_set(radio_t *R)
{
  if (R->state) return ;
  R->state= 1;
  if (R->enabled) radio_draw_button(R,R->state,1,1);
  rgroup_clear_except(R->group, &R->widget);
}

static int radio_click(void *arg, gfx_event_t *event)
{
  radio_t *R;
  R= arg;
  if (!R->state)
  {
    radio_set(arg);
    R->change= 1;
  }
  else
    R->change= 0;
  install_release_handler(arg, radio_release);
  return 1;
}

static int radio_release(void *arg, gfx_event_t *event)
{
  radio_t *R;

  R= arg;
  if (!R->change) return 1;
 
  event->type= R->widget.number;
  R->change= 0;
  return 0;
}


static widget_t* radio_new(const char *text, int group)
{
  radio_t *R;
  R= calloc(1,sizeof(*R));
  R->click= -1;
  if (text) R->text= strdup(text);
  R->group= group;
  R->widget.klass= GFXCLASS_RADIO;
  if (group!=-1) register_radio_in_group(group, &R->widget);
  return &R->widget;
}


static void radio_draw_text(radio_t *R)
{
  unsigned char *td; int tw, th,cw,tx,ty;
  int x,y,w,h;
  if (!R->text || !R->text[0]) return ;

  x= R->widget.x; y= R->widget.y; w= R->widget.w; h= R->widget.h;
  
  get_text_data(1, R->text, &tw, &th, NULL, &td);
  tx= x + radio_pad_left + gfx_radio_width + radio_pad_mid;
  ty= y;
  if (h >= th)
    ty+= (h-th)/2;
  cw= (x+w)-tx;
  if (cw>tw) cw= tw;
  blend_graymap(GFX_BACKGND | GFX_UPDATE, radio_fg, radio_bg,
                td, tw, th, 0,0, tx,ty, cw, th);
  free(td);
}

static void radio_draw(radio_t *R)
{
  int x,y,w,h;
  x= R->widget.x;
  y= R->widget.y;
  w= R->widget.w;
  h= R->widget.h;
  if (!R->enabled) return ;
  gfx_fill_rect(0,x,y,w, h, radio_bg);
  radio_draw_button(R, R->state, 0,0);
  radio_draw_text(R);
  gfx_update(x,y,w, h);
}


static radio_group_t *get_rgroup(int ident)
{
  int i;
  if (!screen || ident==-1) return NULL;
  for(i=0;i<screen->n_rgroups;i++)
    if (screen->rgroups[i].ident==ident)
       return screen->rgroups+i;
  return NULL; 
}

static void rgroup_clear_except(int ident,widget_t *R)
{
  widget_t *P;
  radio_group_t *G;
  int i;

  G= get_rgroup(ident);
  if (!G) return ;
  
  for(i=0;i<G->n_widgets;i++)
  {
    P= G->widgets[i];
    if (P==R) continue;
    widget_set_state(P,0);
  }
}

static void register_radio_in_group(int ident, widget_t *W)
{
  radio_group_t *G;
  G= get_rgroup(ident);
  if (G) goto found;

  if (screen->n_rgroups==screen->s_rgroups)
  {
    screen->s_rgroups+= screen->s_rgroups/2 + 10;
    screen->rgroups= realloc(screen->rgroups, 
                              sizeof(screen->rgroups[0])*screen->s_rgroups);
  }
  G= screen->rgroups+screen->n_rgroups;
  memset(G,0,sizeof(*G));
  G->ident= ident;
  screen->n_rgroups++;
found:
  if (G->n_widgets==G->s_widgets)
  {
    G->s_widgets+= G->s_widgets/2+10;
    G->widgets= realloc(G->widgets, sizeof(G->widgets[0])*G->s_widgets);
  }
  G->widgets[G->n_widgets]= W;
  G->n_widgets++;
}

static void free_rgroups(screen_t *S)
{
  int i;
  for(i=0;i<S->n_rgroups;i++)
    if (S->rgroups[i].widgets) free(S->rgroups[i].widgets);
  if (S->rgroups) free(S->rgroups);
}

static int radio_group_get_selected(int ident)
{
  radio_group_t *G;
  int i;
  G= get_rgroup(ident);
  if (!G) return -1;
  for(i=0;i<G->n_widgets;i++)
    if (widget_get_state(G->widgets[i])) 
       return G->widgets[i]->number;
  return -1;
}


static void init_checkbox_images()
{
  if (checkbox_ok) return ;
  checkbox_ok= convert_graymap_to_color(checkbox_fg, checkbox_bg,Gcheckbox_ok);
  checkbox_nok= convert_graymap_to_color(checkbox_fg, checkbox_bg,Gcheckbox_nok);
}

static void checkbox_draw_button(checkbox_t *R,int state,int bg, int upd)
{
  int w,h,x,y;
  unsigned int *img;

  if (!R->enabled) return ;
  init_checkbox_images();
  img= state ? checkbox_ok : checkbox_nok;
  w= img[0];
  h= img[1];

  x= R->widget.x+checkbox_pad_left;
  y= R->widget.y;
  if (R->widget.h>h) y+= (R->widget.h-h)/2;

  if (bg) gfx_fill_rect(0, x,y,w,h, checkbox_bg);
  gfx_put(upd? GFX_UPDATE :0, img+2,w,h, 0,0, x,y,w,h);
}



static void checkbox_show(checkbox_t *R, int show)
{
  if (show)
  {
    if (R->enabled) return ;
    R->enabled= 1;
    if (R->click==-1)
      R->click= install_click_handler
          (R->widget.x,R->widget.y, R->widget.w, R->widget.h,
             &R->enabled, R, checkbox_click, 1);
    checkbox_draw(R);
  }
  else
  {
    if (!R->enabled) return ;
    // disable the click handler
    R->enabled= 0;
  }
}

static void checkbox_set(checkbox_t *R,int value)
{
  if (value) value= 1;
  if (R->state==value) return ;
  R->state= value;
  if (R->enabled)
    checkbox_draw_button(R,R->state,1,1);
}

static int checkbox_click(void *arg, gfx_event_t *event)
{
  checkbox_t *R;
  R= arg;
  checkbox_set(R, R->state^1);
  install_release_handler(arg, checkbox_release);
  return 1;
}

static int checkbox_release(void *arg, gfx_event_t *event)
{
  checkbox_t *R;
  R= arg;
  event->type= R->widget.number;
  event->key= R->state;
  if (R->clickf && (*R->clickf)(R->evarg, event)) return 1;
  return 0;
}


static widget_t* gui_checkbox_new(const char *text,
    void *evarg, event_function_t clickf)
{
  checkbox_t *R;
  R= calloc(1,sizeof(*R));
  R->click= -1;
  if (text) R->text= strdup(text);
  R->widget.klass= GFXCLASS_CHECKBOX;
  R->widget.destroy= gui_checkbox_destroy;
  R->clickf= clickf;
  R->evarg= evarg;
  return &R->widget;
}

static void gui_checkbox_destroy(widget_t *W)
{
  checkbox_t *R= (void*) W;
  if (R->text) free(R->text);
  remove_click_handler(R->click); 
}



static void checkbox_draw_text(checkbox_t *R)
{
  unsigned char *td; int tw, th,cw,tx,ty;
  int x,y,w,h;
  if (!R->text || !R->text[0]) return ;

  x= R->widget.x; y= R->widget.y; w= R->widget.w; h= R->widget.h;
  
  get_text_data(1, R->text, &tw, &th, NULL, &td);
  tx= x + checkbox_pad_left + gfx_checkbox_width + checkbox_pad_mid;
  ty= y;
  if (h >= th)
    ty+= (h-th)/2;
  cw= (x+w)-tx;
  if (cw>tw) cw= tw;
  blend_graymap(GFX_BACKGND | GFX_UPDATE, checkbox_fg, checkbox_bg,
                td, tw, th, 0,0, tx,ty, cw, th);
  free(td);
}

static void checkbox_draw(checkbox_t *R)
{
  int x,y,w,h;
  x= R->widget.x;
  y= R->widget.y;
  w= R->widget.w;
  h= R->widget.h;
  if (!R->enabled) return ;
  gfx_fill_rect(0,x,y,w, h, checkbox_bg);
  checkbox_draw_button(R, R->state, 0,0);
  checkbox_draw_text(R);
  gfx_update(x,y,w, h);
}


static void scrollbar_compute_trough(scrollbar_t *SB)
{
  if (SB->orient=='V')
  {
    SB->tro_h= SB->widget.h - SB->SH[0]-SB->SH[2];

    SB->tro_c0= SB->widget.y+ SB->SH[0];
    SB->tro_c1= SB->tro_c0+SB->tro_h-1;
    SB->tro_dc= SB->tro_h-1;

    SB->tro_x= SB->widget.x;
    SB->tro_y= SB->tro_c0;
    SB->tro_w= SB->widget.w;
  }
  else
  {
    SB->tro_w= SB->widget.w - SB->SW[0]-SB->SW[2];

    SB->tro_c0= SB->widget.x + SB->SW[0];
    SB->tro_c1= SB->tro_c0 + SB->tro_w - 1;
    SB->tro_dc= SB->tro_w-1;

    SB->tro_x= SB->tro_c0;
    SB->tro_y= SB->widget.y;
    SB->tro_h= SB->widget.h;
  }
  if (SB->tro_dc<1) SB->tro_dc= 1;
}

static void scrollbar_compute_button(scrollbar_t *SB)
{
  SB->but_c0= SB->tro_dc*SB->start + SB->tro_c0;
  SB->but_c1= SB->tro_dc*SB->end   + SB->tro_c0;
}

static void fill_with_horizontal_gradient
             (int x0,int y0, int y1, unsigned int *gra)
{
  int y;
  int graW;
  graW= gra[0];
  gra+= 2;
  for(y=y0;y<=y1;y++)
    put_server_pix(gra, x0, y, graW, 1);
}

static void three_part_assembly_vertical
    (int x0,int y0, int y1, 
     uint32_t *top, uint32_t *mid, uint32_t *bot)
{
  int mid_start_y, mid_end_y;

  uint32_t *topD, topW, topH;
  uint32_t *botD, botW, botH;

  topD= top+2; topW= top[0]; topH= top[1];
  botD= bot+2; botW= bot[0]; botH= bot[1];
  
  mid_start_y= y0 + topH;
  mid_end_y=   y1 - botH;
  put_server_pix(topD, x0, y0, topW, topH);
  fill_with_horizontal_gradient(x0,mid_start_y, mid_end_y, mid);
  put_server_pix(botD, x0, mid_end_y+1, botW, botH);
}

static void fill_with_vertical_gradient
             (int x0, int x1, int y0, unsigned int *gra)
{
  int x;
  int graH;
  graH= gra[1];
  gra+= 2; // skip the W+H
  for(x=x0;x<=x1;x++)
    put_server_pix(gra, x, y0, 1, graH);
}

static void three_part_assembly_horizontal
    (int x0, int x1, int y0, 
     uint32_t *lef, uint32_t *mid, uint32_t *rig)
{
  int mid_start_x, mid_end_x;

  uint32_t *lefD, lefW, lefH,
           *rigD, rigW, rigH;

  lefW= lef[0]; lefH= lef[1]; lefD= lef+2;
  rigW= rig[0]; rigH= rig[1]; rigD= rig+2;

  mid_start_x= x0 + lefW;
  mid_end_x=   x1 - rigW;
  put_server_pix(lefD, x0, y0, lefW, lefH);
  fill_with_vertical_gradient(mid_start_x,mid_end_x, y0, mid);
  put_server_pix(rigD, mid_end_x+1, y0, rigW, rigH);
}

static void scrollbar_draw_trough(scrollbar_t *SB)
{
  static uint32_t* images[]= { 
    Hscroll_ind_left, Hscroll_ind_right, Hscroll_ind_mid, Hscroll_trough,
    Vscroll_ind_top, Vscroll_ind_bot, Vscroll_ind_mid, Vscroll_trough,
    NULL };

  int y,x;
  if (!SB->enabled) return ;
  convert_images_to_server(images);
  if (SB->orient=='V')
  {
    x= SB->widget.x;
    fill_with_horizontal_gradient
             (x, SB->tro_c0, SB->but_c0-1, Vscroll_trough);

    fill_with_horizontal_gradient
             (x, SB->but_c1+1, SB->tro_c1, Vscroll_trough);

    three_part_assembly_vertical
             (x, SB->but_c0, SB->but_c1,
              Vscroll_ind_top, Vscroll_ind_mid, Vscroll_ind_bot);
  }
  else
  {
    y= SB->widget.y;
    fill_with_vertical_gradient
             (SB->tro_c0, SB->but_c0-1, y, Hscroll_trough);

    fill_with_vertical_gradient
             (SB->but_c1+1, SB->tro_c1, y, Hscroll_trough);

    three_part_assembly_horizontal
             (SB->but_c0, SB->but_c1, y,
              Hscroll_ind_left, Hscroll_ind_mid, Hscroll_ind_right);
  }
}

static void scrollbar_draw_stepper(scrollbar_t *SB, int sno, int state)
{
  int img;
  img= sno*2 + state;
  if (!SB->enabled) return ;
  put_server_pix(SB->SD[img], SB->SX[sno], SB->SY[sno],
                              SB->SW[img], SB->SH[img]);
}

static void scrollbar_draw_all(scrollbar_t *SB)
{
  scrollbar_draw_stepper(SB, 0,0);
  scrollbar_draw_stepper(SB, 1,0);
  scrollbar_draw_trough(SB);
}

static void scrollbar_init_buttons
   (scrollbar_t *SB)
{
   int i;
   static uint32_t *images[]=
    { scroll_nor_up, scroll_dpd_up,
      scroll_nor_down, scroll_dpd_down,
      scroll_nor_left, scroll_dpd_left,
      scroll_nor_right, scroll_dpd_right, NULL };

   if (SB==NULL) { gui_scrollbar_width= scroll_nor_up[0] & ~(1<<31);
                   gui_scrollbar_height= scroll_nor_left[1];
                   return ; }

   convert_images_to_server(images);

   if (SB->orient=='V')
   {
     SB->SD[0]= scroll_nor_up+2;   SB->SD[1]= scroll_dpd_up+2;
     SB->SD[2]= scroll_nor_down+2; SB->SD[3]= scroll_dpd_down+2;
   }
   else
   {
     SB->SD[0]= scroll_nor_left+2;  SB->SD[1]= scroll_dpd_left+2;
     SB->SD[2]= scroll_nor_right+2; SB->SD[3]= scroll_dpd_right+2;
   }
   for(i=0;i<4;i++)
   {
     SB->SW[i]= SB->SD[i][-2];
     SB->SH[i]= SB->SD[i][-1];
   }
}

static void scrollbar_position_buttons(scrollbar_t *SB,int x,int y,int w,int h)
{
  if (SB->orient=='V')
  {
    SB->SX[0]= x; SB->SX[1]= x;
    SB->SY[0]= y; SB->SY[1]= y+h-SB->SH[2];
  }
  else
  {
    SB->SY[0]= y;  SB->SY[1]= y;
    SB->SX[0]= x;  SB->SX[1]= x+w-SB->SW[2];
  }
}

static widget_t* scrollbar_new
    (int orient, double start, double end, double step,
     int action, void *reportarg, void *reportfunc)
{
  scrollbar_t *SB;

  SB= calloc(1,sizeof(*SB));

  SB->start= start;
  SB->end= end;
  SB->step= step;
  SB->reportarg= reportarg;
  SB->reportfunc= reportfunc;
  SB->action= action;

  SB->orient= orient ? 'V': 'H';
  SB->enabled= 0;
  SB->widget.klass= GFXCLASS_SCROLLBAR;

  SB->ch0= SB->ch1= SB->ch2= -1;

  scrollbar_init_buttons(SB);

  return &SB->widget;
}

static void scrollbar_position(scrollbar_t *SB,int x,int y,int w,int h)
{
  SB->widget.w= w;
  SB->widget.h= h;
  SB->widget.x= x;
  SB->widget.y= y;

  scrollbar_position_buttons(SB,x,y,w,h);
  scrollbar_compute_trough(SB);
  scrollbar_compute_button(SB);
  scrollbar_draw_all(SB);

  SB->ch0= install_or_modify_click
        (SB->ch0, &SB->enabled, scrollbar_click_up, SB,
        SB->SX[0], SB->SY[0], SB->SW[0], SB->SH[0],1);

  SB->ch1= install_or_modify_click
        (SB->ch1, &SB->enabled, scrollbar_click_down, SB,
        SB->SX[1], SB->SY[1], SB->SW[2], SB->SH[2],1);
 
  SB->ch2= install_or_modify_click
        (SB->ch2, &SB->enabled, scrollbar_click_tro, SB,
         SB->tro_x, SB->tro_y, SB->tro_w, SB->tro_h,1);
}


static int scrollbar_click_up(void *A, gfx_event_t *E)
{
  scrollbar_t *SB= A;
  scrollbar_draw_stepper(SB, 0, 1);
  install_release_handler(A, scrollbar_release_up);
  gfx_update(SB->SX[0], SB->SY[0], SB->SW[0], SB->SH[0]);
  return 1;
}

static int scrollbar_release_up(void *A, gfx_event_t *event)
{
  scrollbar_t *SB= A;
  scrollbar_draw_stepper(SB, 0, 0);
  gfx_update(SB->SX[0], SB->SY[0], SB->SW[0], SB->SH[0]);
  if (SB->start>0.0)
  {
    double S;
    S= dmax2(0.0, SB->start - SB->step);
    return scrollbar_set(SB, S, S-SB->start+SB->end, 1, event);
  }
  return 1;
}

static void scrollbar_update(scrollbar_t *SB)
{
  scrollbar_compute_button(SB);
  scrollbar_draw_trough(SB);
  if (SB->enabled)
    gfx_update(SB->tro_x, SB->tro_y, SB->tro_w, SB->tro_h);
}

static int scrollbar_set
    (scrollbar_t *SB,double S, double E, int report, gfx_event_t* event)
{
  if (SB->start==S && SB->end==E) return 1;
  SB->start= S;
  SB->end= E;
  scrollbar_update(SB);
  if (!report) return 1;
  if (SB->action && event) 
  {
    event->type= SB->widget.number;
    event->flo0= S;
    event->flo1= E;
    return 0;
  }
  if (SB->reportfunc)
    (*SB->reportfunc)(SB->reportarg, S, E);
  return 1;
}

static int scrollbar_click_down(void *A, gfx_event_t *E)
{
  scrollbar_t *SB= A;
  scrollbar_draw_stepper(SB, 1, 1);
  gfx_update(SB->SX[1],SB->SY[1], SB->SW[2], SB->SH[2]);
  install_release_handler(A, scrollbar_release_down);
  return 1;
}

static int scrollbar_release_down(void *A, gfx_event_t *event)
{
  scrollbar_t *SB= A;
  scrollbar_draw_stepper(SB, 1, 0);
  gfx_update(SB->SX[1],SB->SY[1], SB->SW[2], SB->SH[2]);
  if (SB->end<1.0)
  {
    double E;
    E= dmin2(1.0,SB->end + SB->step);
    return scrollbar_set(SB,E-SB->end+SB->start,E, 1, event);
  }
  return 1;
}

static int scrollbar_click_tro(void *A,gfx_event_t *event)
{
  scrollbar_t *SB= A;
  double L,K, S, E;
  int C;

  if (SB->orient=='V') C= event->y; else C= event->x;
  if (C>=SB->but_c0 && C<=SB->but_c1)
  {
    install_release_handler(A, scrollbar_release_tro);
    install_motion_handler(A, scrollbar_move_pointer);
    SB->last_seen_c= C;
    return 1;
  }
  if (C<SB->tro_c0 || C>SB->tro_c1) return 1;
  C -= SB->tro_c0;
  L= SB->end - SB->start;

  K= (double) C / SB->tro_dc;
  S= K-L/2;
  E= S+L;

  if (S<0.0) { S= 0.0; E= S+L; }
  if (E>1.0) { E= 1.0; S= E-L;  }

  install_release_handler(A, scrollbar_release_dummy);
  return scrollbar_set(SB,S,E,1,event);
}

static int scrollbar_release_dummy(void *A, gfx_event_t *E)
{
  // this function is used to eat up the dummy release events
  // left over from clicks into the trough area. 
  // normally, I'd do the returning stuff within this
  // release handler, but there is too much information to
  // pass around.
  return 1;
}

static int scrollbar_move_pointer(void *A, gfx_event_t *event)
{
  scrollbar_t *SB= A;
  int D;
  double L, S, E;
  int C;

  if (SB->orient=='V') C= event->y; else C= event->x;

  if (C>SB->tro_c1 || C<SB->tro_c0) return 1;

  D= C - SB->last_seen_c;
  if (D==0) return 1;

  SB->last_seen_c= C;
 
  L= SB->end - SB->start;
  if (D>0)
  {
    if (SB->end==1.0) return 1;
    E= dmin2(1.0,SB->end + (double) D / SB->tro_dc);
    S= E - L;
  } else {
    if (SB->start==0.0) return 1;
    S= dmax2(0.0, SB->start + (double) D / SB->tro_dc);
    E= S + L;
  }

  return scrollbar_set(SB, S,E, 1, event);
}

static int scrollbar_release_tro(void *A, gfx_event_t *E)
{
  uninstall_motion_handler();
  return 1;
}


static void scrollbar_set_all
  (scrollbar_t *SB, double start, double end, double step)
{
  SB->start= dmin2(1.0,dmax2(0.0, start));
  SB->end=   dmax2(SB->start+0.000001,dmin2(1.0,dmax2(0.0, end)));
  SB->step=  dmin2(1.0,dmax2(0.0,step));
  scrollbar_update(SB);
}


static void scrollbar_relayout
   (scrollbar_t *SB, int nx, int ny, int nw,int nh,
    double start, double end, double step)
{
  SB->start= dmin2(1.0,dmax2(0.0, start));
  SB->end= dmax2(0.0,dmin2(1.0,end));
  SB->step= step;
  if (step<0.0 || step>=1.0) SB->step= 0.1;

  if (nw!=SB->widget.w || nh!=SB->widget.h 
      || nx!=SB->widget.x || ny!=SB->widget.y)
  {
    scrollbar_position(SB,nx,ny,nw,nh);
  }
  else
  {
    scrollbar_compute_trough(SB);
    scrollbar_compute_button(SB);
    scrollbar_draw_all(SB);
  }
}

static void scrollbar_destroy(scrollbar_t *SB)
{
  remove_click_handler(SB->ch0);
  remove_click_handler(SB->ch1);
  remove_click_handler(SB->ch2);
}

static void scrollbar_show(scrollbar_t *SB,int show)
{
  SB->enabled= show;
  if (SB->enabled) 
  {
    scrollbar_draw_all(SB);
    gfx_update(SB->widget.x, SB->widget.y, SB->widget.w, SB->widget.h);
  }
}

static panel_t *panel_new(int nsubs)
{
  panel_t *P;
  P= calloc(1,sizeof(*P));
  P->n_subs= nsubs;
  P->subs= calloc(nsubs,sizeof(P->subs[0]));
  P->widget.klass= GFXCLASS_PANEL;
  return P;
}


static void panel_show(panel_t *P,int show)
{
  P->enabled= show;
  if (show)
    gfx_fill_rect(0, P->widget.x,P->widget.y,P->widget.w,P->widget.h, 0xededed); 
  panel_show_widgets(P,P->active,show);
}

static void panel_show_widgets(panel_t *P,int sub, int show)
{
  int i;
  subscreen_t *S; 
  if (sub<0 || sub>=P->n_subs) return ;
  S= P->subs+sub;

  for(i=0;i<S->n_widgets;i++)
  {
    widget_t *W;
    int n= S->widgets[i];
    if (n<=_XX_WIDGETS_START || n>=_XX_WIDGETS_END) continue;
    W= widgets[n];
    if (W) widget_show(W,show);
  }
}

static void panel_activate(panel_t *P,int sel)
{
  if (sel<0 || sel>=P->n_subs || sel==P->active) return ;
  if (!P->enabled) { P->active= sel; return ; }
  panel_show_widgets(P,P->active,0);
  gfx_fill_rect(0, P->widget.x,P->widget.y,P->widget.w,P->widget.h, 0xededed); 
  panel_show_widgets(P,sel,1);
  P->active= sel;
  gfx_update(P->widget.x,P->widget.y,P->widget.w,P->widget.h);
}

static void panel_position(panel_t *P,int nx,int ny,int nw,int nh)
{
  P->widget.x= nx;
  P->widget.y= ny;
  P->widget.w= nw;
  P->widget.h= nh;
}

static widget_t *dropdown_new(void *evarg, event_function_t clickf)
{
  dropdown_t *DD;
  DD= calloc(1,sizeof(*DD));
  DD->selected= -1;
  DD->click_handler= -1;
  DD->widget.klass= GFXCLASS_DROPDOWN;
  DD->widget.destroy= gui_dropdown_destroy;

  DD->evarg= evarg;
  DD->clickf= clickf;

  return &DD->widget;
}


static void dropdown_show(dropdown_t *DD,int show)
{
  if (show==DD->shown) return ;
  DD->shown= show;
  if (show)
  {
    if (DD->click_handler==-1)
      DD->click_handler= install_click_handler(DD->widget.x,DD->widget.y,
                           DD->widget.w,DD->widget.h,
                           &DD->click_enabled, DD, dropdown_click, 1);
    DD->click_enabled= 1;
    dropdown_render_button(DD,0);
  }
  else
  {
    DD->click_enabled= 0;
  }
}


static void dropdown_render_button(dropdown_t *DD, int p)
{
  char *text;
  int ix,iy, tx,ty;
  int tcw, tch, tsx, tsy, tw,th;
  // int w,h; // W and H minus the border
  unsigned char *tdata;

  int W,H,X,Y;

RES_INT(dropdown_pad_left, 2, "");
RES_INT(dropdown_pad_right, 2, "");
RES_INT(dropdown_pad_mid, 2, "");
RES_COLOR(dropdown_dark1, 0xd5d5d1, "");
RES_COLOR(dropdown_light1, 0xffffff, "");
RES_COLOR(dropdown_border1, 0xaaaaa3, "");
RES_COLOR(dropdown_dark2, 0xffffff, "");
RES_COLOR(dropdown_light2, 0xd5d5d1, "");
RES_COLOR(dropdown_border2, 0xaaaaa3, "");
RES_COLOR(dropdown_gradb1, 0xfcfcfb, "");
RES_COLOR(dropdown_grade1, 0xdbdbd7, "");
RES_COLOR(dropdown_gradb2, 0xcccac9, "");
RES_COLOR(dropdown_grade2, 0xe9e8e7, "");

RES_GRAYIMG(dropd_but, "Dropdown button image")
   11, 7,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x7f,0xef,0xef,0xef,0xef,0xef,0xef,0xef,
    0x7f,0x00,0x00,0x01,0x9a,0xef,0xef,0xef,0xef,0xef,
    0x9a,0x01,0x00,0x00,0x00,0x06,0xb1,0xef,0xef,0xef,
    0xb1,0x06,0x00,0x00,0x00,0x00,0x00,0x0e,0xbb,0xef,
    0xbb,0x0e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x14,
    0xab,0x14,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,
RES_END

  if (!DD->shown) return ;

  tdata= NULL;

  W= DD->widget.w;
  H= DD->widget.h;
  X= DD->widget.x;
  Y= DD->widget.y;

  if (W<4 || H<4)
  {
    // even the border doesn't fit!
    gfx_fill_rect(GFX_UPDATE, DD->widget.x, DD->widget.y, W,H, 0xFFff0000);
    return ;
  }
  gfx_draw_3dbox(X,Y,W,H, 
           p ? dropdown_light2 : dropdown_light1,
           p ? dropdown_dark2  : dropdown_dark1,
           p ? dropdown_border2  : dropdown_border1,
           p ? dropdown_gradb2  : dropdown_gradb1,
           p ? dropdown_grade2  : dropdown_grade1);

  int buW,buH;
  buW= dropd_but[0];
  buH= dropd_but[1];

  ix= W -2 -dropdown_pad_right -buW;
  iy= (H - buH)/2;
    // no space for button. in fact, the text won't fit here also
    // so we simply display an empty area.
  if (ix<2 || iy<2) return ;
  
  blend_graymap(GFX_ALPHA, 0x00, 0xffFFff,
               dropd_but+2, buW, buH, 0,0,
               X+ix, Y+iy+2, buW, buH);

  if (DD->selected<0 || DD->selected>=DD->n_items) goto done;
  text= DD->items[DD->selected].str;
  if (!text || !text[0]) goto done;

  get_text_data(1,text, &tw, &th, NULL, &tdata);

  tx= 2 + dropdown_pad_left;
  tsx= 0;
  tcw= imax2(0,imin2(tw, ix-dropdown_pad_mid-tx));
  if (tcw==0) goto done;

  ty= 2 + imax2( 0, (H-th)/2 );
  tsy= imax2(0, (th-H)/2); 
  tch= imin2(th, H);

  if (tch==0) goto done;

  blend_graymap(GFX_ALPHA, 0x00, 0xffFFff, tdata, tw, th, tsx,tsy,
                             X+tx, Y+ty, tcw, tch);
done:
  if (tdata) free(tdata);
  gfx_update(X,Y,W,H);
}

static int dropdown_click(void *arg, gfx_event_t* event)
{
  dropdown_t *DD= arg;
  if (event->type!=GFXEV_BUTTON_PRESS || event->button!=1) return 0;
  dropdown_render_button(DD,1);
  install_release_handler(DD, dropdown_release);
  return 1;
}

static int dropdown_release(void *arg, gfx_event_t *event)
{
  dropdown_t *DD= arg;
  // dropdown_render_button(DD,0);
  dropdown_show_list(DD);
  return 1;
}


static void dropdown_show_list(dropdown_t *DD)
{
  if (DD->list_backup) { free(DD->list_backup); DD->list_backup= NULL; }
  DD->list_active= 1;

  DD->list_w= DD->widget.w;
  DD->list_x= DD->widget.x;

  DD->list_y= DD->widget.y + DD->widget.h;

  get_text_data(1,"M",NULL,&DD->fh,NULL,NULL);
  int ni;
  ni= imax2(DD->n_items, 1);
  DD->list_cont_h= dropdown_list_padv*2 + ni*DD->fh + (ni-1)*dropdown_list_spc;

  DD->posy= 0;
  if (DD->list_y+DD->list_cont_h+2<=x_window_height)
  {
    // no scrollbar needed
    DD->list_ph= DD->list_cont_h;
    DD->list_h= DD->list_ph+2;
    DD->list_pw= DD->list_w-2;
    DD->list_px= DD->list_x+1;
    DD->list_py= DD->list_y+1;

    if (DD->scroll) DD->scroll->enabled= 0;
    dropdown_get_list_backup(DD);
    dropdown_draw_listframe(DD,0xf);
  }
  else
  {
    DD->list_px= DD->list_x+1;
    DD->list_pw= DD->list_w - 1 - gui_scrollbar_width;
    DD->list_h= x_window_height - DD->list_y;
    if (DD->list_h<(DD->fh+dropdown_list_padv*2+2))
    {
      DD->list_y= DD->widget.y;
      DD->list_h= x_window_height - DD->list_y;
    }
    DD->list_ph= DD->list_h-2;
    DD->list_py= DD->list_y+1;
    if (DD->list_ph<=0) goto impossible;
    if (DD->selected!=-1)
    {
      DD->posy= dropdown_item_pos(DD,DD->selected) - DD->list_ph/2;
      if (DD->posy<0) DD->posy= 0;
      else if (DD->posy+DD->list_ph > DD->list_cont_h)
      {
        DD->posy= DD->list_cont_h - DD->list_ph;
        if (DD->posy<0) DD->posy= 0;
      }
    }
    dropdown_get_list_backup(DD);
     // scrollbar parameters
    int Sx, Sy, Sw, Sh;  
    double Sb, Se, Ss;

    Sx= DD->list_x+DD->list_w-gui_scrollbar_width;
    Sy= DD->list_y;
    Sw= gui_scrollbar_width;
    Sh= DD->list_h;
    Sb= (double)DD->posy/DD->list_cont_h;
    Se= (double)(DD->posy+DD->list_ph)/DD->list_cont_h;
    Ss= DD->list_ph*0.9/DD->list_cont_h;
    if (DD->scroll)
    {
      DD->scroll->enabled= 1;
      scrollbar_relayout(DD->scroll, Sx, Sy,Sw, Sh, Sb, Se, Ss);
    }
    else
    {
      DD->scroll= (scrollbar_t*)
                    scrollbar_new(1, Sb, Se, Ss, 0, DD, dropdown_scroll);
      scrollbar_position(DD->scroll, Sx, Sy,Sw, Sh);
    }
    scrollbar_show(DD->scroll,1);
    dropdown_draw_listframe(DD,0xe);
  }
  dropdown_draw_listbg(DD);
  dropdown_draw_contents(DD);
  gfx_update(DD->list_x,DD->list_y,DD->list_w,DD->list_h);
  DD->selitem= -1;
  DD->but1clicked= 0;
  grab_mouse((void*)dropdown_mouse, DD);
  DD->click_enabled= 0;

impossible:
  return ; // FIXME
}

static void dropdown_draw_listbg(dropdown_t *DD)
{
  gfx_fill_rect(0,DD->list_px,DD->list_py,DD->list_pw,DD->list_ph, 0xffffffff);
}

static void dropdown_get_list_backup(dropdown_t *DD)
{
  if (DD->list_w<=0 || DD->list_h<=0) return ;
  DD->list_backup= get_server_pix(DD->list_x,DD->list_y,DD->list_w,DD->list_h);
}

static void dropdown_put_list_backup(dropdown_t *DD)
{
  if (!DD->list_backup || DD->list_w<=0 || DD->list_h<=0) return ;
  put_server_pix(DD->list_backup, DD->list_x,DD->list_y,DD->list_w,DD->list_h);
  free(DD->list_backup);
  DD->list_backup= NULL;
}

static void dropdown_draw_contents(dropdown_t *DD)
{
  int i,j,k;
  if (DD->n_items==0) return ;
  i= 0; 
  j= DD->n_items-1;
  while(i<=j)
  {
    k= (i+j)/2;
    switch(dropdown_draw_item(DD,k))
    {
     case 1: j= k-1; break;
     case 0: goto found;
     case -1: i= k+1; break;
    }
  }

  return;
found:
  for(i=k-1;i>=0;i--)         if (dropdown_draw_item(DD,i)) break;
  for(j=k+1;j<DD->n_items;j++) if (dropdown_draw_item(DD,j)) break;
}

static int dropdown_draw_item(dropdown_t *DD,int idx)
{
  int P;
  P= dropdown_item_pos(DD,idx);
  if (P>=DD->posy+DD->list_ph) return 1;
  if (P+DD->fh<DD->posy) return -1;
  print_clipped(DD->list_px,DD->list_py,DD->list_pw,DD->list_ph,
           DD->list_px, P-DD->posy+DD->list_py, 1, DD->items[idx].str); 
  return 0;
}

static void print_clipped(int Cx,int Cy,int Cw,int Ch,
                          int x, int y, int font, const char* str)
{
  unsigned char *tdata;
  int tw,th;

  int sx,sy, dx,dy, ow, oh;

  if (x>=Cx+Cw || y>=Cy+Ch || Cw<=0 || Ch<=0) return ;

  get_text_data(font, (char*) str,&tw,&th,NULL,&tdata);

  sx= 0; sy=0; dx= x; dy= y; ow= tw; oh= th;
  if (dx<Cx)
  {
    sx+= (Cx-dx);
    ow-= (Cx-dx);
    dx= Cx;
  }

  if (dy<Cy)
  {
    sy+= (Cy-dy);
    oh-= (Cy-dy);
    dy= Cy;
  }

  if (ow<=0 || oh<=0) goto done;

  if (dx+ow>Cx+Cw)
  {
    ow= (Cx+Cw-dx);
  }
  if (dy+oh>Cy+Ch)
  {
    oh= (Cy+Ch-dy);
  }
  if (ow<=0 || oh<=0) goto done;

  blend_graymap(0, 0xff000000, 0xffFFFFFF, tdata, tw,th, sx, sy, dx,dy,ow,oh);
done:
  free(tdata);
}

static int dropdown_item_pos(dropdown_t *DD,int item)
{
  return item*(dropdown_list_spc+DD->fh) + dropdown_list_padv;
}

static void dropdown_draw_listframe(dropdown_t *DD,int which)
{
  int l,r,t,b;
  l= DD->list_x;
  r= DD->list_x+DD->list_w-1;
  t= DD->list_y;
  b= DD->list_y+DD->list_h-1;
  if (which&1) vline(r, t,b, dropdown_list_border);
  if (which&2) vline(l, t,b, dropdown_list_border);
  if (which&4) hline(l, r,t, dropdown_list_border);
  if (which&8) hline(l, r,b, dropdown_list_border);
}

static void dropdown_scroll(dropdown_t *DD,double S,double E)
{
  dropdown_scroll_to(DD, DD->list_cont_h*S,0);
}

static int dropdown_mouse(dropdown_t *DD, gfx_event_t *event)
{
  switch(event->type)
  {
  case GFXEV_BUTTON_PRESS:
    switch(event->button)
    {
    case 1: 
      if (!in_rect(DD->list_x,DD->list_y,DD->list_w,DD->list_h,
           event->x,event->y))
      {
        DD->but1clicked= 1;
        DD->selitem= -1;
        return 1;
      }
      if (in_rect(DD->list_px,DD->list_py,DD->list_pw,DD->list_ph,
           event->x,event->y))
      {
        DD->but1clicked= 1;
        DD->selitem= dropdown_item_at(DD,event->y);
        dropdown_hilight_item(DD, DD->selitem);
        return 1;
      }
      return 0;
    case 4:
      dropdown_scroll_to(DD, DD->posy-0.9*DD->list_ph, 1);
      return 1;
    case 5:
      dropdown_scroll_to(DD, DD->posy+0.9*DD->list_ph, 1);
      return 1;
    }
    return 0;
  case GFXEV_BUTTON_RELEASE:
    if (event->button!=1 || !DD->but1clicked)
       return 0;
    DD->but1clicked= 0;
    if (DD->selitem!=-1)
       DD->selected= DD->selitem;
    dropdown_hide_list(DD);
    ungrab_mouse();
    if (DD->selitem==-1)
      return 1;
    event->type= DD->widget.number;
    event->key= DD->selitem;
    event->usr= DD->items[DD->selitem].ptr;
    DD->selitem= -1;
    if (DD->clickf && (*DD->clickf)(DD->evarg, event)) 
       return 1;
    return 0;
  }
  return 0;
}

static int in_rect(int rx,int ry,int rw,int rh, int x,int y)
{
  if (x<rx || y<ry || x>=(rx+rw) || y>=(ry+rh)) return 0;
  return 1;
}

static void dropdown_hide_list(dropdown_t *DD)
{
  if (!DD->list_active) return ;
  DD->list_active= 0;
  dropdown_put_list_backup(DD);
  gfx_update(DD->list_x,DD->list_y,DD->list_w,DD->list_h);
  dropdown_render_button(DD,0);
  DD->click_enabled= 1;
  if (DD->scroll) DD->scroll->enabled= 0;
}

static void dropdown_scroll_to(dropdown_t *DD,int pos,int report)
{
  if (pos<0) pos= 0;
  if (pos+DD->list_ph>DD->list_cont_h) pos= DD->list_cont_h-DD->list_ph;
  if (pos<0) pos= 0;
  if (DD->posy==pos) return ;
  
  DD->posy= pos;
  dropdown_draw_listbg(DD);
  dropdown_draw_contents(DD);
  if (report && DD->scroll) 
    scrollbar_set(DD->scroll, (double) DD->posy/DD->list_cont_h, 
                              (double) (DD->posy+DD->list_ph)/DD->list_cont_h, 
                              0, NULL);
  gfx_update(DD->list_x,DD->list_y,DD->list_w,DD->list_h);
}

static int dropdown_item_at(dropdown_t *DD,int y)
{
  int K;
  if (DD->n_items<=0) return -1;
  
  y= y - DD->list_py + DD->posy;
  if (y<DD->fh+dropdown_list_padv)
     K= 0;
  else
     K= (y-dropdown_list_padv+dropdown_list_spc)/(DD->fh+dropdown_list_spc);
  if (K>=DD->n_items) return -1;
  return K;
}

static void dropdown_hilight_item(dropdown_t *DD, int item)
{
  int x,y,w,h;

  if (item<0 || item>=DD->n_items) return ;
  x= DD->list_px;
  y= dropdown_item_pos(DD,item)-dropdown_list_spc+DD->list_py-DD->posy;
  w= DD->list_pw;
  h= DD->fh+dropdown_list_spc;
  fill_clipped_rect(DD->list_px, DD->list_py, DD->list_pw, DD->list_ph,
                    x,y,w,h, dropdown_list_hcolor);
  dropdown_draw_item(DD,item);
  gfx_update(x,y,w,h);
}

static void fill_clipped_rect
               (int Cx,int Cy,int Cw, int Ch, 
                int dx,int dy,int ow, int oh, unsigned int color)
{
  if (ow<=0 || oh<=0) return ;
  if (dx>=(Cx+Cw) || dy>=(Cy+Ch) || (dx+ow<=Cx) || (dy+oh<=Cy)) return ;

  if (dx<Cx)
  {
    ow-= (Cx-dx);
    dx= Cx;
  }

  if (dy<Cy)
  {
    oh-= (Cy-dy);
    dy= Cy;
  }
  if (ow<=0 || oh<=0) return ;

  if ((dy+oh)>=(Cy+Ch))
  {
    oh= Cy+Ch-dy;
  }
  if ((dx+ow)>=(Cx+Cw))
  {
    ow= Cx+Cw-dx;
  }
  if (ow<=0 || oh<=0) return ;
  gfx_fill_rect(0,dx,dy,ow,oh,color);
}


static void dropdown_insert(dropdown_t *DD,
                            int pos, const char *str, void *usr)
{
  TUPsp_t *src, *dst;
  int i;
  
  if (pos<0 || pos>DD->n_items) pos= DD->n_items;
  src= DD->items;
  if (DD->n_items==DD->s_items)
  {
    if (DD->s_items==0) DD->s_items= 10;
    else DD->s_items+= DD->s_items/2;
    DD->items= dst= malloc(DD->s_items*sizeof(DD->items[0]));
  }
  else dst= DD->items;

  if (src)
  {
    for(i=DD->n_items;i>pos;i--) dst[i]= src[i-1];
    if (src!=dst)
      for(i=0;i<pos;i++) dst[i]= src[i];
    if (src!=dst) free(src);
  }
  dst[pos].str= strdup(str);
  dst[pos].ptr= usr;
  DD->n_items++;
  if (pos<=DD->selected) DD->selected++;
}


static void dropdown_remove(dropdown_t *DD,int pos, void **Rusr)
{
  int i;
  
  if (DD->n_items==0) return ; 
  if (pos<0 || pos>=DD->n_items) pos= DD->n_items-1;
  if (Rusr) *Rusr= DD->items[pos].ptr;

  // actually, the string is always gotten from strdup, if is unnecessary
  if (DD->items[pos].str) free(DD->items[pos].str); 
  for(i=pos;i<DD->n_items-1;i++)
    DD->items[i]= DD->items[i+1];
  if (pos==DD->selected) DD->selected= -1;
  else if (pos<DD->selected) DD->selected--;
  DD->n_items--;
}

static void gui_dropdown_clear(dropdown_t *DD)
{
  int i;
  if (DD->n_items==0) return ; 
  for(i=0;i<DD->n_items;i++)
   free(DD->items[i].str);
  DD->selected= -1;
  DD->n_items= 0;  
  if (DD->shown)
    dropdown_render_button(DD,0);
}

static void gfx_dropdown_select(dropdown_t *DD, int pos)
{
  if (pos<0 || pos>=DD->n_items) pos= -1;
  if (DD->selected==pos) return ;
  DD->selected= pos;
  if (DD->shown)
    dropdown_render_button(DD,0);
}


static void gui_dropdown_destroy(widget_t *W)
{
  int i;
  dropdown_t *DD;
  DD= (void*) W;

  if (DD->scroll)
     scrollbar_destroy(DD->scroll);
  remove_click_handler(DD->click_handler);
  freeNnull(DD->list_backup);

  for(i=0;i<DD->n_items;i++)
    free(DD->items[i].str);
  freeNnull(DD->items);
}

static void dropdown_position(dropdown_t *DD,int x,int y,int w,int h)
{
  DD->widget.x= x;
  DD->widget.y= y;
  DD->widget.w= w;
  DD->widget.h= h;
  dropdown_render_button(DD,0);
}


static widget_t* gui_list_new
   (int noicon, int multisel, void *arg, 
       event_function_t clickf,
       event_function_t dlickf)
{
  gui_list_t *LL;

  LL= calloc(1,sizeof(*LL));

  LL->uses_icons= !noicon;
  LL->multiselect= multisel;

  LL->ch0= LL->ch1= LL->ch2= -1;
  LL->click_index= -1;

  LL->evarg= arg;
  LL->clickf= clickf;
  LL->dlickf= dlickf;

  LL->widget.klass= GFXCLASS_LIST;
  return &LL->widget;
}


static void gui_list_set_position(gui_list_t* LL,int x,int y,int w,int h)
{
    LL->x= x; LL->y= y; LL->w= w; LL->h= h;
    LL->port_x= LL->x+1;
    LL->port_y= LL->y+1;
    LL->widget.x= x;
    LL->widget.y= y;
    LL->widget.w= w;
    LL->widget.h= h;
}


static void gfx_list_show(gui_list_t *L, int show)
{
  int hv,hh;

  if ((L->enabled && show) || (!L->enabled && !show)) return ;

  if (!show)
  {
    L->enabled= 0;
    if (L->scrollv) L->scrollv->enabled= 0;
    if (L->scrollh) L->scrollh->enabled= 0;
    return ;
  }

  L->enabled= 1;

  L->max_icon_width= list_max_icon_width(L);
  compute_list_items(L, 0, L->n_items-1);
  compute_list_content_size(L, &L->content_w, &L->content_h);
  compute_list_port(L, &L->port_w, &L->port_h, &hh, &hv);
  list_layout_items(L,0);
  list_draw_borders(L, 0xf);
  list_arrange_scrollbars(L, hh, hv);
  list_draw_contents(L);
  gfx_update(L->x,L->y,L->w,L->h);
  list_install_click_handlers(L);
}



static void list_install_click_handlers(gui_list_t *LL)
{
  int x,y,w,h;
  if (!LL->enabled) return ;

  x= LL->port_x; y= LL->port_y;
  w= LL->port_w; h= LL->port_h;
  
  LL->ch0= install_or_modify_click
             (LL->ch0,&LL->enabled, gui_list_click, LL, x,y,w,h, 1);
  LL->ch1= install_or_modify_click
             (LL->ch1,&LL->enabled, gui_list_click4, LL, x,y,w,h, 4);

  LL->ch2= install_or_modify_click
             (LL->ch2,&LL->enabled, gui_list_click5, LL, x,y,w,h, 5);
}


static void compute_list_items
    (gui_list_t* LL, int start, int end)
{
  int tw,th;
  int i;

  start= imax2(0,start);
  end= imin2(end,LL->n_items-1);

  for(i=start;i<=end;i++)
  {
    list_item_t *item= LL->items+ i;

    get_text_data(1, item->str, &tw, &th, NULL, NULL);
    if (LL->uses_icons)
      item->text_x= gui_list_pad_horz+gui_list_icontext_sep + LL->max_icon_width;
    else
      item->text_x= gui_list_pad_horz;

    item->w= item->text_x + tw + gui_list_pad_horz;

    if (LL->uses_icons&&item->icon_data)
    {
      item->h= imax2(item->icon_height, th);
      item->icon_y= (item->h-item->icon_height)/2;
      item->icon_x= (LL->max_icon_width-item->icon_width)/2 + gui_list_pad_horz;
    }
    else
    {
      item->h= th;
    }
    item->text_y= (item->h-th)/2;

    item->text_w= tw;
    item->text_h= th;
  }
}

static void compute_list_content_size(gui_list_t *LL,int *Rw, int *Rh)
{
  int i;
  int w,h;
  w= h= 0;
  for(i=0;i<LL->n_items;i++)
  {
    h+= LL->items[i].h;
    if (i>0 && i<LL->n_items-1) h+= gui_list_spacing;
    w= imax2(w, LL->items[i].w);
  }
  h+= 2*gui_list_pad_horz;
  if (Rw) *Rw= w;
  if (Rh) *Rh= h;
}

static int list_max_icon_width(gui_list_t *LL)
{
  int i,w;
  w= 0;
  if (!LL->uses_icons) return 0;
  for(i=0;i<LL->n_items;i++)
    if (LL->items[i].icon_data)
      w= imax2(w, LL->items[i].icon_width);
  return w;
}

static void compute_list_port
  (gui_list_t* LL, int *Rportw, int *Rporth, int *Rhs, int *Rvs)
{
  int portw,porth, wA,wB, hA, hB;

  wA= LL->w - 2 ;
  wB= LL->w - 1 - gui_scrollbar_width;

  hA= LL->h - 2; 
  hB= LL->h - 1 - gui_scrollbar_height;

  portw= wA;
  porth= hA;
  if (portw<LL->content_w) porth= hB;
  if (porth<LL->content_h) portw= wB;
  if (portw<LL->content_w) porth= hB;
 
  if (Rportw) *Rportw= portw;
  if (Rporth) *Rporth= porth;
  if (Rhs)    *Rhs= (porth==hB);
  if (Rvs)    *Rvs= (portw==wB);
}

static int list_render_item(gui_list_t *LL,int ino,int bg)
{
  list_item_t *item= LL->items+ino;

  int src_x,src_y, copy_w, copy_h;
  unsigned char *tdata;
  
  int cW = item->icon_width,
      cH = item->icon_height,
      cX = item->icon_x,
      cY = item->icon_y + item->y;

  int tW= item->text_w,
      tH= item->text_h,
      tX= item->text_x,
      tY= item->text_y + item->y;

  int iY= item->y,
      iH= item->h;
      //  iX= 0, iW= item->w,

  int sY= LL->posy, 
      sX= LL->posx,
      sW= LL->port_w,
      sH= LL->port_h;

  if ((iY+iH)<=sY)  return -1;
  if (iY>=(sY+sH))  return 1;

  if (item->selected || bg)
  {
    int bY= iY-sY+LL->port_y,
        bW= LL->port_w,
        bX= LL->port_x,
        bH= iH;
    int color;

    if (bY<LL->port_y) 
    {
      bH-= LL->port_y-bY;
      if (bH<=0) goto bg_done;
      bY= LL->port_y;
    }

    if ((bY+bH)>(LL->port_y+LL->port_h))
    {
      bH= (LL->port_y+LL->port_h) - bY;
      if (bH<=0) goto bg_done;
    }
    if (item->selected) color= 0xaabbff;
             else color= 0xffffff;
    gfx_fill_rect(0, bX, bY, bW, bH, color);
  }

bg_done:
  if (!LL->uses_icons || !item->icon_data) goto icon_done;

  src_x= 0;
  src_y= 0;
  copy_w= cW;
  copy_h= cH;

  if (cX<sX)
  {
    src_x += sX-cX;
    copy_w-= sX-cX;
    cX= sX;
  }

  if (cY<sY)
  {
    src_y+= sY-cY;
    copy_h-= sY-cY;
    cY= sY;
  }

  if ((cX+copy_w)>(sX+sW))
    copy_w-= (cX+copy_w) - (sX+sW);

  if ((cY+copy_h)>(sY+sH))
    copy_h-= (cY+copy_h) - (sY+sH);

    if (copy_w<=0) goto icon_done;
    if (copy_h<=0) goto icon_done;
  if (cY>=(sY+sH)) goto icon_done;
  if (cX>=(sX+sW)) goto icon_done;

  // now, cX and cY contain the document coordinates for copy.

  gfx_put(GFX_ALPHA, item->icon_data, cW, cH, src_x, src_y,
                                      cX-sX+LL->port_x, cY-sY+LL->port_y,
                                      copy_w, copy_h);
icon_done:
  src_x= 0;
  src_y= 0;
  copy_w= tW;
  copy_h= tH;

  if (tX<sX)
  {
    src_x += sX-tX;
    copy_w-= sX-tX;
    tX= sX;
  }

  if (tY<sY)
  {
    src_y += sY-tY;
    copy_h-= sY-tY;
    tY= sY;
  }

  if ((tX+copy_w)>(sX+sW))
  {
    copy_w -= (tX+copy_w)-(sX+sW);
  }
  if ((tY+copy_h)>(sY+sH))
  {
    copy_h -= (tY+copy_h)-(sY+sH);
  }

  if (copy_h<=0) goto text_done;
  if (copy_w<=0) goto text_done;
  if (tY>=(sY+sH)) goto text_done;
  if (tX>=(sX+sW)) goto text_done;

  get_text_data(1, item->str, NULL, NULL, NULL,&tdata);
  blend_graymap(0, 0x00, 0xffffff, tdata, tW, tH, src_x, src_y,
                             tX-sX+LL->port_x, tY-sY+LL->port_y,
                             copy_w, copy_h);
  free(tdata);

text_done:
  return 0;
}


static void gui_list_scrollbar_click_horz(void *a, double S, double E)
{
  int posx;
  gui_list_t *L;
  L= a;

  posx= S*L->content_w;
  if (posx+L->port_w>L->content_w)
    posx= L->content_w - L->port_w;
  if (posx<0) posx= 0;
  if (posx!=L->posx)
  {
    L->posx= posx;
    list_draw_contents(L);
    gfx_update(L->port_x,L->port_y,L->port_w,L->port_h);
  }
}

static void gui_list_scrollbar_click_vert(void *a, double S, double E)
{
  int posy;
  gui_list_t *L;
  L= a;

  posy= S*L->content_h;
  if (posy+L->port_h>L->content_h)
    posy= L->content_h - L->port_h;
  if (posy<0) posy= 0;
  if (posy!=L->posy)
  {
    L->posy= posy;
    list_draw_contents(L);
    gfx_update(L->port_x,L->port_y,L->port_w,L->port_h);
  }
}




static void list_layout_items(gui_list_t *LL,int start)
{
  int i,y;
  start= imax2(0,start);
  if (start==0) y= gui_list_pad_vert;
           else y= LL->items[start-1].y+LL->items[start-1].h+gui_list_spacing;
 
  for(i=start;i<LL->n_items;i++)
  {
    LL->items[i].y= y;
    y+= LL->items[i].h + gui_list_spacing;
  }
}

static void list_draw_borders(gui_list_t *LL,int which)
{
  int x,y,w,h;
  unsigned int border;
  x= LL->x; y= LL->y; w= LL->w; h= LL->h;

  border= color_u_to_s(gui_list_border);
  if (which & 8) hline(x, x+w-1, y, border);
  if (which & 2) hline(x, x+w-1, y+h-1, border);
  if (which & 4) vline(x, y, y+h-1, border);
  if (which & 1) vline(x+w-1, y, y+h-1, border);
}

static void list_draw_contents(gui_list_t *L)
{
  int i,j,k;
  gfx_fill_rect(0,L->port_x,L->port_y,L->port_w,L->port_h, 0xffffff);
  if (L->n_items==0) return ;
  i= 0; 
  j= L->n_items-1;
  while(i<=j)
  {
    k= (i+j)/2;
    switch(list_render_item(L,k,0))
    {
     case 1: j= k-1; break;
     case 0: goto found;
     case -1: i= k+1; break;
    }
  }

  return;
found:
  for(i=k-1;i>=0;i--)         if (list_render_item(L,i,0)) break;
  for(j=k+1;j<L->n_items;j++) if (list_render_item(L,j,0)) break;
}

static void list_compute_scroll
    (int pos,int win,int con, double *Rstart, double *Rend, double *Rstep)
{
  if (con<=0) con= 1;
  *Rstart=  dmax2(0.0,dmin2((double)pos/con,1.0));
  *Rend=    dmin2(1.0,dmax2((double)(pos+win)/con,0.0));
  *Rstep=   dmax2(0.0,dmin2(1.0,(double)win/con*0.9));
}

static void list_arrange_scrollbars
   (gui_list_t *LL, int have_horz, int have_vert)
{
  int ver_scroll_h, hor_scroll_w;
  double start,end,step;

  hor_scroll_w= LL->w;
  if (have_vert) hor_scroll_w-= gui_scrollbar_width;
  ver_scroll_h= LL->h;
  if (have_horz) ver_scroll_h-= gui_scrollbar_height;

  switch((have_vert ? 2: 0) | (LL->has_scrollv ?1:0))
  {
  case 0: break;
  case 1: list_draw_borders(LL, 1); break;
  case 3:
  case 2: 
    list_compute_scroll(LL->posy, LL->port_h, LL->content_h,
                        &start,&end,&step);
    if (LL->scrollv)
      scrollbar_relayout(LL->scrollv, 
                   LL->scrollv->widget.x, LL->scrollv->widget.y,
                   gui_scrollbar_width, ver_scroll_h, start, end,step);
    else {
      LL->scrollv= (scrollbar_t*)
        scrollbar_new(1, start,end,step,0, LL, gui_list_scrollbar_click_vert);
      scrollbar_position(LL->scrollv, LL->x+LL->w-gui_scrollbar_width, LL->y,
                          gui_scrollbar_width, ver_scroll_h);
    }
    scrollbar_show(LL->scrollv,1);
    break;
  }

  switch( (have_horz?2:1)  | (LL->has_scrollh?1:0))
  {
  case 0: break;
  case 1: list_draw_borders(LL,2); break;
  case 3:
  case 2: 
    list_compute_scroll(LL->posx, LL->port_w, LL->content_w,
                        &start,&end,&step);
    if (LL->scrollh)
      scrollbar_relayout(LL->scrollh, 
                   LL->scrollh->widget.x, LL->scrollh->widget.y,
                   hor_scroll_w, gui_scrollbar_height, start,end,step);
    else 
    {
      LL->scrollh= (scrollbar_t*)
        scrollbar_new(0, start,end,step,0, LL, gui_list_scrollbar_click_horz);
      scrollbar_position(LL->scrollh, 
             LL->x,LL->y+LL->h-gui_scrollbar_height,
             hor_scroll_w, gui_scrollbar_height);
    }
    scrollbar_show(LL->scrollh,1);
    break;
  }

  if (LL->scrollv) LL->scrollv->enabled= have_vert;
  if (LL->scrollh) LL->scrollh->enabled= have_horz;
    
  if (have_vert && have_horz)
  {
    if (!LL->has_scrollv || !LL->has_scrollh)
      gfx_fill_rect(0, LL->scrollh->widget.x+ LL->scrollh->widget.w,
                       LL->scrollv->widget.y+ LL->scrollv->widget.h,
                       gui_scrollbar_width, gui_scrollbar_height, 0xdddddd);
  }

  if (have_horz)
    gfx_update(LL->x,LL->scrollh->widget.y, LL->w, gui_scrollbar_height);
  if (have_vert)
    gfx_update(LL->scrollv->widget.x, LL->y, gui_scrollbar_width, LL->h);
  LL->has_scrollh= have_horz;
  LL->has_scrollv= have_vert;
}



static int gui_list_click(void *a, gfx_event_t *ev)
{
  int i,j,k;
  gui_list_t *L;
  int upd;
  event_function_t f;
  
  L= a;
  i= 0; j= L->n_items-1;

  while(i<=j)
  {
    int iY, iH;
    k= (i+j)/2;
    iY= L->items[k].y - L->posy + L->port_y; 
    iH= L->items[k].h;

    if (ev->y<iY) { j= k-1; continue; } 
    if (ev->y>=(iY+iH)) { i= k+1; continue; }
    goto found;
  }
  return 1;
found:
  upd=1;
  if (!L->multiselect)
  {
    for(i=0;i<L->n_items;i++)
      if (i!=k && L->items[i].selected)
      {
        L->items[i].selected= 0;
        upd*= list_render_item(L, i, 1);
      }
    if (!L->items[k].selected)
    {
       L->items[k].selected= 1;
       upd*= list_render_item(L,k,1);
    }
  }
  else
  {
    L->items[k].selected= L->items[k].selected ? 0:1;
    upd= list_render_item(L,k,1);
  }

  if (!upd)
    gfx_update(L->port_x,L->port_y,L->port_w,L->port_h);

  if (L->click_time && ev->time>L->click_time && 
        (ev->time-L->click_time<500) && L->click_index==k)
  {
    ev->type= GFXEV(L->widget.number, DOUBLE_CLICK);
    L->click_time= 0;
    L->click_index= -1;
    f= L->dlickf;
  }
  else
  {
    ev->type= L->widget.number;
    L->click_time= ev->time;
    L->click_index= k;
    f= L->clickf;
  }
  ev->key= k;
  ev->string= L->items[k].str;
  ev->usr= L->items[k].user;

  if (f && (*f)(L->evarg, ev)) return 1; 
  return 0;
}

 // mouse button 4: scroll up
static int gui_list_click4(void *a, gfx_event_t *ev)
{
  gui_list_t *L;
  int posy;
  L= a;

  posy= imax2(L->posy - L->port_h/2,0);
  if (posy!=L->posy)
  {
    L->posy= posy;
    list_draw_contents(L);
    if (L->has_scrollv) 
       scrollbar_set( L->scrollv,
                      (double) L->posy/L->content_h, 
                      (double)(L->posy+L->port_h)/L->content_h,
                      0, NULL );
    gfx_update(L->port_x,L->port_y,L->port_w,L->port_h);
  }
  return 2;
}

 // mouse button 5: scroll down
static int gui_list_click5(void *a, gfx_event_t *ev)
{
  gui_list_t *L;
  int posy;
  L= a;

  posy= imax2(0, imin2(L->posy + L->port_h/2, L->content_h - L->port_h));
  if (posy!=L->posy)
  {
    L->posy= posy;
    list_draw_contents(L);
    if (L->has_scrollv) 
       scrollbar_set( L->scrollv,
                      (double) L->posy/L->content_h, 
                      (double)(L->posy+L->port_h)/L->content_h,
                      0, NULL );
    gfx_update(L->port_x,L->port_y,L->port_w,L->port_h);
  }
  return 2;
}

static void list_relayout(int flags, gui_list_t *L)
{
  int hh, hv;
  compute_list_content_size(L, &L->content_w, &L->content_h);
  compute_list_port(L, &L->port_w, &L->port_h,&hh, &hv);

  L->posy= imax2(0, imin2(L->posy, L->content_h-L->port_h));
  L->posx= imax2(0, imin2(L->posx, L->content_w-L->port_w));

  list_arrange_scrollbars(L,hh,hv);

  list_install_click_handlers(L);

  list_draw_contents(L);

  if (flags&GFX_UPDATE && L->enabled)
    gfx_update(L->x,L->y,L->w,L->h);
}


static void gfx_list_insert(gui_list_t* L, int pos, char *str, void *usr
                          ,const unsigned int*icon) 
{
  list_item_t *item;
  unsigned int icon_w, icon_h;

  if (icon)
  {
  icon_w= icon[0] & ~(1<<31);
  icon_h= icon[1];
  icon= icon+2;
  }
  else icon_w= icon_h= 0;

  if (pos<0 || pos>=L->n_items) pos= L->n_items;

  item= array_make1space(pos,(void**) &L->items, L->n_items, &L->s_items,
                         sizeof(L->items[0]));
  item->str= strdup(str);
  item->user= usr;
  item->icon_data= icon;
  item->icon_width= icon_w;
  item->icon_height= icon_h;
  item->selected= 0;

  L->n_items++;
  compute_list_items(L, pos, pos);

  if (!L->enabled) return ;

  L->max_icon_width= list_max_icon_width(L);
  list_layout_items(L, pos);
  list_relayout(GFX_UPDATE,L);
}


static void gfx_list_delete(gui_list_t *L, int pos, void **Ruser)
{
  int i;

  if (Ruser) *Ruser= NULL;
  if (L->n_items==0) return ;
  if (pos<0) pos= L->n_items-1;
  if (pos>=L->n_items) return ;

  if (Ruser) *Ruser= L->items[pos].user;
  free(L->items[pos].str);

  for(i=pos;i<L->n_items-1;i++)
     L->items[i]= L->items[i+1];
  L->n_items--;

  if (L->enabled)
  {
    if (pos<L->n_items)
      list_layout_items(L, pos);
    list_relayout(GFX_UPDATE,L);
  }
}


static int gfx_list_selected(gui_list_t *L)
{
  int i;
  for(i=0;i<L->n_items;i++)
   if (L->items[i].selected) return i;
  return -1;
}


static void gfx_list_select(gui_list_t* L,int pos)
{
  int i;
  int ch;
  if (pos<0 || pos>=L->n_items) return ;
  if (L->items[pos].selected) return ;
  ch= 1;
  for(i=0;i<L->n_items;i++)
    if (L->items[i].selected)
    {
      L->items[i].selected= 0;
      if (L->enabled) ch&= list_render_item(L,i,1);
    }
  L->items[pos].selected= 1;
  if (L->enabled) 
    ch &=list_render_item(L,pos,1);
  if (L->enabled && !ch)
    gfx_update(L->port_x,L->port_y,L->port_w,L->port_h);
}

static void gfx_list_clear(gui_list_t *L)
{
  int i;
  for(i=0;i<L->n_items;i++)
  {
    free(L->items[i].str);
    L->items[i].str= NULL;
  }
  L->n_items= 0;
  L->posx= 0;
  L->posy= 0;
  if (L->enabled)
    list_relayout(GFX_UPDATE,L);
}


static widget_t *text_entry_new(char *initstr)
{
  text_entry_t *te;
  uint32_t i;
  uint32_t *wide_str, wide_str_len;
  int size;
  int x;

  te= calloc(1,sizeof(*te));

  if (!initstr) initstr= "";
  utf8_decode_alloc(initstr, &wide_str, &wide_str_len);

  size= wide_str_len + wide_str_len/2 + 2;
  if (size<50) size= 50;

  te->size= size;
  te->len= wide_str_len+1;
  te->glyphs= malloc(sizeof(te->glyphs[0])*te->size);
  
  for(i=0;i<te->len-1;i++) mk_glyph(te->glyphs+i, wide_str[i]);
  mk_glyph(te->glyphs+i, ' ');
  free(wide_str);

  x= 0;
  for(i=0;i<te->len;i++)
  {
    te->glyphs[i].x= x;
    x+= te->glyphs[i].w;
  }
  
  te->fonth= font1height;
  
  te->cursor= te->len-1;
  te->left= 0;

  te->widget.can_focus= 1;
  te->widget.has_focus= 0;
  te->widget.focus= textentry_focus;
  te->widget.handle_key= textentry_key;

  te->widget.klass= GFXCLASS_TEXTENTRY;

  te->widget.show= gui_textentry_show;
  te->widget.hide= gui_textentry_hide;

  return &te->widget;
}


static void textentry_position(text_entry_t *te,int x,int y,int w,int h)
{
  widget_t *W;
  te->x= x; te->y= y; te->w= w; te->h= h;
  W= &te->widget;
  W->x= x; W->y= y; W->w= w; W->h= h;
  make_cursor_visible(te);
}

static void make_cursor_visible(text_entry_t *te)
{
  int cx, cw;
  int i;
  cx= te->glyphs[te->cursor].x;
  cw= te->glyphs[te->cursor].w;

  if (cx<te->left) te->left= cx; 
  else if (cx+cw-te->left>te->w) te->left= cx+cw-te->w; 

  if (te->widget.shown)
  {
    gfx_fill_rect(0, te->x, te->y, te->w, te->h, TE_bg);
    gfx_draw_rect(0, te->x-1, te->y-1, te->w+2, te->h+2, 0x888888);
    for(i=0;i<te->len;i++) if (draw_glyph(te, i,0)) break;
    gfx_update(te->x, te->y, te->w, te->h);
  }
}


static void mk_glyph(glyph_t *G, uint32_t chr)
{
  // We don't store the height, they all have the same height.
  font_render(fonts+0,&chr, 1, (int*) &G->w, NULL, NULL, &G->d);
  G->chr= chr;
}

static int draw_glyph(text_entry_t  *te, int gn, int expose)
{
  int ws, we, sx, sy, cw, ch, dx,dy, gs,ge;
  uint32_t fg, bg;
  glyph_t *G;

  ws= te->left; 
  we= te->left+te->w;
  G= te->glyphs+gn;

  if (te->fonth>te->h)
  {
    sy= (te->fonth-te->h)/2;
    ch= te->h;
    dy= 0;
  } else { dy= (te->h-te->fonth)/2; sy=0; ch= te->fonth; }

  gs= G->x;
  ge= gs + G->w;

  if (ge<=ws) return 0;
  if (gs>=we) return 1;
    
  sx= 0; cw= te->glyphs[gn].w;
  if (gs<ws) { sx= ws-gs; cw-= ws-gs; }
  if (ge>we) { cw-= ge-we; }

  dx= sx + gs - ws;
  if (te->widget.has_focus && gn==te->cursor) { fg= TE_cfg; bg= TE_cbg; }
                                  else { fg= TE_fg;  bg= TE_bg; }

  blend_graymap( (expose ? GFX_UPDATE : 0) | GFX_BACKGND, 
                 fg, bg, G->d, G->w, te->fonth, sx, sy,
                         dx + te->x, dy + te->y, cw, ch );
  return 0;
}


static void textentry_focus(void *va, int focus)
{
  text_entry_t *te;
  te= va;
  if (!te->widget.shown) return ;
  if (te->widget.has_focus==focus) return ;
  te->widget.has_focus= focus;
  draw_glyph(te, te->cursor, 1);
}

static int textentry_key(void* va, gfx_event_t *event) 
{
  text_entry_t *te;
  te= va;
    // this will not happen, hopefully.
  if (!te->widget.shown) return 0;
  if (te->key_filter && (*te->key_filter)(te->key_arg,va,event))
    return 1;
  
  switch(event->key)
  {
   case GFX_K_LEFT:
     if (te->cursor!=0) text_entry_move_cursor(te, te->cursor-1);
     return 1;
   case GFX_K_RIGHT:
     if (te->cursor!=te->len-1) text_entry_move_cursor(te,te->cursor+1);
     return 1;
   case GFX_K_HOME: text_entry_move_cursor(te, 0); return 1;
   case GFX_K_END:  text_entry_move_cursor(te, te->len-1); return 1;
   case GFX_K_DELETE:
     if (te->cursor!=te->len-1) delete_cursor_char(te);
     return 1;
   case GFX_K_BACKSPACE:
     if (te->cursor!=0)
     {
       te->cursor--;
       delete_cursor_char(te);
     }
     return 1;
   case GFX_K_PRT:
     insert_char(te, event->wide);
     return 1;
  }
  return 0;
}


static void text_entry_move_cursor(text_entry_t *te, int newcurs)
{
  int ws, we, gs,ge;
  int C;

  if (newcurs<0 || newcurs>=te->len || newcurs==te->cursor) return ;  

  gs= te->glyphs[newcurs].x;
  ge= gs + te->glyphs[newcurs].w;

  ws= te->left; 
  we= te->left+te->w;

  if (gs<ws|| ge>we)
  {
    te->cursor= newcurs;
    make_cursor_visible(te);
    return ;
  }

  C= te->cursor;
  te->cursor= newcurs;
  draw_glyph(te, C,1);
  draw_glyph(te, te->cursor,1);
}

static void insert_char(text_entry_t *te, uint32_t chr)
{
  int i;
  if (te->len==te->size)
  {
    te->size+= te->size/2;
    te->glyphs= realloc(te->glyphs, sizeof(te->glyphs[0])*te->size);
  }
  for(i=te->len;i>te->cursor;i--)
    te->glyphs[i]= te->glyphs[i-1];
  mk_glyph(te->glyphs+ te->cursor, chr);
  
  te->cursor++;
  te->len++;
  for(i=te->cursor;i<te->len;i++)
    te->glyphs[i].x= te->glyphs[i-1].x + te->glyphs[i-1].w;

  make_cursor_visible(te);
}

static void delete_cursor_char(text_entry_t *te)
{
  int i,x;
  free(te->glyphs[te->cursor].d);
  x= te->glyphs[te->cursor].x;
  for(i=te->cursor;i<te->len-1;i++)
  {
    te->glyphs[i]= te->glyphs[i+1];
    te->glyphs[i].x= x;
    x+= te->glyphs[i].w;
  }
  te->len--;
  te->glyphs[i].x= x;
  make_cursor_visible(te);
}


static char *textentry_get_text(text_entry_t *te)
{
  uint32_t *wide, widelen;
  uint8_t *str;
  int i;
  size_t slen;

  widelen= te->len;
  wide= malloc(sizeof(uint32_t)*widelen);
  for(i=0;i<te->len;i++)
    wide[i]= te->glyphs[i].chr;

  str= malloc(widelen+1);
  utf8_encode_string(wide, widelen, str, &slen);
  if (slen) str[slen-1]= 0; // eat up the space we added
  free(wide);
  return (char*) str;
}


static void textentry_free(text_entry_t *te)
{
  int i;
  for(i=0;i<te->len;i++)
   free(te->glyphs[i].d);
  free(te->glyphs);
}


static void text_entry_set(text_entry_t *te, char *str)
{
  uint32_t i;
  uint32_t *wide_str, wide_str_len;
  int x;

  if (!str) str="";
  utf8_decode_alloc(str, &wide_str, &wide_str_len);

  if (wide_str_len>=te->size)
  {
    te->size= wide_str_len + wide_str_len/2 + 2;
    if (te->size<50) te->size= 50;
    te->glyphs= realloc(te->glyphs,sizeof(te->glyphs[0])*te->size);
  }

  for(i=0;i<te->len;i++) free(te->glyphs[i].d);

  te->len= wide_str_len+1;
  
  for(i=0;i<te->len-1;i++) mk_glyph(te->glyphs+i, wide_str[i]);
  mk_glyph(te->glyphs+i, ' ');

  x= 0;
  for(i=0;i<te->len;i++)
  {
    te->glyphs[i].x= x;
    x+= te->glyphs[i].w;
  }
  
  free(wide_str);
  
  te->cursor= te->len-1;
  te->left= 0;
  if (te->widget.shown)
    make_cursor_visible(te);
}





static void gui_textentry_show(widget_t *arg)
{
  text_entry_t *te;
  te= (text_entry_t*) arg;
  te->widget.can_focus= 1;
  make_cursor_visible(te);
}

static void gui_textentry_hide(widget_t *arg)
{
  text_entry_t *te;
  te= (text_entry_t*) arg;
  if (te->widget.has_focus) focus_lost();
  te->widget.can_focus= 0;
  te->widget.has_focus= 0; 
}


static widget_t* gfx_pixgrid()
{
  gui_pixgrid_t *B;
  B= calloc(1,sizeof(*B));
  B->widget.klass= GFXCLASS_PIXGRID;
  B->click_handler= install_click_handler(0,0,0,0,&B->enabled,B, 
                                          gui_pixgrid_click,1);
  return &B->widget;
}



static int gui_pixgrid_click(void *arg,gfx_event_t *event)
{
  gui_pixgrid_t *B;
  B= arg;
  if (!B->enabled) return 0;
  event->type += B->widget.number;
  event->x -= B->widget.x;
  event->y -= B->widget.y;
  install_release_handler(arg,gui_pixgrid_release);
  return 0;
}

static int gui_pixgrid_release(void *arg,gfx_event_t *event)
{
  gui_pixgrid_t *B;
  B= arg;
  event->type += B->widget.number;
  event->x -= B->widget.x;
  event->y -= B->widget.y;
  return 0;
}


static void gfxask_make_buttons
  (char *butstr,int *coor,int *Rnbut, int *Rbut_h,int *Rbut_total_w)
{
  int i,x,dummy,nr;
  char **buttons; int nbuttons;
  int button_h, button_w; // , button_total_w;
  int fh1;             // font height for font 1

  RES_INT(dialog_button_padding, 6, 
         "Internal spacing for confirmation dialog buttons");
  RES_INT(dialog_button_spacing, 10, 
         "External spacing for confirmation dialog buttons");

  butstr= strdup(butstr);
  split_string_bychar_d(butstr+1,butstr[0],&buttons,&nbuttons);

  if (nbuttons>8) nbuttons= 8;

  multi_line_str_dim(1,buttons,nbuttons, &button_w, &dummy);
  button_w += dialog_button_padding;
  *Rbut_total_w= button_w*nbuttons + (nbuttons-1)*dialog_button_spacing;

  get_text_data(1,"M",NULL,&fh1,NULL,NULL);
  button_h= fh1 + dialog_button_padding;

  x= 0;
  for(i=0;i<nbuttons;i++)
  {
    nr= GUIRaskB1+i;
    if (!widgets[nr]) 
    {
      widgets[nr]= (widget_t*) gui_button_new(buttons[i], 0, NULL, 
                                               GFXCLASS_BUTTON);
      widgets[nr]->number= nr;
    }
    else
    {
      gui_button_set_text((gui_button_t*) widgets[nr], buttons[i]);
    }
    coor[4*i+0]= x;
    coor[4*i+2]= button_w;
    coor[4*i+3]= button_h;
    x+= button_w + dialog_button_spacing;
  }
  free(buttons);
  free(butstr); 
  *Rnbut= nbuttons;
  *Rbut_h= button_h;
}

static void gfxask_show_buttons
    (int *coor_widgets, int nbuttons,int X,int Y)
{
  int i;
  for(i=0;i<nbuttons;i++)
  {
    int nr;
    nr= GUIRaskB1+i;
    coor_widgets[4*i+0] += X;
    coor_widgets[4*i+1] = Y;
    gui_button_activate(widgets[nr], 
           coor_widgets[4*i+0], coor_widgets[4*i+1],
           coor_widgets[4*i+2], coor_widgets[4*i+3]);
  }
}


static void gfxask_draw_border(int X,int Y,int W,int H)
{
  int i;
  int border;
  RES_COLOR(confirm_border_color, 0 ,"Border color for confirmation dialog");
  RES_INT(confirm_border_width, 4 , "Border width for confirmation dialog");
  border= color_u_to_s(confirm_border_color);
  for(i=1;i<=confirm_border_width;i++)
  {
    hline(X-i,    X+W-1+i, Y-i     ,border);
    hline(X-i,    X+W-1+i, Y+H-1+i ,border);
    vline(X-i,    Y-i,     Y+H-1+i ,border);
    vline(X+W-1+i,Y-i,     Y+H-1+i ,border);
  }
  gfx_fill_rect(0, X,Y,W,H, confirm_bg);
}


static void split_string_bychar_d(char *str, int chr, char ***Ra,int *Rn)
{
  int d,n;
  char *x,*k,**R;
 
  R= NULL;
retry:
  n= 0;
  d= 0;
  x= str;
  while(!d)
  {
    k= strchr(x,chr);
    if (!k)
    {
      k= x+strlen(x);
      d= 1;
    }
    if (R)
    {
      R[n]= x;
      k[0]= 0;
    }
    n++;
    if (!d) { x= k+1; }
  }

  if (!R)
  {
    R= malloc(sizeof(*R)*(n+1));
    goto retry;
  }
  R[n]= NULL;
  *Ra= R;
  *Rn= n;
}

static void format_multi_line_str(char *fmt, va_list ap, char ***Rl, int *Rn)
{
  char *all;
  all= vmprintf(fmt, ap);
  split_string_bychar_d(all,'\n',Rl, Rn);
}

static void multi_line_str_dim
  (int font,char **lines, int nlines,int *Rw,int *Rh)
{
  int fh,tw;
  int i,w,h;

  get_text_data(font, "M",NULL,&fh,NULL,NULL);
  w= 0; 
  h= 0;
  for(i=0;i<nlines;i++)
  {
    get_text_data(font, lines[i],&tw,NULL,NULL,NULL);
    if (tw>w) w= tw;
    if (i) h+= 1;
    h+= fh;
  }
  *Rw= w;
  *Rh= h;
}


static char **parse_ext_list(char *inp)
{
  char **R;
  char *K,*E,*S;
  int N;

  inp= strchr(inp, '(');
  if (!inp) return NULL;
  R= NULL;

again:
  N= 0;
  K= inp+1;
  while(K[0]!=0 && K[0]!=')')
  {
    for(S=K;S[0]!='.' && S[0]!=0 && S[0]!=')';S++)  ;
    if (S[0]!='.') { K=S; continue; }
    for(E=S+1;E[0]!=0 && E[0]!=')' && E[0]!=' ' && E[0]!=',';E++)  ;
    if (E==S+1) { K=E; continue; }
    if (R)
    {
      R[N]= malloc(E-S+1);
      memcpy(R[N],S, E-S);
      R[N][E-S]= 0;
    }
    N++;
    K= E;
  }
  if (!R)
  {
    R= malloc(sizeof(*R)*(N+1));
    goto again;
  }
  R[N]= NULL;
  return R;
}

static char **make_file_extension_list(char **inp)
{
  int i,j;
  char **R;
  int nent,ne;
  char ***L;

  if (!inp || !inp[0] || !inp[0][0]) return NULL;
  if (strchr(inp[0],'('))
  {
    R= parse_ext_list(inp[0]);
    goto done;
  }

  {
    int first_spc;
    for(i=0;inp[0][i]==' ';i++) ;
    first_spc= i;

    for(i=1;inp[i];i++)
    {
      for(j=0;inp[i][j]==' ';j++) ;
      if (j<=first_spc) break;
    }
    nent= i;
  }
  if (nent==1) return NULL;

  ne= 0;
  L= calloc(nent,sizeof(*L));
  for(i=0;i<nent;i++)
  {
   if (!strchr(inp[i],'(')) continue;
    L[i]= parse_ext_list(inp[i]);
    if (L[i])
    {
      for(j=0;L[i][j];j++) ;
      ne+= j;
    }
  }
  R= malloc(sizeof(*R)*(ne+1));
  ne= 0;
  for(i=0;i<nent;i++)
  {
    if (L[i])
    {
     for(j=0;L[i][j];j++)
       R[ne++]= L[i][j];
     free(L[i]);
    } 
  }
  R[ne]= NULL;
  free(L);

done:
  return R; // maybe sort the list, and unify it??
}

static int file_matches_ext_set(char *fn,char **ext)
{
  int i;
  int lf,le;
  if (!ext) return 1;
  lf= strlen(fn);
  for(i=0;ext[i];i++)
  {
    if (!strcmp(ext[i],".*")) return 1;
    le= strlen(ext[i]);
    if (lf<=le) continue;
    if (!strcasecmp(fn+lf-le,ext[i])) return 1;
  }
  return 0;
}


static char **list_files(char *dn)
{
  DIR *dir;
  struct dirent *de;
  char **ptr;
  char *str;
  size_t i, ptrsize, strsize, L;
  buffer_t *buffer;

  dir= opendir(dn);
  if (!dir)
  {
    ptr= malloc(sizeof(*ptr));
    ptr[0]= NULL;
    return ptr;
  }

  buffer= buffer_new(1024);
  ptrsize= strsize= 0;
  while((de=readdir(dir)))
  {
    buffer_write(buffer, "U", 1);
    L= strlen(de->d_name)+1;
    buffer_write(buffer, de->d_name, L);
    strsize+= L+1;
    ptrsize++;
  }
  closedir(dir);

  ptr= malloc( (ptrsize+1)*sizeof(char*) + strsize );
  str= (char*) ptr + (ptrsize+1)*sizeof(char*) ;

  buffer_read(buffer, str, strsize);
  buffer_free(buffer, NULL, NULL);

  for(i=0;i<ptrsize;i++)
  {
    ptr[i]= str;
    str+= strlen(str)+1;
  }
  ptr[i]= NULL;
  
  return ptr;
}

static void file_types(char *dn, char **files)
{
  size_t i;
  size_t mlen,L, dlen;
  char *path,*name;

  mlen= 0;
  for(i=0;files[i];i++)
  {
    L= strlen(files[i]);
    if (L>mlen) mlen= L;
  }

  dlen= strlen(dn);
  path= malloc(dlen+2+mlen); // slash + null
  name= path+dlen+1;
  memcpy(path, dn, dlen);
  path[dlen]= '/';

  for(i=0;files[i];i++)
  {
    struct stat sbuf;
    strcpy(name, files[i]+1);
    if (stat(path,&sbuf)) continue;
    if (S_ISDIR(sbuf.st_mode))      files[i][0]= 'D';
    else if (S_ISREG(sbuf.st_mode)) files[i][0]= 'F';
  } 

  free(path);
}


_BUFFER_PROTO buffer_t *buffer_new(size_t blksize)
{
  buffer_t *B;
  B= malloc(sizeof(*B));
  B->first= B->last= NULL;
  B->blksize= blksize;
  return B;
}


_BUFFER_PROTO void buffer_free(buffer_t *B, void **Rd, size_t *Rl)
{
  struct buffer_node *P,*N;
  if (Rd || Rl) buffer_collect(B, Rd, Rl);
  for(P=B->first;P;P=N)
  {
    N= P->next;
    free(P);
  }
  free(B);
}

_BUFFER_PROTO void buffer_collect(buffer_t *B, void **Rd, size_t *Rl)
{
  size_t S;
  struct buffer_node *P;
  unsigned char *R;

  if (!Rd && !Rl) return ;

  S= 0;
  for(P=B->first;P;P=P->next) S+= P->len;

  if (S==0) { if (Rd) *Rd= NULL; if (Rl) *Rl= 0; return ; }
  if (!Rd) { *Rl= S; return ; }

  R= malloc(S);
  S= 0;
  for(P=B->first;P;P=P->next)
  {
    memcpy(R+S, P->data+P->start, P->len);
    S+= P->len;
  }

  *Rd= (void*) R;
  if (Rl) *Rl= S;
}

_BUFFER_PROTO void buffer_write(buffer_t *B, void *d, size_t l)
{
  struct buffer_node *P;
  size_t cp;

  while(l)
  {
    P= B->last;
    if (!P || (P->start+P->len)==P->size)
    {
      P= malloc(sizeof(*P)+B->blksize-1);
      P->len= 0;
      P->next= NULL;
      P->size= B->blksize;
      P->start= 0;
      if (!B->last) { B->last= B->first= P; }
      else { B->last->next= P; B->last= P; }
    }

    cp= P->size-P->len-P->start;
    if (cp>l) cp= l; 

    memcpy(P->data+P->len+P->start, d, cp);
    P->len+= cp;
    l-= cp;
    d= (unsigned char*) d + cp;
  }
}

_BUFFER_PROTO void buffer_append(buffer_t *dst, buffer_t *src_f)
{
  if (src_f->first!=NULL)
  {
    if (dst->first==NULL)
    {
      dst->first= src_f->first;
      dst->last= src_f->last;
    }
    else
    {
      dst->last->next= src_f->first;
      dst->last= src_f->last;
    }
  }
  free(src_f);
}



_BUFFER_PROTO size_t buffer_read(buffer_t *B, void *d, size_t l)
{
  size_t total;
  struct buffer_node *P;
  size_t cp;
  total= 0;

  while(l)
  {
    P= B->first;
    if (!P) break;  
    if (P->len==0)
    {
      B->first= P->next;
      if (!B->first) B->last= NULL;
      free(P);
      continue;
    } 
    cp= P->len;
    if (cp>l) cp= l;
    memcpy(d, P->data+P->start, cp);
    P->start+= cp;
    P->len-= cp;
    total+= cp;
    d= (unsigned char*) d + cp;
  }
  return total;
}



static int filter_files_byext(int nfiles,char **files, char **suffixes)
{
  int i;
  char *tmp;
  if (!nfiles) return 0;
  if (!suffixes) return nfiles;
  for(i=0;i<nfiles;i++)
  {
    if (files[i][0]!='F') continue;
    if (file_matches_ext_set(files[i],suffixes)) continue;
    tmp= files[nfiles-1];
    files[nfiles-1]= files[i];
    files[i]= tmp;
    nfiles--;
    i--;
  } 
  return nfiles;
}

static int filter_files_byhid(int nfiles,char **files,int showhid)
{
  int i, last;
  char *tmp;
  if (!nfiles) return 0;
  if (showhid) return nfiles;
  last= nfiles-1;
  for(i=0;i<last;i++)
  {
    if (files[i][1]!='.') continue;
    tmp= files[last];
    files[last]= files[i];
    files[i]= tmp;
    last--;
    i--;
  } 
  if (files[last][1]!='.') return last+1;
  return last;
}

static int comparstr(const void *a,const void* b)
{
  return strcmp(*(const char**) a, *(const char**) b);
}

static void sort_files(int nfiles, char **files)
{
  qsort(files, nfiles, sizeof(files[0]), comparstr);
}


static char *sau_getcwd()
{
  char *buf; size_t siz;

  siz= 0;
  
  while(1)
  {
    if (!siz) { siz= 256;  }
         else { siz+= siz/2; free(buf); }
    buf= malloc(siz);
    if (getcwd(buf,siz)) return buf;
    if (errno!=ERANGE)   return NULL;
  }
}

static char *sau_gethome()
{
  char *x;
  x= getenv("HOME");
  if (!x) x= "/";
  return strdup(x);
}

static char* combine_path(char *dir,char *fn)
{
  char *R;
  int Ld;
  Ld= strlen(dir);
  R= malloc(Ld+strlen(fn)+2);
  if (Ld>0 && dir[Ld-1]=='/')
    sprintf(R,"%s%s",dir,fn);
  else
    sprintf(R,"%s/%s",dir,fn);
  return R;
}

static void split_initial_fn(char *init, char **Rdir, char **Rfil)
{
  char *dir; // , *fil;
  char *pfil,*pdir;
  char *dir_pfx;

  if (!init)
  {
    if (!(dir= sau_getcwd())) dir= sau_gethome();
    *Rdir= dir;
    *Rfil= NULL;
    return ;
  }
  
  pfil= strrchr(init,'/');
  if (pfil) 
  {
    pfil++;  
    pdir= strdup(init); 
    pdir[pfil-init]= 0; 
    if (!pfil[0]) pfil= NULL;
             else pfil= strdup(pfil);
  }
  else 
  { 
    pdir= NULL; 
  }

  if (init[0]=='/')
  {
    *Rdir= pdir;
    *Rfil= pfil;
    return ;
  }

  dir_pfx= sau_getcwd();
  if (!dir_pfx)
  {
    // we can't get the current directory, the rest of the 
    // path is meaningless except for the file name, if any.
    *Rdir= sau_gethome();
    *Rfil= pfil; 
    if (pdir) free(pdir);
    return ;
  }

  if (pdir) 
  {
    dir= malloc(strlen(pdir) + strlen(dir_pfx)+1);
    sprintf(dir,"%s/%s",dir_pfx,pdir);
    free(pdir);
    free(dir_pfx);
  }
  else
  {
    dir= dir_pfx;
  }

  *Rdir= dir;
  *Rfil= pfil;
}


static void filesel_make_screen(int *RX,int *RY,int *RW,int *RH,int title_w)
{
  int W,H,X,Y;
  int coor_screen[4];
  // this list should be the same order as in the enum definition
  static int dlg_widgets[]= {
    GUIRfilD1, GUIRfilD2, GUIRfilD3, GUIRfilD4, GUIRfilD5, GUIRfilD6,
    GUIRfilD7, GUIRfilD8, GUIRfilD9, GUIRfilD10, 
    GUIRfilHOME, GUIRfilREFRESH, GUIRfilOK, GUIRfilCANCEL, GUIRfilLIST,
    GUIRfilNAME,
  };

  W= imin2(imax2(imax2(400,x_window_width *8/10),title_w+2*filesel_pad),
           x_window_width);
  H= imin2(imax2(400,x_window_height*8/10),x_window_height);
  X= (x_window_width-W)/2;
  Y= (x_window_height-H)/2;

  coor_screen[0]= X; coor_screen[1]= Y;
  coor_screen[2]= W; coor_screen[3]= H;

  enter_screen(15, dlg_widgets, coor_screen);
  *RX= X; *RY= Y; *RW= W; *RH= H;

  gfx_fill_rect(0,X,Y,W, H,filesel_bg);
}

static void file_select_dialog
  (filesel_t *fs,int mode,char *ifil)
{
  char *title;
  text_entry_t *entry;
  int i;

  int W,H,X,Y;

  int button_w, button_h;
  int title_w, title_h, title_x, title_y;
  int list_w, list_h, list_x, list_y;
  // int dirst_w, dirst_h;
  int dirst_x, dirst_y;

  int homB_x, homB_y, refB_x, refB_y, okB_x, okB_y, canB_x, canB_y, 
      tex_x, tex_y, tex_w, tex_h;

  int fh1,fh3;

  gfx_text_size(1,"M",NULL,&fh1);
  gfx_text_size(3,"M",NULL,&fh3);

  title= (char*) (mode ? filesel_lbl_save : filesel_lbl_load);
  gfx_text_size(3, title, &title_w, &title_h);

  filesel_make_screen(&X,&Y,&W,&H, title_w);

  button_w= max_text_width(1, filesel_lbl_cancel, filesel_lbl_ok,
                              filesel_lbl_refresh, filesel_lbl_home, NULL) 
           + filesel_ipad;
  button_h= fh1 + filesel_ipad;

  title_x= (W - title_w)/2;
  title_y= filesel_pad;

  dirst_y= title_y + title_h + filesel_pad;
  dirst_x= filesel_dirst_left;

  homB_x= filesel_pad;
  homB_y= dirst_y + button_h + filesel_pad;

  refB_x= W - filesel_pad - button_w;
  refB_y= homB_y;

  tex_x= homB_x + button_w + filesel_pad;
  tex_y= homB_y;
  tex_w= refB_x - filesel_pad - tex_x;
  tex_h= button_h;

  list_y= tex_y + tex_h + filesel_pad;
  list_x= filesel_pad;
  list_w= imax2(1,W-list_x-filesel_pad);

  canB_x= refB_x;
  canB_y= H - filesel_pad - button_h;
  okB_x= canB_x - filesel_pad - button_w;
  okB_y= canB_y;

  list_h= okB_y - filesel_pad - list_y;


  widgets[GUIRfilHOME]= gfx_button(filesel_lbl_home,0,NULL,GFXCLASS_BUTTON);
    button_set_position((gui_button_t*)widgets[GUIRfilHOME],
          X+homB_x, Y+homB_y, button_w, button_h); 
    gui_button_show((gui_button_t*)widgets[GUIRfilHOME],1);

  widgets[GUIRfilREFRESH]= gfx_button(filesel_lbl_refresh,0,NULL,
                                          GFXCLASS_BUTTON);
    button_set_position((gui_button_t*)widgets[GUIRfilREFRESH],
          X+refB_x, Y+refB_y, button_w, button_h); 
    gui_button_show((gui_button_t*)widgets[GUIRfilREFRESH],1);

  widgets[GUIRfilOK]= gfx_button(filesel_lbl_ok, 0, NULL,GFXCLASS_BUTTON);
    button_set_position((gui_button_t*)widgets[GUIRfilOK],
          X+okB_x, Y+okB_y, button_w, button_h); 
    gui_button_show((gui_button_t*)widgets[GUIRfilOK],1);

  widgets[GUIRfilCANCEL]= gfx_button(filesel_lbl_cancel,0,NULL,GFXCLASS_BUTTON);
    button_set_position((gui_button_t*)widgets[GUIRfilCANCEL],
          X+canB_x, Y+canB_y, button_w, button_h); 
    gui_button_show((gui_button_t*)widgets[GUIRfilCANCEL],1);

  widgets[GUIRfilLIST]= gui_list_new(0,0,NULL,NULL,NULL);
    gui_list_set_position((gui_list_t*)widgets[GUIRfilLIST],
          X+list_x, Y+list_y, list_w, list_h);
  widgets[GUIRfilNAME]= text_entry_new(ifil);
    entry= (text_entry_t*) widgets[GUIRfilNAME];
    entry->key_filter= filesel_tab_complete;
    entry->key_arg= fs;
    textentry_position(entry, X+tex_x, Y+tex_y, tex_w, tex_h);
    widget_show((widget_t*)entry, 1);
    set_focus(widgets[GUIRfilNAME]);

  for(i=GUIRfilD1;i<=GUIRfilD10;i++)
  {
    widgets[i]= gfx_button("", 0, NULL, GFXCLASS_TOGGLE);
    button_set_position((gui_button_t*)widgets[i], dirst_x, dirst_y, 
                        100,button_h);
  }

  for(i=GUIRfilD1;i<=GUIRfilNAME;i++)
    widgets[i]->number= i;

  fs->dirst_y= dirst_y;
  fs->x= X;
  fs->y= Y;
  fs->w= W;
  fs->h= H;
  fs->button_h= button_h;

  txt_print(0,3,filesel_fg, filesel_bg,X+title_x, Y+title_y, title, NULL, NULL);
}

static void file_list_icons(const unsigned int **icons)
{
  static const unsigned int ICf[]= {
  16 | (1<<31), 16,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xff211c1d,
    0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xffffffff,0xffedecec,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xff211c1d,0xff211c1d,0xff211c1d,
    0xff211c1d,0xff211c1d,0xffffffff,0xff484445,0xffedecec,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,
    0xffffffff,0xff211c1d,0xff484445,0xffedecec,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xff211c1d,
    0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xffffffff,0xff211c1d,
    0xff211c1d,0xff484445,0xffedecec,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xff211c1d,0xff211c1d,0xff211c1d,
    0xff211c1d,0xff211c1d,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,
    0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xff211c1d,
    0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,
    0xff211c1d,0xff211c1d,0xff211c1d,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xff211c1d,0xff211c1d,0xff211c1d,
    0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,
    0xff211c1d,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,
    0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xff211c1d,
    0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,
    0xff211c1d,0xff211c1d,0xff211c1d,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xff211c1d,0xff211c1d,0xff211c1d,
    0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,
    0xff211c1d,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,
    0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,
  };
  static const unsigned int ICd[]= {
  16 | (1<<31), 16,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xfff8f8f8,0xfff8f8f8,0xfff8f8f8,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xff5d595a,0xff211c1d,0xff211c1d,
    0xff211c1d,0xff5d595a,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xff5f5b5c,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,
    0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff5f5b5c,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,
    0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,
    0xff211c1d,0xff211c1d,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,
    0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xff211c1d,0xff211c1d,
    0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,
    0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,
    0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,
    0xff211c1d,0xff211c1d,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,
    0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xff211c1d,0xff211c1d,
    0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,
    0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xff646161,0xff211c1d,0xff211c1d,0xff211c1d,
    0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,
    0xff211c1d,0xff646161,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,
  };
  static const unsigned int ICa[]= {
  16 | (1<<31), 16,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xff908d8e,
    0xff908d8e,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xff908d8e,0xff211c1d,0xff211c1d,0xff908d8e,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xff908d8e,
    0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff908d8e,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xff908d8e,0xff211c1d,0xff211c1d,0xffffffff,
    0xffffffff,0xff211c1d,0xff211c1d,0xff908d8e,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xff908d8e,
    0xff211c1d,0xff211c1d,0xff211c1d,0xffffffff,0xffffffff,0xff211c1d,
    0xff211c1d,0xff211c1d,0xff908d8e,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xff908d8e,0xff211c1d,0xff211c1d,0xff211c1d,
    0xff211c1d,0xffffffff,0xffffffff,0xff211c1d,0xff211c1d,0xff211c1d,
    0xff211c1d,0xff908d8e,0xffffffff,0xffffffff,0xffffffff,0xff908d8e,
    0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xffffffff,
    0xffffffff,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,
    0xff908d8e,0xffffffff,0xffffffff,0xff908d8e,0xff211c1d,0xff211c1d,
    0xff211c1d,0xff211c1d,0xff211c1d,0xffffffff,0xffffffff,0xff211c1d,
    0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff908d8e,0xffffffff,
    0xffffffff,0xffffffff,0xff908d8e,0xff211c1d,0xff211c1d,0xff211c1d,
    0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,
    0xff211c1d,0xff908d8e,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xff908d8e,0xff211c1d,0xff211c1d,0xff211c1d,0xffffffff,
    0xffffffff,0xff211c1d,0xff211c1d,0xff211c1d,0xff908d8e,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xff908d8e,0xff211c1d,0xff211c1d,0xffffffff,0xffffffff,0xff211c1d,
    0xff211c1d,0xff908d8e,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xff908d8e,
    0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff908d8e,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xff908d8e,0xff211c1d,
    0xff211c1d,0xff908d8e,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xff908d8e,0xff908d8e,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,
  };
  if (icons[0]) return ;
  icons[0]= ICf;
  icons[1]= ICd;
  icons[2]= ICa;
}

static void populate_file_list
        (filesel_t *fs)
{
  char **files;
  int nfiles,shown,i;

  static const unsigned int *icons[3];

  file_list_icons(icons);

  if (fs->files) free(fs->files); // the whole array is one piece.
  files= list_files(fs->dir);
  file_types(fs->dir, files);

  gfx_list_show((gui_list_t*) widgets[GUIRfilLIST],0);
  gfx_list_clear((gui_list_t*) widgets[GUIRfilLIST]);
  for(nfiles=0;files[nfiles];nfiles++) ;

  shown= filter_files_byext(nfiles, files,fs->ext);
  shown= filter_files_byhid(shown, files, 0);
  sort_files(shown, files);
  for(i=0;i<shown;i++)
  {
    int isel;
    switch(files[i][0])
    {
    case 'F': isel= 0; break;
    case 'D': isel= 1; break;
    default:  isel= 2; break;
    }
    gfx_list_insert((gui_list_t*) widgets[GUIRfilLIST], -1,
            files[i]+1, files[i], icons[isel]);
  }
  fs->files= files;
  fs->nfiles= nfiles;
  fs->shown= shown;
  gfx_list_show((gui_list_t*) widgets[GUIRfilLIST],1);
}


static int filesel_tab_complete(void *arg,void *te,gfx_event_t *event)
{
  if (event->type!=GFXEV_KEY_PRESS) return 0;
  switch(event->key)
  {
  case GFX_K_TAB:
     break;
  case GFX_K_RETURN:
     event->type= GUIRfilOK;
     break;
  case GFX_K_ESCAPE:
     event->type= GUIRfilCANCEL;
     break;
  }
  return 0; 
}



static char **sepdir(char *name)
{
  char **R;
  int N,done;
  char *k,*str;

  R= NULL;
/* 
    /home/dodo/foo   : 4 components /,home,dodo,foo
     home/dodo/foo   : 3 components home,dodo,foo
*/
again:
  N= 0;
  str= name;

  if (str[0]=='/')
  {
    if (R) R[N]= strdup("/"); 
    N++;
    while(str[0]=='/') str++;
  }

  done= 0;
  if (!str[0]) done= 1;
  while(!done)
  {
    k= strchr(str,'/');
    if (!k) { k= str+strlen(str); done= 1; }
    if (R)
    {
      R[N]= malloc(k-str+1);
      memcpy(R[N], str, k-str);
      R[N][k-str]= 0;
    }
    N++;
    str= k+1;
  }

  if (R) { R[N]= NULL; return R; }
  R= malloc(sizeof(*R)*(N+1));
  goto again;
}


static void filesel_hide_buttons()
{
  int i;
  for(i=GUIRfilD1;i<=GUIRfilD10;i++)
    gui_button_show((gui_button_t*) widgets[i], 0);
}

static void filesel_show_buttons(filesel_t *fs)
{
  int i;
  for(i=fs->dir_start;i<=fs->dir_end;i++)
    gui_button_show((gui_button_t*) widgets[i-fs->dir_start+GUIRfilD1], 1);
}

static void filesel_render_dirstack(filesel_t *fs)
{
  int i;
  char *dn;

  filesel_hide_buttons();
  dn= remove_trailing_slash(strdup(fs->dir));

again:

  for(i=0;i<fs->n_dirs;i++)
    if (!strcmp(dn,fs->dirs[i].dir)) break;
  if (i!=fs->n_dirs)
  {
    int st,en,K;
    K= i;
    st= imax2(0,K-4);
    en= imin2(K+5,fs->n_dirs-1);
    if (fs->dir_start==st && fs->dir_end==en)
    {
      filesel_activate_button(fs, K-st);
      filesel_show_buttons(fs);
      return ;
    }
    fs->dir_start= st;
    fs->dir_end= en;
    filesel_render_buttons(fs);
    filesel_activate_button(fs, K-st);
    filesel_show_buttons(fs);
    return ;
  }

  filesel_create_buttons(fs);
  fs->dir_start= fs->dir_end= -1;
  goto again;
}

static char* remove_trailing_slash(char *dn)
{
  int L;
  L= strlen(dn);
  while(L>1 && dn[L-1]=='/') { dn[L-1]= 0; L--; }
  return dn;
}

static void filesel_create_buttons(filesel_t *fs)
{
  int i;
  char *dn;
  char **comp;
  int ncomp;
  char *Z;

  dn= remove_trailing_slash(strdup(fs->dir));

  comp= sepdir(dn);
  for(ncomp=0;comp[ncomp];ncomp++) ;

  filesel_free_buttons(fs);
  fs->n_dirs= ncomp;
  fs->dirs= calloc(ncomp,sizeof(fs->dirs[0]));
  Z= NULL;
  for(i=0;i<fs->n_dirs;i++)
  {
    fs->dirs[i].dir= fs_combine(Z, comp[i]);
    fs->dirs[i].label= comp[i];
    Z= fs->dirs[i].dir;
  }
  free(comp);
  free(dn);
}

static void filesel_free_buttons(filesel_t *fs)
{
  int i;
  if (!fs->dirs) return ;
  for(i=0;i<fs->n_dirs;i++)
  {
    free(fs->dirs[i].label);
    free(fs->dirs[i].dir);
  }
  free(fs->dirs);
  fs->dirs= NULL;
  fs->n_dirs= 0;
}

static void filesel_activate_button(filesel_t *fs,int idx)
{
  int i;
  for(i=0;i<=fs->dir_end-fs->dir_start;i++)
    button_set_state((gui_button_t*)widgets[GUIRfilD1+i], i==idx);
}

static void filesel_render_buttons(filesel_t *fs)
{
  int i;
  int x,y;

  y= fs->y+fs->dirst_y;
  x= fs->x+filesel_dirst_left;

  gfx_fill_rect(1, fs->x, y, fs->w, fs->button_h, filesel_bg);
  
  for(i=fs->dir_start;i<=fs->dir_end;i++)
  {
    gui_button_t *B;
    B= (gui_button_t*) widgets[i-fs->dir_start+GUIRfilD1];
    gui_button_set_text(B, fs->dirs[i].label);
    if (!fs->dirs[i].width)
    {
      gfx_text_size(1, fs->dirs[i].label, &fs->dirs[i].width, NULL);
      fs->dirs[i].width+= 2*filesel_dirst_ipad;
    }
    button_set_position(B, x, y, fs->dirs[i].width, fs->button_h);
    x+= filesel_dirst_pad+fs->dirs[i].width;
    button_set_state(B, 0);
  }
}

static char *com3(char *x,char *y,char *z)
{
  char *R;
  int Lx,Ly,Lz;
  Lx= strlen(x); Ly= strlen(y); Lz= strlen(z);
  R= malloc(Lx+Ly+Lz+1);
  memcpy(R, x, Lx); memcpy(R+Lx,y,Ly); memcpy(R+Lx+Ly,z,Lz);
  R[Lx+Ly+Lz]= 0;
  return R;
}

static char *com2(char *x,char *y)
{
  char *R;
  int Lx,Ly;
  Lx= strlen(x); Ly= strlen(y);
  R= malloc(Lx+Ly+1);
  memcpy(R, x, Lx); memcpy(R+Lx,y,Ly);
  R[Lx+Ly]= 0;
  return R;
}

static char *fs_combine(char *x,char *y)
{
  if (!x) return strdup(y);
  if (x[0]=='/' && x[1]==0) return com2(x,y);
  return com3(x,"/",y);
}


static void filesel_activate_dir(filesel_t *fs, int idx)
{
  filesel_activate_button(fs,idx);
  filesel_setdir(fs,fs->dirs[idx+fs->dir_start].dir);
  populate_file_list(fs);
}

static void filesel_setdir(filesel_t *fs,char *dir)
{
  if (fs->dir) free(fs->dir);
  fs->dir= strdup(dir);
}

static widget_t *gui_canvas_new(int shor, int sver)
{
  gui_canvas_t *CC;
  CC= calloc(1,sizeof(*CC));
  CC->widget.klass=GFXCLASS_CANVAS;
  CC->can_scrollv= sver;
  CC->can_scrollh= shor;
  if (CC->can_scrollv)
    CC->scrollv= (scrollbar_t*) scrollbar_new(1, 0.0,1.0,0.1,0,CC,gui_canvas_scrollv);
  if (CC->can_scrollh)
  CC->scrollh= (scrollbar_t*) scrollbar_new(0, 0.0,1.0,0.1,0,CC,gui_canvas_scrollh);

  CC->click1= CC->click3= -1;

  CC->widget.position= (void*) gui_canvas_position;
  return &CC->widget;
}

static void gui_canvas_update_click_handlers(gui_canvas_t *CC)
{
  CC->click1= install_or_modify_click
       (CC->click1, &CC->enabled, gui_canvas_click, CC,
        CC->widget.x, CC->widget.y, CC->port_w, CC->port_h, 1);
  CC->click3= install_or_modify_click
       (CC->click3, &CC->enabled, gui_canvas_click, CC,
        CC->widget.x, CC->widget.y, CC->port_w, CC->port_h, 3);
}

static void gui_canvas_position(gui_canvas_t *CC,int x,int y,int w,int h)
{
  widget_t *W;
  W= &CC->widget;
  W->x= x;
  W->y= y;
  W->w= w;
  W->h= h;

  if (CC->can_scrollh)
    scrollbar_position(CC->scrollh, x, y+h-gui_scrollbar_height,w, 
                     gui_scrollbar_height);
  if (CC->can_scrollv)
    scrollbar_position(CC->scrollv, x+w-gui_scrollbar_width, y, 
                     gui_scrollbar_width, h);
  gui_canvas_arrange_scrollbars(CC);
}


static int gui_canvas_setbuffer(gui_canvas_t *CC,int new_w,int new_h)
{
  uint32_t *nb;

  if (new_w<=0) new_w= CC->buffer_w;
  if (new_h<=0) new_h= CC->buffer_h;

  if (new_w==CC->buffer_w && new_h==CC->buffer_h) return 1;

  nb= calloc(new_w*new_h, sizeof(uint32_t));
  if (CC->buffer)
  {
    int y,x;
    int cw,ch;
    cw= imin2(CC->buffer_w, new_w);
    ch= imin2(CC->buffer_h, new_h);
    for(y=0;y<ch;y++)
      for(x=0;x<cw;x++)
        nb[y*new_w + x]= CC->buffer[y*CC->buffer_w+x];
    free(CC->buffer);
  }
  CC->buffer= nb;
  CC->buffer_w= new_w;
  CC->buffer_h= new_h;

  return 0;
}

static void gui_canvas_arrange_scrollbars
   (gui_canvas_t *CC)
{
  int dw,dh,bw,bh;
  int hor,ver;
  widget_t *W;

  dw= CC->widget.w;
  dh= CC->widget.h;

  bw= CC->buffer_w;
  bh= CC->buffer_h;

  hor= 0;
  ver= 0;
  if (bw>dw && CC->can_scrollh) { hor= 1; dh-= gui_scrollbar_height; }
  if (bh>dh && CC->can_scrollv) { ver= 1; dw-= gui_scrollbar_width; }
  if (!hor && bw>dw && CC->can_scrollh) { hor= 1; dh-= gui_scrollbar_height; }

  if (dw<=0 || dh<=0) { CC->too_small=1; return ; }

  CC->port_w= dw;
  CC->port_h= dh;

  if (hor)
  {
    if (CC->pos_x+CC->port_w>bw)
      CC->pos_x= imax2(0,bw-CC->port_w);

    W= &CC->scrollh->widget;
    scrollbar_relayout(CC->scrollh, W->x, W->y, CC->port_w, W->h,
          (double)CC->pos_x/CC->buffer_w,
          (double)imin2(CC->pos_x+CC->port_w,CC->buffer_w)/CC->buffer_w, 0.1);
    scrollbar_show(CC->scrollh, 1);
  }
  else
  {
    if (CC->have_scrollh)
      scrollbar_show(CC->scrollh, 0);
  }
  CC->have_scrollh= hor;

  if (ver)
  {
    if (CC->pos_y+CC->port_h>bh)
       CC->pos_y= imax2(0,bh-CC->port_h);
    W= &CC->scrollv->widget;
    scrollbar_relayout(CC->scrollv, W->x, W->y, W->w, CC->port_h,
          (double)CC->pos_y/CC->buffer_h,
          (double)imin2(CC->pos_y+CC->port_h,CC->buffer_h)/CC->buffer_h, 0.1);
    scrollbar_show(CC->scrollv, 1);
  }
  else
  {
    if (CC->have_scrollv)
       scrollbar_show(CC->scrollv,0);
  }
  CC->have_scrollv= ver;

  gui_canvas_update_click_handlers(CC);
}

static void gui_canvas_paint_scrollbars(gui_canvas_t *CC)
{
  if (!CC->enabled) return ;
  if (CC->have_scrollv) scrollbar_show(CC->scrollv,1);
  if (CC->have_scrollh) scrollbar_show(CC->scrollh,1);
}

static void gui_canvas_paint_buffer(gui_canvas_t *CC)
{
  if (!CC->enabled) return ;
  if (!CC->buffer)
  {
//
 //   gfx_fill_rect(GFX_UPDATE,CC->widget.x,CC->widget.y,
  //                           CC->port_w, CC->port_h, 0xfF00ff);
    return ;
  }
  gfx_put(GFX_UPDATE, CC->buffer, CC->buffer_w, CC->buffer_h,
            CC->pos_x, CC->pos_y,
           CC->widget.x, CC->widget.y, CC->port_w, CC->port_h);
}

static void gui_canvas_draw_all(gui_canvas_t *CC)
{
  gui_canvas_paint_scrollbars(CC);
  gui_canvas_paint_buffer(CC);
  if (!CC->enabled) return ;
  if (CC->port_w>CC->buffer_w)
    gfx_fill_rect(GFX_UPDATE, 
        CC->widget.x+CC->buffer_w, CC->widget.y, 
                    CC->port_w-CC->buffer_w, CC->port_h,0xFFffff);
  if (CC->port_h>CC->buffer_h)
    gfx_fill_rect(GFX_UPDATE, 
        CC->widget.x, CC->widget.y+CC->buffer_h, 
                    CC->port_w, CC->port_h-CC->buffer_h,0xffFFff);
}


static int subtract_rectangle(rect_t *A,rect_t *B,rect_t *R)
{
  int N;
  N= 0;
  if (B->top<=A->bottom && B->top>=A->top)
  {
    *R= *A; R->bottom= B->top;
    R++; N++;
    A->top= B->top;
  }
  if (B->bottom<=A->bottom && B->bottom>=A->top)
  {
    *R= *A; R->top= B->bottom;
    R++; N++;
    A->bottom= B->bottom;
  }
  if (B->left<=A->right && B->left>=A->left)
  {
    *R= *A; R->right= B->left;
    R++; N++;
    A->left= B->left;
  }
  if (B->right<=A->right && B->right>=A->left)
  {
    *R= *A; R->left= B->right;
    R++; N++;
    A->right= B->right;
  }
  if (N) return N;
  if (B->right<A->left || B->left>A->right || B->top>A->bottom ||
      B->bottom<A->top) return 0;
  *R= *A;
  return 1;
}

static void gui_canvas_update(gui_canvas_t *CC,int x,int y,int w,int h)
{
  int sx,sy,ex,ey;
  rect_t sub[4], ev, block;
  int nsu,i;

  if (w<=0 || h<=0 || !CC->enabled) return ;
  sx= imax2(imax2(x, 0), CC->pos_x);
  sy= imax2(imax2(y, 0), CC->pos_y);

  ex= imin2(imin2(x+w,CC->buffer_w), CC->pos_x+CC->port_w);
  ey= imin2(imin2(y+h,CC->buffer_h), CC->pos_y+CC->port_h);

  if (ex<=sx || ey<=sy) return ;
  if (CC->have_zoom)
  {
    block.left= CC->z_wx; block.right= CC->z_wx+CC->z_ww-1;
    block.top= CC->z_wy;  block.bottom= CC->z_wy+CC->z_wh-1;

    ev.left= sx-CC->pos_x; ev.right= ex-CC->pos_x;
    ev.top= sy-CC->pos_y;  ev.bottom= ey-CC->pos_y;

    nsu= subtract_rectangle(&ev,&block,sub);
  }
  else
  {
    sub[0].left= sx-CC->pos_x; sub[0].right= ex-CC->pos_x;
    sub[0].top= sy-CC->pos_y;  sub[0].bottom= ey-CC->pos_y;
    nsu= 1;
  }

  for(i=0;i<nsu;i++)
  {
    int j;
    gfx_put(0, CC->buffer, CC->buffer_w, CC->buffer_h,
                sub[i].left+CC->pos_x, sub[i].top+CC->pos_y,
                sub[i].left+CC->widget.x, sub[i].top+CC->widget.y,
                sub[i].right-sub[i].left+1, sub[i].bottom-sub[i].top+1);

    for(j=0;j<CC->nsprites;j++)
      gui_canvas_paint_sprite(CC, CC->sprites[j],
            sub[i].left+CC->pos_x, sub[i].top+CC->pos_y,
            sub[i].right-sub[i].left+1, sub[i].bottom-sub[i].top+1);

    gfx_update(sub[i].left+CC->widget.x, sub[i].top+CC->widget.y,
               sub[i].right-sub[i].left+1, sub[i].bottom-sub[i].top+1);
  }
  if (CC->have_zoom)
    gui_canvas_zupdate(CC,x,y,w,h);
}


static void gui_canvas_clipped_hline
   (gui_canvas_t *CC,int color,int x1,int x2,int y)
{
  int x, bw;
  if (y<0 || y>=CC->buffer_h) return ;
  bw= CC->buffer_w;
  x1= imax2(0,x1);
  x2= imin2(x2,bw-1);
  for(x=x1;x<=x2;x++) CC->buffer[y*bw+x]= color;
}


static void gui_canvas_clipped_vline
   (gui_canvas_t *CC,int color,int x,int y1,int y2)
{
  int y, bw;
  if (x<0 || x>=CC->buffer_w) return ;
  bw= CC->buffer_w;
  y1= imax2(0,y1);
  y2= imin2(y2,CC->buffer_h-1);
  for(y=y1;y<=y2;y++) CC->buffer[y*bw+x]= color;
}



static gui_canvas_t *gui_canvas_get(int wno)
{
  widget_t *W;
  W= get_widget(wno);
  if (W && W->klass==GFXCLASS_CANVAS) return (gui_canvas_t*) W;
  return NULL;
}

static void gui_canvas_scrollv(gui_canvas_t *CC,double start,double end)
{
  CC->pos_y= start*CC->buffer_h;
  if (CC->pos_y+CC->port_h>CC->buffer_h)
   CC->pos_y=imax2(0,CC->buffer_h-CC->port_h);
  gui_canvas_paint_buffer(CC);
}
static void gui_canvas_scrollh(gui_canvas_t *CC,double start,double end)
{
  CC->pos_x= start*CC->buffer_w;
  if (CC->pos_x+CC->port_w>CC->buffer_w)
   CC->pos_x=imax2(0,CC->buffer_w-CC->port_w);
  gui_canvas_paint_buffer(CC);
}

static int gui_canvas_click(void *arg,gfx_event_t *ev)
{
  gui_canvas_t *CC;
  CC= arg;
  ev->type= GFXEV(CC->widget.number,BUTTON_PRESS);
  ev->x= ev->x - CC->widget.x + CC->pos_x;
  ev->y= ev->y - CC->widget.y + CC->pos_y;
  install_release_handler(CC, gui_canvas_release);
  return 0;
}

static int gui_canvas_release(void *arg,gfx_event_t *ev)
{
  gui_canvas_t *CC;
  CC= arg;
  ev->type= GFXEV(CC->widget.number,BUTTON_RELEASE);
  ev->x= ev->x - CC->widget.x + CC->pos_x;
  ev->y= ev->y - CC->widget.y + CC->pos_y;
  return 0;
}


static int gui_canvas_motion(void *arg, gfx_event_t *ev)
{
  gui_canvas_t *CC;
  int x,y, minx, maxx, miny, maxy;

  CC= arg;
  x= ev->x;
  y= ev->y;
  if (!range_test(x,CC->widget.x, CC->port_w) ||
      !range_test(y,CC->widget.y, CC->port_h))
    return 1;
  x= x - CC->widget.x + CC->pos_x;
  y= y - CC->widget.y + CC->pos_y;

  if (CC->rs_x0==x && CC->rs_y0==y) return 1;

  minx= imin2(imin2( CC->rs_x0, CC->rs_x1 ), x);
  maxx= imax2(imax2( CC->rs_x0, CC->rs_x1 ), x);
  miny= imin2(imin2( CC->rs_y0, CC->rs_y1 ), y);
  maxy= imax2(imax2( CC->rs_y0, CC->rs_y1 ), y);

  gui_canvas_draw_recsel(CC);
  CC->rs_x1= x;
  CC->rs_y1= y;
  gui_canvas_draw_recsel(CC);
  gui_canvas_update(CC, minx, miny, maxx-minx+1, maxy-miny+1);
  return 1;
}


static void gui_canvas_draw_recsel(gui_canvas_t *CC)
{
  int x,y,w,h,C;

  x= imin2(CC->rs_x0, CC->rs_x1);
  y= imin2(CC->rs_y0, CC->rs_y1);

  w= imax2(CC->rs_x0, CC->rs_x1) - x+1;
  h= imax2(CC->rs_y0, CC->rs_y1) - y+1;

  C=  (w<2) ? 0 : 1;
  C|= (h<2) ? 0 : 2;
  switch(C)
  {
  case 0: break ;
  case 1: gui_canvas_invert_hline(CC,x, x+w-1, y); break ;
  case 2: gui_canvas_invert_vline(CC,x, y, y+h-1); break ;
  case 3: gui_canvas_invert_hline(CC,x, x+w-1, y);
          gui_canvas_invert_hline(CC,x, x+w-1, y+h-1);
          gui_canvas_invert_vline(CC,x, y+1, y+h-2);
          gui_canvas_invert_vline(CC,x+w-1, y+1, y+h-2);
          break;
  }
}

static void gui_canvas_invert_hline(gui_canvas_t *CC, int x1, int x2, int y)
{
  int x;
  x1= imax2(0,x1);
  x2= imin2(CC->buffer_w-1, x2);
  if (range_test(y, 0, CC->buffer_h))
    for(x=x1;x<=x2;x++)
      CC->buffer[CC->buffer_w*y+x] ^= 0xFFffFF;
}

static void gui_canvas_invert_vline(gui_canvas_t *CC,int x,int y1, int y2)
{
  int y;
  y1= imax2(0,y1);
  y2= imin2(CC->buffer_h-1,y2);
  if (range_test(x, 0, CC->buffer_w))
    for(y=y1;y<=y2;y++)
      CC->buffer[CC->buffer_w*y+x] ^= 0xFFffFF;
}


static int gui_canvas_report_motion(void *arg, gfx_event_t *ev)
{
  gui_canvas_t *CC;
  CC= arg;
  if (ev->x < CC->widget.x ||
      ev->x >= CC->widget.x+CC->widget.w ||
      ev->y < CC->widget.y ||
      ev->y >= CC->widget.y+CC->widget.h)
    return 1;
  ev->type= GFXEV(CC->widget.number,POINTER_MOVE);
  ev->x= ev->x - CC->widget.x + CC->pos_x;
  ev->y= ev->y - CC->widget.y + CC->pos_y;
  return 0;
}


static void gui_canvas_zupdate
   (gui_canvas_t *CC,int ux0,int uy0,int uw,int uh)
{
  int ux1,uy1,ux,uy;
  int Xa,Xb,Xc,Xm,Xs,Xe; //int Xn,Yn;
  int Ya,Yb,Yc,Ym,Ys,Ye;
  int z, K, P;
  int ww,hh;
  int zx0,zx1,zy0,zy1,zx,zy,ex0,ey0,ex,ey;
  int bw, sk;

  if (!CC->have_zoom) return ;

  ux1= ux0 + uw-1;
  uy1= uy0 + uh-1;
  bw= CC->z_grid;

  if (!CC->z_buffer)
  {
    CC->z_buffer= calloc(CC->z_ww*CC->z_wh,sizeof(CC->z_buffer[0]));
    //int i;
    //for(i=0;i<CC->z_ww*CC->z_wh;i++) CC->z_buffer[i]= 0xff0000;
  }

  z= CC->z_factor;
  ww= CC->z_ww;             hh= CC->z_wh;
  Xc= CC->z_cx;             Yc= CC->z_cy;

  Xa= (ww-z)/2;            Xb= ww-z-Xa;
  Xs= Xc-GFXceil(Xa,z);       Xe= Xc+GFXceil(Xb,z);
  Xm= Xa-(GFXceil(Xa,z)-1)*z; //Xn= Xb-(GFXceil(Xb,z)-1)*z;

  Ya= (hh-z)/2;            Yb= hh-z-Ya;
  Ys= Yc-GFXceil(Ya,z);       Ye= Yc+GFXceil(Yb,z);
  Ym= Ya-(GFXceil(Ya,z)-1)*z; //Yn= Yb-(GFXceil(Yb,z)-1)*z;

  ux0= imax2(ux0, Xs);     ux1= imin2(ux1, Xe);
  uy0= imax2(uy0, Ys);     uy1= imin2(uy1, Ye);

  if (ux0>Xe || ux1<Xs || uy0>Ye || uy1<Ys) return ;

  zx0= (ux0==Xs) ? 0 : (Xm+(ux0-Xs-1)*z); 
  zx1= imin2(ww-1, z-1+((ux1==Xs) ? 0 : (Xm+(ux1-Xs-1)*z)));
  ex0= (ux0==Xs) ? (z-Xm) : 0;

  zy0= (uy0==Ys) ? 0 : (Ym+(uy0-Ys-1)*z);
  zy1= imin2(hh-1, z-1+((uy1==Ys) ? 0 : (Ym+(uy1-Ys-1)*z)));
  ey0= (uy0==Ys) ? (z-Ym) : 0;
  
  zx= zx0; ex= ex0; ux= ux0; 
  zy= zy0; ey= ey0; uy= uy0;

loop_y:
  if (zy<2 || zy>=hh-2)  goto border_horz; 
  if (ey<bw) goto pixborder_horz;
loop_x:
  P= CC->buffer[ux+uy*CC->buffer_w];
  if (zx<2 || zx>=ww-2) { K= (zx==0 || zx==ww-1) ? 0xffffff : 0; }
  else if (ex<bw) { K= CC->z_gridcolor; }
  else K= P;
  
  CC->z_buffer[zx+zy*ww]= K;
  zx++;
  ex= (ex+1)%z;
  if (ex==0) ux++; 
  if (zx<=zx1) goto loop_x;

loop_x_end:
  zx= 0;
  ux= ux0;
  ex= ex0;
  zy++;
  ey= (ey+1)%z;
  if (ey==0) uy++;
  if (zy<=zy1) goto loop_y;

  gfx_put(GFX_UPDATE,CC->z_buffer,CC->z_ww,CC->z_wh,zx0,zy0,
                     CC->widget.x+CC->z_wx+zx0,
                     CC->widget.y+CC->z_wy+zy0, zx1-zx0+1, zy1-zy0+1);

  return ;
border_horz:
  if (zy==0 || zy==hh-1) { K= 0xffffff; sk= 0; } else { K= 0; sk= 1; }
  for(zx=sk;zx<ww-sk;zx++) 
    CC->z_buffer[zx+zy*ww]= K;
  if (sk) { CC->z_buffer[0+zy*ww]= CC->z_buffer[ww-1+zy*ww]= 0xffFFff; }
  goto loop_x_end;
pixborder_horz:
  K= CC->z_gridcolor;
  CC->z_buffer[0+zy*ww]= CC->z_buffer[ww-1+zy*ww]=  0xffFFff;
  CC->z_buffer[1+zy*ww]= CC->z_buffer[ww-2+zy*ww]=  0x0;
  for(zx=zx0+2;zx<=zx1-2;zx++) 
    CC->z_buffer[zx+zy*ww]= K;
  goto loop_x_end;
}


static int rect_intersect
   (int *Rx, int *Ry, int *Rw, int *Rh,
      int tx, int ty, int tw, int th)
{
  int x0, x1, y0, y1;
  x0= *Rx; x1= x0+*Rw;
  y0= *Ry; y1= y0+*Rh;

  x0= imax2(x0, tx);   x1= imin2(x1, tx+tw);
  y0= imax2(y0, ty);   y1= imin2(y1, ty+th);
  *Rw= x1-x0; if (*Rw<=0) return 1;
  *Rh= y1-y0; if (*Rh<=0) return 1;
  *Rx= x0; *Ry= y0; return 0;
}

static void gui_canvas_paint_sprite
   (gui_canvas_t *C,sprite_t *S,int ux,int uy,int uw,int uh)
{
  int x,y,bx,by,sx,sy;

  if (!S || !S->shown) return ;

  if (rect_intersect(&ux,&uy, &uw, &uh, 
              0,0, C->buffer_w, C->buffer_h)) return ;
  if (rect_intersect(&ux,&uy, &uw, &uh, 
              C->pos_x, C->pos_y, C->port_w, C->port_h)) return ;
  if (rect_intersect(&ux,&uy, &uw, &uh,
              S->x, S->y, S->w, S->h)) return ;

  // now, we have the update coordinates relative to the buffer origin.
  // in order to convert it to screen coordinates, we need to subtract
  // pos_x and pos_y, then add widget.x and widget.y

  bx=  ux - C->pos_x + C->widget.x;
  by=  uy - C->pos_y + C->widget.y;

  // the coordinates within the sprite data are: update-sprite, that's it

  sx= ux - S->x;
  sy= uy - S->y;

#define ALPHABYTE  (0xff<<24)
  for(y=0;y<uh;y++)
    for(x=0;x<uw;x++)
    {
      uint32_t D;
      uint32_t B;
      D= S->data[(x+sx)+(y+sy)*S->w];
      if ( (D&ALPHABYTE)==0 ) continue;  
      D&= ~ALPHABYTE;
      B= x_image_data[y+by][x+bx];
      switch(S->func)
      {
      case SPRITE_FUNC_XOR:  B ^= D; break;
      case SPRITE_FUNC_AND:  B &= D; break;
      case SPRITE_FUNC_NEG:  B = ~B; break;
      case SPRITE_FUNC_SET:  
                   default:   B = D; break;
      }
      x_image_data[y+by][x+bx]= B;
    }
#undef ALPHABYTE
}


static void gui_sprite_free(sprite_t *S)
{
  free(S->data);
  free(S);
}


static int gui_timer_schedule
  (unsigned int msecs, int (*f)(void*,gfx_event_t*), void *a)
{
  static int last_timer;
  if (!screen) return -1;

  if (screen->n_timers==screen->s_timers)
  {
    if (!screen->s_timers) 
    {
      screen->s_timers= 10;
      screen->timers= malloc(sizeof(screen->timers[0])*screen->s_timers);
    }
    else
    {
      screen->s_timers+= screen->s_timers /2; 
      screen->timers= realloc(screen->timers,
                sizeof(screen->timers[0])*screen->s_timers);
    }
  }

  gui_timer_t *tt;
  tt= screen->timers + screen->n_timers;
  screen->n_timers++;
  tt->func= f;
  tt->arg= a;
  tt->value= msecs;
  tt->ident= last_timer++;
  return tt->ident;
}

 // this function returns 0 if there are no timers
 // it returns 1 if there is a timer and the remaining
 // time for it is stored in Rmsecs
static int gui_timer_get(unsigned int *Rmsecs)
{
  int i;
  unsigned int min;
  if (!screen || !screen->n_timers) return 0;
  min= screen->timers[0].value;
  for(i=1;i<screen->n_timers;i++)
     min = min < screen->timers[i].value ? min : screen->timers[i].value;
  *Rmsecs= min;
  return 1;
}

static int gui_timer_elapsed(unsigned int elap,gfx_event_t *event)
{
  int i,R;
  int T;
  if (!screen || !screen->n_timers) return 0;
  R= 0;
  T= screen->n_timers;
  for(i=0;i<T;i++)
  {
    gui_timer_t *tt;
    tt= screen->timers+i;
    if (elap<tt->value) { tt->value-= elap; continue; }
    if (!R)
    {
      int (*F)(void *,gfx_event_t*);
      void *A;
      F= tt->func;
      A= tt->arg;
      screen->timers[i]= screen->timers[T-1];
      i--;
      screen->timers[T-1]= screen->timers[screen->n_timers-1];
      T--;
      screen->n_timers--;
      if (F)
        R= (*F)(A,event); 
      continue;
    }
    tt->value= 0;
  }
  return R;
}

static void gui_timer_cancel(int ident)
{
  int i;
  if (ident==-1 || !screen || !screen->n_timers) return ;
  for(i=0;i<screen->n_timers;i++)
   if (screen->timers[i].ident==ident)
   {
    screen->timers[i]= screen->timers[screen->n_timers-1];
    screen->n_timers--;
    break;
   }
}

static widget_t* gui_spinner(int type, int frac)
{
  gui_spinner_t *SS;

  SS= calloc(1,sizeof(*SS));
  SS->widget.klass= GFXCLASS_SPINNER;
  SS->type= type;
  SS->frac= frac;
    // FIXME: colors should be resources
  SS->label= gfx_label(1,0x00,0xffFFff,'R',"");
  gui_button_init(&SS->less,NULL,'T',RESspinLESS,
                    gui_spinner_less_click, gui_spinner_less_release, SS);
  gui_button_init(&SS->more,NULL,'T',RESspinMORE,
                    gui_spinner_more_click, gui_spinner_more_release, SS);
  spinner_lessb_width= RESspinLESS[0] & ~(1<<31);
  spinner_moreb_width= RESspinMORE[0] & ~(1<<31);
  SS->intq= 1;
  SS->floq= 1.0;
  SS->timer= -1;
  return &SS->widget;
}


static void gui_spinner_destroy(gui_spinner_t *SS)
{
  gui_button_destroy((widget_t*) &SS->less);
  gui_button_destroy((widget_t*) &SS->more);
  widget_destroy(SS->label);
  if (SS->timer!=-1) gui_timer_cancel(SS->timer);
  SS->timer= -1;
}


static void gui_spinner_set_position
   (gui_spinner_t* LL,int x,int y,int w,int h)
{
  LL->widget.x= x;
  LL->widget.y= y;
  LL->widget.w= w;
  LL->widget.h= h;
    // FIXME: paddings should be resources
  button_set_position(&LL->less, x,y, spinner_lessb_width, h);
  button_set_position(&LL->more, x+w-spinner_moreb_width,y,
                                 spinner_moreb_width, h);
  widget_move(LL->label, x+spinner_lessb_width+5, y, 
      w - 10 - spinner_lessb_width-spinner_moreb_width , h);
}


static void gui_spinner_show(gui_spinner_t *S, int show)
{
  if ((S->enabled && show) || (!S->enabled && !show)) return ;

  if (!show)
  {
    S->enabled= 0;
    gui_button_show(&S->less,0);
    gui_button_show(&S->more,0);
    widget_show(S->label, 0);
    return ;
  }

  S->enabled= 1;
  gui_button_show(&S->less,1);
  gui_button_show(&S->more,1);
  gui_spinner_render(S);
  widget_show(S->label, 1);
}

static void gui_spinner_render(gui_spinner_t *S)
{
  char buf[40];
  if (S->type=='F')
  {
    sprintf(buf,"%f",S->flov);
  }
  else
    sprintf(buf,"%d", S->intv);
  gui_label_set_text((gui_label_t*) S->label,buf);
}

static int gui_spinner_delta(gui_spinner_t *S, gfx_event_t *event, int dir)
{
  int iV; double fV;
  if (S->type=='F')
  {
    fV= S->flov;
    S->flov+= dir*S->floq;
    spinner_apply_limits(S);
    if (S->flov!=fV)
    {
       gui_spinner_render(S);
       event->type= S->widget.number;
       event->flo0= S->flov;
       return 0; 
    }
    return 1;
  }
  iV= S->intv;
  S->intv += dir*S->intq;
  spinner_apply_limits(S);  
  if (S->intv!=iV)
  {
     gui_spinner_render(S);
     event->type= S->widget.number;
     event->key= S->intv;
     return 0;
  }
  return 1;
}

static void spinner_apply_limits(gui_spinner_t* S)
{
  if (S->type=='F')
  {
     if ((S->limflags&SPINNER_MIN) && S->flov<S->flomin) S->flov= S->flomin;
     if ((S->limflags&SPINNER_MAX) && S->flov>S->flomax) S->flov= S->flomax;
  }
  else
  {
     if ((S->limflags&SPINNER_MIN) && S->intv<S->intmin) S->intv= S->intmin;
     if ((S->limflags&SPINNER_MAX) && S->intv>S->intmax) S->intv= S->intmax;
  }
}

static gui_spinner_t *get_spinner_widget(int wno)
{
  widget_t *W;
  if (!(W=get_widget(wno))) return NULL;
  return W->klass==GFXCLASS_SPINNER ? (gui_spinner_t*) W : NULL;
}


static void gui_spinner_remove_timer
  (gui_spinner_t *SS)
{
  if (SS->timer!=-1) gui_timer_cancel(SS->timer);
  SS->timer= -1;
}

static void gui_spinner_init_timer
  (gui_spinner_t *SS,int (*F)(void*,gfx_event_t*))
{
  if (SS->timer!=-1) gui_timer_cancel(SS->timer);
  SS->count= 0;
  gui_spinner_reset_timer(SS,F);
}

static void gui_spinner_reset_timer
  (gui_spinner_t *SS,int (*F)(void*,gfx_event_t*))
{
  int delay;
  SS->count++;
  if (SS->count>50) delay= 85;
  else if (SS->count>10) delay= 150;
  else delay= 200;

  SS->timer= gui_timer_schedule(delay, F, SS);
}

static int gui_spinner_less_release(void *arg,gfx_event_t *event)
{
  gui_spinner_remove_timer(arg);
  return 0;
}

static int gui_spinner_less_click(void *arg,gfx_event_t *event)
{
  gui_spinner_init_timer(arg, gui_spinner_less_timeout);
  return gui_spinner_delta(arg, event,-1);
}

static int gui_spinner_less_timeout(void *arg,gfx_event_t *event)
{
  gui_spinner_reset_timer(arg, gui_spinner_less_timeout);
  return !gui_spinner_delta(arg, event,-1);
}

static int gui_spinner_more_release(void *arg,gfx_event_t *event)
{
  gui_spinner_remove_timer(arg);
  return 0;
}

static int gui_spinner_more_click(void *arg,gfx_event_t *event)
{
  gui_spinner_init_timer(arg, gui_spinner_more_timeout);
  return gui_spinner_delta(arg, event,1);
}

static int gui_spinner_more_timeout(void *arg,gfx_event_t *event)
{
  gui_spinner_reset_timer(arg, gui_spinner_more_timeout);
  return !gui_spinner_delta(arg, event,1);
}


static widget_t *gui_logview()
{
  gui_logview_t *B;

  B= calloc(1,sizeof(*B));
  // B->click_handler= -1;

  B->widget.klass= GFXCLASS_LOGVIEW;
  B->widget.show= gui_logview_show;
  B->widget.hide= gui_logview_hide;
  B->widget.destroy= gui_logview_destroy;
  B->widget.position= gui_logview_position;
  B->screen= screen;
  return &B->widget;
}

static void gui_logview_destroy(widget_t *W)
{
  int i;
  gui_logview_t *L= (gui_logview_t *)W;
  if (L->lines)
  {
    for(i=0;i<L->nlines;i++) free(L->lines[i]);
    free(L->lines);
    L->lines= NULL;
  }
  // remove_click_handler(L->click_handler);
}

static void logview_scroll_up(gui_logview_t *L, int yof)
{
  int x,y;
  int cx, cy, cw, ch;
  unsigned int color;
 
  colorpix_t pix;

  cx= L->px;
  cy= L->py;
  cw= L->pw;
  ch= L->ph;

  pix= get_screen_pix(L->screen);

  if (clip_for_rect(&cx, &cw, pix.w)) return ;
  if (clip_for_rect(&cy, &ch, pix.h)) return ;
  for(y=cy;y<cy+ch-yof;y++)
   for(x=cx;x<cx+cw;x++)
     PIX(pix,x,y)= PIX(pix, x,y+yof);

  color= color_u_to_s(logview_background);
  
  for(;y<cy+ch;y++)
   for(x=cx;x<cx+cw;x++)
     PIX(pix,x,y)= color;
}

static void logview_print_line
   (gui_logview_t *L,char *line, 
    int nonl,int *Ruys,int *Ruye)
{
  graypix_t text;
  int delta;

  text_to_graypix(1, line, &text, NULL);

  delta= L->cy+text.h+2 - L->ph;
  if (delta>0)
  {
    *Ruys= 0; *Ruye= L->ph;
    logview_scroll_up(L, delta);
    L->cy-= delta;
  }
  else { *Ruys= L->cy; *Ruye= L->cy+text.h; }

  text.w= imin2(text.w, L->pw - L->cx);
  if (text.w>0)
  {
    colorpix_t pix;
    pix= get_screen_pix(L->screen);

    blend_graypix_bg(logview_foreground, logview_background,
           text, pix, L->cx+L->px, L->cy+L->py);
    if (!nonl) { L->cy+= text.h + 2; L->cx= 0; }
    else { L->cx+= text.w; }
  } 
  free(text.data);
}


static void logview_render(gui_logview_t *L)
{
  int i;
  int dum;
  colorpix_t pix;

  L->cx= 0;
  L->cy= 0;

  pix= get_screen_pix(L->screen);
  colorpix_fill_rect(pix, L->widget.x,L->widget.y, L->widget.w,L->widget.h,
                  logview_background);

  for(i=0;i<L->nlines-1;i++)
   logview_print_line(L,L->lines[i],0,&dum,&dum);
  if (L->nlines) logview_print_line(L,L->lines[L->nlines-1],
                                    L->last_line_incomplete,&dum,&dum);

  update_screen_pixels(L->screen,
         L->widget.x, L->widget.y,L->widget.w,L->widget.h);
}


static void gui_logview_show(widget_t *W)
{
  logview_render((gui_logview_t*)W);
}

static void gui_logview_hide(widget_t *W) { }

static void gui_logview_position(widget_t *W, int x,int y,int w,int h)
{
  gui_logview_t *L= (gui_logview_t*) W;
  int nl;
  char **ll;
  int i;

  widgetpos(W,x,y,w,h);
  if (!L->fh) get_text_data(1,"M",NULL,&L->fh,NULL,NULL);
  nl= (w+L->fh-1)/L->fh;
  if (nl!=L->slines)
  {
    ll= calloc(sizeof(*ll),nl);
    if (nl>L->nlines)
      for(i=0;i<L->nlines;i++) ll[i]= L->lines[i];
    else
    {
      for(i=0;i<nl;i++)
         ll[nl-1-i]= L->lines[L->nlines-i-1];
      for(i=0;i<L->nlines-nl;i++) free(L->lines[i]);
      L->nlines= nl;
    }
    if (L->lines) free(L->lines[i]);
    L->lines= ll;
    L->slines= nl;
  }
  L->pw= w-2*logview_pad;
  L->ph= h-2*logview_pad;
  L->px= x+logview_pad;
  L->py= y+logview_pad;
  if (W->shown) logview_render(L);
}


static void logview_write(gui_logview_t *L, const char *txt, size_t len)
{
  char *E;

  while(len)
  {
    E= memchr(txt, '\n', len);
    if (!E) 
    {
       logview_put_line(L, txt, len, 1);
       len= 0;
    }
    else if (E==txt)
    {
       logview_put_line(L, " ",1, 0);
       txt= E+1;
       len--;
    }
    else
    {
       logview_put_line(L,txt,E-txt,0);
       len-= E-txt+1;
       txt= E+1;
    }
  }
}

static void logview_put_line
   (gui_logview_t *L, const char *txt, size_t len, int nonl)
{
  char *ll,*pp,*oo;
  size_t lo;
  int sy,ey;
  int i;

again:
  if (L->last_line_incomplete)
  {
    if (!L->nlines) { L->last_line_incomplete= 0; goto again; }
    oo= L->lines[L->nlines-1];
    lo= strlen(oo);
    ll= malloc(lo+len+1);
    memcpy(ll, oo, lo);
    memcpy(ll+lo, txt, len);
    ll[len+lo]= 0;
    free(oo);
    L->lines[L->nlines-1]= ll;
    pp= ll+lo;
  }
  else 
  {
    if (L->nlines==L->slines)
    {
      if (L->widget.shown && L->nlines)
      {
        free(L->lines[0]);
        for(i=0;i<L->nlines-1;i++) L->lines[i]= L->lines[i+1];
        L->nlines--;
      }
      else 
      {
        if (!L->slines) 
          { L->slines= 50; L->lines= malloc(sizeof(L->lines[0])*L->slines); }
        else
          { L->slines+= L->slines/2; L->lines= realloc(L->lines,
                                             sizeof(L->lines[0])*L->slines); }
      }
    }
    ll= malloc(len+1);
    memcpy(ll,txt,len);
    ll[len]= 0;
    L->lines[L->nlines]= ll;
    L->nlines++;
    pp= ll;
  }
  L->last_line_incomplete= nonl;
  if (L->widget.shown)
  {
    logview_print_line(L, pp, nonl,&sy,&ey);
    update_screen_pixels(L->screen,L->px, L->py+sy, L->pw, ey-sy);
  }
}



static void slider_layout_vertical(gui_slider_t *B)
{
  int w, linew, x, h;
  B->button_w= Vslider_button[0] & ~(1<<31);
  B->button_h= Vslider_button[1];

  linew= Vslider_tro_top[0] & ~(1<<31);

  h= B->widget.h;
  w= B->widget.w;
  if (linew<w) x= (w-linew)/2;
          else x= 0;
  B->tx1= B->tx2= B->widget.x + x;

  B->ty1= B->widget.y + B->button_h/2;
  B->ty2= B->ty1 + h - B->button_h-1;

  B->button_y= B->ty2-B->pos* (B->ty2-B->ty1)- B->button_h/2;
  B->button_x= B->tx1 - (B->button_w-linew)/2;
}

static void slider_layout_horizontal(gui_slider_t *B)
{
  int h, lineh, y, w;
  B->button_w= Hslider_button[0] & ~(1<<31);
  B->button_h= Hslider_button[1];

  lineh= Hslider_tro_left[1];

  h= B->widget.h;
  w= B->widget.w;
  if (lineh<h) y= (h-lineh)/2;
          else y= 0;
  B->ty1= B->ty2= B->widget.y + y;

  B->tx1= B->widget.x + B->button_w/2;
  B->tx2= B->tx1 + w - B->button_w-1;

  B->button_x= B->pos* (B->tx2-B->tx1) + B->tx1 - B->button_w/2;
  B->button_y= B->ty1 - (B->button_h-lineh)/2;
}

static void slider_layout(gui_slider_t *B)
{
  if (B->orient=='V') slider_layout_vertical(B);
                 else slider_layout_horizontal(B);
}

static void slider_render_horizontal(gui_slider_t *B)
{
  static uint32_t *images[]= 
  {
    Hslider_tro_left, Hslider_tro_right, Hslider_tro_mid,
    Hslider_button, Hslider_button_depressed,
    NULL
  };
  static uint8_t *Hslider_button_mask, *Hslider_button_depressed_mask;
  uint32_t *img; uint8_t *mask;

  extract_resource_image_mask(Hslider_button, &Hslider_button_mask);
  extract_resource_image_mask(Hslider_button_depressed, 
                              &Hslider_button_depressed_mask);

  gfx_fill_rect(0,B->widget.x,B->widget.y,B->widget.w,B->widget.h,0xededed);
  convert_images_to_server(images);

  three_part_assembly_horizontal(B->tx1,B->tx2,B->ty1, 
      Hslider_tro_left, Hslider_tro_mid, Hslider_tro_right);

  if (B->pressed)
  {
    img= Hslider_button_depressed;
    mask= Hslider_button_depressed_mask;
  }
  else
  {
    img= Hslider_button;
    mask= Hslider_button_mask;
  }

  put_server_pix_alphamask(img+2, mask, B->button_x,B->button_y,img[0],img[1]);
  gfx_update(B->widget.x,B->widget.y,B->widget.w,B->widget.h);
}

static void slider_render_vertical(gui_slider_t *B)
{
  static uint32_t *images[]= 
  {
    Vslider_tro_top, Vslider_tro_bot, Vslider_tro_mid,
    Vslider_button, Vslider_button_depressed,
    NULL
  };
  static uint8_t *Vslider_button_mask, *Vslider_button_depressed_mask;
  uint32_t *img; uint8_t *mask;

  extract_resource_image_mask(Vslider_button, &Vslider_button_mask);
  extract_resource_image_mask(Vslider_button_depressed, 
                              &Vslider_button_depressed_mask);

  gfx_fill_rect(0,B->widget.x,B->widget.y,B->widget.w,B->widget.h,0xededed);
  convert_images_to_server(images);

  three_part_assembly_vertical(B->tx1,B->ty1,B->ty2, 
      Vslider_tro_top, Vslider_tro_mid, Vslider_tro_bot);

  if (B->pressed)
  {
    img= Vslider_button_depressed;
    mask= Vslider_button_depressed_mask;
  }
  else
  {
    img= Vslider_button;
    mask= Vslider_button_mask;
  }

  put_server_pix_alphamask(img+2, mask, B->button_x,B->button_y,img[0],img[1]);
  gfx_update(B->widget.x,B->widget.y,B->widget.w,B->widget.h);
}

static void slider_render(gui_slider_t *B)
{
  if (!B->widget.shown) return ;
  if (B->orient=='V') slider_render_vertical(B);
                 else slider_render_horizontal(B);
}

static widget_t *gui_slider_new(int orient)
{
  gui_slider_t *B;

  B= calloc(1,sizeof(*B));
  B->widget.klass= GFXCLASS_SLIDER;
  B->orient= orient;
  B->widget.show= gui_slider_show;
  B->widget.hide= NULL;
  B->widget.destroy= gui_slider_destroy;
  B->widget.position= gui_slider_position;

  B->click_handler= install_click_handler(0,0,0,0, &B->widget.shown,
                                           B, gui_slider_click,1);
  return &B->widget;
}

static void slider_move_button(gui_slider_t *B, gfx_event_t *event)
{
  if (B->orient=='V')
  {
    int y;
    y= imax2(B->ty1, imin2(event->y, B->ty2));
    B->pos= 1.0 - (y-B->ty1)/(double)(B->ty2-B->ty1);
  }
  else
  {
    int x;
    x= imax2(B->tx1, imin2(event->x, B->tx2));
    B->pos= (x-B->tx1)/(double)(B->tx2-B->tx1);
  }
  slider_layout(B);
  slider_render(B);
  event->type= B->widget.number;
  event->flo0= B->pos;
}

static int gui_slider_click(void *arg, gfx_event_t *event)
{
  gui_slider_t *B;
  B= arg;

  if (!B->widget.shown) return 0; // shouldn't happen, but you never know

  B->pressed= 1;
  slider_move_button(B,event);
  install_release_handler(arg, gui_slider_release);
  install_motion_handler(B, gui_slider_motion);
  return 0;
}

static int gui_slider_motion(void *arg, gfx_event_t *event)
{
  slider_move_button(arg,event);
  return 0;
}

static int gui_slider_release(void *arg, gfx_event_t *event)
{
  gui_slider_t *B;
  B= arg;
  B->pressed= 0;
  slider_move_button(B, event);
  uninstall_motion_handler();
  return 0;
}

static void gui_slider_destroy(widget_t *B)
{
  gui_slider_t *S;
  S= (gui_slider_t*) B;
  remove_click_handler(S->click_handler);
}


static void gui_slider_position(widget_t *W, int x,int y,int w,int h)
{
  gui_slider_t *B;
  B= (gui_slider_t*) W;
  set_click_handler(B->click_handler, x,y,w,h);
  B->widget.x= x;
  B->widget.y= y;
  B->widget.w= w;
  B->widget.h= h;
  slider_layout(B);
  if (B->widget.shown) slider_render(B);
}

static void gui_slider_show(widget_t *B)
{
  slider_render((gui_slider_t*) B);
}


static void progressbar_render(gui_progressbar_t *G)
{
  char buf[10];
  int tw, th; unsigned char *td;
  int x,y,w,h,tx;
  int pos;

  if (!G->widget.shown) return ;

  x= G->widget.x; y= G->widget.y; w= G->widget.w; h= G->widget.h;

  if (G->total==0) pos= 0;
              else pos= G->current*w / G->total;
  if (pos<0) pos= 0;
  if (pos>w) pos= w;

  gfx_fill_rect(0, x, y, pos, h, G->fill);
  gfx_fill_rect(0, x+pos, y, w-pos-1, h, G->bg);
  gfx_draw_rect(0, x, y, w, h, G->fill);

  if (G->total==0) sprintf(buf,"0%%");
  else sprintf(buf,"%d%%", G->current*100/G->total);
  get_text_data(G->font, buf, &tw, &th, NULL, &td);

  tx= (w-tw)/2;
  if (pos<tx) {
    blend_graymap(0, G->fg, G->bg, td, tw, th, 0, 0,
                     x+(w-tw)/2, y+(h-th)/2, tw, th);
  } else if (pos>=tx+tw)
  {
    blend_graymap(0, G->bg, G->bg, td, tw, th, 0, 0,
                     x+(w-tw)/2, y+(h-th)/2, tw, th);
  } else
  {
    blend_graymap(0, G->bg, G->bg, td, tw, th, 0, 0,
                     x+(w-tw)/2, y+(h-th)/2, pos-tx, th);

    blend_graymap(0, G->fg, G->bg, td, tw, th, pos-tx, 0,
                     x+(w-tw)/2+pos-tx, y+(h-th)/2, tw-pos+tx, th);
  }
  free(td);
  gfx_update(x,y,w,h);
}


static widget_t* gui_progressbar_new(int font, int fg, int bg, int fill)
{
  gui_progressbar_t *G;
  G= calloc(1,sizeof(*G));
  G->font= font;
  G->fg= fg;
  G->bg= bg;
  G->fill= fill;

  G->widget.klass= GFXCLASS_PROGRESSBAR;
  G->widget.show= gui_progressbar_show;
  G->widget.position= gui_progressbar_position;
  return &G->widget;
}


static void gui_progressbar_show(widget_t *W)
{
  progressbar_render((gui_progressbar_t*) W);
}

static void gui_progressbar_position
   (widget_t *W,int x,int y,int w,int h)
{
  W->x= x; W->y= y; W->w= w; W->h= h;
  progressbar_render((gui_progressbar_t *) W);
}


static widget_t* gui_iconlist_new
  (int fg, int bg,int vpad, int hpad,int max_text_width,int multisel)
{
  gui_iconlist_t *IC;
  IC= calloc(1,sizeof(IC[0]));

  IC->widget.klass= GFXCLASS_ICONLIST;

  IC->fg= fg; IC->bg= bg; IC->vpad= vpad; IC->hpad= hpad;
  IC->max_text_width= max_text_width;
  IC->multi= multisel;

  IC->widget.show= gui_iconlist_show;
  IC->widget.hide= generic_dummy_hide;
  IC->widget.destroy= gui_iconlist_destroy;
  IC->widget.position= gui_iconlist_position;

  IC->click_handler= install_click_handler(0,0,0,0, &IC->widget.shown, 
                                           IC, gui_iconlist_click,1);
  IC->click_handler4= install_click_handler(0,0,0,0, &IC->widget.shown, 
                                           IC, gui_iconlist_click4,4);
  IC->click_handler5= install_click_handler(0,0,0,0, &IC->widget.shown, 
                                           IC, gui_iconlist_click5,5);
  IC->sel= -1;
  return &IC->widget;
}



static void render_icoent
   (gui_iconlist_t *IC, gui_icoent_t *EE,
    char *str, int iw, int ih, unsigned int *id)
{
  graypix_t text;
  colorpix_t pix;
  int x,y,sx;

  text_to_graypix(1,str,&text,NULL);
  pix.w= imax2(iw, imin2(text.w, IC->max_text_width));

// FIXME: 5 here should be a resource
  pix.h= ih + 5 + text.h;
  pix.stride= pix.w;

  pix.data= malloc(pix.w*pix.h*sizeof(pix.data[0]));
  colorpix_fill_rect(pix, 0,0, pix.w, pix.h, IC->bg);

  if (pix.w>iw) sx= (pix.w-iw)/2; 
           else sx= 0;

  for(y=0;y<ih;y++)
   for(x=0;x<iw;x++)
     pix.data[(sx+x)+y*pix.stride]= color_u_to_s(id[x+y*iw]);

  if (text.w>pix.w) text.w= pix.w; 
  blend_graypix(IC->fg,text,pix,(pix.w-text.w)/2,ih+5);
  free(text.data);
  EE->pix= pix;
}


static void gui_iconlist_render(gui_iconlist_t *IC)
{
  int i;
  if (!IC->widget.shown) return ;
  gui_iconlist_layout(IC);
  gfx_fill_rect(0,IC->widget.x, IC->widget.y, IC->disp_w, IC->widget.h,IC->bg);
  gfx_draw_rect(0,IC->widget.x-1, IC->widget.y-1, 
                  IC->widget.w+2, IC->widget.h+2, IC->fg);

  if (!IC->nent) goto done;
  for(i=0;i<IC->nent;i++)
  {
    if (gui_icoent_paint(IC,IC->ent+i)==1) break; 
    if (IC->multi && IC->ent[i].sel)
       gui_iconsel_draw_selrect(IC, i, 1, 0);
  }

done:
  if (!IC->multi)
    gui_iconsel_draw_selrect(IC, IC->sel, 1, 0);
  gfx_update(IC->widget.x-1, IC->widget.y-1, IC->disp_w+2, IC->widget.h+2);
}

static int gui_icoent_paint(gui_iconlist_t *IC, gui_icoent_t *EE)
{
  if (EE->y+EE->pix.h<=IC->pos_y) return -1;
  if (EE->y>=IC->pos_y+IC->widget.h) return 1;

  put_pix_in_area(EE->pix, 
          EE->x+IC->widget.x, EE->y - IC->pos_y + IC->widget.y,
       IC->widget.x, IC->widget.y, IC->disp_w, IC->widget.h);

  return 0;
}

static void gui_iconlist_layout(gui_iconlist_t *IC)
{
  int i, s,e;
  int maxw, avail_w, need_scroll, x, y, maxh;

  if (IC->layout_ok) return;
  avail_w= IC->widget.w;
  need_scroll= 0;
  IC->layout_ok= 1;
  IC->total_h= IC->vpad;
  if (!IC->nent) goto finish; 

  maxw= IC->ent[0].pix.w;
  for(i=1;i<IC->nent;i++) maxw= imax2(maxw,IC->ent[i].pix.w);
  if (maxw<=0) return ;

again:
  y= IC->vpad;
  x= IC->hpad;
  maxh= 0;
  for(i=0;i<IC->nent;i++)
  {
    if (maxh && x+maxw+IC->hpad>avail_w)
    {
      y+= maxh+IC->vpad;
      IC->total_h= y;
      maxh= 0;
      x= IC->hpad;
      if (i!=IC->nent-1 && (y+IC->ent[i].pix.h)>IC->widget.h && !need_scroll)
      {
        need_scroll= 1;
        avail_w -= gui_scrollbar_width;
        goto again;
      }
    }

    maxh= imax2(maxh, IC->ent[i].pix.h);
    IC->ent[i].y= y; IC->ent[i].x= x;
    x+= maxw+IC->hpad;
  } 
  IC->total_h= y + maxh + IC->vpad;

  s= 0;
tapdown:
  for(e=s+1;e<IC->nent;e++)
    if (IC->ent[e].y!=IC->ent[s].y) break;
  e--;
  maxh= 0;
  for(i=s;i<=e;i++)
    maxh= imax2(maxh, IC->ent[i].pix.h);
  for(i=s;i<=e;i++)
  {
    IC->ent[i].y += (maxh - IC->ent[i].pix.h)/2;
    IC->ent[i].x += (maxw-IC->ent[i].pix.w)/2;
  }
  s= e+1;
  if (s<IC->nent) goto tapdown;
  
finish:
  IC->disp_w= avail_w;

  if (need_scroll)
  {
    gui_iconlist_make_scrollbar(IC);
    gui_iconlist_set_scrollbar(IC);
  }
  if (IC->vscroll) 
    scrollbar_show(IC->vscroll,need_scroll);
  if (need_scroll!=IC->has_scroll)
  {
    gui_iconlist_arrange_click_handler(IC, need_scroll);
    IC->has_scroll= need_scroll;
  }
}

static void gui_iconlist_arrange_click_handler
   (gui_iconlist_t *IC, int need_scroll)
{
  set_click_handler(IC->click_handler, IC->widget.x,IC->widget.y,
                            IC->disp_w,IC->widget.h);
  set_click_handler(IC->click_handler4, IC->widget.x,IC->widget.y,
                            IC->disp_w,IC->widget.h);
  set_click_handler(IC->click_handler5, IC->widget.x,IC->widget.y,
                            IC->disp_w,IC->widget.h);
}

static void gui_iconlist_set_scrollbar(gui_iconlist_t *IC)
{
  scrollbar_set_all(IC->vscroll, 
       (double) IC->pos_y/IC->total_h, 
       (double) (IC->pos_y+IC->widget.h)/IC->total_h, 
       0.8*IC->widget.h/IC->total_h);
}

static void gui_iconlist_make_scrollbar(gui_iconlist_t *IC)
{
  if (IC->vscroll) return ;
 
  IC->vscroll= (scrollbar_t*) scrollbar_new(1, 
              0.0, 1.0, 0.02,
              0, IC, gui_iconlist_scrollbar_click);
  scrollbar_position(IC->vscroll,
              IC->widget.x+IC->widget.w-gui_scrollbar_width, IC->widget.y,
              gui_scrollbar_width, IC->widget.h);
}

static void gui_iconlist_destroy(widget_t *W)
{
  gui_iconlist_t *IC;
  int i;
  IC= (gui_iconlist_t*) W;
  for(i=0;i<IC->nent;i++)
   free(IC->ent[i].pix.data);
  free(IC->ent);
  remove_click_handler(IC->click_handler);
  remove_click_handler(IC->click_handler4);
  remove_click_handler(IC->click_handler5);
}


static void gui_iconlist_position(widget_t *W, int x,int y,int w,int h)
{
  gui_iconlist_t *IC; 
  IC= (void*) W;
  set_click_handler(IC->click_handler, x,y,w,h);
  IC->widget.x= x;
  IC->widget.y= y;
  IC->widget.w= w;
  IC->widget.h= h;
}

static void gui_iconlist_show(widget_t *W)
{
  gui_iconlist_render((gui_iconlist_t*) W);
}

static int gui_iconlist_click(void *_arg, gfx_event_t *ev)
{
  gui_iconlist_t *IC;
  int x,y,i;
  IC= _arg;
  x= ev->x - IC->widget.x;
  y= ev->y - IC->widget.y + IC->pos_y;
  for(i=0;i<IC->nent;i++)
  {
    if (x>=IC->ent[i].x && y>=IC->ent[i].y &&
        x<IC->ent[i].x+IC->ent[i].pix.w && y<IC->ent[i].y+IC->ent[i].pix.h)
    break;
  }
  if (i==IC->nent) return 1;
  if (IC->multi)
  {
    IC->ent[i].sel ^= 1;
    if (IC->sel==i) IC->sel= -1;
    else if (IC->sel==-1) IC->sel= i;
    gui_iconsel_draw_selrect(IC, i, IC->ent[i].sel, 1);
  }
  else
  {
    if (i==IC->sel) return 1;
    gui_iconlist_select_item(IC, i);
  }

  ev->type= IC->widget.number;
  ev->key= i;
  ev->usr= IC->ent[i].pv;
  ev->wide= IC->ent[i].iv;
  return 0;
}

static int gui_iconlist_click4(void *_arg, gfx_event_t *ev)
{
  gui_iconlist_t *IC;
  IC= _arg;
  if (!IC->vscroll || !IC->has_scroll || IC->pos_y==0) return 1;

  IC->pos_y = imax2(0, IC->pos_y - IC->widget.h * 8 /10);
 
  gui_iconlist_set_scrollbar(IC);
  gui_iconlist_render(IC); 
  
  return 1;
}

static int gui_iconlist_click5(void *_arg, gfx_event_t *ev)
{
  gui_iconlist_t *IC;
  IC= _arg;
  if (!IC->vscroll || !IC->has_scroll || IC->pos_y+IC->widget.h>=IC->total_h)
        return 1;

  IC->pos_y= imax2(imin2(IC->pos_y+IC->widget.h * 8 /10, 
                         IC->total_h-IC->widget.h),0);
 
  gui_iconlist_set_scrollbar(IC);
  gui_iconlist_render(IC); 
  
  return 1;
}

static void gui_iconsel_draw_selrect
  (gui_iconlist_t *IC,int item, int color,int upd)
{
  int a,sy,sx,i,sw,sh;
  if (item<0 || item>=IC->nent) return ;
  if (!IC->widget.shown) return ;
  if (color) color= IC->fg; else color= IC->bg;

  a= imin2(IC->hpad/2-1,IC->vpad/2-1);

  sx= IC->ent[item].x + IC->widget.x;
  sy= IC->ent[item].y + IC->widget.y - IC->pos_y;
  sw= IC->ent[item].pix.w;
  sh= IC->ent[item].pix.h;

  for(i=1;i<=a;i++)
    gfx_draw_rect_in(color, sx-i, sy-i, sw+2*i, sh+2*i,
                     IC->widget.x, IC->widget.y, IC->disp_w, IC->widget.h);
  i--;
  if (upd)
    gfx_update(sx-i,sy-i, sw+2*i, sh+2*i);
}


static void gui_iconlist_select_item(gui_iconlist_t *IC, int sel)
{
  gui_iconsel_draw_selrect(IC, IC->sel, 0, 1);
  if (IC->sel>=0 && IC->sel<=IC->nent) 
    IC->ent[IC->sel].sel= 0;
  IC->sel= sel;
  gui_iconsel_draw_selrect(IC, IC->sel, 1, 1);
  if (IC->sel>=0 && IC->sel<=IC->nent) 
    IC->ent[IC->sel].sel= 1;
}

static void  gui_iconlist_scrollbar_click(void *_arg,double start,double end)
{
  gui_iconlist_t *IC;
  IC= _arg;
  int py;
  if (start<0.0) start= 0.0;
  py= start*IC->total_h;
  if (py+IC->widget.h>IC->total_h) py= IC->total_h-IC->widget.h;
  if (py<0) py= 0;
  if (py==IC->pos_y) return ;
  IC->pos_y= py;
  gui_iconlist_render(IC);
}


static void gui_iconlist_clear(gui_iconlist_t *IC)
{
  int i;
  if (IC->nent==0) return ;
  IC->sel= -1;
  for(i=0;i<IC->nent;i++)
   free(IC->ent[i].pix.data);
  IC->nent= 0;
  IC->layout_ok= 0;
  gui_iconlist_render(IC);
}


static void gui_iconlist_remove(gui_iconlist_t *IC,int pos, void **Ruser)
{
  int i;
  if (IC->nent==0 || pos<0 || pos>=IC->nent)  return ;
  if (Ruser) *Ruser= IC->ent[pos].pv;
  free(IC->ent[pos].pix.data);
  for(i=pos;i<IC->nent-1;i++)
     IC->ent[i]= IC->ent[i+1];
  if (IC->sel==pos) IC->sel= -1; 
  else if (IC->sel>pos) IC->sel--;
  IC->nent--;
  IC->layout_ok= 0;
  gui_iconlist_render(IC);
}


static void permute(int N, int *pP, void *aA, size_t size)
{
  int *T,*P,j,i,prev,next;
  unsigned char *A,t;

  T= malloc(sizeof(int)*N*2);
  P= T+N;
  A= (unsigned char*) aA;
  for(i=0;i<N;i++)
  {
    P[i]= pP[i];
    T[P[i]]= i;
  }

  for(i=0;i<N;i++)
  {
    if (T[i]==i) continue;
    next= T[i];
    prev= P[i];

    for(j=0;j<size;j++)
    { t= A[i*size+j];
      A[i*size+j]= A[prev*size+j];
      A[prev*size+j]= t; }

    T[prev]= next;
    P[next]= prev;
  }
  free(T);
}


static widget_t *gui_filelist_new
  (int s_ext, int s_hidbox,
        void *evarg,event_function_t clickf, event_function_t dlickf)
{
  gui_filelist_t *FL;
  FL= calloc(1,sizeof(*FL));

  s_ext= 1; s_hidbox= 1;

  FL->widget.klass= GFXCLASS_FILELIST;
  FL->widget.show= gui_filelist_show;
  FL->widget.hide= gui_filelist_hide;
  FL->widget.destroy= gui_filelist_destroy;
  FL->widget.position= gui_filelist_position;

  FL->evarg= evarg;
  FL->clickf= clickf;
  FL->dlickf= dlickf;

  FL->w_list= (gui_list_t*) gui_list_new(0,0, FL, 
                               gui_filelist_listclick, 
                               gui_filesel_listdlick);

  if (s_ext)
  {
    FL->w_typelab= (gui_label_t*) gfx_label(1, 0, 0xededed, 'L', "File type");
    FL->w_type= (dropdown_t*) dropdown_new(FL, gui_filelist_typeselect);
  }
  if (s_hidbox)
  {
    FL->w_hidden= (checkbox_t*) gui_checkbox_new("Show hidden files", FL, 
                                    gui_filelist_hiddenselect);
  }

  return &FL->widget;
}

static int filter_files_byspecial(int nfiles,char **files)
{
  int i;
  char *t;
  for(i=0;i<nfiles;i++)
  {
    if (!strcmp(files[i]+1,".") || !strcmp(files[i]+1,".."))
    {
     t= files[nfiles-1];
     files[nfiles-1]= files[i];
     files[i]= t;
     nfiles--;
     i--;
    }
  }
  return nfiles;
}

static void gui_filelist_set_directory(gui_filelist_t *FL,char *dir)
{
  int i;
  static const unsigned int *icons[3];
  static char fuu[]= "..";

  file_list_icons(icons);

  dir= path_absolute(dir);
  if (FL->dir) free(FL->dir);
  if (FL->files) free(FL->files);
  FL->nfiles= 0; FL->files= NULL; FL->dir= NULL;

  FL->dir= dir;
  FL->files= list_files(FL->dir);
  file_types(FL->dir, FL->files);

  for(i=0;FL->files[i];i++) ;
  FL->nfiles= i;

  FL->nfiles= filter_files_byspecial(FL->nfiles,FL->files);
  FL->nfiles= filter_files_byhid(FL->nfiles,FL->files,FL->show_hidden);
  FL->nfiles= filter_files_byext(FL->nfiles,FL->files,FL->extensions);
  sort_files(FL->nfiles,FL->files);

  gfx_list_show(FL->w_list, 0);
  gfx_list_clear(FL->w_list);

  if (strcmp(FL->dir,"/"))
    gfx_list_insert(FL->w_list, -1, "<PARENT DIRECTORY>", fuu, icons[1]);
  for(i=0;i<FL->nfiles;i++)
  {
    gfx_list_insert( FL->w_list, -1, FL->files[i]+1, FL->files[i], 
           icons[ FL->files[i][0]=='F' ? 0: (FL->files[i][0]=='D'?1:2) ] );
  }
  gfx_list_show(FL->w_list,1);
}

static void gui_filelist_show_all(gui_filelist_t *FL,int show)
{
  widget_show(&FL->w_list->widget,show);
  if (FL->w_typelab) widget_show(&FL->w_typelab->widget,show);
  if (FL->w_type) widget_show(&FL->w_type->widget, show);
  if (FL->w_hidden) widget_show(&FL->w_hidden->widget, show);
}

static void gui_filelist_show(widget_t *W)
{
  gui_filelist_t *FL;
  FL= (gui_filelist_t*) W;
  if (W->shown)
    gfx_fill_rect(0, W->x, W->y, W->w, W->h, 0xededed);
  gui_filelist_show_all(FL, 1);
  if (W->shown)
    gfx_update(W->x, W->y, W->w, W->h);
}
static void gui_filelist_hide(widget_t *W)
{
  gui_filelist_t *FL;
  FL= (gui_filelist_t*) W;
  gui_filelist_show_all(FL, 0);
}
static void gui_filelist_destroy(widget_t *W)
{
  gui_filelist_t *FL;
  FL= (gui_filelist_t*) W;
  // gui_list_destroy(&FL->w_list->widget); FIXME: implement this
  if (FL->w_hidden) gui_checkbox_destroy(&FL->w_hidden->widget);
  if (FL->w_typelab) gui_label_destroy(&FL->w_typelab->widget);
  if (FL->w_type) gui_dropdown_destroy(&FL->w_type->widget);
  freeNnull(FL->w_list); 
  freeNnull(FL->w_hidden); 
  freeNnull(FL->w_typelab); 
  freeNnull(FL->w_type); 

  freeNnull(FL->dir);
  freeNnull(FL->files);
}

static void gui_filelist_position(widget_t *W, int x,int y,int w,int h)
{
  gui_filelist_t *FL;
  int PAD,BUTH,LABW;
  int bot, top,left;

// FIXME: convert these to resources
  PAD= 8;
  BUTH= 28;
  LABW= 120;
  FL= (gui_filelist_t*) W;

  W->x= x; W->y= y; W->w= w; W->h= h;
  if (W->shown)
    gfx_fill_rect(0, x,y,w,h, 0xededed);

  bot= h-PAD;

  if (FL->w_hidden)
  {
    top= bot - BUTH;
    widget_move(&FL->w_hidden->widget, W->x+PAD, W->y+top, w-2*PAD, BUTH);
    bot= top-PAD;
  }
  if (FL->w_typelab)
  {
   left= PAD;
   top= bot-BUTH;
   widget_move(&FL->w_typelab->widget, W->x+left, W->y+top, LABW, BUTH);
   left+= LABW+PAD;
   widget_move(&FL->w_type->widget, W->x+left, W->y+top, w-left-PAD, BUTH);
   bot= top-PAD;
  }

  top= PAD;
  widget_move(&FL->w_list->widget,W->x+PAD, W->y+top, w-2*PAD, bot-top);
  
  if (W->shown)
    gfx_update(x,y,w,h);
}

static int gui_filelist_ipret_click(gui_filelist_t *FL, gfx_event_t *event)
{
  int sel;
  char *f;
  char *d;

  sel= event->key;
  if (!FL->dir || sel>FL->nfiles || sel<0) return 1;

  if (strcmp(FL->dir,"/"))
  {
    if (sel==0) // go up
    {
      gui_filelist_set_directory(FL,path_child(FL->dir, ".."));
      return 1;
    }
    sel--;
  }
  f= FL->files[sel];
  if (f[0]=='D')
  {
    gui_filelist_set_directory(FL,d=path_child(FL->dir, f+1));
    free(d);
    return 1;
  }
  event->string= path_absolute(d= path_child(FL->dir,f+1));
  free(d);
  return 0;
}

static int gui_filelist_listclick(void *arg, gfx_event_t *event)
{
  gui_filelist_t *FL;
  FL= arg;
  if (gui_filelist_ipret_click(FL,event)) return 1;
  event->type= FL->widget.number;
  if (FL->clickf && (*FL->clickf)(FL->evarg,event)) return 1;
  return 0;
} 

static int gui_filesel_listdlick(void *arg, gfx_event_t *event)
{
  gui_filelist_t *FL;
  FL= arg;
  if (gui_filelist_ipret_click(FL,event)) return 1;
  event->type= GFXEV(FL->widget.number, DOUBLE_CLICK);
  if (FL->dlickf && (*FL->dlickf)(FL->evarg,event)) return 1;
  return 0;
} 

static int gui_filelist_typeselect(void *arg, gfx_event_t *event)
{
  gui_filelist_t *FL;
  FL= arg;
  FL->extensions= event->usr;
  gui_filelist_set_directory(FL, FL->dir);
  return 1;
} 
static int gui_filelist_hiddenselect(void *arg, gfx_event_t *event)
{
  gui_filelist_t *FL;
  FL= arg;
  FL->show_hidden= event->key;
  gui_filelist_set_directory(FL, FL->dir);
  return 1;
} 

static void free_extension_list(char **E)
{
  int i;
  for(i=0;E[i];i++) free(E[i]);
  free(E);
}
static void gui_filelist_set_types(gui_filelist_t *FL, char **types)
{
  int i;
  if (!FL->w_type)
  {
    if (FL->extensions) free_extension_list(FL->extensions);
    FL->extensions= make_file_extension_list(types);
    return ;
  }
  while(1)
  {
    char **K;
    K= NULL;
    dropdown_remove(FL->w_type,-1,(void**) &K);
    if (!K) break;
    free_extension_list(K);
  }
  gui_dropdown_clear(FL->w_type);

  for(i=0;types[i];i++)
  {
    char **el;
    dropdown_insert(FL->w_type, -1, types[i], 
              el= make_file_extension_list(types+i));
    if (i==0) FL->extensions= el;
  }
  gfx_dropdown_select(FL->w_type, 0);
  if (FL->dir)
    gui_filelist_set_directory(FL,FL->dir);
}


static int have_user_timer(int *Rms)
{
  int i;
  int R= 0;
  int ms= 0;
  for(i=0;i<nusrtimers;i++)
   if (usrtimers[i].enabled)
   {
     if (usrtimers[i].left<0) usrtimers[i].left= 0;
     if (R) ms= imin2(ms, usrtimers[i].left);
       else ms= usrtimers[i].left;
     R= 1;
   }
  *Rms= ms;
  return R;
}

static int elapsed_user_timer(int ms,int retev, gfx_event_t *event)
{
  int i;
  int R;
  R= 0;
  for(i=0;i<nusrtimers;i++)
  {
    if (!usrtimers[i].enabled) continue;
    usrtimers[i].left -= ms;
    if (usrtimers[i].left<0) usrtimers[i].left= 0;
    if (usrtimers[i].left==0 && retev)
    {
      event->type= GFXEV(usrtimers[i].ident,TIMEOUT);
      usrtimers[i].enabled= 0;
      R= 1;
      retev= 0;
    }
  }
  return R;
}


static void vkey_render(vkb_t *V, int kn, int state,int upd)
{
  graypix_t text;
  colorpix_t button;
  char *s;
  vkey_t *K;
  K= V->keys + kn;

  s= K->str[V->state];
  if (s) text_to_graypix(1, s, &text, NULL);

  button.data= x_image_data[K->y] + K->x;
  button.stride= x_window_width;
  button.w= K->w; button.h= K->h;

  colorpix_3dbox(&button, 
    color_u_to_s(state ? buttonDPD_SHDlight : buttonNOR_SHDlight),
    color_u_to_s(state ? buttonDPD_SHDdark  : buttonNOR_SHDdark),
    color_u_to_s(state ? buttonDPD_BRD      : buttonNOR_BRD),
    color_u_to_s(state ? buttonDPD_GRDstart : buttonNOR_GRDstart),
    color_u_to_s(state ? buttonDPD_GRDend   : buttonNOR_GRDend)); 

  if (s)
  {
    colorpix_put_graypix_centered(&button, &text, 0x00);
    free(text.data);
  }
  
  if (upd)
    gfx_update(K->x, K->y, K->w, K->h);
}


static uint32_t objid(int type, int id)
{
  uint32_t V;
  V= (type<<24) | id;
  return V;
}

static void* obj_get(int type, int id)
{
  if (!gfx_objid_map) return NULL;
  return womap_find(gfx_objid_map, objid(type,id));
}

static void* obj_put(int type, int id, void *data)
{
  if (!gfx_objid_map) gfx_objid_map= womap_new();
  return womap_insert(gfx_objid_map, objid(type,id), data);
}

static void* obj_remove(int type, int id)
{
  if (!gfx_objid_map) return NULL;
  return womap_remove(gfx_objid_map, objid(type,id));
}

static void vk_textdim(char* str, int *Rw, int *Rh)
{
  int w,h;
  if (!str) return ;
  get_text_data(1,str, &w, &h, NULL, NULL);
  if (*Rw<w) *Rw= w;
  if (*Rh<h) *Rh= h;
}


static void vkey_getdesc(vkb_t *V, gfx_vkbdef_t *D)
{
  int nk, i, r, c, x;
  char *t;

  nk= 0;
  for(r=0;r<15;r++) 
  {
    for(c=0;c<50;c++)
      if (D->keys[r][c].func) nk++;
                         else break;
    if (!c) break;
  }
  V->nrows= r;
  V->nkeys= nk;
  V->keys= calloc(nk,sizeof(V->keys[0]));
  i= 0;
  for(r=0;r<V->nrows;r++)
  {
    x= 0;
    for(c=0;c<50;c++)
    {
      if (!D->keys[r][c].func) break;
      if (D->keys[r][c].func==GFX_VK_NOP) 
      {
        x+= D->keys[r][c].span;
        continue;
      }
      V->keys[i].x= x;
      V->keys[i].y= r;
      V->keys[i].w= imax2(1,D->keys[r][c].span);
      V->keys[i].h= 1;
      V->keys[i].func= D->keys[r][c].func;
      x+= V->keys[i].w;
      t= NULL;
      switch(V->keys[i].func)
      {
      case GFX_K_PRT:
        V->keys[i].str[0]= nstrdup(D->keys[r][c].str[0]);
        V->keys[i].str[1]= nstrdup(D->keys[r][c].str[1]);
        V->keys[i].str[2]= nstrdup(D->keys[r][c].str[2]);
        break;
      case GFX_K_BACKSPACE: t= "BKSP"; break;
      case GFX_K_RETURN: t= "OK"; break;
      }
      if (t)
      {
        V->keys[i].str[0]= strdup(t);
        V->keys[i].str[1]= strdup(t);
        V->keys[i].str[2]= strdup(t);
      }
      i++;
    }
  }
}

static void vkey_layout(vkb_t *V)
{
  int i, s, tw, th, maxtw, maxth, maxrw, cellw, cellh, j, ox, sx, ex, w;
  int vs, vp;
  maxrw= maxtw= maxth= 0;
  for(i=0;i<V->nkeys;i++)
  {
    tw= th= 0;
    for(s=0;s<3;s++) vk_textdim(V->keys[i].str[s], &tw, &th);
    if (tw%V->keys[i].w) tw= tw/V->keys[i].w+1;
                    else tw= tw/V->keys[i].w;
    maxtw= imax2(tw, maxtw);
    maxth= imax2(th, maxth);
    maxrw= imax2(V->keys[i].x+V->keys[i].w, maxrw);
  }

  vp= vkey_vpadding;
  vs= vkey_vspacing;

  V->h= V->nrows*(maxth+vp+vs)+vs;
  while(vs>0 && V->h>x_window_height/2)
  {
    vs--;
    V->h= V->nrows*(maxth+vp+vs)+vs;
  }
  while(vp>0 && V->h>x_window_height/2)
  {
    vp--;
    V->h= V->nrows*(maxth+vp+vs)+vs;
  }
  V->vs= vs;

  cellw= (x_window_width-vkey_hspacing) / maxrw - vkey_hspacing;
  if (cellw-maxtw>vkey_hpadding) 
     cellw= vkey_hpadding + maxtw;

  cellh= vp+ maxth;
  
  for(i=0;i<V->nkeys;i++) 
  {
    V->keys[i].x = V->keys[i].x*(cellw + vkey_hspacing) + vkey_hspacing;
    V->keys[i].y = V->keys[i].y*(cellh + vs) + vs;
    V->keys[i].w = cellw + (cellw+vkey_hspacing)*(V->keys[i].w-1);
    V->keys[i].h = cellh;
  }

  for(i=0;i<V->nkeys;)
  {
    for(j=i+1;j<V->nkeys;j++)
      if (V->keys[j].x<=V->keys[i].x) break;
    sx= V->keys[i].x;
    ex= V->keys[j-1].x + V->keys[j-1].w;
    w= ex-sx;
    ox= (x_window_width - w) /2;
    for(;i<j;i++) V->keys[i].x += ox; 
  }
  V->y= 0;
  V->x= 0;
  V->w= x_window_width;
}

static void vkey_hide(vkb_t *V)
{
  if (active_vk!=V) return ;
  active_vk= NULL;
  if (!V->backstore) return ;
  put_server_pix(V->backstore, V->x, V->y, V->w, V->h);
  free(V->backstore);
  V->backstore= NULL;
  gfx_update(V->x, V->y, V->w, V->h);
}

static void vkey_show(vkb_t *V)
{
  int i;
  if (active_vk==V) return ;
  if (active_vk) vkey_hide(active_vk);
  V->backstore= get_server_pix(V->x,V->y, V->w, V->h);
  active_vk= V;
  gfx_fill_rect(0, V->x, V->y, V->w, V->h,0xccCCcc);
  V->state= 0;
  for(i=0;i<V->nkeys;i++) vkey_render(V, i, 0, 0);
  gfx_update(V->x, V->y, V->w, V->h);
}

static void vkey_ypos(vkb_t *V, int yp)
{
  int i, D, h;
  if (yp==V->y) return ;
  h= 0;
  if (active_vk==V) { h=1; vkey_hide(V); }
  D= V->keys[0].y;
  for(i=0;i<V->nkeys;i++)
    V->keys[i].y= V->keys[i].y - D + yp + V->vs;
  V->y= yp;
  if (h) vkey_show(V);
}


static int vkey_event(gfx_event_t *ev)
{
  vkey_t *K;
  int k;
  char *s;
  if (!active_vk) return 0;
  if (ev->type==GFXEV_BUTTON_PRESS) goto button_press;
  if (ev->type==GFXEV_BUTTON_RELEASE) goto button_release;
  return 0;
  
button_press:
  if (active_vk->pressed!=-1) return 0;
  k= vkey_find_button(active_vk,ev->x,ev->y);
  if (k==-1) return 0;
  active_vk->pressed= k;
  vkey_render(active_vk, k, 1, 1);
  return 1;

button_release:
  if (active_vk->pressed==-1) return 0;
  k= active_vk->pressed;
  active_vk->pressed= -1;
  vkey_render(active_vk, k, 0, 1);
  K= active_vk->keys+k;
  ev->string= NULL;
  s= K->str[ active_vk->state ];
  switch(K->func)
  {
  case GFX_K_PRT:
    if (!s) return 0;
    ev->string= s;
    ev->wide= utf8_decode_single_char(s);
    break;
  case GFX_K_RETURN:
  case GFX_K_BACKSPACE:
    ev->string= NULL;
    break;
  default:
    return 0;
  }
  ev->key= K->func;
  ev->type= GFXEV_KEY_PRESS;
  return 0;
}

static int vkey_find_button(vkb_t *V, int x, int y)
{
  int i,j,t;
  i= 0;
  j= V->nkeys-1;
  while(i<=j)
  {
    t= (i+j)/2;
    if ((y>V->keys[t].y+V->keys[t].h)||(x>V->keys[t].x+V->keys[t].w)) i= t+1;
    else if ((y<V->keys[t].y) || (x<V->keys[t].x)) j= t-1;
    else return t;
  }
  return -1;
}


void gfx_geometry(unsigned int *W, unsigned int *H)
{
  if (W) *W= x_window_width;
  if (H) *H= x_window_height;
}

void gfx_set_sysbar_height(int hh)
{
  gui_sysbar_height= hh;
}

int gfx_get_dpi()
{
  return getdpi();
}

void gfx_pause() { updates_on= 0; }
void gfx_resume() { updates_on= 1; }


void gfx_monitor_file(int fd, int ident, int R,int W,int X)
{
  file_monitor_t *F;
  if (n_fmon==100) return ;
  if (!R && !W && !X) return ;
  F= fmon + n_fmon;
  n_fmon++;
  F->fd= fd;
  F->ident= ident;
  F->events= (R?1:0) | (W?2:0) | (X?4:0);
#ifdef GFX_ANDROID
  ALooper_addFd(my_app->looper, fd, ident | (1<<16), 
         (R ? ALOOPER_EVENT_INPUT:0) |
         (W ? ALOOPER_EVENT_OUTPUT:0) |
         (X ? ALOOPER_EVENT_ERROR|ALOOPER_EVENT_HANGUP
                                 |ALOOPER_EVENT_INVALID:0), NULL, my_app);
#endif
}

void gfx_stop_monitor_file(int fd,int ident)
{
  int i;
  for(i=0;i<n_fmon;i++)
    if ( (fd==-1 || fmon[i].fd==fd) &&
         (ident==-1 || fmon[i].ident==ident))
    {
#ifdef GFX_ANDROID
      ALooper_removeFd(my_app->looper, fmon[i].fd);
#endif
      fmon[i]= fmon[n_fmon-1];
      n_fmon--;
      i--;
    }
}


void gfx_leave_screen()
{
  screen_t *S;
  int i;

  screen_op_count++;

  if (!screen) return ;
  gfx_hide_virtual_keyboard();

  S= screen;

  for(i=0;i<S->n_widgets;i++)
    if (widgets[S->widgets[i]])
    {
      widget_destroy(widgets[S->widgets[i]]);
      widgets[S->widgets[i]]= NULL;
    }
  if (S->click_handlers) free(S->click_handlers);
  if (S->backstore)      free(S->backstore);
  free_rgroups(S);

  screen= S->down;
  free(S);
  if (screen) screen->up= NULL;

  screen_restore_contents(screen);

  if (screen)
  {
    widget_t *W;
    W= screen->focus_widget;
    if (W && W->focus)
    {
      (*W->focus)(W,1); 
      W->has_focus= 1;
    }
  }
}


void gfx_set_state(int wno, int state)
{
  widget_set_state(get_widget(wno),state);
}

int  gfx_get_state(int wno)
{
  return widget_get_state(get_widget(wno));
}

int  gfx_get_selected(int wno)
{
  return widget_get_selected(get_widget(wno));
}

void gfx_set_selected(int wno,int sel)
{
  widget_set_selected(get_widget(wno),sel);
}

void gfx_set_text(int wno,char *str)
{
  widget_set_text(get_widget(wno),str);
}

void gfx_set_fgbg(int wno, int fg, int bg)
{
  widget_set_fgbg(get_widget(wno),fg,bg);
}

void gfx_insert(int wno,int pos, char *text,void *user,unsigned int* icon)
{
  widget_insert(get_widget(wno),pos,text,user,icon);
}

void gfx_remove(int wno, int pos, void **Ruser)
{
  widget_remove(get_widget(wno),pos, Ruser);
}

char* gfx_get_text(int wno)
{
  return widget_get_text(get_widget(wno));
}

void gfx_clear(int wno)
{
  return widget_clear(get_widget(wno));
}


void gfx_focus(int wno)
{
  widget_t *W;
  W= get_widget(wno);
  if (!W) remove_focus();
     else set_focus(W);
}




void gfx_text_data(int font, const char *str, 
                   int *Rw, int *Rh,int *Ra,unsigned char **Rd)
{
  get_text_data(font,str,Rw,Rh,Ra,Rd);
}


void gfx_scrollbar_set(int wno, double start, double end, double step)
{
  scrollbar_t *SB;
  SB= (scrollbar_t*) get_widget(wno);
  if (!SB|| SB->widget.klass!= GFXCLASS_SCROLLBAR) return ;
  scrollbar_set_all(SB, start, end, step);
}


void gfx_pixgrid_attribs(int pg, int *Rshown, unsigned int *Rw, unsigned int *Rh)
{
  gui_pixgrid_t *B;
  B= (gui_pixgrid_t*) get_widget(pg);
  if (!B || B->widget.klass!=GFXCLASS_PIXGRID) 
  {
    if (Rshown) *Rshown= 0;
    if (Rw) *Rw= 1;
    if (Rh) *Rh= 1;
  }
  else
  {
    if (Rshown) *Rshown= B->enabled;
    if (Rw) *Rw= B->widget.w;
    if (Rh) *Rh= B->widget.h;
  }
}


int gfx_pixgrid_buffer
  (int pg, int *Rbpl, int *Rbpp, int *Rorder, unsigned char **Rbuffer)
{
  gui_pixgrid_t *B;
  B= (gui_pixgrid_t*) get_widget(pg);
  if (!B || B->widget.klass!=GFXCLASS_PIXGRID)  return 1;
#ifdef GFX_ANDROID
  if (Rbpl) *Rbpl= x_window_width * 4;
#else
  if (Rbpl) *Rbpl= x_image->bpl;
#endif
  if (Rbpp) *Rbpp= 4; // this library only works if this is true..
  if (Rbuffer) 
  {
    unsigned char *P;
#ifdef GFX_ANDROID
    P= (unsigned char*) x_image_data[0];
    *Rbuffer= P + (B->widget.y*x_window_width+B->widget.x)*4;
#else
    P= (unsigned char*) x_image->data;
    *Rbuffer= P+B->widget.y*x_image->bpl+B->widget.x*4;
#endif
  }
  if (Rorder)
  {
    Rorder[0]= x_red_shift/8;
    Rorder[1]= x_green_shift/8;
    Rorder[2]= x_blue_shift/8;
  }
  return 0;
}

void gfx_pixgrid_update(int pg, int x,int y,int w, int h)
{
  gui_pixgrid_t *B;
  B= (gui_pixgrid_t*) get_widget(pg);
  if (!B || B->widget.klass!=GFXCLASS_PIXGRID)  return ;
  gfx_update(B->widget.x+x, B->widget.y+y, w,h);
}

void gfx_pixgrid_put(int pg, int x,int y,
                     unsigned int *img, unsigned int iW,unsigned int iH,
                     int src_x, int src_y, 
                     int copy_w, int copy_h)
{
  gui_pixgrid_t *B;
  B= (gui_pixgrid_t*) get_widget(pg);
  if (!B || B->widget.klass!=GFXCLASS_PIXGRID || !B->enabled)  return ;

  clip_for_rect(&src_x, &copy_w, iW);
  clip_for_rect(&src_y, &copy_h, iH);
  clip_for_rect(&x, &copy_w, B->widget.w);
  clip_for_rect(&y, &copy_h, B->widget.h);
  if (copy_w<=0 || copy_h<=0) return ;
  
  gfx_put(GFX_UPDATE,img,iW,iH,src_x,src_y,
                B->widget.x+x,B->widget.y+y, copy_w, copy_h);
}

void gfx_pixgrid_putsimple(int pg, unsigned int *img)
{
  gui_pixgrid_t *B;
  B= (gui_pixgrid_t*) get_widget(pg);
  if (!B || B->widget.klass!=GFXCLASS_PIXGRID || !B->enabled)  return ;

  gfx_pixgrid_put(pg, 0,0,
                  img, B->widget.w, B->widget.h,
                  0,0, B->widget.w, B->widget.h);
}
 
int gfx_ask(char *title, char *butstr, char *fmt, ...)
{
  va_list ap;
  int buttons_h, buttons_w, nbuttons;
  int titw, tith, titx, tity;
  int R;

  int W,H,X,Y; // for the whole dialog
  char **lines; int nlines, lw, lh,lx,ly;

  int i;

  static int dlg_widgets[]= 
    { GUIRaskB1, GUIRaskB2, GUIRaskB3, GUIRaskB4, GUIRaskB5,
      GUIRaskB6, GUIRaskB7, GUIRaskB8 };
  int coor_screen[4];
  int coor_widgets[4*8];

  // LAYOSCR_SCREEN_0(LL,x_window_width,x_window_height);
  gfxask_make_buttons(butstr, coor_widgets, 
                       &nbuttons, &buttons_h, &buttons_w);

  if (title)
    get_text_data(2,title,&titw,&tith,NULL,NULL);

  va_start(ap,fmt);
  format_multi_line_str(fmt, ap, &lines, &nlines);
  va_end(ap);
  multi_line_str_dim(1,lines,nlines,&lw,&lh);

  W= imax2(lw,buttons_w)+2*dialog_spacing;
  H= 3*dialog_spacing + lh + buttons_h;

  if (title) H+= dialog_spacing + tith;
  if (title) W= imax2(W, titw+2*dialog_spacing);

  if (H>x_window_height) Y= x_window_height - H;
                    else Y= (x_window_height-H)/2;
  if (W>x_window_width)  X= 0;
                    else X= (x_window_width-W)/2;

  coor_screen[0]= X; coor_screen[1]= Y;
  coor_screen[2]= W; coor_screen[3]= H;

  enter_screen(8, dlg_widgets, coor_screen);

  // FIXME: make it possible to reposition the dialog
  // when the containing window gets resized..
  // LAYOWID_SCREEN_0(x_window_width,x_window_height,LC);

  gfxask_draw_border(X,Y,W,H);
  gfxask_show_buttons(coor_widgets, nbuttons,
          X+(W - buttons_w)/2,
          Y+H - buttons_h - dialog_spacing);

  if (lw>W) lx= X+0;
       else lx= X+(W-lw)/2;
  ly= Y+ dialog_spacing;
  if (title) ly+= tith+dialog_spacing;

  for(i=0;i<nlines;i++)
  {
    int fh;
    txt_print(0, 1, confirm_fg, confirm_bg, lx,ly, lines[i], NULL,&fh);
    ly+= fh + 1;
  } 
  free(lines[0]);
  free(lines);

  if (title)
  {
    if (titw>W) titx= X+0;
           else titx= X+(W-titw)/2;
    tity= Y+dialog_spacing;
    txt_print(0, 2, confirm_fg, confirm_bg, titx,tity, title, NULL,NULL);
  }

  gfx_update_all();

  R= -1;
  while(1)
  {
    gfx_event_t event;
    if (!gfx_event(NULL,&event)) continue;
    if (event.type==GFXEV_QUIT) { R= -1; break; }
    R= event.type- GUIRaskB1;
    if (R<0 || R>=nbuttons) continue;
    break; 
  }
  gfx_leave_screen();
  return R;
}


char* gfx_select_file(int mode,char *init,char **types)
{
  char *idir, *ifil;
  char *x;
  filesel_t *fs;
  int q;
  char *result;

  if (mode) mode= 1;

  split_initial_fn(init, &idir, &ifil);
  fs= calloc(1,sizeof(*fs));
  fs->dir_start= fs->dir_end= -1;
  filesel_setdir(fs,idir);
  free(idir);
  fs->types= types;
  fs->ext= make_file_extension_list(types);
  file_select_dialog(fs,mode,ifil);
  filesel_render_dirstack(fs);
  populate_file_list(fs);
  gfx_update_all();

  if (ifil) free(ifil);
  ifil= NULL;

retry:
  q= -1;

  while(q<0)
  {
    gfx_event_t event;
    if (gfx_event(NULL,&event))
     switch(event.type)
     {
     case GUIRfilCANCEL:
     case GFXEV_QUIT:   q= 0; break;
     case GUIRfilOK: q= 1; break;
     case GUIRfilREFRESH:
       populate_file_list(fs);
       break;
     case GUIRfilHOME:
       filesel_setdir(fs, sau_gethome());
       populate_file_list(fs);
       filesel_render_dirstack(fs);
       break;
    case GUIRfilLIST:
       x= event.usr;
       if (!x) continue;
       if (x[0]=='D')
       {
         filesel_setdir(fs, combine_path(fs->dir,x+1));
         populate_file_list(fs);
         filesel_render_dirstack(fs);
         break;
       }
       if (x[0]=='F')
       {
         text_entry_set((text_entry_t*) widgets[GUIRfilNAME],x+1);
         break;
       }
       break;
     case GUIRfilD1: case GUIRfilD2: case GUIRfilD3: case GUIRfilD4:
     case GUIRfilD5: case GUIRfilD6: case GUIRfilD7: case GUIRfilD8:
     case GUIRfilD9: case GUIRfilD10:
       filesel_activate_dir(fs, event.type-GUIRfilD1);
       break;
     }
  }
  if (q)
  {
    char *fn, *path;
    int exists, isfile;
    int valid;

    struct stat sbuf;

    fn= textentry_get_text((text_entry_t*)widgets[GUIRfilNAME]);
    if (!fn[0]) { free(fn); goto retry; }
    path= combine_path(fs->dir, fn);

    if (stat(path,&sbuf))                 exists=0; else exists=1;
    if (exists && S_ISREG(sbuf.st_mode)) isfile= 1; else isfile= 0;

    valid= 1;
    if (exists & !isfile)
    {
      gfx_ask("Invalid Selection", "!OK",
              "Selected entry\n\n%s\n\nis not a regular file", path);
      valid= 0; 
    }
    else if (mode==0 && !exists)
    {
      gfx_ask("Invalid Selection", "!OK",
              "Entered path\n\n%s\n\ndoes not exist.", path); 
      valid= 0; 
    }
    else if (mode==1 && exists)
    {
       if ((!init ||strcmp(init,path)) && 
               gfx_ask("Confirm Overwrite", "!OK!Cancel",
                   "%s\n\nDo you want to overwrite this file?", path))
          valid= 0; 
    }
    if (!valid) { free(path); free(fn); goto retry; }
    result= path;
    free(fn);
  }
  else
    result= NULL;

  gfx_leave_screen();

  if (fs->ext)
  {
    int i;
    for(i=0;fs->ext[i];i++) free(fs->ext[i]);
    free(fs->ext[i]);
  }
  filesel_free_buttons(fs);
  free(fs->dir);
  free(fs->files);
  free(fs);
  
  return result;
}


void gfx_canvas_setsize(int wno, int new_w, int new_h)
{
  gui_canvas_t *CC;
  CC= (gui_canvas_t*) get_widget(wno);
  if (!CC || CC->widget.klass!=GFXCLASS_CANVAS) return ;

  if (gui_canvas_setbuffer(CC,new_w,new_h)) return ;
  CC->pos_x= 0;
  CC->pos_y= 0;
  gui_canvas_arrange_scrollbars(CC);
  gui_canvas_draw_all(CC);
}


void gfx_canvas_draw_rectangle(int wno,int color, int x,int y,int w,int h)
{
  gui_canvas_t *CC;
  if (!(CC=gui_canvas_get(wno))) return ;
  if (w<=0 || h<=0 || !CC->buffer) return ;
  color= color_u_to_s(color);

  gui_canvas_clipped_hline(CC, color, x,x+w-1, y);
  gui_canvas_clipped_hline(CC, color, x,x+w-1, y+h-1);
 
  gui_canvas_clipped_vline(CC, color, x,y,y+h-1);
  gui_canvas_clipped_vline(CC, color, x+w-1,y, y+h-1);
  gui_canvas_update(CC,x,y,w,h);
}

void gfx_canvas_fill_rectangle(int wno,int color, int x,int y,int w,int h)
{
  gui_canvas_t *CC;
  int sx,sy,ex,ey,bw;

  if (!(CC=gui_canvas_get(wno))) return ;
  if (w<=0 || h<=0 || !CC->buffer) return ;
  color= color_u_to_s(color);

  sx= imin2(imax2(0,x),CC->buffer_w-1);
  sy= imin2(imax2(0,y),CC->buffer_h-1);

  ex= imin2(imax2(0,x+w), CC->buffer_w);
  ey= imin2(imax2(0,y+h), CC->buffer_h);

  bw= CC->buffer_w;
  for(y=sy;y<ey;y++)
    for(x=sx;x<ex;x++)
      CC->buffer[y*bw+x]= color;

  gui_canvas_update(CC,sx,sy,ex-sx,ey-sy);
}


void gfx_canvas_recsel_begin(int wno, gfx_event_t *ev)
{
  gui_canvas_t *CC;
  if (!(CC= gui_canvas_get(wno))) return ;
  if (!CC->buffer) return ;
  CC->rs_x0= CC->rs_x1= ev->x;
  CC->rs_y0= CC->rs_y1= ev->y;
  CC->recsel= 1;
  install_motion_handler(CC, gui_canvas_motion);
}


void gfx_canvas_recsel_end(int wno,int *Rx1, int *Ry1, int *Rx2, int *Ry2)
{
  int minx,miny,maxx,maxy,Z;
  gui_canvas_t *CC;
  if (!(CC= gui_canvas_get(wno))) return ;

  uninstall_motion_handler();
  gui_canvas_draw_recsel(CC);
  minx= imin2( CC->rs_x0, CC->rs_x1 );
  maxx= imax2( CC->rs_x0, CC->rs_x1 );
  miny= imin2( CC->rs_y0, CC->rs_y1 );
  maxy= imax2( CC->rs_y0, CC->rs_y1 );
  gui_canvas_update(CC, minx, miny, maxx-minx+1, maxy-miny+1);

  Rx1= Rx1 ? Rx1 : &Z;
  Ry1= Ry1 ? Ry1 : &Z;
  Rx2= Rx2 ? Rx2 : &Z;
  Ry2= Ry2 ? Ry2 : &Z;

  *Rx1= CC->rs_x0;
  *Ry1= CC->rs_y0;
  *Rx2= CC->rs_x1;
  *Ry2= CC->rs_y1;
  CC->recsel= 0;
}


void gfx_canvas_print(int wno, int font, int color, int x, int y, char *str)
{
  gui_canvas_t *CC;
  int bw;
  uint32_t *B; 
  int dp,sp;
  unsigned char *td; int tw, th, ta;
  int sx,sy,dx,dy,w,h;

  CC= (gui_canvas_t*) get_widget(wno);
  
  if (!CC || CC->widget.klass!=GFXCLASS_CANVAS || !CC->buffer
      || !str || !str[0]) return ;
  
  get_text_data(font,str,&tw,&th,&ta,&td);
 
  w= tw; h= th;
  sx= 0; sy= 0;
  dx= x; dy= y;
  if (clip_for_rect(&sx, &w, tw) ||
      clip_for_rect(&sy, &h, th) ||
      clip_for_rect(&dx, &w, CC->buffer_w) ||
      clip_for_rect(&dy, &h, CC->buffer_h)) 
    goto free_td;

  bw= CC->buffer_w;
  B= CC->buffer;
  for(y=0;y<h;y++)
    for(x=0;x<w;x++)
    {
      dp= (dy+y)*bw + (dx+x);
      sp= (sy+y)*tw + (sx+x);
      B[dp]= blend_usr_svr(td[sp], color, B[dp]);
    }

  gui_canvas_update(CC, dx, dy, w,h);
free_td:
  free(td);
}

void gfx_canvas_put_graymap
       (int wno, unsigned int color, int dx,int dy, int w, int h,
        unsigned char *source, int sw, int sh, int sx, int sy)
{
  gui_canvas_t *CC;
  int x,y;
  int bw;
  uint32_t *B; 
  int dp,sp;

  CC= (gui_canvas_t*) get_widget(wno);
  
  if (!CC || CC->widget.klass!=GFXCLASS_CANVAS || !CC->buffer ||
      clip_for_rect(&sx, &w, sw) ||
      clip_for_rect(&sy, &h, sh) ||
      clip_for_rect(&dx, &w, CC->buffer_w) ||
      clip_for_rect(&dy, &h, CC->buffer_h)) 
    return ;

  color= color_u_to_s(color);

  bw= CC->buffer_w;
  B= CC->buffer;
  for(y=0;y<h;y++)
    for(x=0;x<w;x++)
    {
      dp= (dy+y)*bw + (dx+x);
      sp= (sy+y)*sw + (sx+x);
      B[dp]= blend_usr_svr(source[sp], color, B[dp]);
    }

  gui_canvas_update(CC, dx, dy, w,h);
}

void gfx_canvas_put
       (int wno, int dx,int dy, int w, int h,
        unsigned int *source, int sw, int sh, int sx, int sy)
{
  gui_canvas_t *CC;
  int x,y;
  int bw;
  uint32_t *B; 
  int dp,sp;

  CC= (gui_canvas_t*) get_widget(wno);
  
  if (!CC || CC->widget.klass!=GFXCLASS_CANVAS || !CC->buffer ||
      clip_for_rect(&sx, &w, sw) ||
      clip_for_rect(&sy, &h, sh) ||
      clip_for_rect(&dx, &w, CC->buffer_w) ||
      clip_for_rect(&dy, &h, CC->buffer_h)) 
    return ;


  bw= CC->buffer_w;
  B= CC->buffer;

  for(y=0;y<h;y++)
    for(x=0;x<w;x++)
    {
      dp= (dy+y)*bw + (dx+x);
      sp= (sy+y)*sw + (sx+x);
      B[dp]= source[sp];
    }

  gui_canvas_update(CC, dx, dy, w,h);
}

int gfx_canvas_get_buffer
   (int wno, unsigned int *W, unsigned int *H, unsigned int **B)
{
  gui_canvas_t *CC;
  if (!(CC=gui_canvas_get(wno)))
  { 
    static unsigned int K;
    *W= *H= 1; *B= &K;
    return 1;
  }
  if (!CC->buffer)
    gfx_canvas_setsize(wno, CC->widget.w, CC->widget.h);
  *W= CC->buffer_w;
  *H= CC->buffer_h;
   // this is wrong, FIXME
  *B= (unsigned int*) CC->buffer;
  return 0;
}

void gfx_canvas_update(int wno, int x, int y, int w, int h)
{
  gui_canvas_t *CC;
  if ((CC=gui_canvas_get(wno))) gui_canvas_update(CC,x,y,w,h);
}


void gfx_canvas_begin_report_mouse_position(int wno)
{
  gui_canvas_t *CC;
  if (!(CC= gui_canvas_get(wno))) return ;
  if (!CC->buffer) return ;
  install_motion_handler(CC, gui_canvas_report_motion);
}

void gfx_canvas_end_report_mouse_position(int wno)
{
  gui_canvas_t *CC;
  if (!(CC= gui_canvas_get(wno))) return ;
  if (!CC->buffer) return ;
  uninstall_motion_handler();
}


void gfx_canvas_set_zoom_params
  (int wno, int zf, int grid, unsigned int gridcolor,int w,int h)
{
  gui_canvas_t* CC;
  if (!(CC=gui_canvas_get(wno))) return ;
  w= imin2(CC->port_w/2,w);
  h= imin2(CC->port_h/2,h);
  CC->z_factor= zf;
  CC->z_ww= w;
  CC->z_wh= h;
  CC->z_grid= grid;
  CC->z_gridcolor= gridcolor;
  gui_canvas_zupdate(CC,0,0,CC->buffer_w,CC->buffer_h);
}

void gfx_canvas_zoom(int wno,int x,int y)
{
  gui_canvas_t* CC;
  int Xa,Xb,Xc,Xs,Xe;
  int Ya,Yb,Yc,Ys,Ye;
  int z, ww, hh, D, wx, wy;

  if (!(CC=gui_canvas_get(wno))) return ;
  if (!CC->buffer) return ;
  if (x<0 || y<0 || x>=CC->buffer_w || y>=CC->buffer_h) return ;
  if (!CC->z_factor || !CC->z_ww || !CC->z_wh) return ;

  z= CC->z_factor;
  ww= CC->z_ww;            hh= CC->z_wh;
  Xc= x;                   Yc= y;

  Xa= (ww-z)/2;            Xb= ww-z-Xa;
  Xs= Xc-GFXceil(Xa,z);       Xe= Xc+GFXceil(Xb,z);

  Ya= (hh-z)/2;            Yb= hh-z-Ya;
  Ys= Yc-GFXceil(Ya,z);       Ye= Yc+GFXceil(Yb,z);

  if (Xs<0) { Xe-= Xs; Xc-= Xs; Xs= 0; }
  if (Ys<0) { Ye-= Ys; Yc-= Ys; Ys= 0; }
  D= Xe-CC->buffer_w-1;
  if (D>0) { Xs-= D; Xc-= D; Xe= CC->buffer_w-1; }
  D= Ye-CC->buffer_h-1;
  if (D>0) { Ys-= D; Yc-= D; Ye= CC->buffer_h-1; }
  if (Xs<0 || Ys<0) return ; // FIXME: the buffer is too small, we should
                             // still display a zoom window, with decorations
                             // for the missing pixels.
  if (Xc-CC->pos_x<CC->buffer_w/2)
    wx= CC->port_w-CC->z_ww;
  else
    wx= 0; 

  if (Yc-CC->pos_y<CC->buffer_h/2)
    wy= CC->port_h-CC->z_wh;
  else
    wy= 0;

  if (CC->have_zoom && (wx!=CC->z_wx || wy!=CC->z_wy))
  {
    CC->have_zoom= 0;
    gui_canvas_update(CC,CC->z_wx+CC->pos_x,CC->z_wy+CC->pos_y,
                         CC->z_ww, CC->z_wh);
  }
  CC->have_zoom= 1;
  CC->z_cx= Xc;
  CC->z_cy= Yc;
  CC->z_wx= wx;
  CC->z_wy= wy;

  gui_canvas_zupdate(CC,0,0,CC->buffer_w,CC->buffer_h);
}

void gfx_canvas_hide_zoom(int wno)
{
  gui_canvas_t* CC;
  if (!(CC=gui_canvas_get(wno))) return ;
  if (!CC->have_zoom) return ;
  CC->have_zoom= 0;
  gui_canvas_update(CC,CC->z_wx+CC->pos_x,CC->z_wy+CC->pos_y,
                         CC->z_ww, CC->z_wh);
}


int gfx_sprite_new(int wno,int func, int w,int h, uint32_t *data)
{
  gui_canvas_t *CC;
  int i,RV;

  if (w<=0 || h<=0 || !data) return -1;
  if (!(CC=gui_canvas_get(wno))) return -1;
  for(i=0;i<CC->ssprites;i++)
    if (CC->sprites[i]==NULL) break;

  if (i==CC->ssprites)
  {
    sprite_t **ns; int s;
    s= CC->ssprites+CC->ssprites/2+10;
    ns= calloc(s, sizeof(ns[0]));
    if (CC->ssprites)
      memcpy(ns, CC->sprites, CC->ssprites*sizeof(CC->sprites[0]));
    CC->ssprites= s;
    if (CC->sprites) free(CC->sprites);
    CC->sprites= ns;
  }
  RV= i;

  switch(func) 
  {
    case 'A': func= SPRITE_FUNC_AND; break;
    case 'N': func= SPRITE_FUNC_NEG; break;
    case 'X': func= SPRITE_FUNC_XOR; break;
    case 'S': default: func= SPRITE_FUNC_SET; break;
  }

  sprite_t *S;
  S= calloc(1,sizeof(*S));
  S->data= calloc(w*h,sizeof(S->data[0]));
  S->w= w;
  S->h= h;
  S->x= 0;
  S->y= 0;
  S->func= func;
  CC->sprites[RV]= S;

#define ALPHABYTE  (0xff<<24)
  for(i=0;i<w*h;i++)
   if (data[i]&ALPHABYTE)
    S->data[i]= color_u_to_s(data[i]) | ALPHABYTE;
#undef ALPHABYTE

  for(i=CC->ssprites;i>=1;i--)
   if (CC->sprites[i-1]!=NULL) break;
  CC->nsprites= i;

  return RV;
}

void gfx_sprite_move(int wno,int sp, int x,int y)
{
  gui_canvas_t *CC;
  sprite_t *S;

  if (!(CC=gui_canvas_get(wno))) return ;
  if (sp>=CC->ssprites || sp<0) return ;
  S= CC->sprites[sp];
  if (!S) return ;
  if (!S->shown) { S->x= x; S->y= y; return ; }

  int ux, uy, uw, uh;
  ux= S->x; uy= S->y; uw= S->w; uh= S->h;

  if (x<S->x) { ux= x; uw+= S->x-x; }
  else if (x>S->x) { uw+= x-S->x; }

  if (y<S->y) { uy= y; uh+= S->y-y; }
  else if (y>S->y) { uh+= y-S->y; }

  S->x= x; S->y= y;
  gui_canvas_update(CC, ux, uy, uw, uh);
}

void gfx_sprite_show(int wno,int sp,int sho)
{
  gui_canvas_t *CC;
  sprite_t *S;

  if (!(CC=gui_canvas_get(wno))) return ;
  if (sp>=CC->ssprites || sp<0) return ;
  S= CC->sprites[sp];
  if (!S) return ;
  if (sho==S->shown) return ;

  S->shown= sho;
  gui_canvas_update(CC, S->x, S->y, S->w, S->h);
}


void gfx_sprite_remove(int wno, int sp)
{
  gui_canvas_t *CC;
  sprite_t *S;
  int i;

  if (!(CC=gui_canvas_get(wno))) return ;
  if (sp>=CC->ssprites || sp<0) return ;
  S= CC->sprites[sp];
  if (!S) return ;
  if (S->shown) 
  {
    S->shown= 0; 
    gui_canvas_update(CC, S->x, S->y, S->w, S->h);
  }
  gui_sprite_free(S);
  CC->sprites[sp]= NULL;
  
  for(i=CC->ssprites;i>=1;i--)
   if (CC->sprites[i-1]!=NULL) break;
  CC->nsprites= i;
}


void gfx_spinner_set_imin(int wno, int min)
{
  gui_spinner_t *SS;
  if (!(SS= get_spinner_widget(wno))) return ;
  SS->limflags |= SPINNER_MIN;
  SS->intmin= min;
  spinner_apply_limits(SS);
}

void gfx_spinner_set_imax(int wno, int max)
{
  gui_spinner_t *SS;
  if (!(SS= get_spinner_widget(wno))) return ;
  SS->limflags |= SPINNER_MAX;
  SS->intmax= max;
  spinner_apply_limits(SS);
}

void gfx_spinner_set_iquant(int wno, int qua)
{
  gui_spinner_t *SS;
  if (!(SS= get_spinner_widget(wno))) return ;
  SS->intq= qua;
  spinner_apply_limits(SS);
}

void gfx_spinner_set_fmin(int wno, double min)
{
  gui_spinner_t *SS;
  if (!(SS= get_spinner_widget(wno))) return ;
  SS->limflags |= SPINNER_MIN;
  SS->flomin= min;
  spinner_apply_limits(SS);
}

void gfx_spinner_set_fmax(int wno, double max)
{
  gui_spinner_t *SS;
  if (!(SS= get_spinner_widget(wno))) return ;
  SS->limflags |= SPINNER_MAX;
  SS->flomax= max;
  spinner_apply_limits(SS);
}

void gfx_spinner_set_fquant(int wno, double qua)
{
  gui_spinner_t *SS;
  if (!(SS= get_spinner_widget(wno))) return ;
  SS->floq= qua;
  spinner_apply_limits(SS);
}

void gfx_spinner_set_fvalue(int wno, double value)
{
  double V;
  gui_spinner_t *SS;
  if (!(SS= get_spinner_widget(wno))) return ;
  V= SS->flov;
  SS->flov= value;
  spinner_apply_limits(SS);
  if (V!=SS->flov) gui_spinner_render(SS);
}

void gfx_spinner_set_ivalue(int wno, int value)
{
  int V;
  gui_spinner_t *SS;
  if (!(SS= get_spinner_widget(wno))) return ;
  V= SS->intv;
  SS->intv= value;
  spinner_apply_limits(SS);
  if (V!=SS->intv) gui_spinner_render(SS);
}

int gfx_spinner_get_ivalue(int wno)
{
  gui_spinner_t *SS;
  if (!(SS= get_spinner_widget(wno))) return 0;
  return SS->intv; 
}

double gfx_spinner_get_fvalue(int wno)
{
  gui_spinner_t *SS;
  if (!(SS= get_spinner_widget(wno))) return 0.0;
  return SS->flov; 
}



void gfx_logview_printf(int wno, const char *fmt, ...)
{
  widget_t *W; 
  char *txt;
  va_list ap;
  W= get_widget(wno);
  if (!W || W->klass!=GFXCLASS_LOGVIEW) return ;
  va_start(ap,fmt);
  txt= vmprintf(fmt, ap);
  va_end(ap);
  
  logview_write((gui_logview_t*) W, txt, strlen(txt));
  free(txt);
}

void gfx_logview_write(int wno, const char *txt, size_t len)
{
  widget_t *W;
  W= get_widget(wno);
  if (!W || W->klass!=GFXCLASS_LOGVIEW) return ;
  logview_write((gui_logview_t*) W, txt, len);
}


void gfx_logview_clear(int wno)
{
  widget_t *W;
  int i;
  gui_logview_t *L;
  W= get_widget(wno);
  if (!W || W->klass!=GFXCLASS_LOGVIEW) return ;
  L= (gui_logview_t*) W;
  if (L->nlines==0) return ;
  for(i=0;i<L->nlines;i++) free(L->lines[i]);
  L->nlines= 0;
  if (W->shown) logview_render(L);
}

void gfx_set_log(int wno)
{
  logwidget= wno;
}


void loprintv(const char *fmt, va_list ap)
{
  widget_t *W; 
  char *txt;
  W= get_widget(logwidget);
  if (!W || W->klass!=GFXCLASS_LOGVIEW) return ;
  txt= vmprintf(fmt, ap);
  logview_write((gui_logview_t*) W, txt, strlen(txt));
  free(txt);
}

void loprintf(const char *fmt, ...)
{
  va_list ap;
  va_start(ap,fmt);
  loprintv(fmt,ap);
  va_end(ap);
}


void gfx_slider_set(int wno, double pos)
{
  widget_t *W;
  gui_slider_t *B;
  W= get_widget(wno);
  if (!W || W->klass!=GFXCLASS_SLIDER) return ;
  B= (gui_slider_t*) W;
  if (pos<0.0) pos= 0.0;
  if (pos>1.0) pos= 1.0;
  B->pos= pos;
  slider_layout(B);
  slider_render(B);
}

double gfx_slider_get(int wno)
{
  widget_t *W;
  gui_slider_t *B;
  W= get_widget(wno);
  if (!W || W->klass!=GFXCLASS_SLIDER) return 0.0;
  B= (gui_slider_t*) W;
  return B->pos;
}

void gfx_progressbar_total(int wno, int total)
{
  gui_progressbar_t *G;
  G= get_widgetk(wno, GFXCLASS_PROGRESSBAR);
  if (!G) return ;
  G->total= total;
}

void gfx_progressbar_set(int wno, int value)
{
  gui_progressbar_t *G;
  G= get_widgetk(wno, GFXCLASS_PROGRESSBAR);
  if (!G) return ;
  G->current= value;
  progressbar_render(G);
}


void gfx_iconlist_insert
   (int wno, int pos,
    char *text, 
    unsigned int w, unsigned int h, unsigned int *data,
    int ival, void *pval)
{
  gui_iconlist_t *IC;
  gui_icoent_t *EE;

  if (!(IC=get_widgetk(wno,GFXCLASS_ICONLIST))) return ;

  if (pos<0 || pos>=IC->nent) pos= IC->nent;
  EE= array_make1space(pos, (void**) &IC->ent, IC->nent, &IC->sent,
                             sizeof(IC->ent[0]));
  IC->nent++;
  if (IC->sel>=pos) IC->sel++;

  EE->iv= ival; EE->pv= pval; EE->sel= 0;
  IC->layout_ok= 0;
  render_icoent(IC, EE,text,w,h,data);
  gui_iconlist_render(IC);
}


void gfx_iconlist_updates(int wno, int upd)
{
  gui_iconlist_t *IC;
  if (!(IC=get_widgetk(wno,GFXCLASS_ICONLIST))) return ;
  IC->widget.shown= upd;
  if (upd) gui_iconlist_render(IC);
}

void gfx_iconlist_area(int wno, int *Rw, int *Rh)
{
  gui_iconlist_t *IC;
  int w, h;
  if ((IC=get_widgetk(wno,GFXCLASS_ICONLIST)))
  { w=  IC->widget.w;
    h=  IC->widget.h; }
  else { w= h= 10; }
  if (Rw) *Rw= w;
  if (Rh) *Rh= h;
}

void gfx_iconlist_select(int wno, int item, int sel)
{
  gui_iconlist_t *IC;
  int S;
  if (!(IC=get_widgetk(wno,GFXCLASS_ICONLIST))) return ;
  if (wno<0 || wno>=IC->nent) return ;
  if (sel) sel= 1;
  S=IC->ent[wno].sel;
  IC->ent[wno].sel= sel;  
  if (S==sel) return ;
  gui_iconsel_draw_selrect(IC, item, sel, 1);
}

void gfx_iconlist_permute(int wno, int N, int *P)
{
  gui_iconlist_t *IC;
  int i;
  if (!(IC=get_widgetk(wno,GFXCLASS_ICONLIST))) return ;
  if (N!=IC->nent) return ;
  for(i=0;i<N;i++) if (P[i]==IC->sel) { IC->sel= i; break; }
  IC->layout_ok= 0;
  permute(N, P, IC->ent, sizeof(IC->ent[0]));
  gui_iconlist_render(IC);
}

void gfx_iconlist_clear_selection(int wno)
{
  gui_iconlist_t *IC;
  int i;
  if (!(IC=get_widgetk(wno,GFXCLASS_ICONLIST))) return ;
  for(i=0;i<IC->nent;i++)
    if (IC->ent[i].sel)
    {
      IC->ent[i].sel= 0; 
      gui_iconsel_draw_selrect(IC, i, 0, 1);
      if (i==IC->sel) IC->sel= -1;
    }
  if (IC->sel!=-1)
  {
    gui_iconsel_draw_selrect(IC, IC->sel, 0, 1);
    IC->sel= -1;
  }
}

void gfx_iconlist_get_selection(int wno,int *Rn, int **Rs)
{
  gui_iconlist_t *IC;
  int i, n, *s;
  if (Rn) *Rn= 0;
  if (!(IC=get_widgetk(wno,GFXCLASS_ICONLIST))) return ;
  n= 0;
  for(i=0;i<IC->nent;i++)
    if (IC->ent[i].sel) n++;
  if (Rn) *Rn= n;
  if (!Rs) return ;
  s= malloc((n+1)*sizeof(int));
  n= 0;
  for(i=0;i<IC->nent;i++)
    if (IC->ent[i].sel) s[n++]= i;
  s[n]= -1;
  *Rs= s;
}


void gfx_filelist_set_directory(int wno,char *dir)
{
  gui_filelist_t *FL;
  FL= get_widgetk(wno, GFXCLASS_FILELIST);
  if (!FL) return ;
  gui_filelist_set_directory(FL, dir);
}

void gfx_filelist_set_types(int wno, char **types)
{
  gui_filelist_t *FL;
  FL= get_widgetk(wno, GFXCLASS_FILELIST);
  if (!FL) return ;
  gui_filelist_set_types(FL, types);
}

char** gfx_filelist_get_files(int wno)
{
  char **R,*s;
  gui_filelist_t *FL;
  int ssize,psize,L,i;
  FL= get_widgetk(wno, GFXCLASS_FILELIST);
  if (!FL || !FL->nfiles) 
  {
    R= malloc(sizeof(void*)); 
    R[0]= NULL;
    return R;
  }
  ssize= 0;
  for(i=0;i<FL->nfiles;i++)
    ssize+= strlen(FL->files[i])+1;
  psize= (FL->nfiles+1)*sizeof(char*);
  s= malloc(psize+ssize);
  R= (void*) s;
  s+= psize;
  
  for(i=0;i<FL->nfiles;i++)
  {
    R[i]= s;
    L= strlen(FL->files[i]);
    memcpy(s, FL->files[i], L+1);
    s+= L+1;
  }
  R[i]= NULL;
  return R;
}

char *gfx_filelist_get_directory(int wno)
{
  gui_filelist_t *FL;
  FL= get_widgetk(wno, GFXCLASS_FILELIST);
  if (!FL || !FL->dir)
    return strdup(".");
  return strdup(FL->dir);
}

void gfx_filelist_refresh(int wno)
{
  gui_filelist_t *FL;
  FL= get_widgetk(wno, GFXCLASS_FILELIST);
  if (!FL || !FL->dir) return ;
  gui_filelist_set_directory(FL, FL->dir);
}


void gfx_timer_start(int ident, int ms)
{
  int i;
  usr_timer_t *T;
  if (ident<0) return ;
  T= NULL;
  if (!usrtimers)
  {
   usrtimers= calloc(sizeof(usrtimers),10);
   susrtimers= 10;
  }
  for(i=0;i<nusrtimers;i++)
  {
    T= usrtimers+i;
    if (T->ident==ident) break;
  }
  if (i==nusrtimers)
  {
    T= array_make1space(nusrtimers, (void**) &usrtimers, nusrtimers, 
                          &susrtimers, sizeof(usrtimers[0]));
    nusrtimers++;
  }
  T->ident= ident;
  T->enabled= 1;
  T->left= ms;
}

void gfx_timer_stop(int ident)
{
  int i;
  usr_timer_t *T;
  if (ident<0 || ident>=nusrtimers) return ;
  for(i=0;i<nusrtimers;i++)
  {
    T= usrtimers+i;
    if (T->ident==ident) { T->enabled= 0; break; }
  }
}


void gfx_virtual_keyboard(int num, gfx_vkbdef_t *D)
{
  vkb_t *V;
  V= calloc(1,sizeof(*V));
  vkey_getdesc(V, D);
  vkey_layout(V);
  V= obj_put(OBJ_VKB, num, V);
  // FIXME: free V
}

void gfx_edit_field(int widget, int kbnum)
{
  vkb_t *V;
  text_entry_t *W;
  int vtop;
  int off;
  V= obj_get(OBJ_VKB, kbnum);
  if (!V) return ;
  W= get_widgetk(widget, GFXCLASS_TEXTENTRY);
  if (!W) return ;
  vtop= x_window_height - V->h;
  if (W->y+W->h<=vtop) off= vtop;
                  else off= 0;
  vkey_ypos(V, off);
  vkey_show(V);
}


void gfx_hide_virtual_keyboard()
{
  if (!active_vk) return ;
  vkey_hide(active_vk);
}
static void LAYOWID_Wopbtn_XO_0(int WIDTH,int HEIGHT,int *L) {
//NOTHING
}
static void LAYOWID_Wopbtn_XO_1(int WIDTH,int HEIGHT,int *L) {
 int VBUTW= 70;
 int VPAD= 8;
 int VBUTH= 28;
 int COWconOK_left= VPAD;
 int COWconCANCEL_height= VBUTH;
 int COWconCANCEL_width= VBUTW;
 int COWconOK_top= (HEIGHT-VBUTH)/2;
 int COWconCANCEL_top= COWconOK_top;
 int COWconOK_width= VBUTW;
 int COWconOK_height= VBUTH;
 int COWconCANCEL_bottom= COWconCANCEL_top+COWconCANCEL_height;
 int COWconOK_right= COWconOK_left+COWconOK_width;
 int COWconOK_bottom= COWconOK_top+COWconOK_height;
 int COWconCANCEL_left= COWconOK_right+VPAD;
 int COWconCANCEL_right= COWconCANCEL_left+COWconCANCEL_width;
  L[0]= COWconOK_left; L[1]= COWconOK_top;
  L[2]= COWconOK_width; L[3]= COWconOK_height;
  L[4]= COWconCANCEL_left; L[5]= COWconCANCEL_top;
  L[6]= COWconCANCEL_width; L[7]= COWconCANCEL_height;
}
static void LAYOWID_SCRres(int WIDTH,int HEIGHT,int *L) {
 int COWresLAB0_width= 60;
 int VBUTW= 80;
 int VBUTH= 28;
 int VPAD= 8;
 int COWresMESSAGE_height= 26;
 int COWresLAB0_height= VBUTH;
 int COWresMESSAGE_bottom= HEIGHT-VPAD;
 int COWresMESSAGE_top= COWresMESSAGE_bottom-COWresMESSAGE_height;
 int COWresMESSAGE_right= WIDTH-VPAD;
 int COWresMESSAGE_left= VPAD;
 int COWresTITLE_height= 50;
 int COWresTITLE_width= WIDTH;
 int COWresUSE_bottom= COWresMESSAGE_top-VPAD;
 int COWresTITLE_top= 0;
 int COWresUSE_width= VBUTW;
 int COWresTITLE_left= 0;
 int COWresUSE_height= VBUTH;
 int COWresLIST_left= VPAD;
 int COWresTITLE_right= COWresTITLE_left+COWresTITLE_width;
 int COWresUSE_top= COWresUSE_bottom-COWresUSE_height;
 int COWresLIST_right= WIDTH-VPAD;
 int COWresLIST_width= COWresLIST_right-COWresLIST_left;
 int COWresTITLE_bottom= COWresTITLE_top+COWresTITLE_height;
 int COWresMESSAGE_width= COWresMESSAGE_right-COWresMESSAGE_left;
 int COWresLAB0_bottom= COWresUSE_top-VPAD;
 int COWresLAB0_top= COWresLAB0_bottom-COWresLAB0_height;
 int COWresDELETE_width= VBUTW;
 int COWresLAB0_left= VPAD;
 int COWresADD_height= VBUTH;
 int COWresADD_width= VBUTW;
 int COWresDELETE_height= VBUTH;
 int COWresADD_top= COWresLAB0_top;
 int COWresADD_right= WIDTH-VPAD;
 int COWresADD_left= COWresADD_right-COWresADD_width;
 int COWresNAME_height= VBUTH;
 int COWresCLOSE_top= COWresUSE_top;
 int COWresCLOSE_width= VBUTW;
 int COWresNAME_top= COWresLAB0_top;
 int COWresNAME_right= COWresADD_left-VPAD;
 int COWresCLOSE_height= VBUTH;
 int COWresLIST_top= COWresTITLE_bottom+VPAD;
 int COWresLAB0_right= COWresLAB0_left+COWresLAB0_width;
 int COWresCLOSE_bottom= COWresCLOSE_top+COWresCLOSE_height;
 int COWresNAME_bottom= COWresNAME_top+COWresNAME_height;
 int COWresCLOSE_right= COWresNAME_right;
 int COWresCLOSE_left= COWresCLOSE_right-COWresCLOSE_width;
 int COWresDELETE_bottom= COWresNAME_top-VPAD;
 int COWresADD_bottom= COWresADD_top+COWresADD_height;
 int COWresNAME_left= COWresLAB0_right+VPAD;
 int COWresDELETE_top= COWresDELETE_bottom-COWresDELETE_height;
 int COWresLIST_bottom= COWresDELETE_top-VPAD;
 int COWresDELETE_left= COWresNAME_left;
 int COWresLIST_height= COWresLIST_bottom-COWresLIST_top;
 int COWresNAME_width= COWresNAME_right-COWresNAME_left;
 int COWresUSE_left= COWresNAME_left;
 int COWresDELETE_right= COWresDELETE_left+COWresDELETE_width;
 int COWresUSE_right= COWresUSE_left+COWresUSE_width;
  L[0]= COWresLIST_left; L[1]= COWresLIST_top;
  L[2]= COWresLIST_width; L[3]= COWresLIST_height;
  L[4]= COWresDELETE_left; L[5]= COWresDELETE_top;
  L[6]= COWresDELETE_width; L[7]= COWresDELETE_height;
  L[8]= COWresCLOSE_left; L[9]= COWresCLOSE_top;
  L[10]= COWresCLOSE_width; L[11]= COWresCLOSE_height;
  L[12]= COWresNAME_left; L[13]= COWresNAME_top;
  L[14]= COWresNAME_width; L[15]= COWresNAME_height;
  L[16]= COWresADD_left; L[17]= COWresADD_top;
  L[18]= COWresADD_width; L[19]= COWresADD_height;
  L[20]= COWresLAB0_left; L[21]= COWresLAB0_top;
  L[22]= COWresLAB0_width; L[23]= COWresLAB0_height;
  L[24]= COWresUSE_left; L[25]= COWresUSE_top;
  L[26]= COWresUSE_width; L[27]= COWresUSE_height;
  L[28]= COWresTITLE_left; L[29]= COWresTITLE_top;
  L[30]= COWresTITLE_width; L[31]= COWresTITLE_height;
  L[32]= COWresMESSAGE_left; L[33]= COWresMESSAGE_top;
  L[34]= COWresMESSAGE_width; L[35]= COWresMESSAGE_height;
}
static void LAYOSCR_SCRres(int *L,int WIDTH,int HEIGHT) {
 int COleft= (WIDTH-350)/2;
 int COheight= 600;
 int COwidth= 350;
 int COright= COleft+COwidth;
 int COtop= (HEIGHT-600)/2;
 int CObottom= COtop+COheight;
  L[0]= COleft;
  L[1]= COtop;
  L[2]= COwidth;
  L[3]= COheight;
}
void gfx_SCRres(){
 static int SWID[]= {     WresLIST,
    WresDELETE,
    WresCLOSE,
    WresNAME,
    WresADD,
    WresLAB0,
    WresUSE,
    WresTITLE,
    WresMESSAGE,
};
  int i;
  int LC[36]; /*widget coords */
  int LL[4]; /* screen coords */
  LAYOSCR_SCRres(LL,x_window_width,x_window_height);
  enter_screen(9, SWID,LL);
  widgets[WresLIST]= gui_list_new(0,0,NULL,NULL,NULL);
  widgets[WresLIST]->number= WresLIST;
  widgets[WresDELETE]= gfx_button("Delete", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WresDELETE]->number= WresDELETE;
  widgets[WresCLOSE]= gfx_button("Close", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WresCLOSE]->number= WresCLOSE;
  widgets[WresNAME]= text_entry_new("");
  widgets[WresNAME]->number= WresNAME;
  widgets[WresADD]= gfx_button("Add", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WresADD]->number= WresADD;
  widgets[WresLAB0]= gfx_label(1,0x000000,0xededed,'L',"Name");
  widgets[WresLAB0]->number= WresLAB0;
  widgets[WresUSE]= gfx_button("Use", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WresUSE]->number= WresUSE;
  widgets[WresTITLE]= gfx_label(3,0x000000,0xcccccc,'C',"Resources");
  widgets[WresTITLE]->number= WresTITLE;
  widgets[WresMESSAGE]= gfx_label(1,0x000000,0xededed,'C',"");
  widgets[WresMESSAGE]->number= WresMESSAGE;
  LAYOWID_SCRres(LL[2],LL[3],LC);
  for(i=0;i<9;i++) { LC[4*i]+= LL[0]; LC[4*i+1]+= LL[1]; }
  widget_move(widgets[WresLIST], LC[0], LC[1],LC[2],LC[3]);
  widget_move(widgets[WresDELETE], LC[4], LC[5],LC[6],LC[7]);
  widget_move(widgets[WresCLOSE], LC[8], LC[9],LC[10],LC[11]);
  widget_move(widgets[WresNAME], LC[12], LC[13],LC[14],LC[15]);
  widget_move(widgets[WresADD], LC[16], LC[17],LC[18],LC[19]);
  widget_move(widgets[WresLAB0], LC[20], LC[21],LC[22],LC[23]);
  widget_move(widgets[WresUSE], LC[24], LC[25],LC[26],LC[27]);
  widget_move(widgets[WresTITLE], LC[28], LC[29],LC[30],LC[31]);
  widget_move(widgets[WresMESSAGE], LC[32], LC[33],LC[34],LC[35]);
  widget_show(widgets[WresLIST], 1);
  widget_show(widgets[WresDELETE], 1);
  widget_show(widgets[WresCLOSE], 1);
  widget_show(widgets[WresNAME], 1);
  widget_show(widgets[WresADD], 1);
  widget_show(widgets[WresLAB0], 1);
  widget_show(widgets[WresUSE], 1);
  widget_show(widgets[WresTITLE], 1);
  widget_show(widgets[WresMESSAGE], 1);
  gfx_update_all();
}
static void LAYOWID_SCRvar(int WIDTH,int HEIGHT,int *L) {
 int COWvarTITLE_left= 0;
 int VPAD= 8;
 int VBUTW= 90;
 int VBUTH= 28;
 int COWvarTITLE_height= 50;
 int COWvarTITLE_width= WIDTH;
 int COWvarTITLE_right= COWvarTITLE_left+COWvarTITLE_width;
 int COWvarTITLE_top= 0;
 int COWvarLIST_left= VPAD;
 int COWvarTITLE_bottom= COWvarTITLE_top+COWvarTITLE_height;
 int COWvarCLOSE_height= VBUTH;
 int COWvarCLOSE_width= VBUTW;
 int COWvarCLOSE_bottom= HEIGHT-VPAD;
 int COWvarCLOSE_top= COWvarCLOSE_bottom-COWvarCLOSE_height;
 int COWvarCLOSE_right= WIDTH-VPAD;
 int COWvarCLOSE_left= COWvarCLOSE_right-COWvarCLOSE_width;
 int COWvarLAB0_height= VBUTH;
 int COWvarLAB0_width= VBUTW;
 int COWvarLAB0_bottom= COWvarCLOSE_top-VPAD;
 int COWvarLAB0_top= COWvarLAB0_bottom-COWvarLAB0_height;
 int COWvarLIST_right= WIDTH-VPAD;
 int COWvarLAB0_left= VPAD;
 int COWvarLAB1_height= VBUTH;
 int COWvarLAB1_width= VBUTW;
 int COWvarLAB1_bottom= COWvarLAB0_top-VPAD;
 int COWvarLAB1_top= COWvarLAB1_bottom-COWvarLAB1_height;
 int COWvarLIST_top= COWvarTITLE_bottom+VPAD;
 int COWvarLAB1_left= VPAD;
 int COWvarLAB2_height= VBUTH;
 int COWvarLAB2_width= VBUTW;
 int COWvarLAB2_bottom= COWvarLAB1_top-VPAD;
 int COWvarLAB2_top= COWvarLAB2_bottom-COWvarLAB2_height;
 int COWvarLIST_width= COWvarLIST_right-COWvarLIST_left;
 int COWvarLAB2_left= VPAD;
 int COWvarADD_height= VBUTH;
 int COWvarADD_width= VBUTW;
 int COWvarADD_bottom= COWvarLAB2_top-VPAD;
 int COWvarADD_top= COWvarADD_bottom-COWvarADD_height;
 int COWvarUPDATE_top= COWvarCLOSE_top;
 int COWvarADD_left= VPAD;
 int COWvarDEL_height= VBUTH;
 int COWvarDEL_width= VBUTW;
 int COWvarUPDATE_width= VBUTW;
 int COWvarDEL_top= COWvarADD_top;
 int COWvarUPDATE_height= VBUTH;
 int COWvarTYPE_top= COWvarLAB0_top;
 int COWvarNAME_height= VBUTH;
 int COWvarTYPE_width= VBUTW;
 int COWvarTYPE_height= VBUTH;
 int COWvarNAME_top= COWvarLAB2_top;
 int COWvarNAME_right= WIDTH-VPAD;
 int COWvarVALUE_right= COWvarNAME_right;
 int COWvarVALUE_height= VBUTH;
 int COWvarVALUE_top= COWvarLAB1_top;
 int COWvarVALUE_bottom= COWvarVALUE_top+COWvarVALUE_height;
 int COWvarLAB0_right= COWvarLAB0_left+COWvarLAB0_width;
 int COWvarLAB1_right= COWvarLAB1_left+COWvarLAB1_width;
 int COWvarLAB2_right= COWvarLAB2_left+COWvarLAB2_width;
 int COWvarLIST_bottom= COWvarADD_top-VPAD;
 int COWvarNAME_bottom= COWvarNAME_top+COWvarNAME_height;
 int COWvarTYPE_bottom= COWvarTYPE_top+COWvarTYPE_height;
 int COWvarADD_right= COWvarADD_left+COWvarADD_width;
 int COWvarLIST_height= COWvarLIST_bottom-COWvarLIST_top;
 int COWvarDEL_bottom= COWvarDEL_top+COWvarDEL_height;
 int COWvarDEL_left= COWvarADD_right+VPAD;
 int COWvarDEL_right= COWvarDEL_left+COWvarDEL_width;
 int COWvarUPDATE_bottom= COWvarUPDATE_top+COWvarUPDATE_height;
 int COWvarVALUE_left= COWvarDEL_left;
 int COWvarNAME_left= COWvarDEL_left;
 int COWvarUPDATE_left= COWvarDEL_left;
 int COWvarTYPE_left= COWvarDEL_left;
 int COWvarTYPE_right= COWvarTYPE_left+COWvarTYPE_width;
 int COWvarNAME_width= COWvarNAME_right-COWvarNAME_left;
 int COWvarVALUE_width= COWvarVALUE_right-COWvarVALUE_left;
 int COWvarUPDATE_right= COWvarUPDATE_left+COWvarUPDATE_width;
  L[0]= COWvarLIST_left; L[1]= COWvarLIST_top;
  L[2]= COWvarLIST_width; L[3]= COWvarLIST_height;
  L[4]= COWvarUPDATE_left; L[5]= COWvarUPDATE_top;
  L[6]= COWvarUPDATE_width; L[7]= COWvarUPDATE_height;
  L[8]= COWvarTYPE_left; L[9]= COWvarTYPE_top;
  L[10]= COWvarTYPE_width; L[11]= COWvarTYPE_height;
  L[12]= COWvarVALUE_left; L[13]= COWvarVALUE_top;
  L[14]= COWvarVALUE_width; L[15]= COWvarVALUE_height;
  L[16]= COWvarNAME_left; L[17]= COWvarNAME_top;
  L[18]= COWvarNAME_width; L[19]= COWvarNAME_height;
  L[20]= COWvarDEL_left; L[21]= COWvarDEL_top;
  L[22]= COWvarDEL_width; L[23]= COWvarDEL_height;
  L[24]= COWvarADD_left; L[25]= COWvarADD_top;
  L[26]= COWvarADD_width; L[27]= COWvarADD_height;
  L[28]= COWvarLAB2_left; L[29]= COWvarLAB2_top;
  L[30]= COWvarLAB2_width; L[31]= COWvarLAB2_height;
  L[32]= COWvarLAB1_left; L[33]= COWvarLAB1_top;
  L[34]= COWvarLAB1_width; L[35]= COWvarLAB1_height;
  L[36]= COWvarLAB0_left; L[37]= COWvarLAB0_top;
  L[38]= COWvarLAB0_width; L[39]= COWvarLAB0_height;
  L[40]= COWvarCLOSE_left; L[41]= COWvarCLOSE_top;
  L[42]= COWvarCLOSE_width; L[43]= COWvarCLOSE_height;
  L[44]= COWvarTITLE_left; L[45]= COWvarTITLE_top;
  L[46]= COWvarTITLE_width; L[47]= COWvarTITLE_height;
}
static void LAYOSCR_SCRvar(int *L,int WIDTH,int HEIGHT) {
 int COleft= (WIDTH-400)/2;
 int COheight= 600;
 int COwidth= 400;
 int COright= COleft+COwidth;
 int COtop= (HEIGHT-600)/2;
 int CObottom= COtop+COheight;
  L[0]= COleft;
  L[1]= COtop;
  L[2]= COwidth;
  L[3]= COheight;
}
void gfx_SCRvar(){
 static int SWID[]= {     WvarLIST,
    WvarUPDATE,
    WvarTYPE,
    WvarVALUE,
    WvarNAME,
    WvarDEL,
    WvarADD,
    WvarLAB2,
    WvarLAB1,
    WvarLAB0,
    WvarCLOSE,
    WvarTITLE,
};
  int i;
  int LC[48]; /*widget coords */
  int LL[4]; /* screen coords */
  LAYOSCR_SCRvar(LL,x_window_width,x_window_height);
  enter_screen(12, SWID,LL);
  widgets[WvarLIST]= gui_list_new(0,0,NULL,NULL,NULL);
  widgets[WvarLIST]->number= WvarLIST;
  widgets[WvarUPDATE]= gfx_button("Update", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WvarUPDATE]->number= WvarUPDATE;
  widgets[WvarTYPE]= dropdown_new(NULL,NULL);
  widgets[WvarTYPE]->number= WvarTYPE;
  widgets[WvarVALUE]= text_entry_new("");
  widgets[WvarVALUE]->number= WvarVALUE;
  widgets[WvarNAME]= text_entry_new("");
  widgets[WvarNAME]->number= WvarNAME;
  widgets[WvarDEL]= gfx_button("Delete", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WvarDEL]->number= WvarDEL;
  widgets[WvarADD]= gfx_button("Add", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WvarADD]->number= WvarADD;
  widgets[WvarLAB2]= gfx_label(1,0x000000,0xededed,'L',"Name");
  widgets[WvarLAB2]->number= WvarLAB2;
  widgets[WvarLAB1]= gfx_label(1,0x000000,0xededed,'L',"Value");
  widgets[WvarLAB1]->number= WvarLAB1;
  widgets[WvarLAB0]= gfx_label(1,0x000000,0xededed,'L',"Type");
  widgets[WvarLAB0]->number= WvarLAB0;
  widgets[WvarCLOSE]= gfx_button("Close", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WvarCLOSE]->number= WvarCLOSE;
  widgets[WvarTITLE]= gfx_label(3,0x000000,0xcccccc,'C',"Layout Variables");
  widgets[WvarTITLE]->number= WvarTITLE;
  LAYOWID_SCRvar(LL[2],LL[3],LC);
  for(i=0;i<12;i++) { LC[4*i]+= LL[0]; LC[4*i+1]+= LL[1]; }
  widget_move(widgets[WvarLIST], LC[0], LC[1],LC[2],LC[3]);
  widget_move(widgets[WvarUPDATE], LC[4], LC[5],LC[6],LC[7]);
  widget_move(widgets[WvarTYPE], LC[8], LC[9],LC[10],LC[11]);
  widget_move(widgets[WvarVALUE], LC[12], LC[13],LC[14],LC[15]);
  widget_move(widgets[WvarNAME], LC[16], LC[17],LC[18],LC[19]);
  widget_move(widgets[WvarDEL], LC[20], LC[21],LC[22],LC[23]);
  widget_move(widgets[WvarADD], LC[24], LC[25],LC[26],LC[27]);
  widget_move(widgets[WvarLAB2], LC[28], LC[29],LC[30],LC[31]);
  widget_move(widgets[WvarLAB1], LC[32], LC[33],LC[34],LC[35]);
  widget_move(widgets[WvarLAB0], LC[36], LC[37],LC[38],LC[39]);
  widget_move(widgets[WvarCLOSE], LC[40], LC[41],LC[42],LC[43]);
  widget_move(widgets[WvarTITLE], LC[44], LC[45],LC[46],LC[47]);
  widget_show(widgets[WvarLIST], 1);
  widget_show(widgets[WvarUPDATE], 1);
  widget_show(widgets[WvarTYPE], 1);
  widget_show(widgets[WvarVALUE], 1);
  widget_show(widgets[WvarNAME], 1);
  widget_show(widgets[WvarDEL], 1);
  widget_show(widgets[WvarADD], 1);
  widget_show(widgets[WvarLAB2], 1);
  widget_show(widgets[WvarLAB1], 1);
  widget_show(widgets[WvarLAB0], 1);
  widget_show(widgets[WvarCLOSE], 1);
  widget_show(widgets[WvarTITLE], 1);
  gfx_update_all();
}
static void LAYOWID_SCRset(int WIDTH,int HEIGHT,int *L) {
 int COWsetTITLE_left= 0;
 int VPAD= 8;
 int VBUTW= 80;
 int VBUTH= 28;
 int COWsetTITLE_top= 0;
 int VDLABW= 130;
 int COWsetTITLE_width= WIDTH;
 int VENTW= 180;
 int COWsetTITLE_height= 50;
 int COWsetCANCEL_width= VBUTW;
 int COWsetTITLE_bottom= COWsetTITLE_top+COWsetTITLE_height;
 int COWsetCANCEL_height= VBUTH;
 int COWsetTITLE_right= COWsetTITLE_left+COWsetTITLE_width;
 int VCOL1= VPAD+VDLABW+VPAD;
 int COWsetLABEL0_height= VBUTH;
 int COWsetLABEL0_width= VDLABW;
 int COWsetOK_left= (WIDTH-2*VBUTW-VPAD)/2;
 int COWsetLABEL0_top= COWsetTITLE_bottom+VPAD;
 int COWsetOK_width= VBUTW;
 int COWsetLABEL0_left= VPAD;
 int COWsetLABEL1_height= VBUTH;
 int COWsetLABEL1_width= VDLABW;
 int COWsetOK_height= VBUTH;
 int COWsetHDRbut_width= VBUTW;
 int COWsetHDRbut_height= VBUTH;
 int COWsetLABEL1_left= VPAD;
 int COWsetLABEL2_height= VBUTH;
 int COWsetLABEL2_width= VDLABW;
 int COWsetSRCbut_width= VBUTW;
 int COWsetSRCbut_height= VBUTH;
 int COWsetHEIGHT_left= VCOL1;
 int COWsetLABEL2_left= VPAD;
 int COWsetLABEL3_height= VBUTH;
 int COWsetLABEL3_width= VDLABW;
 int COWsetHEIGHT_width= VENTW/2;
 int COWsetHEIGHT_height= VBUTH;
 int COWsetWIDTH_left= VCOL1;
 int COWsetLABEL3_left= VPAD;
 int COWsetSRC_height= VBUTH;
 int COWsetSRC_width= VENTW;
 int COWsetWIDTH_width= VENTW/2;
 int COWsetSRC_top= COWsetLABEL0_top;
 int COWsetWIDTH_height= VBUTH;
 int COWsetSRC_left= VCOL1;
 int COWsetHDR_height= VBUTH;
 int COWsetHDR_width= VENTW;
 int COWsetHDR_left= VCOL1;
 int COWsetHDR_right= COWsetHDR_left+COWsetHDR_width;
 int VCOL2= VCOL1+VENTW+VPAD;
 int COWsetLABEL0_bottom= COWsetLABEL0_top+COWsetLABEL0_height;
 int COWsetLABEL0_right= COWsetLABEL0_left+COWsetLABEL0_width;
 int COWsetSRC_right= COWsetSRC_left+COWsetSRC_width;
 int COWsetOK_right= COWsetOK_left+COWsetOK_width;
 int COWsetLABEL1_top= COWsetLABEL0_bottom+VPAD;
 int COWsetWIDTH_right= COWsetWIDTH_left+COWsetWIDTH_width;
 int COWsetSRC_bottom= COWsetSRC_top+COWsetSRC_height;
 int COWsetLABEL3_right= COWsetLABEL3_left+COWsetLABEL3_width;
 int COWsetLABEL1_right= COWsetLABEL1_left+COWsetLABEL1_width;
 int COWsetSRCbut_left= VCOL2;
 int COWsetSRCbut_right= COWsetSRCbut_left+COWsetSRCbut_width;
 int COWsetHEIGHT_right= COWsetHEIGHT_left+COWsetHEIGHT_width;
 int COWsetSRCbut_top= COWsetSRC_top;
 int COWsetLABEL2_right= COWsetLABEL2_left+COWsetLABEL2_width;
 int COWsetSRCbut_bottom= COWsetSRCbut_top+COWsetSRCbut_height;
 int COWsetCANCEL_left= COWsetOK_right+VPAD;
 int COWsetCANCEL_right= COWsetCANCEL_left+COWsetCANCEL_width;
 int COWsetHDR_top= COWsetLABEL1_top;
 int COWsetHDR_bottom= COWsetHDR_top+COWsetHDR_height;
 int COWsetLABEL1_bottom= COWsetLABEL1_top+COWsetLABEL1_height;
 int COWsetHDRbut_left= COWsetSRCbut_left;
 int COWsetHDRbut_right= COWsetHDRbut_left+COWsetHDRbut_width;
 int COWsetHDRbut_top= COWsetHDR_top;
 int COWsetLABEL2_top= COWsetLABEL1_bottom+VPAD;
 int COWsetHDRbut_bottom= COWsetHDRbut_top+COWsetHDRbut_height;
 int COWsetLABEL2_bottom= COWsetLABEL2_top+COWsetLABEL2_height;
 int COWsetWIDTH_top= COWsetLABEL2_top;
 int COWsetLABEL3_top= COWsetLABEL2_bottom+VPAD;
 int COWsetLABEL3_bottom= COWsetLABEL3_top+COWsetLABEL3_height;
 int COWsetHEIGHT_top= COWsetLABEL3_top;
 int COWsetWIDTH_bottom= COWsetWIDTH_top+COWsetWIDTH_height;
 int COWsetHEIGHT_bottom= COWsetHEIGHT_top+COWsetHEIGHT_height;
 int COWsetOK_top= COWsetHEIGHT_bottom+VPAD;
 int COWsetOK_bottom= COWsetOK_top+COWsetOK_height;
 int COWsetCANCEL_top= COWsetOK_top;
 int COWsetCANCEL_bottom= COWsetCANCEL_top+COWsetCANCEL_height;
  L[0]= COWsetCANCEL_left; L[1]= COWsetCANCEL_top;
  L[2]= COWsetCANCEL_width; L[3]= COWsetCANCEL_height;
  L[4]= COWsetOK_left; L[5]= COWsetOK_top;
  L[6]= COWsetOK_width; L[7]= COWsetOK_height;
  L[8]= COWsetHDRbut_left; L[9]= COWsetHDRbut_top;
  L[10]= COWsetHDRbut_width; L[11]= COWsetHDRbut_height;
  L[12]= COWsetSRCbut_left; L[13]= COWsetSRCbut_top;
  L[14]= COWsetSRCbut_width; L[15]= COWsetSRCbut_height;
  L[16]= COWsetHEIGHT_left; L[17]= COWsetHEIGHT_top;
  L[18]= COWsetHEIGHT_width; L[19]= COWsetHEIGHT_height;
  L[20]= COWsetWIDTH_left; L[21]= COWsetWIDTH_top;
  L[22]= COWsetWIDTH_width; L[23]= COWsetWIDTH_height;
  L[24]= COWsetHDR_left; L[25]= COWsetHDR_top;
  L[26]= COWsetHDR_width; L[27]= COWsetHDR_height;
  L[28]= COWsetSRC_left; L[29]= COWsetSRC_top;
  L[30]= COWsetSRC_width; L[31]= COWsetSRC_height;
  L[32]= COWsetLABEL3_left; L[33]= COWsetLABEL3_top;
  L[34]= COWsetLABEL3_width; L[35]= COWsetLABEL3_height;
  L[36]= COWsetLABEL2_left; L[37]= COWsetLABEL2_top;
  L[38]= COWsetLABEL2_width; L[39]= COWsetLABEL2_height;
  L[40]= COWsetLABEL1_left; L[41]= COWsetLABEL1_top;
  L[42]= COWsetLABEL1_width; L[43]= COWsetLABEL1_height;
  L[44]= COWsetLABEL0_left; L[45]= COWsetLABEL0_top;
  L[46]= COWsetLABEL0_width; L[47]= COWsetLABEL0_height;
  L[48]= COWsetTITLE_left; L[49]= COWsetTITLE_top;
  L[50]= COWsetTITLE_width; L[51]= COWsetTITLE_height;
}
static void LAYOSCR_SCRset(int *L,int WIDTH,int HEIGHT) {
 int COleft= 80;
 int COheight= 240;
 int COwidth= 424;
 int COright= COleft+COwidth;
 int COtop= 80;
 int CObottom= COtop+COheight;
  L[0]= COleft;
  L[1]= COtop;
  L[2]= COwidth;
  L[3]= COheight;
}
void gfx_SCRset(){
 static int SWID[]= {     WsetCANCEL,
    WsetOK,
    WsetHDRbut,
    WsetSRCbut,
    WsetHEIGHT,
    WsetWIDTH,
    WsetHDR,
    WsetSRC,
    WsetLABEL3,
    WsetLABEL2,
    WsetLABEL1,
    WsetLABEL0,
    WsetTITLE,
};
  int i;
  int LC[52]; /*widget coords */
  int LL[4]; /* screen coords */
  LAYOSCR_SCRset(LL,x_window_width,x_window_height);
  enter_screen(13, SWID,LL);
  widgets[WsetCANCEL]= gfx_button("Cancel", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WsetCANCEL]->number= WsetCANCEL;
  widgets[WsetOK]= gfx_button("OK", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WsetOK]->number= WsetOK;
  widgets[WsetHDRbut]= gfx_button("Browse", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WsetHDRbut]->number= WsetHDRbut;
  widgets[WsetSRCbut]= gfx_button("Browse", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WsetSRCbut]->number= WsetSRCbut;
  widgets[WsetHEIGHT]= text_entry_new("");
  widgets[WsetHEIGHT]->number= WsetHEIGHT;
  widgets[WsetWIDTH]= text_entry_new("");
  widgets[WsetWIDTH]->number= WsetWIDTH;
  widgets[WsetHDR]= text_entry_new("");
  widgets[WsetHDR]->number= WsetHDR;
  widgets[WsetSRC]= text_entry_new("");
  widgets[WsetSRC]->number= WsetSRC;
  widgets[WsetLABEL3]= gfx_label(1,0x000000,0xededed,'L',"Work Area Height");
  widgets[WsetLABEL3]->number= WsetLABEL3;
  widgets[WsetLABEL2]= gfx_label(1,0x000000,0xededed,'L',"Work Area Width");
  widgets[WsetLABEL2]->number= WsetLABEL2;
  widgets[WsetLABEL1]= gfx_label(1,0x000000,0xededed,'L',"Header File");
  widgets[WsetLABEL1]->number= WsetLABEL1;
  widgets[WsetLABEL0]= gfx_label(1,0x000000,0xededed,'L',"Source File");
  widgets[WsetLABEL0]->number= WsetLABEL0;
  widgets[WsetTITLE]= gfx_label(3,0x000000,0xcccccc,'C',"Project Settings");
  widgets[WsetTITLE]->number= WsetTITLE;
  LAYOWID_SCRset(LL[2],LL[3],LC);
  for(i=0;i<13;i++) { LC[4*i]+= LL[0]; LC[4*i+1]+= LL[1]; }
  widget_move(widgets[WsetCANCEL], LC[0], LC[1],LC[2],LC[3]);
  widget_move(widgets[WsetOK], LC[4], LC[5],LC[6],LC[7]);
  widget_move(widgets[WsetHDRbut], LC[8], LC[9],LC[10],LC[11]);
  widget_move(widgets[WsetSRCbut], LC[12], LC[13],LC[14],LC[15]);
  widget_move(widgets[WsetHEIGHT], LC[16], LC[17],LC[18],LC[19]);
  widget_move(widgets[WsetWIDTH], LC[20], LC[21],LC[22],LC[23]);
  widget_move(widgets[WsetHDR], LC[24], LC[25],LC[26],LC[27]);
  widget_move(widgets[WsetSRC], LC[28], LC[29],LC[30],LC[31]);
  widget_move(widgets[WsetLABEL3], LC[32], LC[33],LC[34],LC[35]);
  widget_move(widgets[WsetLABEL2], LC[36], LC[37],LC[38],LC[39]);
  widget_move(widgets[WsetLABEL1], LC[40], LC[41],LC[42],LC[43]);
  widget_move(widgets[WsetLABEL0], LC[44], LC[45],LC[46],LC[47]);
  widget_move(widgets[WsetTITLE], LC[48], LC[49],LC[50],LC[51]);
  widget_show(widgets[WsetCANCEL], 1);
  widget_show(widgets[WsetOK], 1);
  widget_show(widgets[WsetHDRbut], 1);
  widget_show(widgets[WsetSRCbut], 1);
  widget_show(widgets[WsetHEIGHT], 1);
  widget_show(widgets[WsetWIDTH], 1);
  widget_show(widgets[WsetHDR], 1);
  widget_show(widgets[WsetSRC], 1);
  widget_show(widgets[WsetLABEL3], 1);
  widget_show(widgets[WsetLABEL2], 1);
  widget_show(widgets[WsetLABEL1], 1);
  widget_show(widgets[WsetLABEL0], 1);
  widget_show(widgets[WsetTITLE], 1);
  gfx_update_all();
}
static void LAYOWID_SCRselscr(int WIDTH,int HEIGHT,int *L) {
 int COWsselTITLE_left= 0;
 int VPAD= 8;
 int VBUTW= 80;
 int VBUTH= 30;
 int COWsselTITLE_height= 50;
 int COWsselTITLE_width= WIDTH;
 int COWsselTITLE_right= COWsselTITLE_left+COWsselTITLE_width;
 int COWsselTITLE_top= 0;
 int COWsselCANCEL_right= WIDTH-VPAD;
 int COWsselTITLE_bottom= COWsselTITLE_top+COWsselTITLE_height;
 int COWsselCANCEL_width= VBUTW;
 int COWsselCANCEL_height= VBUTH;
 int COWsselUSE_width= VBUTW;
 int COWsselLIST_top= COWsselTITLE_bottom+VPAD;
 int COWsselLIST_right= WIDTH-VPAD;
 int COWsselLIST_left= VPAD;
 int COWsselDEL_height= VBUTH;
 int COWsselDEL_width= VBUTW;
 int COWsselDEL_bottom= HEIGHT-VPAD;
 int COWsselDEL_top= COWsselDEL_bottom-COWsselDEL_height;
 int COWsselUSE_height= VBUTH;
 int COWsselDEL_left= VPAD;
 int COWsselNEW_height= VBUTH;
 int COWsselNEW_width= VBUTW;
 int COWsselNEW_top= COWsselDEL_top;
 int COWsselCANCEL_left= COWsselCANCEL_right-COWsselCANCEL_width;
 int COWsselCANCEL_top= COWsselDEL_top;
 int COWsselCANCEL_bottom= COWsselCANCEL_top+COWsselCANCEL_height;
 int COWsselNEW_bottom= COWsselNEW_top+COWsselNEW_height;
 int COWsselDEL_right= COWsselDEL_left+COWsselDEL_width;
 int COWsselLIST_width= COWsselLIST_right-COWsselLIST_left;
 int COWsselUSE_top= COWsselDEL_top;
 int COWsselUSE_right= COWsselCANCEL_left-VPAD;
 int COWsselUSE_left= COWsselUSE_right-COWsselUSE_width;
 int COWsselLIST_bottom= COWsselUSE_top-VPAD;
 int COWsselLIST_height= COWsselLIST_bottom-COWsselLIST_top;
 int COWsselUSE_bottom= COWsselUSE_top+COWsselUSE_height;
 int COWsselNEW_left= COWsselDEL_right+VPAD;
 int COWsselNEW_right= COWsselNEW_left+COWsselNEW_width;
  L[0]= COWsselCANCEL_left; L[1]= COWsselCANCEL_top;
  L[2]= COWsselCANCEL_width; L[3]= COWsselCANCEL_height;
  L[4]= COWsselUSE_left; L[5]= COWsselUSE_top;
  L[6]= COWsselUSE_width; L[7]= COWsselUSE_height;
  L[8]= COWsselNEW_left; L[9]= COWsselNEW_top;
  L[10]= COWsselNEW_width; L[11]= COWsselNEW_height;
  L[12]= COWsselDEL_left; L[13]= COWsselDEL_top;
  L[14]= COWsselDEL_width; L[15]= COWsselDEL_height;
  L[16]= COWsselLIST_left; L[17]= COWsselLIST_top;
  L[18]= COWsselLIST_width; L[19]= COWsselLIST_height;
  L[20]= COWsselTITLE_left; L[21]= COWsselTITLE_top;
  L[22]= COWsselTITLE_width; L[23]= COWsselTITLE_height;
}
static void LAYOSCR_SCRselscr(int *L,int WIDTH,int HEIGHT) {
 int COleft= (WIDTH-400)/2;
 int COheight= 400;
 int COwidth= 400;
 int COright= COleft+COwidth;
 int COtop= (HEIGHT-400)/2;
 int CObottom= COtop+COheight;
  L[0]= COleft;
  L[1]= COtop;
  L[2]= COwidth;
  L[3]= COheight;
}
void gfx_SCRselscr(){
 static int SWID[]= {     WsselCANCEL,
    WsselUSE,
    WsselNEW,
    WsselDEL,
    WsselLIST,
    WsselTITLE,
};
  int i;
  int LC[24]; /*widget coords */
  int LL[4]; /* screen coords */
  LAYOSCR_SCRselscr(LL,x_window_width,x_window_height);
  enter_screen(6, SWID,LL);
  widgets[WsselCANCEL]= gfx_button("Cancel", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WsselCANCEL]->number= WsselCANCEL;
  widgets[WsselUSE]= gfx_button("Use", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WsselUSE]->number= WsselUSE;
  widgets[WsselNEW]= gfx_button("Create", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WsselNEW]->number= WsselNEW;
  widgets[WsselDEL]= gfx_button("Delete", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WsselDEL]->number= WsselDEL;
  widgets[WsselLIST]= gui_list_new(0,0,NULL,NULL,NULL);
  widgets[WsselLIST]->number= WsselLIST;
  widgets[WsselTITLE]= gfx_label(3,0x000000,0xcccccc,'C',"Screen List");
  widgets[WsselTITLE]->number= WsselTITLE;
  LAYOWID_SCRselscr(LL[2],LL[3],LC);
  for(i=0;i<6;i++) { LC[4*i]+= LL[0]; LC[4*i+1]+= LL[1]; }
  widget_move(widgets[WsselCANCEL], LC[0], LC[1],LC[2],LC[3]);
  widget_move(widgets[WsselUSE], LC[4], LC[5],LC[6],LC[7]);
  widget_move(widgets[WsselNEW], LC[8], LC[9],LC[10],LC[11]);
  widget_move(widgets[WsselDEL], LC[12], LC[13],LC[14],LC[15]);
  widget_move(widgets[WsselLIST], LC[16], LC[17],LC[18],LC[19]);
  widget_move(widgets[WsselTITLE], LC[20], LC[21],LC[22],LC[23]);
  widget_show(widgets[WsselCANCEL], 1);
  widget_show(widgets[WsselUSE], 1);
  widget_show(widgets[WsselNEW], 1);
  widget_show(widgets[WsselDEL], 1);
  widget_show(widgets[WsselLIST], 1);
  widget_show(widgets[WsselTITLE], 1);
  gfx_update_all();
}
static void LAYOWID_SCReval(int WIDTH,int HEIGHT,int *L) {
 int COWevTITLE_left= 0;
 int VBUTH= 33;
 int VBUTW= 80;
 int VPAD= 8;
 int COWevTITLE_height= 50;
 int COWevTITLE_width= WIDTH;
 int COWevTITLE_right= COWevTITLE_left+COWevTITLE_width;
 int COWevTITLE_top= 0;
 int COWevOK_left= (WIDTH-VBUTW)/2;
 int COWevTITLE_bottom= COWevTITLE_top+COWevTITLE_height;
 int COWevOK_bottom= HEIGHT-VPAD;
 int COWevOK_width= VBUTW;
 int COWevLIST_bottom= HEIGHT-VPAD-VBUTH-VPAD;
 int COWevLIST_top= COWevTITLE_bottom+VPAD;
 int COWevLIST_right= WIDTH-VPAD;
 int COWevLIST_left= VPAD;
 int COWevOK_height= VBUTH;
 int COWevLIST_height= COWevLIST_bottom-COWevLIST_top;
 int COWevLIST_width= COWevLIST_right-COWevLIST_left;
 int COWevOK_top= COWevOK_bottom-COWevOK_height;
 int COWevOK_right= COWevOK_left+COWevOK_width;
  L[0]= COWevOK_left; L[1]= COWevOK_top;
  L[2]= COWevOK_width; L[3]= COWevOK_height;
  L[4]= COWevLIST_left; L[5]= COWevLIST_top;
  L[6]= COWevLIST_width; L[7]= COWevLIST_height;
  L[8]= COWevTITLE_left; L[9]= COWevTITLE_top;
  L[10]= COWevTITLE_width; L[11]= COWevTITLE_height;
}
static void LAYOSCR_SCReval(int *L,int WIDTH,int HEIGHT) {
 int COleft= (WIDTH-400)/2;
 int COheight= 400;
 int COwidth= 400;
 int COright= COleft+COwidth;
 int COtop= (HEIGHT-400)/2;
 int CObottom= COtop+COheight;
  L[0]= COleft;
  L[1]= COtop;
  L[2]= COwidth;
  L[3]= COheight;
}
void gfx_SCReval(){
 static int SWID[]= {     WevOK,
    WevLIST,
    WevTITLE,
};
  int i;
  int LC[12]; /*widget coords */
  int LL[4]; /* screen coords */
  LAYOSCR_SCReval(LL,x_window_width,x_window_height);
  enter_screen(3, SWID,LL);
  widgets[WevOK]= gfx_button("OK", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WevOK]->number= WevOK;
  widgets[WevLIST]= gui_list_new(0,0,NULL,NULL,NULL);
  widgets[WevLIST]->number= WevLIST;
  widgets[WevTITLE]= gfx_label(3,0x000000,0xcccccc,'C',"Evaluation Results");
  widgets[WevTITLE]->number= WevTITLE;
  LAYOWID_SCReval(LL[2],LL[3],LC);
  for(i=0;i<3;i++) { LC[4*i]+= LL[0]; LC[4*i+1]+= LL[1]; }
  widget_move(widgets[WevOK], LC[0], LC[1],LC[2],LC[3]);
  widget_move(widgets[WevLIST], LC[4], LC[5],LC[6],LC[7]);
  widget_move(widgets[WevTITLE], LC[8], LC[9],LC[10],LC[11]);
  widget_show(widgets[WevOK], 1);
  widget_show(widgets[WevLIST], 1);
  widget_show(widgets[WevTITLE], 1);
  gfx_update_all();
}
static void LAYOWID_SCRwidsel(int WIDTH,int HEIGHT,int *L) {
 int COWwselTITLE_left= 0;
 int COWwselTITLE_top= 0;
 int COWwselTITLE_width= WIDTH;
 int VPAD= 8;
 int VBUTW= 80;
 int VBUTH= 24;
 int VCOL0= VPAD;
 int VCOL1= VCOL0+VPAD+VBUTW;
 int VCOL2= VCOL1+VPAD+VBUTW;
 int VCOL3= VCOL2+VPAD+VBUTW;
 int VROW0= 50+VPAD;
 int COWwselTITLE_height= 50;
 int COWwselSPINNER_left= VPAD;
 int COWwselSPINNER_width= VBUTW;
 int VROW0A= VROW0+VPAD+VBUTH;
 int COWwselSPINNER_height= VBUTH;
 int COWwselLOGVIEW_left= VCOL2;
 int COWwselICONLIST_height= VBUTH;
 int COWwselICONLIST_width= VBUTW;
 int COWwselLOGVIEW_width= VBUTW;
 int COWwselICONLIST_top= VROW0A;
 int COWwselLOGVIEW_height= VBUTH;
 int COWwselICONLIST_left= VCOL1;
 int COWwselPROGRESS_height= VBUTH;
 int COWwselPROGRESS_width= VBUTW;
 int COWwselSLIDER_left= VCOL3;
 int COWwselSLIDER_width= VBUTW;
 int COWwselSLIDER_height= VBUTH;
 int COWwselPROGRESS_left= VCOL1;
 int COWwselFILELIST_height= VBUTH;
 int COWwselFILELIST_width= VBUTW;
 int COWwselFILELIST_left= VCOL0;
 int COWwselFILELIST_top= VROW0A;
 int COWwselFILELIST_right= COWwselFILELIST_left+COWwselFILELIST_width;
 int COWwselCANCEL_left= VCOL3;
 int COWwselFILELIST_bottom= COWwselFILELIST_top+COWwselFILELIST_height;
 int COWwselPROGRESS_right= COWwselPROGRESS_left+COWwselPROGRESS_width;
 int COWwselCANCEL_bottom= HEIGHT-VPAD;
 int COWwselCANCEL_width= VBUTW;
 int COWwselSLIDER_right= COWwselSLIDER_left+COWwselSLIDER_width;
 int COWwselCANCEL_height= VBUTH;
 int COWwselTOGGLE_left= VCOL2;
 int COWwselICONLIST_right= COWwselICONLIST_left+COWwselICONLIST_width;
 int COWwselTOGGLE_width= VBUTW;
 int COWwselTOGGLE_height= VBUTH;
 int COWwselLOGVIEW_right= COWwselLOGVIEW_left+COWwselLOGVIEW_width;
 int COWwselICONLIST_bottom= COWwselICONLIST_top+COWwselICONLIST_height;
 int COWwselTEXTENTRY_left= VCOL1;
 int COWwselTEXTENTRY_width= VBUTW;
 int COWwselTEXTENTRY_height= VBUTH;
 int COWwselSCROLLBAR_left= VCOL2;
 int COWwselSPINNER_right= COWwselSPINNER_left+COWwselSPINNER_width;
 int COWwselSCROLLBAR_width= VBUTW;
 int COWwselSCROLLBAR_height= VBUTH;
 int VROW1= VROW0A+VPAD+VBUTH;
 int COWwselTITLE_bottom= COWwselTITLE_top+COWwselTITLE_height;
 int Vscrwidth= 5*VPAD+4*VBUTW;
 int COWwselTITLE_right= COWwselTITLE_left+COWwselTITLE_width;
 int Vscrheight= 5*VPAD+4*VBUTH+50;
 int COWwselBUTTON_height= VBUTH;
 int COWwselBUTTON_width= VBUTW;
 int COWwselRADIO_left= VCOL1;
 int COWwselBUTTON_top= VROW0;
 int COWwselRADIO_width= VBUTW;
 int COWwselBUTTON_left= VCOL0;
 int COWwselCANVAS_height= VBUTH;
 int COWwselCANVAS_width= VBUTW;
 int COWwselRADIO_height= VBUTH;
 int COWwselCANVAS_top= VROW0;
 int COWwselPIXGRID_left= VCOL0;
 int COWwselCANVAS_left= VCOL1;
 int COWwselCHECKBOX_height= VBUTH;
 int COWwselCHECKBOX_width= VBUTW;
 int COWwselPIXGRID_width= VBUTW;
 int COWwselCHECKBOX_top= VROW0;
 int COWwselPIXGRID_height= VBUTH;
 int COWwselCHECKBOX_left= VCOL2;
 int COWwselDROPDOWN_height= VBUTH;
 int COWwselDROPDOWN_width= VBUTW;
 int COWwselPANEL_left= VCOL3;
 int COWwselDROPDOWN_top= VROW0;
 int COWwselPANEL_top= VROW1;
 int COWwselDROPDOWN_left= VCOL3;
 int COWwselLABEL_height= VBUTH;
 int COWwselLABEL_width= VBUTW;
 int COWwselPANEL_width= VBUTW;
 int COWwselLABEL_top= VROW1;
 int COWwselPANEL_height= VBUTH;
 int COWwselLABEL_left= VCOL0;
 int COWwselLIST_height= VBUTH;
 int COWwselLIST_width= VBUTW;
 int COWwselLIST_left= VCOL1;
 int COWwselLIST_top= VROW1;
 int COWwselLIST_right= COWwselLIST_left+COWwselLIST_width;
 int COWwselCANCEL_right= COWwselCANCEL_left+COWwselCANCEL_width;
 int COWwselLIST_bottom= COWwselLIST_top+COWwselLIST_height;
 int COWwselLABEL_right= COWwselLABEL_left+COWwselLABEL_width;
 int COWwselPANEL_bottom= COWwselPANEL_top+COWwselPANEL_height;
 int COWwselLABEL_bottom= COWwselLABEL_top+COWwselLABEL_height;
 int COWwselPANEL_right= COWwselPANEL_left+COWwselPANEL_width;
 int COWwselDROPDOWN_right= COWwselDROPDOWN_left+COWwselDROPDOWN_width;
 int COWwselDROPDOWN_bottom= COWwselDROPDOWN_top+COWwselDROPDOWN_height;
 int COWwselCHECKBOX_right= COWwselCHECKBOX_left+COWwselCHECKBOX_width;
 int COWwselCANCEL_top= COWwselCANCEL_bottom-COWwselCANCEL_height;
 int COWwselTOGGLE_right= COWwselTOGGLE_left+COWwselTOGGLE_width;
 int COWwselPIXGRID_right= COWwselPIXGRID_left+COWwselPIXGRID_width;
 int COWwselCHECKBOX_bottom= COWwselCHECKBOX_top+COWwselCHECKBOX_height;
 int COWwselCANVAS_right= COWwselCANVAS_left+COWwselCANVAS_width;
 int COWwselCANVAS_bottom= COWwselCANVAS_top+COWwselCANVAS_height;
 int COWwselLOGVIEW_top= VROW1;
 int COWwselTEXTENTRY_right= COWwselTEXTENTRY_left+COWwselTEXTENTRY_width;
 int COWwselRADIO_right= COWwselRADIO_left+COWwselRADIO_width;
 int COWwselBUTTON_right= COWwselBUTTON_left+COWwselBUTTON_width;
 int COWwselBUTTON_bottom= COWwselBUTTON_top+COWwselBUTTON_height;
 int VROW2= VROW1+VPAD+VBUTH;
 int COWwselSCROLLBAR_right= COWwselSCROLLBAR_left+COWwselSCROLLBAR_width;
 int COWwselPIXGRID_top= VROW2;
 int COWwselPROGRESS_top= VROW2;
 int COWwselPROGRESS_bottom= COWwselPROGRESS_top+COWwselPROGRESS_height;
 int COWwselLOGVIEW_bottom= COWwselLOGVIEW_top+COWwselLOGVIEW_height;
 int VROW2A= VROW2+VPAD+VBUTH;
 int COWwselPIXGRID_bottom= COWwselPIXGRID_top+COWwselPIXGRID_height;
 int COWwselSCROLLBAR_top= VROW2A;
 int COWwselSCROLLBAR_bottom= COWwselSCROLLBAR_top+COWwselSCROLLBAR_height;
 int COWwselSLIDER_top= VROW2A;
 int VROW3= VROW2A+VPAD+VBUTH;
 int COWwselRADIO_top= VROW2A;
 int COWwselSPINNER_top= VROW3;
 int COWwselTOGGLE_top= VROW3;
 int COWwselRADIO_bottom= COWwselRADIO_top+COWwselRADIO_height;
 int COWwselSPINNER_bottom= COWwselSPINNER_top+COWwselSPINNER_height;
 int COWwselSLIDER_bottom= COWwselSLIDER_top+COWwselSLIDER_height;
 int COWwselTOGGLE_bottom= COWwselTOGGLE_top+COWwselTOGGLE_height;
 int COWwselTEXTENTRY_top= VROW3;
 int VROW4= VROW3+VPAD+VBUTH;
 int COWwselTEXTENTRY_bottom= COWwselTEXTENTRY_top+COWwselTEXTENTRY_height;
  L[0]= COWwselCANCEL_left; L[1]= COWwselCANCEL_top;
  L[2]= COWwselCANCEL_width; L[3]= COWwselCANCEL_height;
  L[4]= COWwselTOGGLE_left; L[5]= COWwselTOGGLE_top;
  L[6]= COWwselTOGGLE_width; L[7]= COWwselTOGGLE_height;
  L[8]= COWwselTEXTENTRY_left; L[9]= COWwselTEXTENTRY_top;
  L[10]= COWwselTEXTENTRY_width; L[11]= COWwselTEXTENTRY_height;
  L[12]= COWwselSCROLLBAR_left; L[13]= COWwselSCROLLBAR_top;
  L[14]= COWwselSCROLLBAR_width; L[15]= COWwselSCROLLBAR_height;
  L[16]= COWwselRADIO_left; L[17]= COWwselRADIO_top;
  L[18]= COWwselRADIO_width; L[19]= COWwselRADIO_height;
  L[20]= COWwselPIXGRID_left; L[21]= COWwselPIXGRID_top;
  L[22]= COWwselPIXGRID_width; L[23]= COWwselPIXGRID_height;
  L[24]= COWwselPANEL_left; L[25]= COWwselPANEL_top;
  L[26]= COWwselPANEL_width; L[27]= COWwselPANEL_height;
  L[28]= COWwselLIST_left; L[29]= COWwselLIST_top;
  L[30]= COWwselLIST_width; L[31]= COWwselLIST_height;
  L[32]= COWwselLABEL_left; L[33]= COWwselLABEL_top;
  L[34]= COWwselLABEL_width; L[35]= COWwselLABEL_height;
  L[36]= COWwselDROPDOWN_left; L[37]= COWwselDROPDOWN_top;
  L[38]= COWwselDROPDOWN_width; L[39]= COWwselDROPDOWN_height;
  L[40]= COWwselCHECKBOX_left; L[41]= COWwselCHECKBOX_top;
  L[42]= COWwselCHECKBOX_width; L[43]= COWwselCHECKBOX_height;
  L[44]= COWwselCANVAS_left; L[45]= COWwselCANVAS_top;
  L[46]= COWwselCANVAS_width; L[47]= COWwselCANVAS_height;
  L[48]= COWwselBUTTON_left; L[49]= COWwselBUTTON_top;
  L[50]= COWwselBUTTON_width; L[51]= COWwselBUTTON_height;
  L[52]= COWwselTITLE_left; L[53]= COWwselTITLE_top;
  L[54]= COWwselTITLE_width; L[55]= COWwselTITLE_height;
  L[56]= COWwselSPINNER_left; L[57]= COWwselSPINNER_top;
  L[58]= COWwselSPINNER_width; L[59]= COWwselSPINNER_height;
  L[60]= COWwselLOGVIEW_left; L[61]= COWwselLOGVIEW_top;
  L[62]= COWwselLOGVIEW_width; L[63]= COWwselLOGVIEW_height;
  L[64]= COWwselSLIDER_left; L[65]= COWwselSLIDER_top;
  L[66]= COWwselSLIDER_width; L[67]= COWwselSLIDER_height;
  L[68]= COWwselFILELIST_left; L[69]= COWwselFILELIST_top;
  L[70]= COWwselFILELIST_width; L[71]= COWwselFILELIST_height;
  L[72]= COWwselPROGRESS_left; L[73]= COWwselPROGRESS_top;
  L[74]= COWwselPROGRESS_width; L[75]= COWwselPROGRESS_height;
  L[76]= COWwselICONLIST_left; L[77]= COWwselICONLIST_top;
  L[78]= COWwselICONLIST_width; L[79]= COWwselICONLIST_height;
}
static void LAYOSCR_SCRwidsel(int *L,int WIDTH,int HEIGHT) {
 int COleft= (WIDTH-370)/2;
 int COheight= 420;
 int COwidth= 370;
 int COright= COleft+COwidth;
 int COtop= (HEIGHT-420)/2;
 int CObottom= COtop+COheight;
  L[0]= COleft;
  L[1]= COtop;
  L[2]= COwidth;
  L[3]= COheight;
}
void gfx_SCRwidsel(){
 static int SWID[]= {     WwselCANCEL,
    WwselTOGGLE,
    WwselTEXTENTRY,
    WwselSCROLLBAR,
    WwselRADIO,
    WwselPIXGRID,
    WwselPANEL,
    WwselLIST,
    WwselLABEL,
    WwselDROPDOWN,
    WwselCHECKBOX,
    WwselCANVAS,
    WwselBUTTON,
    WwselTITLE,
    WwselSPINNER,
    WwselLOGVIEW,
    WwselSLIDER,
    WwselFILELIST,
    WwselPROGRESS,
    WwselICONLIST,
};
  int i;
  int LC[80]; /*widget coords */
  int LL[4]; /* screen coords */
  LAYOSCR_SCRwidsel(LL,x_window_width,x_window_height);
  enter_screen(20, SWID,LL);
  widgets[WwselCANCEL]= gfx_button("Cancel", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WwselCANCEL]->number= WwselCANCEL;
  widgets[WwselTOGGLE]= gfx_button("Toggle", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WwselTOGGLE]->number= WwselTOGGLE;
  widgets[WwselTEXTENTRY]= gfx_button("TextEntry", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WwselTEXTENTRY]->number= WwselTEXTENTRY;
  widgets[WwselSCROLLBAR]= gfx_button("ScrollBar", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WwselSCROLLBAR]->number= WwselSCROLLBAR;
  widgets[WwselRADIO]= gfx_button("Radio", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WwselRADIO]->number= WwselRADIO;
  widgets[WwselPIXGRID]= gfx_button("PixGrid", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WwselPIXGRID]->number= WwselPIXGRID;
  widgets[WwselPANEL]= gfx_button("Panel", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WwselPANEL]->number= WwselPANEL;
  widgets[WwselLIST]= gfx_button("List", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WwselLIST]->number= WwselLIST;
  widgets[WwselLABEL]= gfx_button("Label", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WwselLABEL]->number= WwselLABEL;
  widgets[WwselDROPDOWN]= gfx_button("DropDown", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WwselDROPDOWN]->number= WwselDROPDOWN;
  widgets[WwselCHECKBOX]= gfx_button("CheckBox", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WwselCHECKBOX]->number= WwselCHECKBOX;
  widgets[WwselCANVAS]= gfx_button("Canvas", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WwselCANVAS]->number= WwselCANVAS;
  widgets[WwselBUTTON]= gfx_button("Button", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WwselBUTTON]->number= WwselBUTTON;
  widgets[WwselTITLE]= gfx_label(3,0x000000,0xcccccc,'C',"Select Widget Class");
  widgets[WwselTITLE]->number= WwselTITLE;
  widgets[WwselSPINNER]= gfx_button("Spinner", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WwselSPINNER]->number= WwselSPINNER;
  widgets[WwselLOGVIEW]= gfx_button("LogView", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WwselLOGVIEW]->number= WwselLOGVIEW;
  widgets[WwselSLIDER]= gfx_button("Slider", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WwselSLIDER]->number= WwselSLIDER;
  widgets[WwselFILELIST]= gfx_button("FileList", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WwselFILELIST]->number= WwselFILELIST;
  widgets[WwselPROGRESS]= gfx_button("ProgressBar", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WwselPROGRESS]->number= WwselPROGRESS;
  widgets[WwselICONLIST]= gfx_button("IconList", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WwselICONLIST]->number= WwselICONLIST;
  LAYOWID_SCRwidsel(LL[2],LL[3],LC);
  for(i=0;i<20;i++) { LC[4*i]+= LL[0]; LC[4*i+1]+= LL[1]; }
  widget_move(widgets[WwselCANCEL], LC[0], LC[1],LC[2],LC[3]);
  widget_move(widgets[WwselTOGGLE], LC[4], LC[5],LC[6],LC[7]);
  widget_move(widgets[WwselTEXTENTRY], LC[8], LC[9],LC[10],LC[11]);
  widget_move(widgets[WwselSCROLLBAR], LC[12], LC[13],LC[14],LC[15]);
  widget_move(widgets[WwselRADIO], LC[16], LC[17],LC[18],LC[19]);
  widget_move(widgets[WwselPIXGRID], LC[20], LC[21],LC[22],LC[23]);
  widget_move(widgets[WwselPANEL], LC[24], LC[25],LC[26],LC[27]);
  widget_move(widgets[WwselLIST], LC[28], LC[29],LC[30],LC[31]);
  widget_move(widgets[WwselLABEL], LC[32], LC[33],LC[34],LC[35]);
  widget_move(widgets[WwselDROPDOWN], LC[36], LC[37],LC[38],LC[39]);
  widget_move(widgets[WwselCHECKBOX], LC[40], LC[41],LC[42],LC[43]);
  widget_move(widgets[WwselCANVAS], LC[44], LC[45],LC[46],LC[47]);
  widget_move(widgets[WwselBUTTON], LC[48], LC[49],LC[50],LC[51]);
  widget_move(widgets[WwselTITLE], LC[52], LC[53],LC[54],LC[55]);
  widget_move(widgets[WwselSPINNER], LC[56], LC[57],LC[58],LC[59]);
  widget_move(widgets[WwselLOGVIEW], LC[60], LC[61],LC[62],LC[63]);
  widget_move(widgets[WwselSLIDER], LC[64], LC[65],LC[66],LC[67]);
  widget_move(widgets[WwselFILELIST], LC[68], LC[69],LC[70],LC[71]);
  widget_move(widgets[WwselPROGRESS], LC[72], LC[73],LC[74],LC[75]);
  widget_move(widgets[WwselICONLIST], LC[76], LC[77],LC[78],LC[79]);
  widget_show(widgets[WwselCANCEL], 1);
  widget_show(widgets[WwselTOGGLE], 1);
  widget_show(widgets[WwselTEXTENTRY], 1);
  widget_show(widgets[WwselSCROLLBAR], 1);
  widget_show(widgets[WwselRADIO], 1);
  widget_show(widgets[WwselPIXGRID], 1);
  widget_show(widgets[WwselPANEL], 1);
  widget_show(widgets[WwselLIST], 1);
  widget_show(widgets[WwselLABEL], 1);
  widget_show(widgets[WwselDROPDOWN], 1);
  widget_show(widgets[WwselCHECKBOX], 1);
  widget_show(widgets[WwselCANVAS], 1);
  widget_show(widgets[WwselBUTTON], 1);
  widget_show(widgets[WwselTITLE], 1);
  widget_show(widgets[WwselSPINNER], 1);
  widget_show(widgets[WwselLOGVIEW], 1);
  widget_show(widgets[WwselSLIDER], 1);
  widget_show(widgets[WwselFILELIST], 1);
  widget_show(widgets[WwselPROGRESS], 1);
  widget_show(widgets[WwselICONLIST], 1);
  gfx_update_all();
}
static void LAYOWID_SCRwidpos(int WIDTH,int HEIGHT,int *L) {
 int COWwpeMESSAGE_left= 0;
 int VPAD= 8;
 int VWwpeLABw= 60;
 int VWwpeLABh= 24;
 int VWwpeTXEleft= VPAD+VWwpeLABw+VPAD;
 int COWwpeMESSAGE_width= WIDTH;
 int VWwpeBUTh= 24;
 int VWwpeBUTw= 60;
 int COWwpeMESSAGE_height= VWwpeLABh;
 int COWwpeLAB0_height= VWwpeLABh;
 int COWwpeLAB0_width= VWwpeLABw;
 int COWwpeCANCEL_width= VWwpeBUTw;
 int COWwpeCANCEL_height= VWwpeBUTh;
 int COWwpeOK_width= VWwpeBUTw;
 int COWwpeLAB0_left= VPAD;
 int COWwpeLAB1_height= VWwpeLABh;
 int COWwpeLAB1_width= VWwpeLABw;
 int COWwpeOK_height= VWwpeBUTh;
 int COWwpeWIDTHvb_width= VWwpeBUTw;
 int COWwpeWIDTHvb_height= VWwpeBUTh;
 int COWwpeLAB1_left= VPAD;
 int COWwpeLAB2_height= VWwpeLABh;
 int COWwpeLAB2_width= VWwpeLABw;
 int COWwpeRIGHTvb_width= VWwpeBUTw;
 int COWwpeRIGHTvb_height= VWwpeBUTh;
 int COWwpeLEFTvb_width= VWwpeBUTw;
 int COWwpeLAB2_left= VPAD;
 int COWwpeLAB3_height= VWwpeLABh;
 int COWwpeLAB3_width= VWwpeLABw;
 int COWwpeLEFTvb_height= VWwpeBUTh;
 int COWwpeHEIGHTvb_width= VWwpeBUTw;
 int COWwpeHEIGHTvb_height= VWwpeBUTh;
 int COWwpeLAB3_left= VPAD;
 int COWwpeLAB4_height= VWwpeLABh;
 int COWwpeLAB4_width= VWwpeLABw;
 int COWwpeBOTTOMvb_width= VWwpeBUTw;
 int COWwpeBOTTOMvb_height= VWwpeBUTh;
 int COWwpeTOPvb_width= VWwpeBUTw;
 int COWwpeLAB4_left= VPAD;
 int COWwpeLAB5_height= VWwpeBUTh;
 int COWwpeLAB5_width= VWwpeLABw;
 int COWwpeTOPvb_height= VWwpeBUTh;
 int COWwpeWIDTH_left= VWwpeTXEleft;
 int COWwpeWIDTH_height= VWwpeLABh;
 int COWwpeLAB5_left= VPAD;
 int COWwpeLAB6_height= VWwpeLABh;
 int COWwpeLAB6_width= VWwpeLABw;
 int COWwpeRIGHT_left= VWwpeTXEleft;
 int COWwpeRIGHT_height= VWwpeLABh;
 int COWwpeLEFT_left= VWwpeTXEleft;
 int COWwpeLAB6_left= VPAD;
 int COWwpeTITLE_height= 50;
 int COWwpeTITLE_width= WIDTH;
 int COWwpeLEFT_height= VWwpeLABh;
 int COWwpeTITLE_top= 0;
 int COWwpeHEIGHT_left= VWwpeTXEleft;
 int COWwpeTITLE_left= 0;
 int COWwpeIDENT_height= VWwpeLABh;
 int COWwpeHEIGHT_height= VWwpeLABh;
 int COWwpeBOTTOM_left= VWwpeTXEleft;
 int COWwpeBOTTOM_height= VWwpeLABh;
 int COWwpeTOP_left= VWwpeTXEleft;
 int COWwpeIDENT_left= VWwpeTXEleft;
 int COWwpeTOP_height= VWwpeLABh;
 int VWwpeVBUleft= WIDTH-VPAD-VWwpeBUTw;
 int COWwpeMESSAGE_right= COWwpeMESSAGE_left+COWwpeMESSAGE_width;
 int VWwpeTXEw= VWwpeVBUleft-VPAD-VWwpeTXEleft;
 int COWwpeLAB0_right= COWwpeLAB0_left+COWwpeLAB0_width;
 int COWwpeTOP_width= VWwpeTXEw;
 int COWwpeWIDTHvb_left= VWwpeVBUleft;
 int COWwpeBOTTOM_width= VWwpeTXEw;
 int COWwpeWIDTHvb_right= COWwpeWIDTHvb_left+COWwpeWIDTHvb_width;
 int COWwpeLAB1_right= COWwpeLAB1_left+COWwpeLAB1_width;
 int COWwpeBOTTOM_right= COWwpeBOTTOM_left+COWwpeBOTTOM_width;
 int COWwpeRIGHTvb_left= VWwpeVBUleft;
 int COWwpeRIGHTvb_right= COWwpeRIGHTvb_left+COWwpeRIGHTvb_width;
 int COWwpeHEIGHT_width= VWwpeTXEw;
 int COWwpeLAB2_right= COWwpeLAB2_left+COWwpeLAB2_width;
 int COWwpeLEFTvb_left= VWwpeVBUleft;
 int COWwpeHEIGHT_right= COWwpeHEIGHT_left+COWwpeHEIGHT_width;
 int COWwpeIDENT_width= VWwpeTXEw;
 int COWwpeTITLE_right= COWwpeTITLE_left+COWwpeTITLE_width;
 int COWwpeLEFT_width= VWwpeTXEw;
 int COWwpeLEFTvb_right= COWwpeLEFTvb_left+COWwpeLEFTvb_width;
 int COWwpeHEIGHTvb_left= VWwpeVBUleft;
 int COWwpeLEFT_right= COWwpeLEFT_left+COWwpeLEFT_width;
 int COWwpeTITLE_bottom= COWwpeTITLE_top+COWwpeTITLE_height;
 int COWwpeLAB6_right= COWwpeLAB6_left+COWwpeLAB6_width;
 int COWwpeRIGHT_width= VWwpeTXEw;
 int COWwpeHEIGHTvb_right= COWwpeHEIGHTvb_left+COWwpeHEIGHTvb_width;
 int COWwpeLAB3_right= COWwpeLAB3_left+COWwpeLAB3_width;
 int COWwpeRIGHT_right= COWwpeRIGHT_left+COWwpeRIGHT_width;
 int COWwpeBOTTOMvb_left= VWwpeVBUleft;
 int COWwpeBOTTOMvb_right= COWwpeBOTTOMvb_left+COWwpeBOTTOMvb_width;
 int COWwpeWIDTH_width= VWwpeTXEw;
 int COWwpeLAB4_right= COWwpeLAB4_left+COWwpeLAB4_width;
 int COWwpeTOPvb_left= VWwpeVBUleft;
 int COWwpeWIDTH_right= COWwpeWIDTH_left+COWwpeWIDTH_width;
 int COWwpeLAB5_right= COWwpeLAB5_left+COWwpeLAB5_width;
 int COWwpeTOPvb_right= COWwpeTOPvb_left+COWwpeTOPvb_width;
 int COWwpeTOP_right= COWwpeTOP_left+COWwpeTOP_width;
 int COWwpeLAB0_top= COWwpeTITLE_bottom+VPAD;
 int COWwpeIDENT_right= COWwpeIDENT_left+COWwpeIDENT_width;
 int COWwpeOK_left= COWwpeLAB6_left+(COWwpeTOPvb_right-COWwpeLAB1_left-2*VWwpeBUTw-VPAD)/2;
 int COWwpeOK_right= COWwpeOK_left+COWwpeOK_width;
 int COWwpeIDENT_top= COWwpeLAB0_top;
 int COWwpeIDENT_bottom= COWwpeIDENT_top+COWwpeIDENT_height;
 int COWwpeLAB0_bottom= COWwpeLAB0_top+COWwpeLAB0_height;
 int COWwpeCANCEL_left= COWwpeOK_right+VPAD;
 int COWwpeCANCEL_right= COWwpeCANCEL_left+COWwpeCANCEL_width;
 int COWwpeLAB1_top= COWwpeLAB0_bottom+VPAD;
 int COWwpeTOP_top= COWwpeLAB1_top;
 int COWwpeTOPvb_top= COWwpeTOP_top;
 int COWwpeLAB1_bottom= COWwpeLAB1_top+COWwpeLAB1_height;
 int COWwpeLAB2_top= COWwpeLAB1_bottom+VPAD;
 int COWwpeTOP_bottom= COWwpeTOP_top+COWwpeTOP_height;
 int COWwpeTOPvb_bottom= COWwpeTOPvb_top+COWwpeTOPvb_height;
 int COWwpeBOTTOM_top= COWwpeLAB2_top;
 int COWwpeLAB2_bottom= COWwpeLAB2_top+COWwpeLAB2_height;
 int COWwpeBOTTOMvb_top= COWwpeBOTTOM_top;
 int COWwpeLAB5_top= COWwpeLAB2_bottom+VPAD;
 int COWwpeBOTTOM_bottom= COWwpeBOTTOM_top+COWwpeBOTTOM_height;
 int COWwpeBOTTOMvb_bottom= COWwpeBOTTOMvb_top+COWwpeBOTTOMvb_height;
 int COWwpeHEIGHT_top= COWwpeLAB5_top;
 int COWwpeHEIGHT_bottom= COWwpeHEIGHT_top+COWwpeHEIGHT_height;
 int COWwpeLAB5_bottom= COWwpeLAB5_top+COWwpeLAB5_height;
 int COWwpeHEIGHTvb_top= COWwpeHEIGHT_top;
 int COWwpeLAB3_top= COWwpeLAB5_bottom+VPAD;
 int COWwpeHEIGHTvb_bottom= COWwpeHEIGHTvb_top+COWwpeHEIGHTvb_height;
 int COWwpeLEFT_top= COWwpeLAB3_top;
 int COWwpeLEFT_bottom= COWwpeLEFT_top+COWwpeLEFT_height;
 int COWwpeLAB3_bottom= COWwpeLAB3_top+COWwpeLAB3_height;
 int COWwpeLEFTvb_top= COWwpeLEFT_top;
 int COWwpeLEFTvb_bottom= COWwpeLEFTvb_top+COWwpeLEFTvb_height;
 int COWwpeLAB4_top= COWwpeLAB3_bottom+VPAD;
 int COWwpeLAB4_bottom= COWwpeLAB4_top+COWwpeLAB4_height;
 int COWwpeLAB6_top= COWwpeLAB4_bottom+VPAD;
 int COWwpeRIGHT_top= COWwpeLAB4_top;
 int COWwpeLAB6_bottom= COWwpeLAB6_top+COWwpeLAB6_height;
 int COWwpeWIDTH_top= COWwpeLAB6_top;
 int COWwpeRIGHTvb_top= COWwpeRIGHT_top;
 int COWwpeRIGHT_bottom= COWwpeRIGHT_top+COWwpeRIGHT_height;
 int COWwpeWIDTHvb_top= COWwpeWIDTH_top;
 int COWwpeWIDTH_bottom= COWwpeWIDTH_top+COWwpeWIDTH_height;
 int COWwpeRIGHTvb_bottom= COWwpeRIGHTvb_top+COWwpeRIGHTvb_height;
 int COWwpeWIDTHvb_bottom= COWwpeWIDTHvb_top+COWwpeWIDTHvb_height;
 int COWwpeMESSAGE_top= COWwpeWIDTH_bottom+VPAD;
 int COWwpeMESSAGE_bottom= COWwpeMESSAGE_top+COWwpeMESSAGE_height;
 int COWwpeOK_top= COWwpeMESSAGE_bottom+VPAD;
 int COWwpeCANCEL_top= COWwpeOK_top;
 int COWwpeCANCEL_bottom= COWwpeCANCEL_top+COWwpeCANCEL_height;
 int COWwpeOK_bottom= COWwpeOK_top+COWwpeOK_height;
  L[0]= COWwpeMESSAGE_left; L[1]= COWwpeMESSAGE_top;
  L[2]= COWwpeMESSAGE_width; L[3]= COWwpeMESSAGE_height;
  L[4]= COWwpeCANCEL_left; L[5]= COWwpeCANCEL_top;
  L[6]= COWwpeCANCEL_width; L[7]= COWwpeCANCEL_height;
  L[8]= COWwpeOK_left; L[9]= COWwpeOK_top;
  L[10]= COWwpeOK_width; L[11]= COWwpeOK_height;
  L[12]= COWwpeWIDTHvb_left; L[13]= COWwpeWIDTHvb_top;
  L[14]= COWwpeWIDTHvb_width; L[15]= COWwpeWIDTHvb_height;
  L[16]= COWwpeRIGHTvb_left; L[17]= COWwpeRIGHTvb_top;
  L[18]= COWwpeRIGHTvb_width; L[19]= COWwpeRIGHTvb_height;
  L[20]= COWwpeLEFTvb_left; L[21]= COWwpeLEFTvb_top;
  L[22]= COWwpeLEFTvb_width; L[23]= COWwpeLEFTvb_height;
  L[24]= COWwpeHEIGHTvb_left; L[25]= COWwpeHEIGHTvb_top;
  L[26]= COWwpeHEIGHTvb_width; L[27]= COWwpeHEIGHTvb_height;
  L[28]= COWwpeBOTTOMvb_left; L[29]= COWwpeBOTTOMvb_top;
  L[30]= COWwpeBOTTOMvb_width; L[31]= COWwpeBOTTOMvb_height;
  L[32]= COWwpeTOPvb_left; L[33]= COWwpeTOPvb_top;
  L[34]= COWwpeTOPvb_width; L[35]= COWwpeTOPvb_height;
  L[36]= COWwpeWIDTH_left; L[37]= COWwpeWIDTH_top;
  L[38]= COWwpeWIDTH_width; L[39]= COWwpeWIDTH_height;
  L[40]= COWwpeRIGHT_left; L[41]= COWwpeRIGHT_top;
  L[42]= COWwpeRIGHT_width; L[43]= COWwpeRIGHT_height;
  L[44]= COWwpeLEFT_left; L[45]= COWwpeLEFT_top;
  L[46]= COWwpeLEFT_width; L[47]= COWwpeLEFT_height;
  L[48]= COWwpeHEIGHT_left; L[49]= COWwpeHEIGHT_top;
  L[50]= COWwpeHEIGHT_width; L[51]= COWwpeHEIGHT_height;
  L[52]= COWwpeBOTTOM_left; L[53]= COWwpeBOTTOM_top;
  L[54]= COWwpeBOTTOM_width; L[55]= COWwpeBOTTOM_height;
  L[56]= COWwpeTOP_left; L[57]= COWwpeTOP_top;
  L[58]= COWwpeTOP_width; L[59]= COWwpeTOP_height;
  L[60]= COWwpeIDENT_left; L[61]= COWwpeIDENT_top;
  L[62]= COWwpeIDENT_width; L[63]= COWwpeIDENT_height;
  L[64]= COWwpeTITLE_left; L[65]= COWwpeTITLE_top;
  L[66]= COWwpeTITLE_width; L[67]= COWwpeTITLE_height;
  L[68]= COWwpeLAB6_left; L[69]= COWwpeLAB6_top;
  L[70]= COWwpeLAB6_width; L[71]= COWwpeLAB6_height;
  L[72]= COWwpeLAB5_left; L[73]= COWwpeLAB5_top;
  L[74]= COWwpeLAB5_width; L[75]= COWwpeLAB5_height;
  L[76]= COWwpeLAB4_left; L[77]= COWwpeLAB4_top;
  L[78]= COWwpeLAB4_width; L[79]= COWwpeLAB4_height;
  L[80]= COWwpeLAB3_left; L[81]= COWwpeLAB3_top;
  L[82]= COWwpeLAB3_width; L[83]= COWwpeLAB3_height;
  L[84]= COWwpeLAB2_left; L[85]= COWwpeLAB2_top;
  L[86]= COWwpeLAB2_width; L[87]= COWwpeLAB2_height;
  L[88]= COWwpeLAB1_left; L[89]= COWwpeLAB1_top;
  L[90]= COWwpeLAB1_width; L[91]= COWwpeLAB1_height;
  L[92]= COWwpeLAB0_left; L[93]= COWwpeLAB0_top;
  L[94]= COWwpeLAB0_width; L[95]= COWwpeLAB0_height;
}
static void LAYOSCR_SCRwidpos(int *L,int WIDTH,int HEIGHT) {
 int COleft= (WIDTH-380)/2;
 int COheight= 362;
 int COwidth= 380;
 int COright= COleft+COwidth;
 int COtop= (HEIGHT-362)/2;
 int CObottom= COtop+COheight;
  L[0]= COleft;
  L[1]= COtop;
  L[2]= COwidth;
  L[3]= COheight;
}
void gfx_SCRwidpos(){
 static int SWID[]= {     WwpeMESSAGE,
    WwpeCANCEL,
    WwpeOK,
    WwpeWIDTHvb,
    WwpeRIGHTvb,
    WwpeLEFTvb,
    WwpeHEIGHTvb,
    WwpeBOTTOMvb,
    WwpeTOPvb,
    WwpeWIDTH,
    WwpeRIGHT,
    WwpeLEFT,
    WwpeHEIGHT,
    WwpeBOTTOM,
    WwpeTOP,
    WwpeIDENT,
    WwpeTITLE,
    WwpeLAB6,
    WwpeLAB5,
    WwpeLAB4,
    WwpeLAB3,
    WwpeLAB2,
    WwpeLAB1,
    WwpeLAB0,
};
  int i;
  int LC[96]; /*widget coords */
  int LL[4]; /* screen coords */
  LAYOSCR_SCRwidpos(LL,x_window_width,x_window_height);
  enter_screen(24, SWID,LL);
  widgets[WwpeMESSAGE]= gfx_label(1,0x000000,0xededed,'C',"");
  widgets[WwpeMESSAGE]->number= WwpeMESSAGE;
  widgets[WwpeCANCEL]= gfx_button("Cancel", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WwpeCANCEL]->number= WwpeCANCEL;
  widgets[WwpeOK]= gfx_button("OK", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WwpeOK]->number= WwpeOK;
  widgets[WwpeWIDTHvb]= gfx_button("Var", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WwpeWIDTHvb]->number= WwpeWIDTHvb;
  widgets[WwpeRIGHTvb]= gfx_button("Var", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WwpeRIGHTvb]->number= WwpeRIGHTvb;
  widgets[WwpeLEFTvb]= gfx_button("Var", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WwpeLEFTvb]->number= WwpeLEFTvb;
  widgets[WwpeHEIGHTvb]= gfx_button("Var", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WwpeHEIGHTvb]->number= WwpeHEIGHTvb;
  widgets[WwpeBOTTOMvb]= gfx_button("Var", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WwpeBOTTOMvb]->number= WwpeBOTTOMvb;
  widgets[WwpeTOPvb]= gfx_button("Var", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WwpeTOPvb]->number= WwpeTOPvb;
  widgets[WwpeWIDTH]= text_entry_new("");
  widgets[WwpeWIDTH]->number= WwpeWIDTH;
  widgets[WwpeRIGHT]= text_entry_new("");
  widgets[WwpeRIGHT]->number= WwpeRIGHT;
  widgets[WwpeLEFT]= text_entry_new("");
  widgets[WwpeLEFT]->number= WwpeLEFT;
  widgets[WwpeHEIGHT]= text_entry_new("");
  widgets[WwpeHEIGHT]->number= WwpeHEIGHT;
  widgets[WwpeBOTTOM]= text_entry_new("");
  widgets[WwpeBOTTOM]->number= WwpeBOTTOM;
  widgets[WwpeTOP]= text_entry_new("");
  widgets[WwpeTOP]->number= WwpeTOP;
  widgets[WwpeIDENT]= text_entry_new("");
  widgets[WwpeIDENT]->number= WwpeIDENT;
  widgets[WwpeTITLE]= gfx_label(3,0x000000,0xcccccc,'C',"Edit Widget Position");
  widgets[WwpeTITLE]->number= WwpeTITLE;
  widgets[WwpeLAB6]= gfx_label(1,0x000000,0xededed,'L',"Width");
  widgets[WwpeLAB6]->number= WwpeLAB6;
  widgets[WwpeLAB5]= gfx_label(1,0x000000,0xededed,'L',"Height");
  widgets[WwpeLAB5]->number= WwpeLAB5;
  widgets[WwpeLAB4]= gfx_label(1,0x000000,0xededed,'L',"Right");
  widgets[WwpeLAB4]->number= WwpeLAB4;
  widgets[WwpeLAB3]= gfx_label(1,0x000000,0xededed,'L',"Left");
  widgets[WwpeLAB3]->number= WwpeLAB3;
  widgets[WwpeLAB2]= gfx_label(1,0x000000,0xededed,'L',"Bottom");
  widgets[WwpeLAB2]->number= WwpeLAB2;
  widgets[WwpeLAB1]= gfx_label(1,0x000000,0xededed,'L',"Top");
  widgets[WwpeLAB1]->number= WwpeLAB1;
  widgets[WwpeLAB0]= gfx_label(1,0x000000,0xededed,'L',"Ident");
  widgets[WwpeLAB0]->number= WwpeLAB0;
  LAYOWID_SCRwidpos(LL[2],LL[3],LC);
  for(i=0;i<24;i++) { LC[4*i]+= LL[0]; LC[4*i+1]+= LL[1]; }
  widget_move(widgets[WwpeMESSAGE], LC[0], LC[1],LC[2],LC[3]);
  widget_move(widgets[WwpeCANCEL], LC[4], LC[5],LC[6],LC[7]);
  widget_move(widgets[WwpeOK], LC[8], LC[9],LC[10],LC[11]);
  widget_move(widgets[WwpeWIDTHvb], LC[12], LC[13],LC[14],LC[15]);
  widget_move(widgets[WwpeRIGHTvb], LC[16], LC[17],LC[18],LC[19]);
  widget_move(widgets[WwpeLEFTvb], LC[20], LC[21],LC[22],LC[23]);
  widget_move(widgets[WwpeHEIGHTvb], LC[24], LC[25],LC[26],LC[27]);
  widget_move(widgets[WwpeBOTTOMvb], LC[28], LC[29],LC[30],LC[31]);
  widget_move(widgets[WwpeTOPvb], LC[32], LC[33],LC[34],LC[35]);
  widget_move(widgets[WwpeWIDTH], LC[36], LC[37],LC[38],LC[39]);
  widget_move(widgets[WwpeRIGHT], LC[40], LC[41],LC[42],LC[43]);
  widget_move(widgets[WwpeLEFT], LC[44], LC[45],LC[46],LC[47]);
  widget_move(widgets[WwpeHEIGHT], LC[48], LC[49],LC[50],LC[51]);
  widget_move(widgets[WwpeBOTTOM], LC[52], LC[53],LC[54],LC[55]);
  widget_move(widgets[WwpeTOP], LC[56], LC[57],LC[58],LC[59]);
  widget_move(widgets[WwpeIDENT], LC[60], LC[61],LC[62],LC[63]);
  widget_move(widgets[WwpeTITLE], LC[64], LC[65],LC[66],LC[67]);
  widget_move(widgets[WwpeLAB6], LC[68], LC[69],LC[70],LC[71]);
  widget_move(widgets[WwpeLAB5], LC[72], LC[73],LC[74],LC[75]);
  widget_move(widgets[WwpeLAB4], LC[76], LC[77],LC[78],LC[79]);
  widget_move(widgets[WwpeLAB3], LC[80], LC[81],LC[82],LC[83]);
  widget_move(widgets[WwpeLAB2], LC[84], LC[85],LC[86],LC[87]);
  widget_move(widgets[WwpeLAB1], LC[88], LC[89],LC[90],LC[91]);
  widget_move(widgets[WwpeLAB0], LC[92], LC[93],LC[94],LC[95]);
  widget_show(widgets[WwpeMESSAGE], 1);
  widget_show(widgets[WwpeCANCEL], 1);
  widget_show(widgets[WwpeOK], 1);
  widget_show(widgets[WwpeWIDTHvb], 1);
  widget_show(widgets[WwpeRIGHTvb], 1);
  widget_show(widgets[WwpeLEFTvb], 1);
  widget_show(widgets[WwpeHEIGHTvb], 1);
  widget_show(widgets[WwpeBOTTOMvb], 1);
  widget_show(widgets[WwpeTOPvb], 1);
  widget_show(widgets[WwpeWIDTH], 1);
  widget_show(widgets[WwpeRIGHT], 1);
  widget_show(widgets[WwpeLEFT], 1);
  widget_show(widgets[WwpeHEIGHT], 1);
  widget_show(widgets[WwpeBOTTOM], 1);
  widget_show(widgets[WwpeTOP], 1);
  widget_show(widgets[WwpeIDENT], 1);
  widget_show(widgets[WwpeTITLE], 1);
  widget_show(widgets[WwpeLAB6], 1);
  widget_show(widgets[WwpeLAB5], 1);
  widget_show(widgets[WwpeLAB4], 1);
  widget_show(widgets[WwpeLAB3], 1);
  widget_show(widgets[WwpeLAB2], 1);
  widget_show(widgets[WwpeLAB1], 1);
  widget_show(widgets[WwpeLAB0], 1);
  gfx_update_all();
}
static void LAYOWID_SCREEN_0(int WIDTH,int HEIGHT,int *L) {
 int COWsta_bottom= HEIGHT;
 int VBUTW= 80;
 int VC0LABW= 120;
 int VLABH= 18;
 int COWsta_height= 30;
 int VBUTH= 33;
 int COWres_height= VBUTH;
 int COWlayVAR_height= VBUTH;
 int VPAD= 8;
 int COWlayAPP_height= VBUTH;
 int COWlayEVA_left= VPAD;
 int COWlayEVA_height= VBUTH;
 int COWlab3_height= VLABH;
 int COWwidPOS_height= VBUTH;
 int COWwidEDI_left= VPAD;
 int COWwidEDI_height= VBUTH;
 int COWwidDEL_height= VBUTH;
 int COWwidNEW_left= VPAD;
 int COWwidNEW_height= VBUTH;
 int COWlab2_height= VLABH;
 int COWfilGEN_left= VPAD;
 int COWfilGEN_height= VBUTH;
 int COWfilLOD_height= VBUTH;
 int COWfilSAV_left= VPAD;
 int COWfilSAV_height= VBUTH;
 int COWlab1_left= VPAD;
 int COWcut_left= VPAD;
 int COWopbtn_height= COWsta_height;
 int COWopbtn_width= 2*VBUTW+3*VPAD;
 int COWopbtn_bottom= HEIGHT;
 int COWopbtn_top= COWopbtn_bottom-COWopbtn_height;
 int COWopbtn_right= WIDTH;
 int COWopbtn_left= COWopbtn_right-COWopbtn_width;
 int COWlayALGN_height= VBUTH;
 int COWlab1_top= VPAD;
 int COWlab1_width= VC0LABW;
 int COWlab1_height= VLABH;
 int COWscrEDI_height= VBUTH;
 int COWscrLIS_left= VPAD;
 int COWlab0_height= VLABH;
 int COWlab0_width= VC0LABW;
 int COWscrLIS_height= VBUTH;
 int COWlab0_left= VPAD;
 int COWlab0_right= COWlab0_left+COWlab0_width;
 int COWcan_right= WIDTH-VPAD;
 int COWcan_top= VPAD;
 int COWsta_left= VPAD;
 int COWsta_right= COWopbtn_left;
 int COWsta_top= COWsta_bottom-COWsta_height;
 int Vco1x= VC0LABW/2+VPAD/2;
 int COWsta_width= COWsta_right-COWsta_left;
 int Vco2x= Vco1x+VPAD;
 int Vco3x= VPAD+VC0LABW;
 int COWlayVAR_left= VPAD;
 int COWlayVAR_right= Vco1x;
 int COWscrEDI_right= Vco3x;
 int COWscrEDI_left= Vco2x;
 int COWlayALGN_right= Vco3x;
 int COWlayVAR_width= COWlayVAR_right-COWlayVAR_left;
 int COWlab1_bottom= COWlab1_top+COWlab1_height;
 int COWlayAPP_left= Vco2x;
 int COWlab1_right= COWlab1_left+COWlab1_width;
 int COWlayAPP_right= Vco3x;
 int COWcut_right= Vco1x;
 int COWlayAPP_width= COWlayAPP_right-COWlayAPP_left;
 int COWlayEVA_right= Vco1x;
 int COWfilSAV_top= COWlab1_bottom+VPAD;
 int COWfilSAV_right= Vco1x;
 int COWlayEVA_width= COWlayEVA_right-COWlayEVA_left;
 int COWwidPOS_left= Vco2x;
 int COWwidPOS_right= Vco3x;
 int COWwidPOS_width= COWwidPOS_right-COWwidPOS_left;
 int COWfilLOD_top= COWfilSAV_top;
 int COWfilLOD_right= Vco3x;
 int COWfilLOD_left= Vco2x;
 int COWcut_width= COWcut_right-COWcut_left;
 int COWpaste_height= COWwidDEL_height;
 int COWwidEDI_right= Vco1x;
 int COWwidEDI_width= COWwidEDI_right-COWwidEDI_left;
 int COWfilGEN_right= Vco1x;
 int COWcut_height= COWpaste_height;
 int COWwidDEL_left= Vco2x;
 int COWwidDEL_right= Vco3x;
 int COWwidDEL_width= COWwidDEL_right-COWwidDEL_left;
 int COWwidNEW_right= Vco1x;
 int COWlab2_right= COWlab1_right;
 int COWlab2_left= COWlab0_left;
 int COWpaste_right= COWwidDEL_right;
 int COWwidNEW_width= COWwidNEW_right-COWwidNEW_left;
 int COWfilSET_left= COWfilLOD_left;
 int COWfilSET_right= COWfilLOD_right;
 int COWfilSET_width= COWfilSET_right-COWfilSET_left;
 int COWcan_left= COWlab1_right+VPAD;
 int COWcan_bottom= COWsta_top-VPAD;
 int COWcan_width= COWcan_right-COWcan_left;
 int COWcan_height= COWcan_bottom-COWcan_top;
 int COWscrLIS_right= Vco1x;
 int COWlayALGN_left= COWlayAPP_left;
 int COWlab2_width= COWlab2_right-COWlab2_left;
 int COWscrEDI_width= COWscrEDI_right-COWscrEDI_left;
 int COWpaste_left= COWwidDEL_left;
 int COWres_left= COWlayEVA_left+COWlayEVA_width/2;
 int COWres_right= COWlayAPP_left+COWlayAPP_width/2;
 int COWres_width= COWres_right-COWres_left;
 int COWfont_height= COWcut_height;
 int COWfont_left= COWres_left;
 int COWfilGEN_width= COWfilGEN_right-COWfilGEN_left;
 int COWlayALGN_width= COWlayALGN_right-COWlayALGN_left;
 int COWfilSAV_width= COWfilSAV_right-COWfilSAV_left;
 int COWfilLOD_bottom= COWfilLOD_top+COWfilLOD_height;
 int COWfilLOD_width= COWfilLOD_right-COWfilLOD_left;
 int COWfilSAV_bottom= COWfilSAV_top+COWfilSAV_height;
 int COWfont_width= COWres_width;
 int COWlab3_left= COWlab2_left;
 int COWlab3_right= COWlab2_right;
 int COWscrLIS_width= COWscrLIS_right-COWscrLIS_left;
 int COWpaste_width= COWpaste_right-COWpaste_left;
 int COWfilGEN_top= COWfilSAV_bottom+VPAD;
 int COWfilGEN_bottom= COWfilGEN_top+COWfilGEN_height;
 int COWfont_right= COWfont_left+COWfont_width;
 int COWlab3_width= COWlab3_right-COWlab3_left;
 int COWfilSET_top= COWfilGEN_top;
 int COWfilSET_bottom= COWfilGEN_bottom;
 int COWfilSET_height= COWfilSET_bottom-COWfilSET_top;
 int COWlab0_top= COWfilGEN_bottom+VPAD;
 int COWlab0_bottom= COWlab0_top+COWlab0_height;
 int COWscrLIS_top= COWlab0_bottom+VPAD;
 int COWscrEDI_top= COWscrLIS_top;
 int COWscrLIS_bottom= COWscrLIS_top+COWscrLIS_height;
 int COWscrEDI_bottom= COWscrEDI_top+COWscrEDI_height;
 int COWlab2_top= COWscrEDI_bottom+VPAD;
 int COWlab2_bottom= COWlab2_top+COWlab2_height;
 int COWwidNEW_top= COWlab2_bottom+VPAD;
 int COWwidNEW_bottom= COWwidNEW_top+COWwidNEW_height;
 int COWwidDEL_top= COWwidNEW_top;
 int COWwidEDI_top= COWwidNEW_bottom+VPAD;
 int COWwidDEL_bottom= COWwidDEL_top+COWwidDEL_height;
 int COWwidEDI_bottom= COWwidEDI_top+COWwidEDI_height;
 int COWlab3_top= COWwidEDI_bottom+VPAD;
 int COWwidPOS_bottom= COWwidEDI_bottom;
 int COWwidPOS_top= COWwidPOS_bottom-COWwidPOS_height;
 int COWlab3_bottom= COWlab3_top+COWlab3_height;
 int COWlayEVA_top= COWlab3_bottom+VPAD;
 int COWlayAPP_top= COWlayEVA_top;
 int COWlayAPP_bottom= COWlayAPP_top+COWlayAPP_height;
 int COWlayEVA_bottom= COWlayEVA_top+COWlayEVA_height;
 int COWlayVAR_top= COWlayEVA_bottom+VPAD;
 int COWlayVAR_bottom= COWlayVAR_top+COWlayVAR_height;
 int COWlayALGN_top= COWlayVAR_top;
 int COWres_top= COWlayVAR_bottom+VPAD;
 int COWlayALGN_bottom= COWlayALGN_top+COWlayALGN_height;
 int COWres_bottom= COWres_top+COWres_height;
 int COWcut_top= COWres_bottom+VPAD;
 int COWcut_bottom= COWcut_top+COWcut_height;
 int COWpaste_top= COWcut_top;
 int COWfont_top= COWcut_bottom+VPAD;
 int COWfont_bottom= COWfont_top+COWfont_height;
 int COWpaste_bottom= COWpaste_top+COWpaste_height;
  L[0]= COWfilSET_left; L[1]= COWfilSET_top;
  L[2]= COWfilSET_width; L[3]= COWfilSET_height;
  L[4]= COWcan_left; L[5]= COWcan_top;
  L[6]= COWcan_width; L[7]= COWcan_height;
  L[8]= COWsta_left; L[9]= COWsta_top;
  L[10]= COWsta_width; L[11]= COWsta_height;
  L[12]= COWres_left; L[13]= COWres_top;
  L[14]= COWres_width; L[15]= COWres_height;
  L[16]= COWlayVAR_left; L[17]= COWlayVAR_top;
  L[18]= COWlayVAR_width; L[19]= COWlayVAR_height;
  L[20]= COWlayAPP_left; L[21]= COWlayAPP_top;
  L[22]= COWlayAPP_width; L[23]= COWlayAPP_height;
  L[24]= COWlayEVA_left; L[25]= COWlayEVA_top;
  L[26]= COWlayEVA_width; L[27]= COWlayEVA_height;
  L[28]= COWlab3_left; L[29]= COWlab3_top;
  L[30]= COWlab3_width; L[31]= COWlab3_height;
  L[32]= COWwidPOS_left; L[33]= COWwidPOS_top;
  L[34]= COWwidPOS_width; L[35]= COWwidPOS_height;
  L[36]= COWwidEDI_left; L[37]= COWwidEDI_top;
  L[38]= COWwidEDI_width; L[39]= COWwidEDI_height;
  L[40]= COWwidDEL_left; L[41]= COWwidDEL_top;
  L[42]= COWwidDEL_width; L[43]= COWwidDEL_height;
  L[44]= COWwidNEW_left; L[45]= COWwidNEW_top;
  L[46]= COWwidNEW_width; L[47]= COWwidNEW_height;
  L[48]= COWlab2_left; L[49]= COWlab2_top;
  L[50]= COWlab2_width; L[51]= COWlab2_height;
  L[52]= COWfilGEN_left; L[53]= COWfilGEN_top;
  L[54]= COWfilGEN_width; L[55]= COWfilGEN_height;
  L[56]= COWfilLOD_left; L[57]= COWfilLOD_top;
  L[58]= COWfilLOD_width; L[59]= COWfilLOD_height;
  L[60]= COWfilSAV_left; L[61]= COWfilSAV_top;
  L[62]= COWfilSAV_width; L[63]= COWfilSAV_height;
  L[64]= COWlab1_left; L[65]= COWlab1_top;
  L[66]= COWlab1_width; L[67]= COWlab1_height;
  L[68]= COWscrEDI_left; L[69]= COWscrEDI_top;
  L[70]= COWscrEDI_width; L[71]= COWscrEDI_height;
  L[72]= COWscrLIS_left; L[73]= COWscrLIS_top;
  L[74]= COWscrLIS_width; L[75]= COWscrLIS_height;
  L[76]= COWlab0_left; L[77]= COWlab0_top;
  L[78]= COWlab0_width; L[79]= COWlab0_height;
  L[80]= COWlayALGN_left; L[81]= COWlayALGN_top;
  L[82]= COWlayALGN_width; L[83]= COWlayALGN_height;
  L[84]= COWopbtn_left; L[85]= COWopbtn_top;
  L[86]= COWopbtn_width; L[87]= COWopbtn_height;
  L[88]= COWcut_left; L[89]= COWcut_top;
  L[90]= COWcut_width; L[91]= COWcut_height;
  L[92]= COWpaste_left; L[93]= COWpaste_top;
  L[94]= COWpaste_width; L[95]= COWpaste_height;
  L[96]= COWfont_left; L[97]= COWfont_top;
  L[98]= COWfont_width; L[99]= COWfont_height;
}
static void LAYOSCR_SCREEN_0(int *L,int WIDTH,int HEIGHT) {
int COleft= -1;
int COright= -1;
int COtop= -1;
int CObottom= -1;
int COwidth= -1;
int COheight= -1;
  L[0]= COleft;
  L[1]= COtop;
  L[2]= COwidth;
  L[3]= COheight;
}
void gfx_SCREEN_0(){
 static int SWID[]= {     WfilSET,
    Wcan,
    Wsta,
    Wres,
    WlayVAR,
    WlayAPP,
    WlayEVA,
    Wlab3,
    WwidPOS,
    WwidEDI,
    WwidDEL,
    WwidNEW,
    Wlab2,
    WfilGEN,
    WfilLOD,
    WfilSAV,
    Wlab1,
    WscrEDI,
    WscrLIS,
    Wlab0,
    WlayALGN,
    Wopbtn,
    Wcut,
    Wpaste,
    Wfont,
    WconOK,
    WconCANCEL,
};
  int i;
  int LC[108]; /*widget coords */
  int LL[4]; /* screen coords */
  LAYOSCR_SCREEN_0(LL,x_window_width,x_window_height);
  enter_screen(27, SWID,LL);
  widgets[WfilSET]= gfx_button("Setng", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WfilSET]->number= WfilSET;
  widgets[Wcan]= gui_canvas_new(1,1);
  widgets[Wcan]->number= Wcan;
  widgets[Wsta]= gfx_label(1,0x000000,0xededed,'C',"");
  widgets[Wsta]->number= Wsta;
  widgets[Wres]= gfx_button("Resou", 'T', NULL,GFXCLASS_BUTTON);
  widgets[Wres]->number= Wres;
  widgets[WlayVAR]= gfx_button("Vars", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WlayVAR]->number= WlayVAR;
  widgets[WlayAPP]= gfx_button("Apply", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WlayAPP]->number= WlayAPP;
  widgets[WlayEVA]= gfx_button("Eval", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WlayEVA]->number= WlayEVA;
  widgets[Wlab3]= gfx_label(1,0x000000,0xededed,'C',"Layout");
  widgets[Wlab3]->number= Wlab3;
  widgets[WwidPOS]= gfx_button("Posn", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WwidPOS]->number= WwidPOS;
  widgets[WwidEDI]= gfx_button("Edit", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WwidEDI]->number= WwidEDI;
  widgets[WwidDEL]= gfx_button("Delete", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WwidDEL]->number= WwidDEL;
  widgets[WwidNEW]= gfx_button("New", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WwidNEW]->number= WwidNEW;
  widgets[Wlab2]= gfx_label(1,0x000000,0xededed,'C',"Widget");
  widgets[Wlab2]->number= Wlab2;
  widgets[WfilGEN]= gfx_button("Gen", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WfilGEN]->number= WfilGEN;
  widgets[WfilLOD]= gfx_button("Load", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WfilLOD]->number= WfilLOD;
  widgets[WfilSAV]= gfx_button("Save", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WfilSAV]->number= WfilSAV;
  widgets[Wlab1]= gfx_label(1,0x000000,0xededed,'C',"File");
  widgets[Wlab1]->number= Wlab1;
  widgets[WscrEDI]= gfx_button("Edit", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WscrEDI]->number= WscrEDI;
  widgets[WscrLIS]= gfx_button("Sel", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WscrLIS]->number= WscrLIS;
  widgets[Wlab0]= gfx_label(1,0x000000,0xededed,'C',"Screen");
  widgets[Wlab0]->number= Wlab0;
  widgets[WlayALGN]= gfx_button("Align", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WlayALGN]->number= WlayALGN;
  {
    panel_t *PP; 
    widgets[Wopbtn]= (widget_t*) (PP= panel_new(2));
    static int WL_0[]= {
    };
    PP->subs[0].n_widgets= 0;
    PP->subs[0].widgets= WL_0;
    static int WL_1[]= {
    WconOK,
    WconCANCEL,
    };
    PP->subs[1].n_widgets= 2;
    PP->subs[1].widgets= WL_1;
  }
  widgets[Wopbtn]->number= Wopbtn;
  widgets[Wcut]= gfx_button("Cut", 'T', NULL,GFXCLASS_BUTTON);
  widgets[Wcut]->number= Wcut;
  widgets[Wpaste]= gfx_button("Paste", 'T', NULL,GFXCLASS_BUTTON);
  widgets[Wpaste]->number= Wpaste;
  widgets[Wfont]= gfx_button("Fonts", 'T', NULL,GFXCLASS_BUTTON);
  widgets[Wfont]->number= Wfont;
  widgets[WconOK]= gfx_button("OK", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WconOK]->number= WconOK;
  widgets[WconCANCEL]= gfx_button("Cancel", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WconCANCEL]->number= WconCANCEL;
  LAYOWID_SCREEN_0(LL[2],LL[3],LC);
  LAYOWID_Wopbtn_XO_0(LC[86],LC[87], LC+100);
  for(i=25;i<0;i++) { LC[4*i]+= LC[84]; LC[4*i+1]+= LC[85];}
  LAYOWID_Wopbtn_XO_1(LC[86],LC[87], LC+100);
  for(i=25;i<27;i++) { LC[4*i]+= LC[84]; LC[4*i+1]+= LC[85];}
  for(i=0;i<27;i++) { LC[4*i]+= LL[0]; LC[4*i+1]+= LL[1]; }
  widget_move(widgets[WfilSET], LC[0], LC[1],LC[2],LC[3]);
  widget_move(widgets[Wcan], LC[4], LC[5],LC[6],LC[7]);
  widget_move(widgets[Wsta], LC[8], LC[9],LC[10],LC[11]);
  widget_move(widgets[Wres], LC[12], LC[13],LC[14],LC[15]);
  widget_move(widgets[WlayVAR], LC[16], LC[17],LC[18],LC[19]);
  widget_move(widgets[WlayAPP], LC[20], LC[21],LC[22],LC[23]);
  widget_move(widgets[WlayEVA], LC[24], LC[25],LC[26],LC[27]);
  widget_move(widgets[Wlab3], LC[28], LC[29],LC[30],LC[31]);
  widget_move(widgets[WwidPOS], LC[32], LC[33],LC[34],LC[35]);
  widget_move(widgets[WwidEDI], LC[36], LC[37],LC[38],LC[39]);
  widget_move(widgets[WwidDEL], LC[40], LC[41],LC[42],LC[43]);
  widget_move(widgets[WwidNEW], LC[44], LC[45],LC[46],LC[47]);
  widget_move(widgets[Wlab2], LC[48], LC[49],LC[50],LC[51]);
  widget_move(widgets[WfilGEN], LC[52], LC[53],LC[54],LC[55]);
  widget_move(widgets[WfilLOD], LC[56], LC[57],LC[58],LC[59]);
  widget_move(widgets[WfilSAV], LC[60], LC[61],LC[62],LC[63]);
  widget_move(widgets[Wlab1], LC[64], LC[65],LC[66],LC[67]);
  widget_move(widgets[WscrEDI], LC[68], LC[69],LC[70],LC[71]);
  widget_move(widgets[WscrLIS], LC[72], LC[73],LC[74],LC[75]);
  widget_move(widgets[Wlab0], LC[76], LC[77],LC[78],LC[79]);
  widget_move(widgets[WlayALGN], LC[80], LC[81],LC[82],LC[83]);
  widget_move(widgets[Wopbtn], LC[84], LC[85],LC[86],LC[87]);
  widget_move(widgets[Wcut], LC[88], LC[89],LC[90],LC[91]);
  widget_move(widgets[Wpaste], LC[92], LC[93],LC[94],LC[95]);
  widget_move(widgets[Wfont], LC[96], LC[97],LC[98],LC[99]);
  widget_move(widgets[WconOK], LC[100], LC[101],LC[102],LC[103]);
  widget_move(widgets[WconCANCEL], LC[104], LC[105],LC[106],LC[107]);
  widget_show(widgets[WfilSET], 1);
  widget_show(widgets[Wcan], 1);
  widget_show(widgets[Wsta], 1);
  widget_show(widgets[Wres], 1);
  widget_show(widgets[WlayVAR], 1);
  widget_show(widgets[WlayAPP], 1);
  widget_show(widgets[WlayEVA], 1);
  widget_show(widgets[Wlab3], 1);
  widget_show(widgets[WwidPOS], 1);
  widget_show(widgets[WwidEDI], 1);
  widget_show(widgets[WwidDEL], 1);
  widget_show(widgets[WwidNEW], 1);
  widget_show(widgets[Wlab2], 1);
  widget_show(widgets[WfilGEN], 1);
  widget_show(widgets[WfilLOD], 1);
  widget_show(widgets[WfilSAV], 1);
  widget_show(widgets[Wlab1], 1);
  widget_show(widgets[WscrEDI], 1);
  widget_show(widgets[WscrLIS], 1);
  widget_show(widgets[Wlab0], 1);
  widget_show(widgets[WlayALGN], 1);
  widget_show(widgets[Wopbtn], 1);
  widget_show(widgets[Wcut], 1);
  widget_show(widgets[Wpaste], 1);
  widget_show(widgets[Wfont], 1);
  gfx_update_all();
}
static void LAYOWID_SCRewLABEL(int WIDTH,int HEIGHT,int *L) {
 int COEWlabTITLE_left= 0;
 int VPAD= 8;
 int VBUTH= 28;
 int VBUTW= 80;
 int VCOL1= 100;
 int VLABH= 28;
 int COEWlabJUST_height= VBUTH;
 int COEWlabJUST_width= 120;
 int COEWlabTITLE_top= 0;
 int COEWlabTITLE_bottom= 50;
 int COEWlabTITLE_width= WIDTH;
 int COEWlabJUST_left= VCOL1;
 int COEWlabFONT_height= VBUTH;
 int COEWlabFONT_width= 120;
 int COEWlabTITLE_height= COEWlabTITLE_bottom-COEWlabTITLE_top;
 int COEWlabLAB0_left= VPAD;
 int COEWlabLAB0_right= VCOL1-VPAD;
 int COEWlabFONT_left= VCOL1;
 int COEWlabBG_height= VBUTH;
 int COEWlabLAB0_top= COEWlabTITLE_bottom+VPAD;
 int COEWlabLAB0_width= COEWlabLAB0_right-COEWlabLAB0_left;
 int COEWlabLAB0_height= VLABH;
 int COEWlabLAB1_left= VPAD;
 int COEWlabBG_left= VCOL1;
 int COEWlabFG_height= VBUTH;
 int COEWlabFG_width= 100;
 int COEWlabLAB1_right= VCOL1-VPAD;
 int COEWlabLAB1_width= COEWlabLAB1_right-COEWlabLAB1_left;
 int COEWlabLAB1_height= VLABH;
 int COEWlabFG_left= VCOL1;
 int COEWlabTEXT_height= VBUTH;
 int COEWlabTEXT_width= 140;
 int COEWlabLAB2_left= VPAD;
 int COEWlabTEXT_top= COEWlabLAB0_top;
 int COEWlabLAB2_right= VCOL1-VPAD;
 int COEWlabTEXT_left= VCOL1;
 int COEWlabCANCEL_height= VBUTH;
 int COEWlabCANCEL_width= VBUTW;
 int COEWlabLAB2_width= COEWlabLAB2_right-COEWlabLAB2_left;
 int COEWlabLAB2_height= VLABH;
 int COEWlabLAB3_left= VPAD;
 int COEWlabLAB3_right= VCOL1-VPAD;
 int COEWlabOK_height= VBUTH;
 int COEWlabOK_width= VBUTW;
 int COEWlabOK_bottom= HEIGHT-VPAD;
 int COEWlabOK_top= COEWlabOK_bottom-COEWlabOK_height;
 int COEWlabLAB3_width= COEWlabLAB3_right-COEWlabLAB3_left;
 int COEWlabOK_left= (WIDTH-VPAD-2*VBUTW)/2;
 int COEWlabLAB4_height= VLABH;
 int COEWlabLAB3_height= VLABH;
 int COEWlabLAB4_left= VPAD;
 int COEWlabLAB4_right= VCOL1-VPAD;
 int COEWlabTITLE_right= COEWlabTITLE_left+COEWlabTITLE_width;
 int COEWlabJUST_right= COEWlabJUST_left+COEWlabJUST_width;
 int COEWlabFONT_right= COEWlabFONT_left+COEWlabFONT_width;
 int COEWlabLAB4_width= COEWlabLAB4_right-COEWlabLAB4_left;
 int COEWlabBG_width= COEWlabFG_width;
 int COEWlabLAB0_bottom= COEWlabLAB0_top+COEWlabLAB0_height;
 int COEWlabOK_right= COEWlabOK_left+COEWlabOK_width;
 int COEWlabCANCEL_left= COEWlabOK_right+VPAD;
 int COEWlabCANCEL_right= COEWlabCANCEL_left+COEWlabCANCEL_width;
 int COEWlabCANCEL_top= COEWlabOK_top;
 int COEWlabBG_right= COEWlabBG_left+COEWlabBG_width;
 int COEWlabLAB1_top= COEWlabLAB0_bottom+VPAD;
 int COEWlabCANCEL_bottom= COEWlabCANCEL_top+COEWlabCANCEL_height;
 int COEWlabTEXT_right= COEWlabTEXT_left+COEWlabTEXT_width;
 int COEWlabTEXT_bottom= COEWlabTEXT_top+COEWlabTEXT_height;
 int COEWlabFG_right= COEWlabFG_left+COEWlabFG_width;
 int COEWlabLAB1_bottom= COEWlabLAB1_top+COEWlabLAB1_height;
 int COEWlabLAB2_top= COEWlabLAB1_bottom+VPAD;
 int COEWlabFG_top= COEWlabLAB1_top;
 int COEWlabFG_bottom= COEWlabFG_top+COEWlabFG_height;
 int COEWlabLAB2_bottom= COEWlabLAB2_top+COEWlabLAB2_height;
 int COEWlabBG_top= COEWlabLAB2_top;
 int COEWlabLAB3_top= COEWlabLAB2_bottom+VPAD;
 int COEWlabBG_bottom= COEWlabBG_top+COEWlabBG_height;
 int COEWlabFONT_top= COEWlabLAB3_top;
 int COEWlabLAB3_bottom= COEWlabLAB3_top+COEWlabLAB3_height;
 int COEWlabLAB4_top= COEWlabLAB3_bottom+VPAD;
 int COEWlabFONT_bottom= COEWlabFONT_top+COEWlabFONT_height;
 int COEWlabLAB4_bottom= COEWlabLAB4_top+COEWlabLAB4_height;
 int COEWlabJUST_top= COEWlabLAB4_top;
 int COEWlabJUST_bottom= COEWlabJUST_top+COEWlabJUST_height;
  L[0]= COEWlabTITLE_left; L[1]= COEWlabTITLE_top;
  L[2]= COEWlabTITLE_width; L[3]= COEWlabTITLE_height;
  L[4]= COEWlabLAB0_left; L[5]= COEWlabLAB0_top;
  L[6]= COEWlabLAB0_width; L[7]= COEWlabLAB0_height;
  L[8]= COEWlabLAB1_left; L[9]= COEWlabLAB1_top;
  L[10]= COEWlabLAB1_width; L[11]= COEWlabLAB1_height;
  L[12]= COEWlabLAB2_left; L[13]= COEWlabLAB2_top;
  L[14]= COEWlabLAB2_width; L[15]= COEWlabLAB2_height;
  L[16]= COEWlabLAB3_left; L[17]= COEWlabLAB3_top;
  L[18]= COEWlabLAB3_width; L[19]= COEWlabLAB3_height;
  L[20]= COEWlabLAB4_left; L[21]= COEWlabLAB4_top;
  L[22]= COEWlabLAB4_width; L[23]= COEWlabLAB4_height;
  L[24]= COEWlabOK_left; L[25]= COEWlabOK_top;
  L[26]= COEWlabOK_width; L[27]= COEWlabOK_height;
  L[28]= COEWlabCANCEL_left; L[29]= COEWlabCANCEL_top;
  L[30]= COEWlabCANCEL_width; L[31]= COEWlabCANCEL_height;
  L[32]= COEWlabTEXT_left; L[33]= COEWlabTEXT_top;
  L[34]= COEWlabTEXT_width; L[35]= COEWlabTEXT_height;
  L[36]= COEWlabFG_left; L[37]= COEWlabFG_top;
  L[38]= COEWlabFG_width; L[39]= COEWlabFG_height;
  L[40]= COEWlabBG_left; L[41]= COEWlabBG_top;
  L[42]= COEWlabBG_width; L[43]= COEWlabBG_height;
  L[44]= COEWlabFONT_left; L[45]= COEWlabFONT_top;
  L[46]= COEWlabFONT_width; L[47]= COEWlabFONT_height;
  L[48]= COEWlabJUST_left; L[49]= COEWlabJUST_top;
  L[50]= COEWlabJUST_width; L[51]= COEWlabJUST_height;
}
static void LAYOSCR_SCRewLABEL(int *L,int WIDTH,int HEIGHT) {
 int COleft= 50;
 int COheight= 400;
 int COwidth= 400;
 int COright= COleft+COwidth;
 int COtop= 50;
 int CObottom= COtop+COheight;
  L[0]= COleft;
  L[1]= COtop;
  L[2]= COwidth;
  L[3]= COheight;
}
void gfx_SCRewLABEL(){
 static int SWID[]= {     EWlabTITLE,
    EWlabLAB0,
    EWlabLAB1,
    EWlabLAB2,
    EWlabLAB3,
    EWlabLAB4,
    EWlabOK,
    EWlabCANCEL,
    EWlabTEXT,
    EWlabFG,
    EWlabBG,
    EWlabFONT,
    EWlabJUST,
};
  int i;
  int LC[52]; /*widget coords */
  int LL[4]; /* screen coords */
  LAYOSCR_SCRewLABEL(LL,x_window_width,x_window_height);
  enter_screen(13, SWID,LL);
  widgets[EWlabTITLE]= gfx_label(3,0x000000,0xcccccc,'C',"Label Attributes");
  widgets[EWlabTITLE]->number= EWlabTITLE;
  widgets[EWlabLAB0]= gfx_label(1,0x000000,0xededed,'L',"Text");
  widgets[EWlabLAB0]->number= EWlabLAB0;
  widgets[EWlabLAB1]= gfx_label(1,0x000000,0xededed,'C',"Foreground");
  widgets[EWlabLAB1]->number= EWlabLAB1;
  widgets[EWlabLAB2]= gfx_label(1,0x000000,0xededed,'C',"Background");
  widgets[EWlabLAB2]->number= EWlabLAB2;
  widgets[EWlabLAB3]= gfx_label(1,0x000000,0xededed,'L',"Font");
  widgets[EWlabLAB3]->number= EWlabLAB3;
  widgets[EWlabLAB4]= gfx_label(1,0x000000,0xededed,'L',"Justification");
  widgets[EWlabLAB4]->number= EWlabLAB4;
  widgets[EWlabOK]= gfx_button("OK", 'L', NULL,GFXCLASS_BUTTON);
  widgets[EWlabOK]->number= EWlabOK;
  widgets[EWlabCANCEL]= gfx_button("Cancel", 'L', NULL,GFXCLASS_BUTTON);
  widgets[EWlabCANCEL]->number= EWlabCANCEL;
  widgets[EWlabTEXT]= text_entry_new("");
  widgets[EWlabTEXT]->number= EWlabTEXT;
  widgets[EWlabFG]= text_entry_new("");
  widgets[EWlabFG]->number= EWlabFG;
  widgets[EWlabBG]= text_entry_new("");
  widgets[EWlabBG]->number= EWlabBG;
  widgets[EWlabFONT]= dropdown_new(NULL,NULL);
  widgets[EWlabFONT]->number= EWlabFONT;
  widgets[EWlabJUST]= dropdown_new(NULL,NULL);
  widgets[EWlabJUST]->number= EWlabJUST;
  LAYOWID_SCRewLABEL(LL[2],LL[3],LC);
  for(i=0;i<13;i++) { LC[4*i]+= LL[0]; LC[4*i+1]+= LL[1]; }
  widget_move(widgets[EWlabTITLE], LC[0], LC[1],LC[2],LC[3]);
  widget_move(widgets[EWlabLAB0], LC[4], LC[5],LC[6],LC[7]);
  widget_move(widgets[EWlabLAB1], LC[8], LC[9],LC[10],LC[11]);
  widget_move(widgets[EWlabLAB2], LC[12], LC[13],LC[14],LC[15]);
  widget_move(widgets[EWlabLAB3], LC[16], LC[17],LC[18],LC[19]);
  widget_move(widgets[EWlabLAB4], LC[20], LC[21],LC[22],LC[23]);
  widget_move(widgets[EWlabOK], LC[24], LC[25],LC[26],LC[27]);
  widget_move(widgets[EWlabCANCEL], LC[28], LC[29],LC[30],LC[31]);
  widget_move(widgets[EWlabTEXT], LC[32], LC[33],LC[34],LC[35]);
  widget_move(widgets[EWlabFG], LC[36], LC[37],LC[38],LC[39]);
  widget_move(widgets[EWlabBG], LC[40], LC[41],LC[42],LC[43]);
  widget_move(widgets[EWlabFONT], LC[44], LC[45],LC[46],LC[47]);
  widget_move(widgets[EWlabJUST], LC[48], LC[49],LC[50],LC[51]);
  widget_show(widgets[EWlabTITLE], 1);
  widget_show(widgets[EWlabLAB0], 1);
  widget_show(widgets[EWlabLAB1], 1);
  widget_show(widgets[EWlabLAB2], 1);
  widget_show(widgets[EWlabLAB3], 1);
  widget_show(widgets[EWlabLAB4], 1);
  widget_show(widgets[EWlabOK], 1);
  widget_show(widgets[EWlabCANCEL], 1);
  widget_show(widgets[EWlabTEXT], 1);
  widget_show(widgets[EWlabFG], 1);
  widget_show(widgets[EWlabBG], 1);
  widget_show(widgets[EWlabFONT], 1);
  widget_show(widgets[EWlabJUST], 1);
  gfx_update_all();
}
static void LAYOWID_SCRewPANEL(int WIDTH,int HEIGHT,int *L) {
 int COEWpanTITLE_left= 0;
 int VBUTH= 28;
 int VBUTW= 70;
 int VPAD= 8;
 int COEWpanOK_height= VBUTH;
 int COEWpanOK_width= VBUTW;
 int COEWpanOK_bottom= HEIGHT-VPAD;
 int COEWpanOK_top= COEWpanOK_bottom-COEWpanOK_height;
 int COEWpanTITLE_top= 0;
 int COEWpanOK_left= (WIDTH-VBUTW)/2;
 int COEWpanDEL_height= VBUTH;
 int COEWpanDEL_width= VBUTW;
 int COEWpanTITLE_width= WIDTH;
 int COEWpanTITLE_height= 50;
 int COEWpanLIST_left= VPAD;
 int COEWpanLIST_right= WIDTH-VPAD;
 int COEWpanNEW_height= VBUTH;
 int COEWpanNEW_width= VBUTW;
 int COEWpanNEW_bottom= COEWpanOK_top-VPAD;
 int COEWpanNEW_top= COEWpanNEW_bottom-COEWpanNEW_height;
 int COEWpanLIST_bottom= COEWpanNEW_top-VPAD;
 int COEWpanNEW_left= VPAD;
 int COEWpanLIST_width= COEWpanLIST_right-COEWpanLIST_left;
 int COEWpanOK_right= COEWpanOK_left+COEWpanOK_width;
 int COEWpanTITLE_right= COEWpanTITLE_left+COEWpanTITLE_width;
 int COEWpanTITLE_bottom= COEWpanTITLE_top+COEWpanTITLE_height;
 int COEWpanNEW_right= COEWpanNEW_left+COEWpanNEW_width;
 int COEWpanDEL_left= COEWpanNEW_right+VPAD;
 int COEWpanDEL_right= COEWpanDEL_left+COEWpanDEL_width;
 int COEWpanDEL_top= COEWpanNEW_top;
 int COEWpanLIST_top= COEWpanTITLE_bottom+VPAD;
 int COEWpanDEL_bottom= COEWpanDEL_top+COEWpanDEL_height;
 int COEWpanLIST_height= COEWpanLIST_bottom-COEWpanLIST_top;
  L[0]= COEWpanTITLE_left; L[1]= COEWpanTITLE_top;
  L[2]= COEWpanTITLE_width; L[3]= COEWpanTITLE_height;
  L[4]= COEWpanLIST_left; L[5]= COEWpanLIST_top;
  L[6]= COEWpanLIST_width; L[7]= COEWpanLIST_height;
  L[8]= COEWpanNEW_left; L[9]= COEWpanNEW_top;
  L[10]= COEWpanNEW_width; L[11]= COEWpanNEW_height;
  L[12]= COEWpanDEL_left; L[13]= COEWpanDEL_top;
  L[14]= COEWpanDEL_width; L[15]= COEWpanDEL_height;
  L[16]= COEWpanOK_left; L[17]= COEWpanOK_top;
  L[18]= COEWpanOK_width; L[19]= COEWpanOK_height;
}
static void LAYOSCR_SCRewPANEL(int *L,int WIDTH,int HEIGHT) {
 int COleft= 50;
 int COheight= 400;
 int COwidth= 400;
 int COright= COleft+COwidth;
 int COtop= 80;
 int CObottom= COtop+COheight;
  L[0]= COleft;
  L[1]= COtop;
  L[2]= COwidth;
  L[3]= COheight;
}
void gfx_SCRewPANEL(){
 static int SWID[]= {     EWpanTITLE,
    EWpanLIST,
    EWpanNEW,
    EWpanDEL,
    EWpanOK,
};
  int i;
  int LC[20]; /*widget coords */
  int LL[4]; /* screen coords */
  LAYOSCR_SCRewPANEL(LL,x_window_width,x_window_height);
  enter_screen(5, SWID,LL);
  widgets[EWpanTITLE]= gfx_label(3,0x000000,0xcccccc,'C',"Panel Subscreens");
  widgets[EWpanTITLE]->number= EWpanTITLE;
  widgets[EWpanLIST]= gui_list_new(0,0,NULL,NULL,NULL);
  widgets[EWpanLIST]->number= EWpanLIST;
  widgets[EWpanNEW]= gfx_button("Create", 'L', NULL,GFXCLASS_BUTTON);
  widgets[EWpanNEW]->number= EWpanNEW;
  widgets[EWpanDEL]= gfx_button("Delete", 'L', NULL,GFXCLASS_BUTTON);
  widgets[EWpanDEL]->number= EWpanDEL;
  widgets[EWpanOK]= gfx_button("OK", 'L', NULL,GFXCLASS_BUTTON);
  widgets[EWpanOK]->number= EWpanOK;
  LAYOWID_SCRewPANEL(LL[2],LL[3],LC);
  for(i=0;i<5;i++) { LC[4*i]+= LL[0]; LC[4*i+1]+= LL[1]; }
  widget_move(widgets[EWpanTITLE], LC[0], LC[1],LC[2],LC[3]);
  widget_move(widgets[EWpanLIST], LC[4], LC[5],LC[6],LC[7]);
  widget_move(widgets[EWpanNEW], LC[8], LC[9],LC[10],LC[11]);
  widget_move(widgets[EWpanDEL], LC[12], LC[13],LC[14],LC[15]);
  widget_move(widgets[EWpanOK], LC[16], LC[17],LC[18],LC[19]);
  widget_show(widgets[EWpanTITLE], 1);
  widget_show(widgets[EWpanLIST], 1);
  widget_show(widgets[EWpanNEW], 1);
  widget_show(widgets[EWpanDEL], 1);
  widget_show(widgets[EWpanOK], 1);
  gfx_update_all();
}
static void LAYOWID_SCRewBUTTON(int WIDTH,int HEIGHT,int *L) {
 int COEWbuttonTITLE_left= 0;
 int VPAD= 8;
 int VBUTW= 80;
 int VBUTH= 28;
 int COEWbuttonICON_height= VBUTH;
 int COEWbuttonTITLE_top= 0;
 int COEWbuttonTITLE_width= WIDTH;
 int COEWbuttonTITLE_height= 50;
 int COEWbuttonLAB0_left= VPAD;
 int COEWbuttonLAB0_width= 120;
 int COEWbuttonCANCEL_height= VBUTH;
 int COEWbuttonCANCEL_width= VBUTW;
 int COEWbuttonLAB0_height= VBUTH;
 int COEWbuttonTEXT_width= 120;
 int COEWbuttonTEXT_height= VBUTH;
 int COEWbuttonLAB1_left= VPAD;
 int COEWbuttonOK_height= VBUTH;
 int COEWbuttonOK_width= VBUTW;
 int COEWbuttonOK_bottom= HEIGHT-VPAD;
 int COEWbuttonOK_top= COEWbuttonOK_bottom-COEWbuttonOK_height;
 int COEWbuttonLAB1_height= VBUTH;
 int COEWbuttonOK_left= (WIDTH-VPAD-2*VBUTW)/2;
 int COEWbuttonICONCHOOSE_height= VBUTH;
 int COEWbuttonICONCHOOSE_width= VBUTW;
 int COEWbuttonICONPOS_width= VBUTW;
 int COEWbuttonICONPOS_height= VBUTH;
 int COEWbuttonLAB2_left= VPAD;
 int COEWbuttonLAB2_height= VBUTH;
 int COEWbuttonICON_width= COEWbuttonICONPOS_width;
 int COEWbuttonTITLE_right= COEWbuttonTITLE_left+COEWbuttonTITLE_width;
 int COEWbuttonTITLE_bottom= COEWbuttonTITLE_top+COEWbuttonTITLE_height;
 int COEWbuttonLAB0_right= COEWbuttonLAB0_left+COEWbuttonLAB0_width;
 int COEWbuttonLAB0_top= COEWbuttonTITLE_bottom+VPAD;
 int COEWbuttonLAB0_bottom= COEWbuttonLAB0_top+COEWbuttonLAB0_height;
 int COEWbuttonCANCEL_top= COEWbuttonOK_top;
 int COEWbuttonTEXT_left= COEWbuttonLAB0_right+VPAD;
 int COEWbuttonTEXT_right= COEWbuttonTEXT_left+COEWbuttonTEXT_width;
 int COEWbuttonTEXT_top= COEWbuttonLAB0_top;
 int COEWbuttonTEXT_bottom= COEWbuttonTEXT_top+COEWbuttonTEXT_height;
 int COEWbuttonOK_right= COEWbuttonOK_left+COEWbuttonOK_width;
 int COEWbuttonLAB1_right= COEWbuttonLAB0_right;
 int COEWbuttonLAB1_width= COEWbuttonLAB1_right-COEWbuttonLAB1_left;
 int COEWbuttonLAB1_top= COEWbuttonLAB0_bottom+VPAD;
 int COEWbuttonLAB2_right= COEWbuttonLAB1_right;
 int COEWbuttonLAB1_bottom= COEWbuttonLAB1_top+COEWbuttonLAB1_height;
 int COEWbuttonCANCEL_bottom= COEWbuttonCANCEL_top+COEWbuttonCANCEL_height;
 int COEWbuttonCANCEL_left= COEWbuttonOK_right+VPAD;
 int COEWbuttonCANCEL_right= COEWbuttonCANCEL_left+COEWbuttonCANCEL_width;
 int COEWbuttonICONPOS_left= COEWbuttonLAB1_right+VPAD;
 int COEWbuttonICONPOS_right= COEWbuttonICONPOS_left+COEWbuttonICONPOS_width;
 int COEWbuttonICONPOS_top= COEWbuttonLAB1_top;
 int COEWbuttonICONPOS_bottom= COEWbuttonICONPOS_top+COEWbuttonICONPOS_height;
 int COEWbuttonLAB2_width= COEWbuttonLAB2_right-COEWbuttonLAB2_left;
 int COEWbuttonLAB2_top= COEWbuttonLAB1_bottom+VPAD;
 int COEWbuttonICON_top= COEWbuttonLAB2_top;
 int COEWbuttonICON_left= COEWbuttonLAB2_right+VPAD;
 int COEWbuttonICONCHOOSE_top= COEWbuttonICON_top;
 int COEWbuttonICONCHOOSE_bottom= COEWbuttonICONCHOOSE_top+COEWbuttonICONCHOOSE_height;
 int COEWbuttonICON_right= COEWbuttonICON_left+COEWbuttonICON_width;
 int COEWbuttonICONCHOOSE_left= COEWbuttonICON_right+VPAD;
 int COEWbuttonICONCHOOSE_right= COEWbuttonICONCHOOSE_left+COEWbuttonICONCHOOSE_width;
 int COEWbuttonICON_bottom= COEWbuttonICON_top+COEWbuttonICON_height;
 int COEWbuttonLAB2_bottom= COEWbuttonLAB2_top+COEWbuttonLAB2_height;
  L[0]= COEWbuttonTITLE_left; L[1]= COEWbuttonTITLE_top;
  L[2]= COEWbuttonTITLE_width; L[3]= COEWbuttonTITLE_height;
  L[4]= COEWbuttonLAB0_left; L[5]= COEWbuttonLAB0_top;
  L[6]= COEWbuttonLAB0_width; L[7]= COEWbuttonLAB0_height;
  L[8]= COEWbuttonTEXT_left; L[9]= COEWbuttonTEXT_top;
  L[10]= COEWbuttonTEXT_width; L[11]= COEWbuttonTEXT_height;
  L[12]= COEWbuttonLAB1_left; L[13]= COEWbuttonLAB1_top;
  L[14]= COEWbuttonLAB1_width; L[15]= COEWbuttonLAB1_height;
  L[16]= COEWbuttonICONPOS_left; L[17]= COEWbuttonICONPOS_top;
  L[18]= COEWbuttonICONPOS_width; L[19]= COEWbuttonICONPOS_height;
  L[20]= COEWbuttonLAB2_left; L[21]= COEWbuttonLAB2_top;
  L[22]= COEWbuttonLAB2_width; L[23]= COEWbuttonLAB2_height;
  L[24]= COEWbuttonICONCHOOSE_left; L[25]= COEWbuttonICONCHOOSE_top;
  L[26]= COEWbuttonICONCHOOSE_width; L[27]= COEWbuttonICONCHOOSE_height;
  L[28]= COEWbuttonOK_left; L[29]= COEWbuttonOK_top;
  L[30]= COEWbuttonOK_width; L[31]= COEWbuttonOK_height;
  L[32]= COEWbuttonCANCEL_left; L[33]= COEWbuttonCANCEL_top;
  L[34]= COEWbuttonCANCEL_width; L[35]= COEWbuttonCANCEL_height;
  L[36]= COEWbuttonICON_left; L[37]= COEWbuttonICON_top;
  L[38]= COEWbuttonICON_width; L[39]= COEWbuttonICON_height;
}
static void LAYOSCR_SCRewBUTTON(int *L,int WIDTH,int HEIGHT) {
 int COleft= 50;
 int COheight= 400;
 int COwidth= 400;
 int COright= COleft+COwidth;
 int COtop= 50;
 int CObottom= COtop+COheight;
  L[0]= COleft;
  L[1]= COtop;
  L[2]= COwidth;
  L[3]= COheight;
}
void gfx_SCRewBUTTON(){
 static int SWID[]= {     EWbuttonTITLE,
    EWbuttonLAB0,
    EWbuttonTEXT,
    EWbuttonLAB1,
    EWbuttonICONPOS,
    EWbuttonLAB2,
    EWbuttonICONCHOOSE,
    EWbuttonOK,
    EWbuttonCANCEL,
    EWbuttonICON,
};
  int i;
  int LC[40]; /*widget coords */
  int LL[4]; /* screen coords */
  LAYOSCR_SCRewBUTTON(LL,x_window_width,x_window_height);
  enter_screen(10, SWID,LL);
  widgets[EWbuttonTITLE]= gfx_label(3,0x000000,0xcccccc,'C',"Button Attributes");
  widgets[EWbuttonTITLE]->number= EWbuttonTITLE;
  widgets[EWbuttonLAB0]= gfx_label(1,0x000000,0xededed,'L',"Text");
  widgets[EWbuttonLAB0]->number= EWbuttonLAB0;
  widgets[EWbuttonTEXT]= text_entry_new("");
  widgets[EWbuttonTEXT]->number= EWbuttonTEXT;
  widgets[EWbuttonLAB1]= gfx_label(1,0x000000,0xededed,'L',"Icon Position");
  widgets[EWbuttonLAB1]->number= EWbuttonLAB1;
  widgets[EWbuttonICONPOS]= dropdown_new(NULL,NULL);
  widgets[EWbuttonICONPOS]->number= EWbuttonICONPOS;
  widgets[EWbuttonLAB2]= gfx_label(1,0x000000,0xededed,'L',"Icon");
  widgets[EWbuttonLAB2]->number= EWbuttonLAB2;
  widgets[EWbuttonICONCHOOSE]= gfx_button("Choose", 'L', NULL,GFXCLASS_BUTTON);
  widgets[EWbuttonICONCHOOSE]->number= EWbuttonICONCHOOSE;
  widgets[EWbuttonOK]= gfx_button("OK", 'L', NULL,GFXCLASS_BUTTON);
  widgets[EWbuttonOK]->number= EWbuttonOK;
  widgets[EWbuttonCANCEL]= gfx_button("Cancel", 'L', NULL,GFXCLASS_BUTTON);
  widgets[EWbuttonCANCEL]->number= EWbuttonCANCEL;
  widgets[EWbuttonICON]= text_entry_new("");
  widgets[EWbuttonICON]->number= EWbuttonICON;
  LAYOWID_SCRewBUTTON(LL[2],LL[3],LC);
  for(i=0;i<10;i++) { LC[4*i]+= LL[0]; LC[4*i+1]+= LL[1]; }
  widget_move(widgets[EWbuttonTITLE], LC[0], LC[1],LC[2],LC[3]);
  widget_move(widgets[EWbuttonLAB0], LC[4], LC[5],LC[6],LC[7]);
  widget_move(widgets[EWbuttonTEXT], LC[8], LC[9],LC[10],LC[11]);
  widget_move(widgets[EWbuttonLAB1], LC[12], LC[13],LC[14],LC[15]);
  widget_move(widgets[EWbuttonICONPOS], LC[16], LC[17],LC[18],LC[19]);
  widget_move(widgets[EWbuttonLAB2], LC[20], LC[21],LC[22],LC[23]);
  widget_move(widgets[EWbuttonICONCHOOSE], LC[24], LC[25],LC[26],LC[27]);
  widget_move(widgets[EWbuttonOK], LC[28], LC[29],LC[30],LC[31]);
  widget_move(widgets[EWbuttonCANCEL], LC[32], LC[33],LC[34],LC[35]);
  widget_move(widgets[EWbuttonICON], LC[36], LC[37],LC[38],LC[39]);
  widget_show(widgets[EWbuttonTITLE], 1);
  widget_show(widgets[EWbuttonLAB0], 1);
  widget_show(widgets[EWbuttonTEXT], 1);
  widget_show(widgets[EWbuttonLAB1], 1);
  widget_show(widgets[EWbuttonICONPOS], 1);
  widget_show(widgets[EWbuttonLAB2], 1);
  widget_show(widgets[EWbuttonICONCHOOSE], 1);
  widget_show(widgets[EWbuttonOK], 1);
  widget_show(widgets[EWbuttonCANCEL], 1);
  widget_show(widgets[EWbuttonICON], 1);
  gfx_update_all();
}
static void LAYOWID_SCRewSIMPLE(int WIDTH,int HEIGHT,int *L) {
 int COEWsimpleTITLE_left= 0;
 int VPAD= 8;
 int VBUTH= 28;
 int VBUTW= 80;
 int COEWsimpleCANCEL_height= VBUTH;
 int COEWsimpleCANCEL_width= VBUTW;
 int COEWsimpleTITLE_top= 0;
 int COEWsimpleTITLE_width= WIDTH;
 int COEWsimpleTITLE_height= 50;
 int COEWsimpleLAB0_left= VPAD;
 int COEWsimpleOK_height= VBUTH;
 int COEWsimpleOK_width= VBUTW;
 int COEWsimpleOK_bottom= HEIGHT-VPAD;
 int COEWsimpleOK_top= COEWsimpleOK_bottom-COEWsimpleOK_height;
 int COEWsimpleLAB0_width= 90;
 int COEWsimpleOK_left= (WIDTH-2*VBUTW-VPAD)/2;
 int COEWsimpleTEXT_height= VBUTH;
 int COEWsimpleLAB0_height= VBUTH;
 int COEWsimpleTEXT_right= WIDTH-VPAD;
 int COEWsimpleTITLE_right= COEWsimpleTITLE_left+COEWsimpleTITLE_width;
 int COEWsimpleCANCEL_top= COEWsimpleOK_top;
 int COEWsimpleTITLE_bottom= COEWsimpleTITLE_top+COEWsimpleTITLE_height;
 int COEWsimpleOK_right= COEWsimpleOK_left+COEWsimpleOK_width;
 int COEWsimpleLAB0_right= COEWsimpleLAB0_left+COEWsimpleLAB0_width;
 int COEWsimpleLAB0_top= COEWsimpleTITLE_bottom+VPAD;
 int COEWsimpleCANCEL_bottom= COEWsimpleCANCEL_top+COEWsimpleCANCEL_height;
 int COEWsimpleLAB0_bottom= COEWsimpleLAB0_top+COEWsimpleLAB0_height;
 int COEWsimpleTEXT_top= COEWsimpleLAB0_top;
 int COEWsimpleCANCEL_left= COEWsimpleOK_right+VPAD;
 int COEWsimpleCANCEL_right= COEWsimpleCANCEL_left+COEWsimpleCANCEL_width;
 int COEWsimpleTEXT_bottom= COEWsimpleTEXT_top+COEWsimpleTEXT_height;
 int COEWsimpleTEXT_left= COEWsimpleLAB0_right+VPAD;
 int COEWsimpleTEXT_width= COEWsimpleTEXT_right-COEWsimpleTEXT_left;
  L[0]= COEWsimpleTITLE_left; L[1]= COEWsimpleTITLE_top;
  L[2]= COEWsimpleTITLE_width; L[3]= COEWsimpleTITLE_height;
  L[4]= COEWsimpleLAB0_left; L[5]= COEWsimpleLAB0_top;
  L[6]= COEWsimpleLAB0_width; L[7]= COEWsimpleLAB0_height;
  L[8]= COEWsimpleTEXT_left; L[9]= COEWsimpleTEXT_top;
  L[10]= COEWsimpleTEXT_width; L[11]= COEWsimpleTEXT_height;
  L[12]= COEWsimpleOK_left; L[13]= COEWsimpleOK_top;
  L[14]= COEWsimpleOK_width; L[15]= COEWsimpleOK_height;
  L[16]= COEWsimpleCANCEL_left; L[17]= COEWsimpleCANCEL_top;
  L[18]= COEWsimpleCANCEL_width; L[19]= COEWsimpleCANCEL_height;
}
static void LAYOSCR_SCRewSIMPLE(int *L,int WIDTH,int HEIGHT) {
 int COleft= 50;
 int COheight= 200;
 int COwidth= 300;
 int COright= COleft+COwidth;
 int COtop= 50;
 int CObottom= COtop+COheight;
  L[0]= COleft;
  L[1]= COtop;
  L[2]= COwidth;
  L[3]= COheight;
}
void gfx_SCRewSIMPLE(){
 static int SWID[]= {     EWsimpleTITLE,
    EWsimpleLAB0,
    EWsimpleTEXT,
    EWsimpleOK,
    EWsimpleCANCEL,
};
  int i;
  int LC[20]; /*widget coords */
  int LL[4]; /* screen coords */
  LAYOSCR_SCRewSIMPLE(LL,x_window_width,x_window_height);
  enter_screen(5, SWID,LL);
  widgets[EWsimpleTITLE]= gfx_label(3,0x000000,0xcccccc,'C',"");
  widgets[EWsimpleTITLE]->number= EWsimpleTITLE;
  widgets[EWsimpleLAB0]= gfx_label(1,0x000000,0xededed,'L',"Text");
  widgets[EWsimpleLAB0]->number= EWsimpleLAB0;
  widgets[EWsimpleTEXT]= text_entry_new("");
  widgets[EWsimpleTEXT]->number= EWsimpleTEXT;
  widgets[EWsimpleOK]= gfx_button("OK", 'L', NULL,GFXCLASS_BUTTON);
  widgets[EWsimpleOK]->number= EWsimpleOK;
  widgets[EWsimpleCANCEL]= gfx_button("Cancel", 'L', NULL,GFXCLASS_BUTTON);
  widgets[EWsimpleCANCEL]->number= EWsimpleCANCEL;
  LAYOWID_SCRewSIMPLE(LL[2],LL[3],LC);
  for(i=0;i<5;i++) { LC[4*i]+= LL[0]; LC[4*i+1]+= LL[1]; }
  widget_move(widgets[EWsimpleTITLE], LC[0], LC[1],LC[2],LC[3]);
  widget_move(widgets[EWsimpleLAB0], LC[4], LC[5],LC[6],LC[7]);
  widget_move(widgets[EWsimpleTEXT], LC[8], LC[9],LC[10],LC[11]);
  widget_move(widgets[EWsimpleOK], LC[12], LC[13],LC[14],LC[15]);
  widget_move(widgets[EWsimpleCANCEL], LC[16], LC[17],LC[18],LC[19]);
  widget_show(widgets[EWsimpleTITLE], 1);
  widget_show(widgets[EWsimpleLAB0], 1);
  widget_show(widgets[EWsimpleTEXT], 1);
  widget_show(widgets[EWsimpleOK], 1);
  widget_show(widgets[EWsimpleCANCEL], 1);
  gfx_update_all();
}
static void LAYOWID_SCRewSCROLL(int WIDTH,int HEIGHT,int *L) {
 int COEWscbTITLE_left= 0;
 int VPAD= 8;
 int VBUTW= 80;
 int VBUTH= 28;
 int COEWscbVERTICAL_height= VBUTH;
 int COEWscbVERTICAL_width= VBUTW+30;
 int COEWscbTITLE_top= 0;
 int COEWscbTITLE_width= WIDTH;
 int COEWscbTITLE_height= 50;
 int COEWscbOK_left= (WIDTH-2*VBUTW-VPAD)/2;
 int COEWscbLAB0_height= VBUTH;
 int COEWscbLAB0_width= 100;
 int COEWscbOK_bottom= HEIGHT-VPAD;
 int COEWscbOK_width= VBUTW;
 int COEWscbOK_height= VBUTH;
 int COEWscbLAB0_left= VPAD;
 int COEWscbCANCEL_height= VBUTH;
 int COEWscbCANCEL_width= VBUTW;
 int COEWscbTITLE_right= COEWscbTITLE_left+COEWscbTITLE_width;
 int COEWscbTITLE_bottom= COEWscbTITLE_top+COEWscbTITLE_height;
 int COEWscbOK_right= COEWscbOK_left+COEWscbOK_width;
 int COEWscbCANCEL_left= COEWscbOK_right+VPAD;
 int COEWscbOK_top= COEWscbOK_bottom-COEWscbOK_height;
 int COEWscbLAB0_right= COEWscbLAB0_left+COEWscbLAB0_width;
 int COEWscbLAB0_top= COEWscbTITLE_bottom+VPAD;
 int COEWscbCANCEL_top= COEWscbOK_top;
 int COEWscbCANCEL_bottom= COEWscbCANCEL_top+COEWscbCANCEL_height;
 int COEWscbLAB0_bottom= COEWscbLAB0_top+COEWscbLAB0_height;
 int COEWscbVERTICAL_left= COEWscbLAB0_right+VPAD;
 int COEWscbVERTICAL_right= COEWscbVERTICAL_left+COEWscbVERTICAL_width;
 int COEWscbCANCEL_right= COEWscbCANCEL_left+COEWscbCANCEL_width;
 int COEWscbVERTICAL_top= COEWscbLAB0_top;
 int COEWscbVERTICAL_bottom= COEWscbVERTICAL_top+COEWscbVERTICAL_height;
  L[0]= COEWscbTITLE_left; L[1]= COEWscbTITLE_top;
  L[2]= COEWscbTITLE_width; L[3]= COEWscbTITLE_height;
  L[4]= COEWscbOK_left; L[5]= COEWscbOK_top;
  L[6]= COEWscbOK_width; L[7]= COEWscbOK_height;
  L[8]= COEWscbCANCEL_left; L[9]= COEWscbCANCEL_top;
  L[10]= COEWscbCANCEL_width; L[11]= COEWscbCANCEL_height;
  L[12]= COEWscbLAB0_left; L[13]= COEWscbLAB0_top;
  L[14]= COEWscbLAB0_width; L[15]= COEWscbLAB0_height;
  L[16]= COEWscbVERTICAL_left; L[17]= COEWscbVERTICAL_top;
  L[18]= COEWscbVERTICAL_width; L[19]= COEWscbVERTICAL_height;
}
static void LAYOSCR_SCRewSCROLL(int *L,int WIDTH,int HEIGHT) {
 int COleft= 50;
 int COheight= 180;
 int COwidth= 300;
 int COright= COleft+COwidth;
 int COtop= 50;
 int CObottom= COtop+COheight;
  L[0]= COleft;
  L[1]= COtop;
  L[2]= COwidth;
  L[3]= COheight;
}
void gfx_SCRewSCROLL(){
 static int SWID[]= {     EWscbTITLE,
    EWscbOK,
    EWscbCANCEL,
    EWscbLAB0,
    EWscbVERTICAL,
};
  int i;
  int LC[20]; /*widget coords */
  int LL[4]; /* screen coords */
  LAYOSCR_SCRewSCROLL(LL,x_window_width,x_window_height);
  enter_screen(5, SWID,LL);
  widgets[EWscbTITLE]= gfx_label(3,0x000000,0xccCCcc,'C',"Scroll Bar Attributes");
  widgets[EWscbTITLE]->number= EWscbTITLE;
  widgets[EWscbOK]= gfx_button("OK", 'T', NULL,GFXCLASS_BUTTON);
  widgets[EWscbOK]->number= EWscbOK;
  widgets[EWscbCANCEL]= gfx_button("Cancel", 'T', NULL,GFXCLASS_BUTTON);
  widgets[EWscbCANCEL]->number= EWscbCANCEL;
  widgets[EWscbLAB0]= gfx_label(1,0x000000,0xededed,'L',"Orientation");
  widgets[EWscbLAB0]->number= EWscbLAB0;
  widgets[EWscbVERTICAL]= dropdown_new(NULL,NULL);
  widgets[EWscbVERTICAL]->number= EWscbVERTICAL;
  LAYOWID_SCRewSCROLL(LL[2],LL[3],LC);
  for(i=0;i<5;i++) { LC[4*i]+= LL[0]; LC[4*i+1]+= LL[1]; }
  widget_move(widgets[EWscbTITLE], LC[0], LC[1],LC[2],LC[3]);
  widget_move(widgets[EWscbOK], LC[4], LC[5],LC[6],LC[7]);
  widget_move(widgets[EWscbCANCEL], LC[8], LC[9],LC[10],LC[11]);
  widget_move(widgets[EWscbLAB0], LC[12], LC[13],LC[14],LC[15]);
  widget_move(widgets[EWscbVERTICAL], LC[16], LC[17],LC[18],LC[19]);
  widget_show(widgets[EWscbTITLE], 1);
  widget_show(widgets[EWscbOK], 1);
  widget_show(widgets[EWscbCANCEL], 1);
  widget_show(widgets[EWscbLAB0], 1);
  widget_show(widgets[EWscbVERTICAL], 1);
  gfx_update_all();
}
static void LAYOWID_SCRewRADIO(int WIDTH,int HEIGHT,int *L) {
 int COEWradioTITLE_left= 0;
 int VBUTH= 28;
 int VPAD= 8;
 int VBUTW= 90;
 int COEWradioCANCEL_height= VBUTH;
 int COEWradioCANCEL_width= VBUTW;
 int COEWradioTITLE_top= 0;
 int COEWradioTITLE_width= WIDTH;
 int COEWradioTITLE_height= 50;
 int COEWradioLAB0_left= VPAD;
 int COEWradioOK_height= VBUTH;
 int COEWradioOK_width= VBUTW;
 int COEWradioOK_bottom= HEIGHT-VPAD;
 int COEWradioOK_top= COEWradioOK_bottom-COEWradioOK_height;
 int COEWradioLAB0_width= 100;
 int COEWradioOK_left= (WIDTH-VPAD-2*VBUTW)/2;
 int COEWradioGROUP_height= VBUTH;
 int COEWradioLAB0_height= VBUTH;
 int COEWradioLAB1_left= VPAD;
 int COEWradioLAB1_width= COEWradioLAB0_width;
 int COEWradioLAB1_height= VBUTH;
 int COEWradioTEXT_right= WIDTH-VPAD;
 int COEWradioTEXT_height= VBUTH;
 int COEWradioTITLE_right= COEWradioTITLE_left+COEWradioTITLE_width;
 int COEWradioCANCEL_top= COEWradioOK_top;
 int COEWradioTITLE_bottom= COEWradioTITLE_top+COEWradioTITLE_height;
 int COEWradioOK_right= COEWradioOK_left+COEWradioOK_width;
 int COEWradioLAB0_right= COEWradioLAB0_left+COEWradioLAB0_width;
 int COEWradioLAB0_top= COEWradioTITLE_bottom+VPAD;
 int COEWradioGROUP_right= COEWradioTEXT_right;
 int COEWradioLAB0_bottom= COEWradioLAB0_top+COEWradioLAB0_height;
 int COEWradioLAB1_top= COEWradioLAB0_bottom+VPAD;
 int COEWradioLAB1_right= COEWradioLAB1_left+COEWradioLAB1_width;
 int COEWradioGROUP_top= COEWradioLAB1_top;
 int COEWradioGROUP_bottom= COEWradioGROUP_top+COEWradioGROUP_height;
 int COEWradioCANCEL_bottom= COEWradioCANCEL_top+COEWradioCANCEL_height;
 int COEWradioTEXT_top= COEWradioLAB0_top;
 int COEWradioLAB1_bottom= COEWradioLAB1_top+COEWradioLAB1_height;
 int COEWradioCANCEL_left= COEWradioOK_right+VPAD;
 int COEWradioTEXT_left= COEWradioLAB0_right+VPAD;
 int COEWradioTEXT_bottom= COEWradioTEXT_top+COEWradioTEXT_height;
 int COEWradioCANCEL_right= COEWradioCANCEL_left+COEWradioCANCEL_width;
 int COEWradioTEXT_width= COEWradioTEXT_right-COEWradioTEXT_left;
 int COEWradioGROUP_left= COEWradioTEXT_left;
 int COEWradioGROUP_width= COEWradioGROUP_right-COEWradioGROUP_left;
  L[0]= COEWradioTITLE_left; L[1]= COEWradioTITLE_top;
  L[2]= COEWradioTITLE_width; L[3]= COEWradioTITLE_height;
  L[4]= COEWradioLAB0_left; L[5]= COEWradioLAB0_top;
  L[6]= COEWradioLAB0_width; L[7]= COEWradioLAB0_height;
  L[8]= COEWradioLAB1_left; L[9]= COEWradioLAB1_top;
  L[10]= COEWradioLAB1_width; L[11]= COEWradioLAB1_height;
  L[12]= COEWradioTEXT_left; L[13]= COEWradioTEXT_top;
  L[14]= COEWradioTEXT_width; L[15]= COEWradioTEXT_height;
  L[16]= COEWradioGROUP_left; L[17]= COEWradioGROUP_top;
  L[18]= COEWradioGROUP_width; L[19]= COEWradioGROUP_height;
  L[20]= COEWradioOK_left; L[21]= COEWradioOK_top;
  L[22]= COEWradioOK_width; L[23]= COEWradioOK_height;
  L[24]= COEWradioCANCEL_left; L[25]= COEWradioCANCEL_top;
  L[26]= COEWradioCANCEL_width; L[27]= COEWradioCANCEL_height;
}
static void LAYOSCR_SCRewRADIO(int *L,int WIDTH,int HEIGHT) {
 int COleft= 50;
 int COheight= 300;
 int COwidth= 300;
 int COright= COleft+COwidth;
 int COtop= 50;
 int CObottom= COtop+COheight;
  L[0]= COleft;
  L[1]= COtop;
  L[2]= COwidth;
  L[3]= COheight;
}
void gfx_SCRewRADIO(){
 static int SWID[]= {     EWradioTITLE,
    EWradioLAB0,
    EWradioLAB1,
    EWradioTEXT,
    EWradioGROUP,
    EWradioOK,
    EWradioCANCEL,
};
  int i;
  int LC[28]; /*widget coords */
  int LL[4]; /* screen coords */
  LAYOSCR_SCRewRADIO(LL,x_window_width,x_window_height);
  enter_screen(7, SWID,LL);
  widgets[EWradioTITLE]= gfx_label(3,0x000000,0xccCCcc,'C',"Radio Button Attributes");
  widgets[EWradioTITLE]->number= EWradioTITLE;
  widgets[EWradioLAB0]= gfx_label(1,0x000000,0xededed,'L',"Text");
  widgets[EWradioLAB0]->number= EWradioLAB0;
  widgets[EWradioLAB1]= gfx_label(1,0x000000,0xededed,'L',"Group");
  widgets[EWradioLAB1]->number= EWradioLAB1;
  widgets[EWradioTEXT]= text_entry_new("");
  widgets[EWradioTEXT]->number= EWradioTEXT;
  widgets[EWradioGROUP]= text_entry_new("");
  widgets[EWradioGROUP]->number= EWradioGROUP;
  widgets[EWradioOK]= gfx_button("OK", 'T', NULL,GFXCLASS_BUTTON);
  widgets[EWradioOK]->number= EWradioOK;
  widgets[EWradioCANCEL]= gfx_button("Cancel", 'T', NULL,GFXCLASS_BUTTON);
  widgets[EWradioCANCEL]->number= EWradioCANCEL;
  LAYOWID_SCRewRADIO(LL[2],LL[3],LC);
  for(i=0;i<7;i++) { LC[4*i]+= LL[0]; LC[4*i+1]+= LL[1]; }
  widget_move(widgets[EWradioTITLE], LC[0], LC[1],LC[2],LC[3]);
  widget_move(widgets[EWradioLAB0], LC[4], LC[5],LC[6],LC[7]);
  widget_move(widgets[EWradioLAB1], LC[8], LC[9],LC[10],LC[11]);
  widget_move(widgets[EWradioTEXT], LC[12], LC[13],LC[14],LC[15]);
  widget_move(widgets[EWradioGROUP], LC[16], LC[17],LC[18],LC[19]);
  widget_move(widgets[EWradioOK], LC[20], LC[21],LC[22],LC[23]);
  widget_move(widgets[EWradioCANCEL], LC[24], LC[25],LC[26],LC[27]);
  widget_show(widgets[EWradioTITLE], 1);
  widget_show(widgets[EWradioLAB0], 1);
  widget_show(widgets[EWradioLAB1], 1);
  widget_show(widgets[EWradioTEXT], 1);
  widget_show(widgets[EWradioGROUP], 1);
  widget_show(widgets[EWradioOK], 1);
  widget_show(widgets[EWradioCANCEL], 1);
  gfx_update_all();
}
static void LAYOWID_SCRalign(int WIDTH,int HEIGHT,int *L) {
 int COWalnTITLE_left= 0;
 int VPAD= 8;
 int Vcol1= WIDTH/3;
 int Vcol0= VPAD;
 int Vcol2= WIDTH*2/3;
 int Vcol2e= WIDTH-VPAD;
 int Vcol1e= Vcol2-VPAD;
 int Vcol0e= Vcol1-VPAD;
 int VBUTW= 80;
 int VBUTH= 28;
 int COWalnEheight_height= VBUTH;
 int COWalnTITLE_top= 0;
 int COWalnTITLE_width= WIDTH;
 int COWalnTITLE_height= 50;
 int COWalnEheight_right= Vcol2e;
 int COWalnEheight_left= Vcol2;
 int COWalnEwidth_height= VBUTH;
 int COWalnLAB0_left= Vcol0;
 int COWalnLAB0_right= Vcol0e;
 int COWalnLAB0_width= COWalnLAB0_right-COWalnLAB0_left;
 int COWalnEwidth_right= Vcol2e;
 int COWalnEwidth_left= Vcol2;
 int COWalnPAD_height= VBUTH;
 int COWalnLAB0_height= VBUTH;
 int COWalnLAB1_left= Vcol1;
 int COWalnLAB1_right= Vcol1e;
 int COWalnPAD_right= Vcol1e;
 int COWalnLAB1_width= COWalnLAB1_right-COWalnLAB1_left;
 int COWalnLAB3_height= VBUTH;
 int COWalnLAB3_width= 60;
 int COWalnLAB1_height= VBUTH;
 int COWalnLAB2_left= Vcol2;
 int COWalnLAB2_right= Vcol2e;
 int COWalnLAB3_left= Vcol1;
 int COWalnSright_height= VBUTH;
 int COWalnLAB2_width= COWalnLAB2_right-COWalnLAB2_left;
 int COWalnLAB2_height= VBUTH;
 int COWalnOK_left= (WIDTH-2*VBUTW-VPAD)/2;
 int COWalnSright_right= Vcol1e;
 int COWalnSright_left= Vcol1;
 int COWalnSleft_height= VBUTH;
 int COWalnOK_bottom= HEIGHT-VPAD;
 int COWalnOK_width= VBUTW;
 int COWalnOK_height= VBUTH;
 int COWalnSleft_right= Vcol1e;
 int COWalnSleft_left= Vcol1;
 int COWalnSnone_height= VBUTH;
 int COWalnCANCEL_width= VBUTW;
 int COWalnCANCEL_height= VBUTH;
 int COWalnAleft_left= Vcol0;
 int COWalnSnone_right= Vcol1e;
 int COWalnSnone_left= Vcol1;
 int COWalnSbottom_height= VBUTH;
 int COWalnAleft_right= Vcol0e;
 int COWalnAleft_width= COWalnAleft_right-COWalnAleft_left;
 int COWalnAleft_height= VBUTH;
 int COWalnSbottom_right= Vcol1e;
 int COWalnSbottom_left= Vcol1;
 int COWalnStop_height= VBUTH;
 int COWalnAright_left= Vcol0;
 int COWalnAright_right= Vcol0e;
 int COWalnAright_width= COWalnAright_right-COWalnAright_left;
 int COWalnStop_right= Vcol1e;
 int COWalnStop_left= Vcol1;
 int COWalnAnone_height= VBUTH;
 int COWalnAright_height= VBUTH;
 int COWalnAtop_left= Vcol0;
 int COWalnAtop_right= Vcol0e;
 int COWalnAnone_right= Vcol0e;
 int COWalnAnone_left= Vcol0;
 int COWalnAbottom_height= VBUTH;
 int COWalnAtop_width= COWalnAtop_right-COWalnAtop_left;
 int COWalnAtop_height= VBUTH;
 int COWalnAbottom_left= Vcol0;
 int COWalnAbottom_right= Vcol0e;
 int COWalnEheight_width= COWalnEheight_right-COWalnEheight_left;
 int COWalnTITLE_right= COWalnTITLE_left+COWalnTITLE_width;
 int COWalnTITLE_bottom= COWalnTITLE_top+COWalnTITLE_height;
 int COWalnEwidth_width= COWalnEwidth_right-COWalnEwidth_left;
 int COWalnLAB0_top= COWalnTITLE_bottom+VPAD;
 int COWalnAbottom_width= COWalnAbottom_right-COWalnAbottom_left;
 int COWalnLAB0_bottom= COWalnLAB0_top+COWalnLAB0_height;
 int COWalnLAB1_top= COWalnLAB0_top;
 int COWalnAnone_width= COWalnAnone_right-COWalnAnone_left;
 int COWalnLAB1_bottom= COWalnLAB1_top+COWalnLAB1_height;
 int COWalnLAB3_right= COWalnLAB3_left+COWalnLAB3_width;
 int COWalnSright_width= COWalnSright_right-COWalnSright_left;
 int COWalnLAB2_top= COWalnLAB0_top;
 int COWalnStop_width= COWalnStop_right-COWalnStop_left;
 int COWalnLAB2_bottom= COWalnLAB2_top+COWalnLAB2_height;
 int COWalnSleft_width= COWalnSleft_right-COWalnSleft_left;
 int COWalnAleft_top= COWalnLAB0_bottom+VPAD;
 int COWalnOK_right= COWalnOK_left+COWalnOK_width;
 int COWalnSbottom_width= COWalnSbottom_right-COWalnSbottom_left;
 int COWalnOK_top= COWalnOK_bottom-COWalnOK_height;
 int COWalnSleft_top= COWalnAleft_top;
 int COWalnSnone_width= COWalnSnone_right-COWalnSnone_left;
 int COWalnCANCEL_top= COWalnOK_top;
 int COWalnCANCEL_left= COWalnOK_right+VPAD;
 int COWalnEwidth_top= COWalnSleft_top;
 int COWalnCANCEL_right= COWalnCANCEL_left+COWalnCANCEL_width;
 int COWalnCANCEL_bottom= COWalnCANCEL_top+COWalnCANCEL_height;
 int COWalnSleft_bottom= COWalnSleft_top+COWalnSleft_height;
 int COWalnPAD_left= COWalnLAB3_right+VPAD;
 int COWalnAleft_bottom= COWalnAleft_top+COWalnAleft_height;
 int COWalnEwidth_bottom= COWalnEwidth_top+COWalnEwidth_height;
 int COWalnPAD_width= COWalnPAD_right-COWalnPAD_left;
 int COWalnAright_top= COWalnAleft_bottom+VPAD;
 int COWalnSright_top= COWalnAright_top;
 int COWalnSright_bottom= COWalnSright_top+COWalnSright_height;
 int COWalnAright_bottom= COWalnAright_top+COWalnAright_height;
 int COWalnEheight_top= COWalnSright_top;
 int COWalnAtop_top= COWalnAright_bottom+VPAD;
 int COWalnStop_top= COWalnAtop_top;
 int COWalnEheight_bottom= COWalnEheight_top+COWalnEheight_height;
 int COWalnAtop_bottom= COWalnAtop_top+COWalnAtop_height;
 int COWalnStop_bottom= COWalnStop_top+COWalnStop_height;
 int COWalnAbottom_top= COWalnAtop_bottom+VPAD;
 int COWalnAbottom_bottom= COWalnAbottom_top+COWalnAbottom_height;
 int COWalnSbottom_top= COWalnAbottom_top;
 int COWalnAnone_top= COWalnAbottom_bottom+VPAD;
 int COWalnSbottom_bottom= COWalnSbottom_top+COWalnSbottom_height;
 int COWalnSnone_top= COWalnAnone_top;
 int COWalnAnone_bottom= COWalnAnone_top+COWalnAnone_height;
 int COWalnSnone_bottom= COWalnSnone_top+COWalnSnone_height;
 int COWalnLAB3_top= COWalnSnone_bottom+VPAD;
 int COWalnLAB3_bottom= COWalnLAB3_top+COWalnLAB3_height;
 int COWalnPAD_top= COWalnLAB3_top;
 int COWalnPAD_bottom= COWalnPAD_top+COWalnPAD_height;
  L[0]= COWalnTITLE_left; L[1]= COWalnTITLE_top;
  L[2]= COWalnTITLE_width; L[3]= COWalnTITLE_height;
  L[4]= COWalnLAB0_left; L[5]= COWalnLAB0_top;
  L[6]= COWalnLAB0_width; L[7]= COWalnLAB0_height;
  L[8]= COWalnLAB1_left; L[9]= COWalnLAB1_top;
  L[10]= COWalnLAB1_width; L[11]= COWalnLAB1_height;
  L[12]= COWalnLAB2_left; L[13]= COWalnLAB2_top;
  L[14]= COWalnLAB2_width; L[15]= COWalnLAB2_height;
  L[16]= COWalnOK_left; L[17]= COWalnOK_top;
  L[18]= COWalnOK_width; L[19]= COWalnOK_height;
  L[20]= COWalnCANCEL_left; L[21]= COWalnCANCEL_top;
  L[22]= COWalnCANCEL_width; L[23]= COWalnCANCEL_height;
  L[24]= COWalnAleft_left; L[25]= COWalnAleft_top;
  L[26]= COWalnAleft_width; L[27]= COWalnAleft_height;
  L[28]= COWalnAright_left; L[29]= COWalnAright_top;
  L[30]= COWalnAright_width; L[31]= COWalnAright_height;
  L[32]= COWalnAtop_left; L[33]= COWalnAtop_top;
  L[34]= COWalnAtop_width; L[35]= COWalnAtop_height;
  L[36]= COWalnAbottom_left; L[37]= COWalnAbottom_top;
  L[38]= COWalnAbottom_width; L[39]= COWalnAbottom_height;
  L[40]= COWalnAnone_left; L[41]= COWalnAnone_top;
  L[42]= COWalnAnone_width; L[43]= COWalnAnone_height;
  L[44]= COWalnStop_left; L[45]= COWalnStop_top;
  L[46]= COWalnStop_width; L[47]= COWalnStop_height;
  L[48]= COWalnSbottom_left; L[49]= COWalnSbottom_top;
  L[50]= COWalnSbottom_width; L[51]= COWalnSbottom_height;
  L[52]= COWalnSnone_left; L[53]= COWalnSnone_top;
  L[54]= COWalnSnone_width; L[55]= COWalnSnone_height;
  L[56]= COWalnSleft_left; L[57]= COWalnSleft_top;
  L[58]= COWalnSleft_width; L[59]= COWalnSleft_height;
  L[60]= COWalnSright_left; L[61]= COWalnSright_top;
  L[62]= COWalnSright_width; L[63]= COWalnSright_height;
  L[64]= COWalnLAB3_left; L[65]= COWalnLAB3_top;
  L[66]= COWalnLAB3_width; L[67]= COWalnLAB3_height;
  L[68]= COWalnPAD_left; L[69]= COWalnPAD_top;
  L[70]= COWalnPAD_width; L[71]= COWalnPAD_height;
  L[72]= COWalnEwidth_left; L[73]= COWalnEwidth_top;
  L[74]= COWalnEwidth_width; L[75]= COWalnEwidth_height;
  L[76]= COWalnEheight_left; L[77]= COWalnEheight_top;
  L[78]= COWalnEheight_width; L[79]= COWalnEheight_height;
}
static void LAYOSCR_SCRalign(int *L,int WIDTH,int HEIGHT) {
 int COleft= 50;
 int COheight= 380;
 int COwidth= 400;
 int COright= COleft+COwidth;
 int COtop= 120;
 int CObottom= COtop+COheight;
  L[0]= COleft;
  L[1]= COtop;
  L[2]= COwidth;
  L[3]= COheight;
}
void gfx_SCRalign(){
 static int SWID[]= {     WalnTITLE,
    WalnLAB0,
    WalnLAB1,
    WalnLAB2,
    WalnOK,
    WalnCANCEL,
    WalnAleft,
    WalnAright,
    WalnAtop,
    WalnAbottom,
    WalnAnone,
    WalnStop,
    WalnSbottom,
    WalnSnone,
    WalnSleft,
    WalnSright,
    WalnLAB3,
    WalnPAD,
    WalnEwidth,
    WalnEheight,
};
  int i;
  int LC[80]; /*widget coords */
  int LL[4]; /* screen coords */
  LAYOSCR_SCRalign(LL,x_window_width,x_window_height);
  enter_screen(20, SWID,LL);
  widgets[WalnTITLE]= gfx_label(3,0x000000,0xcccccc,'C',"Alignment Options");
  widgets[WalnTITLE]->number= WalnTITLE;
  widgets[WalnLAB0]= gfx_label(2,0x000000,0xbcbcbc,'C',"Align");
  widgets[WalnLAB0]->number= WalnLAB0;
  widgets[WalnLAB1]= gfx_label(2,0x000000,0xbcbcbc,'C',"Stack");
  widgets[WalnLAB1]->number= WalnLAB1;
  widgets[WalnLAB2]= gfx_label(2,0x000000,0xbcbcbc,'C',"Equate");
  widgets[WalnLAB2]->number= WalnLAB2;
  widgets[WalnOK]= gfx_button("OK", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WalnOK]->number= WalnOK;
  widgets[WalnCANCEL]= gfx_button("Cancel", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WalnCANCEL]->number= WalnCANCEL;
  widgets[WalnAleft]= radio_new("Left Edge",WalnAleft);
  widgets[WalnAleft]->number= WalnAleft;
  widgets[WalnAright]= radio_new("Right Edge",WalnAleft);
  widgets[WalnAright]->number= WalnAright;
  widgets[WalnAtop]= radio_new("Top Edge",WalnAleft);
  widgets[WalnAtop]->number= WalnAtop;
  widgets[WalnAbottom]= radio_new("Bottom Edge",WalnAleft);
  widgets[WalnAbottom]->number= WalnAbottom;
  widgets[WalnAnone]= radio_new("None",WalnAleft);
  widgets[WalnAnone]->number= WalnAnone;
  widgets[WalnStop]= radio_new("Top Down",WalnStop);
  widgets[WalnStop]->number= WalnStop;
  widgets[WalnSbottom]= radio_new("Bottom Up",WalnSbottom);
  widgets[WalnSbottom]->number= WalnSbottom;
  widgets[WalnSnone]= radio_new("None",WalnStop);
  widgets[WalnSnone]->number= WalnSnone;
  widgets[WalnSleft]= radio_new("Left to Right",WalnStop);
  widgets[WalnSleft]->number= WalnSleft;
  widgets[WalnSright]= radio_new("Right to Left",WalnStop);
  widgets[WalnSright]->number= WalnSright;
  widgets[WalnLAB3]= gfx_label(1,0x000000,0xededed,'R',"Padding");
  widgets[WalnLAB3]->number= WalnLAB3;
  widgets[WalnPAD]= text_entry_new("");
  widgets[WalnPAD]->number= WalnPAD;
  widgets[WalnEwidth]= gui_checkbox_new("Width",NULL,NULL);
  widgets[WalnEwidth]->number= WalnEwidth;
  widgets[WalnEheight]= gui_checkbox_new("Height",NULL,NULL);
  widgets[WalnEheight]->number= WalnEheight;
  LAYOWID_SCRalign(LL[2],LL[3],LC);
  for(i=0;i<20;i++) { LC[4*i]+= LL[0]; LC[4*i+1]+= LL[1]; }
  widget_move(widgets[WalnTITLE], LC[0], LC[1],LC[2],LC[3]);
  widget_move(widgets[WalnLAB0], LC[4], LC[5],LC[6],LC[7]);
  widget_move(widgets[WalnLAB1], LC[8], LC[9],LC[10],LC[11]);
  widget_move(widgets[WalnLAB2], LC[12], LC[13],LC[14],LC[15]);
  widget_move(widgets[WalnOK], LC[16], LC[17],LC[18],LC[19]);
  widget_move(widgets[WalnCANCEL], LC[20], LC[21],LC[22],LC[23]);
  widget_move(widgets[WalnAleft], LC[24], LC[25],LC[26],LC[27]);
  widget_move(widgets[WalnAright], LC[28], LC[29],LC[30],LC[31]);
  widget_move(widgets[WalnAtop], LC[32], LC[33],LC[34],LC[35]);
  widget_move(widgets[WalnAbottom], LC[36], LC[37],LC[38],LC[39]);
  widget_move(widgets[WalnAnone], LC[40], LC[41],LC[42],LC[43]);
  widget_move(widgets[WalnStop], LC[44], LC[45],LC[46],LC[47]);
  widget_move(widgets[WalnSbottom], LC[48], LC[49],LC[50],LC[51]);
  widget_move(widgets[WalnSnone], LC[52], LC[53],LC[54],LC[55]);
  widget_move(widgets[WalnSleft], LC[56], LC[57],LC[58],LC[59]);
  widget_move(widgets[WalnSright], LC[60], LC[61],LC[62],LC[63]);
  widget_move(widgets[WalnLAB3], LC[64], LC[65],LC[66],LC[67]);
  widget_move(widgets[WalnPAD], LC[68], LC[69],LC[70],LC[71]);
  widget_move(widgets[WalnEwidth], LC[72], LC[73],LC[74],LC[75]);
  widget_move(widgets[WalnEheight], LC[76], LC[77],LC[78],LC[79]);
  widget_show(widgets[WalnTITLE], 1);
  widget_show(widgets[WalnLAB0], 1);
  widget_show(widgets[WalnLAB1], 1);
  widget_show(widgets[WalnLAB2], 1);
  widget_show(widgets[WalnOK], 1);
  widget_show(widgets[WalnCANCEL], 1);
  widget_show(widgets[WalnAleft], 1);
  widget_show(widgets[WalnAright], 1);
  widget_show(widgets[WalnAtop], 1);
  widget_show(widgets[WalnAbottom], 1);
  widget_show(widgets[WalnAnone], 1);
  widget_show(widgets[WalnStop], 1);
  widget_show(widgets[WalnSbottom], 1);
  widget_show(widgets[WalnSnone], 1);
  widget_show(widgets[WalnSleft], 1);
  widget_show(widgets[WalnSright], 1);
  widget_show(widgets[WalnLAB3], 1);
  widget_show(widgets[WalnPAD], 1);
  widget_show(widgets[WalnEwidth], 1);
  widget_show(widgets[WalnEheight], 1);
  gfx_update_all();
}
static void LAYOWID_SCRewSLIDER(int WIDTH,int HEIGHT,int *L) {
 int COEWsliderTITLE_left= 0;
 int VBUTW= 80;
 int VBUTH= 30;
 int VRADW= 200;
 int VPAD= 8;
 int COEWsliderORIENT_height= VBUTH;
 int COEWsliderORIENT_width= VRADW;
 int COEWsliderTITLE_top= 0;
 int COEWsliderTITLE_width= WIDTH;
 int COEWsliderTITLE_height= 50;
 int COEWsliderOK_left= (WIDTH-VPAD-2*VBUTW)/2;
 int COEWsliderLAB0_height= VBUTH;
 int COEWsliderLAB0_width= 120;
 int COEWsliderOK_bottom= HEIGHT-VPAD;
 int COEWsliderOK_width= VBUTW;
 int COEWsliderOK_height= VBUTH;
 int COEWsliderLAB0_left= VPAD;
 int COEWsliderCANCEL_height= VBUTH;
 int COEWsliderCANCEL_width= VBUTW;
 int COEWsliderTITLE_right= COEWsliderTITLE_left+COEWsliderTITLE_width;
 int COEWsliderTITLE_bottom= COEWsliderTITLE_top+COEWsliderTITLE_height;
 int COEWsliderOK_right= COEWsliderOK_left+COEWsliderOK_width;
 int COEWsliderCANCEL_left= COEWsliderOK_right+VPAD;
 int COEWsliderOK_top= COEWsliderOK_bottom-COEWsliderOK_height;
 int COEWsliderLAB0_right= COEWsliderLAB0_left+COEWsliderLAB0_width;
 int COEWsliderLAB0_top= COEWsliderTITLE_bottom+VPAD;
 int COEWsliderCANCEL_top= COEWsliderOK_top;
 int COEWsliderCANCEL_bottom= COEWsliderCANCEL_top+COEWsliderCANCEL_height;
 int COEWsliderLAB0_bottom= COEWsliderLAB0_top+COEWsliderLAB0_height;
 int COEWsliderORIENT_left= COEWsliderLAB0_right+VPAD;
 int COEWsliderORIENT_right= COEWsliderORIENT_left+COEWsliderORIENT_width;
 int COEWsliderCANCEL_right= COEWsliderCANCEL_left+COEWsliderCANCEL_width;
 int COEWsliderORIENT_top= COEWsliderLAB0_top;
 int COEWsliderORIENT_bottom= COEWsliderORIENT_top+COEWsliderORIENT_height;
  L[0]= COEWsliderTITLE_left; L[1]= COEWsliderTITLE_top;
  L[2]= COEWsliderTITLE_width; L[3]= COEWsliderTITLE_height;
  L[4]= COEWsliderOK_left; L[5]= COEWsliderOK_top;
  L[6]= COEWsliderOK_width; L[7]= COEWsliderOK_height;
  L[8]= COEWsliderCANCEL_left; L[9]= COEWsliderCANCEL_top;
  L[10]= COEWsliderCANCEL_width; L[11]= COEWsliderCANCEL_height;
  L[12]= COEWsliderLAB0_left; L[13]= COEWsliderLAB0_top;
  L[14]= COEWsliderLAB0_width; L[15]= COEWsliderLAB0_height;
  L[16]= COEWsliderORIENT_left; L[17]= COEWsliderORIENT_top;
  L[18]= COEWsliderORIENT_width; L[19]= COEWsliderORIENT_height;
}
static void LAYOSCR_SCRewSLIDER(int *L,int WIDTH,int HEIGHT) {
 int COleft= 180;
 int COheight= 300;
 int COwidth= 400;
 int COright= COleft+COwidth;
 int COtop= 120;
 int CObottom= COtop+COheight;
  L[0]= COleft;
  L[1]= COtop;
  L[2]= COwidth;
  L[3]= COheight;
}
void gfx_SCRewSLIDER(){
 static int SWID[]= {     EWsliderTITLE,
    EWsliderOK,
    EWsliderCANCEL,
    EWsliderLAB0,
    EWsliderORIENT,
};
  int i;
  int LC[20]; /*widget coords */
  int LL[4]; /* screen coords */
  LAYOSCR_SCRewSLIDER(LL,x_window_width,x_window_height);
  enter_screen(5, SWID,LL);
  widgets[EWsliderTITLE]= gfx_label(3,0x000000,0xcccccc,'C',"Slider Attributes");
  widgets[EWsliderTITLE]->number= EWsliderTITLE;
  widgets[EWsliderOK]= gfx_button("OK", 'T', NULL,GFXCLASS_BUTTON);
  widgets[EWsliderOK]->number= EWsliderOK;
  widgets[EWsliderCANCEL]= gfx_button("Cancel", 'T', NULL,GFXCLASS_BUTTON);
  widgets[EWsliderCANCEL]->number= EWsliderCANCEL;
  widgets[EWsliderLAB0]= gfx_label(1,0x000000,0xededed,'C',"Orientation");
  widgets[EWsliderLAB0]->number= EWsliderLAB0;
  widgets[EWsliderORIENT]= dropdown_new(NULL,NULL);
  widgets[EWsliderORIENT]->number= EWsliderORIENT;
  LAYOWID_SCRewSLIDER(LL[2],LL[3],LC);
  for(i=0;i<5;i++) { LC[4*i]+= LL[0]; LC[4*i+1]+= LL[1]; }
  widget_move(widgets[EWsliderTITLE], LC[0], LC[1],LC[2],LC[3]);
  widget_move(widgets[EWsliderOK], LC[4], LC[5],LC[6],LC[7]);
  widget_move(widgets[EWsliderCANCEL], LC[8], LC[9],LC[10],LC[11]);
  widget_move(widgets[EWsliderLAB0], LC[12], LC[13],LC[14],LC[15]);
  widget_move(widgets[EWsliderORIENT], LC[16], LC[17],LC[18],LC[19]);
  widget_show(widgets[EWsliderTITLE], 1);
  widget_show(widgets[EWsliderOK], 1);
  widget_show(widgets[EWsliderCANCEL], 1);
  widget_show(widgets[EWsliderLAB0], 1);
  widget_show(widgets[EWsliderORIENT], 1);
  gfx_update_all();
}
static void LAYOWID_SCRewCANVAS(int WIDTH,int HEIGHT,int *L) {
 int COEWcanHORSCROLL_left= 8;
 int COEWcanTITLE_height= 50;
 int COEWcanTITLE_width= WIDTH;
 int COEWcanHORSCROLL_width= 140;
 int COEWcanTITLE_top= 0;
 int COEWcanHORSCROLL_height= 30;
 int COEWcanTITLE_left= 0;
 int COEWcanVERSCROLL_left= COEWcanHORSCROLL_left;
 int COEWcanVERSCROLL_width= COEWcanHORSCROLL_width;
 int COEWcanVERSCROLL_height= COEWcanHORSCROLL_height;
 int COEWcanOK_left= COEWcanVERSCROLL_left;
 int COEWcanOK_width= 80;
 int COEWcanOK_height= 30;
 int COEWcanTITLE_bottom= COEWcanTITLE_top+COEWcanTITLE_height;
 int COEWcanHORSCROLL_right= COEWcanHORSCROLL_left+COEWcanHORSCROLL_width;
 int COEWcanHORSCROLL_top= COEWcanTITLE_bottom+8;
 int COEWcanHORSCROLL_bottom= COEWcanHORSCROLL_top+COEWcanHORSCROLL_height;
 int COEWcanOK_right= COEWcanOK_left+COEWcanOK_width;
 int COEWcanTITLE_right= COEWcanTITLE_left+COEWcanTITLE_width;
 int COEWcanCANCEL_height= COEWcanOK_height;
 int COEWcanCANCEL_width= COEWcanOK_width;
 int COEWcanVERSCROLL_right= COEWcanVERSCROLL_left+COEWcanVERSCROLL_width;
 int COEWcanVERSCROLL_top= COEWcanHORSCROLL_bottom+8;
 int COEWcanCANCEL_left= COEWcanOK_right+8;
 int COEWcanVERSCROLL_bottom= COEWcanVERSCROLL_top+COEWcanVERSCROLL_height;
 int COEWcanOK_top= COEWcanVERSCROLL_bottom+8;
 int COEWcanCANCEL_top= COEWcanOK_top;
 int COEWcanCANCEL_right= COEWcanCANCEL_left+COEWcanCANCEL_width;
 int COEWcanCANCEL_bottom= COEWcanCANCEL_top+COEWcanCANCEL_height;
 int COEWcanOK_bottom= COEWcanOK_top+COEWcanOK_height;
  L[0]= COEWcanHORSCROLL_left; L[1]= COEWcanHORSCROLL_top;
  L[2]= COEWcanHORSCROLL_width; L[3]= COEWcanHORSCROLL_height;
  L[4]= COEWcanVERSCROLL_left; L[5]= COEWcanVERSCROLL_top;
  L[6]= COEWcanVERSCROLL_width; L[7]= COEWcanVERSCROLL_height;
  L[8]= COEWcanOK_left; L[9]= COEWcanOK_top;
  L[10]= COEWcanOK_width; L[11]= COEWcanOK_height;
  L[12]= COEWcanCANCEL_left; L[13]= COEWcanCANCEL_top;
  L[14]= COEWcanCANCEL_width; L[15]= COEWcanCANCEL_height;
  L[16]= COEWcanTITLE_left; L[17]= COEWcanTITLE_top;
  L[18]= COEWcanTITLE_width; L[19]= COEWcanTITLE_height;
}
static void LAYOSCR_SCRewCANVAS(int *L,int WIDTH,int HEIGHT) {
 int COleft= 200;
 int COheight= 300;
 int COwidth= 300;
 int COright= COleft+COwidth;
 int COtop= 200;
 int CObottom= COtop+COheight;
  L[0]= COleft;
  L[1]= COtop;
  L[2]= COwidth;
  L[3]= COheight;
}
void gfx_SCRewCANVAS(){
 static int SWID[]= {     EWcanHORSCROLL,
    EWcanVERSCROLL,
    EWcanOK,
    EWcanCANCEL,
    EWcanTITLE,
};
  int i;
  int LC[20]; /*widget coords */
  int LL[4]; /* screen coords */
  LAYOSCR_SCRewCANVAS(LL,x_window_width,x_window_height);
  enter_screen(5, SWID,LL);
  widgets[EWcanHORSCROLL]= gui_checkbox_new("Scroll Horizontally",NULL,NULL);
  widgets[EWcanHORSCROLL]->number= EWcanHORSCROLL;
  widgets[EWcanVERSCROLL]= gui_checkbox_new("Scroll Vertically",NULL,NULL);
  widgets[EWcanVERSCROLL]->number= EWcanVERSCROLL;
  widgets[EWcanOK]= gfx_button("OK", 'T', NULL,GFXCLASS_BUTTON);
  widgets[EWcanOK]->number= EWcanOK;
  widgets[EWcanCANCEL]= gfx_button("Cancel", 'T', NULL,GFXCLASS_BUTTON);
  widgets[EWcanCANCEL]->number= EWcanCANCEL;
  widgets[EWcanTITLE]= gfx_label(3,0x000000,0xcccccc,'C',"Canvas Attributes");
  widgets[EWcanTITLE]->number= EWcanTITLE;
  LAYOWID_SCRewCANVAS(LL[2],LL[3],LC);
  for(i=0;i<5;i++) { LC[4*i]+= LL[0]; LC[4*i+1]+= LL[1]; }
  widget_move(widgets[EWcanHORSCROLL], LC[0], LC[1],LC[2],LC[3]);
  widget_move(widgets[EWcanVERSCROLL], LC[4], LC[5],LC[6],LC[7]);
  widget_move(widgets[EWcanOK], LC[8], LC[9],LC[10],LC[11]);
  widget_move(widgets[EWcanCANCEL], LC[12], LC[13],LC[14],LC[15]);
  widget_move(widgets[EWcanTITLE], LC[16], LC[17],LC[18],LC[19]);
  widget_show(widgets[EWcanHORSCROLL], 1);
  widget_show(widgets[EWcanVERSCROLL], 1);
  widget_show(widgets[EWcanOK], 1);
  widget_show(widgets[EWcanCANCEL], 1);
  widget_show(widgets[EWcanTITLE], 1);
  gfx_update_all();
}
static void LAYOWID_SCRewPROGRESS(int WIDTH,int HEIGHT,int *L) {
 int COEWprogTITLE_left= 0;
 int VPAD= 8;
 int VBUTW= 80;
 int VBUTH= 30;
 int VLABW= 220;
 int COEWprogCANCEL_height= VBUTH;
 int COEWprogCANCEL_width= VBUTW;
 int COEWprogTITLE_top= 0;
 int COEWprogTITLE_width= WIDTH;
 int COEWprogTITLE_height= 50;
 int COEWprogLAB0_left= VPAD;
 int COEWprogOK_height= VBUTH;
 int COEWprogOK_width= VBUTW;
 int COEWprogOK_bottom= HEIGHT-VPAD;
 int COEWprogOK_top= COEWprogOK_bottom-COEWprogOK_height;
 int COEWprogLAB0_width= VLABW;
 int COEWprogOK_left= (WIDTH-VPAD-2*VBUTW)/2;
 int COEWprogFILL_height= VBUTH;
 int COEWprogLAB0_height= VBUTH;
 int COEWprogLAB1_left= VPAD;
 int COEWprogLAB1_width= VLABW;
 int COEWprogLAB1_height= VBUTH;
 int COEWprogLAB2_left= VPAD;
 int COEWprogBG_height= VBUTH;
 int COEWprogLAB2_width= VLABW;
 int COEWprogLAB2_height= VBUTH;
 int COEWprogLAB3_left= VPAD;
 int COEWprogLAB3_width= VLABW;
 int COEWprogLAB3_height= VBUTH;
 int COEWprogFG_height= VBUTH;
 int COEWprogFONT_width= VBUTW*1.5;
 int COEWprogFONT_height= VBUTH;
 int COEWprogTITLE_right= COEWprogTITLE_left+COEWprogTITLE_width;
 int COEWprogCANCEL_top= COEWprogOK_top;
 int COEWprogTITLE_bottom= COEWprogTITLE_top+COEWprogTITLE_height;
 int COEWprogOK_right= COEWprogOK_left+COEWprogOK_width;
 int COEWprogLAB0_right= COEWprogLAB0_left+COEWprogLAB0_width;
 int COEWprogLAB0_top= COEWprogTITLE_bottom+VPAD;
 int COEWprogFONT_top= COEWprogLAB0_top;
 int COEWprogLAB0_bottom= COEWprogLAB0_top+COEWprogLAB0_height;
 int COEWprogFONT_left= COEWprogLAB0_right+VPAD;
 int COEWprogFG_width= COEWprogFONT_width;
 int COEWprogLAB1_right= COEWprogLAB1_left+COEWprogLAB1_width;
 int COEWprogLAB1_top= COEWprogLAB0_bottom+VPAD;
 int COEWprogLAB1_bottom= COEWprogLAB1_top+COEWprogLAB1_height;
 int COEWprogLAB3_right= COEWprogLAB3_left+COEWprogLAB3_width;
 int COEWprogBG_width= COEWprogFG_width;
 int COEWprogLAB2_right= COEWprogLAB2_left+COEWprogLAB2_width;
 int COEWprogLAB2_top= COEWprogLAB1_bottom+VPAD;
 int COEWprogLAB2_bottom= COEWprogLAB2_top+COEWprogLAB2_height;
 int COEWprogCANCEL_bottom= COEWprogCANCEL_top+COEWprogCANCEL_height;
 int COEWprogFG_left= COEWprogFONT_left;
 int COEWprogBG_top= COEWprogLAB2_top;
 int COEWprogFG_top= COEWprogLAB1_top;
 int COEWprogCANCEL_left= COEWprogOK_right+VPAD;
 int COEWprogFG_bottom= COEWprogFG_top+COEWprogFG_height;
 int COEWprogLAB3_top= COEWprogLAB2_bottom+VPAD;
 int COEWprogLAB3_bottom= COEWprogLAB3_top+COEWprogLAB3_height;
 int COEWprogFILL_top= COEWprogLAB3_top;
 int COEWprogFILL_bottom= COEWprogFILL_top+COEWprogFILL_height;
 int COEWprogFILL_width= COEWprogBG_width;
 int COEWprogBG_left= COEWprogFG_left;
 int COEWprogFONT_right= COEWprogFONT_left+COEWprogFONT_width;
 int COEWprogFONT_bottom= COEWprogFONT_top+COEWprogFONT_height;
 int COEWprogBG_bottom= COEWprogBG_top+COEWprogBG_height;
 int COEWprogBG_right= COEWprogBG_left+COEWprogBG_width;
 int COEWprogCANCEL_right= COEWprogCANCEL_left+COEWprogCANCEL_width;
 int COEWprogFG_right= COEWprogFG_left+COEWprogFG_width;
 int COEWprogFILL_left= COEWprogBG_left;
 int COEWprogFILL_right= COEWprogFILL_left+COEWprogFILL_width;
  L[0]= COEWprogTITLE_left; L[1]= COEWprogTITLE_top;
  L[2]= COEWprogTITLE_width; L[3]= COEWprogTITLE_height;
  L[4]= COEWprogLAB0_left; L[5]= COEWprogLAB0_top;
  L[6]= COEWprogLAB0_width; L[7]= COEWprogLAB0_height;
  L[8]= COEWprogLAB1_left; L[9]= COEWprogLAB1_top;
  L[10]= COEWprogLAB1_width; L[11]= COEWprogLAB1_height;
  L[12]= COEWprogLAB2_left; L[13]= COEWprogLAB2_top;
  L[14]= COEWprogLAB2_width; L[15]= COEWprogLAB2_height;
  L[16]= COEWprogLAB3_left; L[17]= COEWprogLAB3_top;
  L[18]= COEWprogLAB3_width; L[19]= COEWprogLAB3_height;
  L[20]= COEWprogFONT_left; L[21]= COEWprogFONT_top;
  L[22]= COEWprogFONT_width; L[23]= COEWprogFONT_height;
  L[24]= COEWprogFG_left; L[25]= COEWprogFG_top;
  L[26]= COEWprogFG_width; L[27]= COEWprogFG_height;
  L[28]= COEWprogBG_left; L[29]= COEWprogBG_top;
  L[30]= COEWprogBG_width; L[31]= COEWprogBG_height;
  L[32]= COEWprogFILL_left; L[33]= COEWprogFILL_top;
  L[34]= COEWprogFILL_width; L[35]= COEWprogFILL_height;
  L[36]= COEWprogOK_left; L[37]= COEWprogOK_top;
  L[38]= COEWprogOK_width; L[39]= COEWprogOK_height;
  L[40]= COEWprogCANCEL_left; L[41]= COEWprogCANCEL_top;
  L[42]= COEWprogCANCEL_width; L[43]= COEWprogCANCEL_height;
}
static void LAYOSCR_SCRewPROGRESS(int *L,int WIDTH,int HEIGHT) {
 int COleft= 50;
 int COheight= 400;
 int COwidth= 400;
 int COright= COleft+COwidth;
 int COtop= 50;
 int CObottom= COtop+COheight;
  L[0]= COleft;
  L[1]= COtop;
  L[2]= COwidth;
  L[3]= COheight;
}
void gfx_SCRewPROGRESS(){
 static int SWID[]= {     EWprogTITLE,
    EWprogLAB0,
    EWprogLAB1,
    EWprogLAB2,
    EWprogLAB3,
    EWprogFONT,
    EWprogFG,
    EWprogBG,
    EWprogFILL,
    EWprogOK,
    EWprogCANCEL,
};
  int i;
  int LC[44]; /*widget coords */
  int LL[4]; /* screen coords */
  LAYOSCR_SCRewPROGRESS(LL,x_window_width,x_window_height);
  enter_screen(11, SWID,LL);
  widgets[EWprogTITLE]= gfx_label(3,0x000000,0xcccccc,'C',"Progress Bar Attributes");
  widgets[EWprogTITLE]->number= EWprogTITLE;
  widgets[EWprogLAB0]= gfx_label(1,0x000000,0xededed,'L',"Font");
  widgets[EWprogLAB0]->number= EWprogLAB0;
  widgets[EWprogLAB1]= gfx_label(1,0x000000,0xededed,'L',"Foreground");
  widgets[EWprogLAB1]->number= EWprogLAB1;
  widgets[EWprogLAB2]= gfx_label(1,0x000000,0xededed,'L',"Background");
  widgets[EWprogLAB2]->number= EWprogLAB2;
  widgets[EWprogLAB3]= gfx_label(1,0x000000,0xededed,'L',"Fill Color");
  widgets[EWprogLAB3]->number= EWprogLAB3;
  widgets[EWprogFONT]= dropdown_new(NULL,NULL);
  widgets[EWprogFONT]->number= EWprogFONT;
  widgets[EWprogFG]= text_entry_new("");
  widgets[EWprogFG]->number= EWprogFG;
  widgets[EWprogBG]= text_entry_new("");
  widgets[EWprogBG]->number= EWprogBG;
  widgets[EWprogFILL]= text_entry_new("");
  widgets[EWprogFILL]->number= EWprogFILL;
  widgets[EWprogOK]= gfx_button("OK", 'T', NULL,GFXCLASS_BUTTON);
  widgets[EWprogOK]->number= EWprogOK;
  widgets[EWprogCANCEL]= gfx_button("Cancel", 'T', NULL,GFXCLASS_BUTTON);
  widgets[EWprogCANCEL]->number= EWprogCANCEL;
  LAYOWID_SCRewPROGRESS(LL[2],LL[3],LC);
  for(i=0;i<11;i++) { LC[4*i]+= LL[0]; LC[4*i+1]+= LL[1]; }
  widget_move(widgets[EWprogTITLE], LC[0], LC[1],LC[2],LC[3]);
  widget_move(widgets[EWprogLAB0], LC[4], LC[5],LC[6],LC[7]);
  widget_move(widgets[EWprogLAB1], LC[8], LC[9],LC[10],LC[11]);
  widget_move(widgets[EWprogLAB2], LC[12], LC[13],LC[14],LC[15]);
  widget_move(widgets[EWprogLAB3], LC[16], LC[17],LC[18],LC[19]);
  widget_move(widgets[EWprogFONT], LC[20], LC[21],LC[22],LC[23]);
  widget_move(widgets[EWprogFG], LC[24], LC[25],LC[26],LC[27]);
  widget_move(widgets[EWprogBG], LC[28], LC[29],LC[30],LC[31]);
  widget_move(widgets[EWprogFILL], LC[32], LC[33],LC[34],LC[35]);
  widget_move(widgets[EWprogOK], LC[36], LC[37],LC[38],LC[39]);
  widget_move(widgets[EWprogCANCEL], LC[40], LC[41],LC[42],LC[43]);
  widget_show(widgets[EWprogTITLE], 1);
  widget_show(widgets[EWprogLAB0], 1);
  widget_show(widgets[EWprogLAB1], 1);
  widget_show(widgets[EWprogLAB2], 1);
  widget_show(widgets[EWprogLAB3], 1);
  widget_show(widgets[EWprogFONT], 1);
  widget_show(widgets[EWprogFG], 1);
  widget_show(widgets[EWprogBG], 1);
  widget_show(widgets[EWprogFILL], 1);
  widget_show(widgets[EWprogOK], 1);
  widget_show(widgets[EWprogCANCEL], 1);
  gfx_update_all();
}
static void LAYOWID_SCRewICONLIST(int WIDTH,int HEIGHT,int *L) {
 int COEWiconlistTITLE_left= 0;
 int VPAD= 8;
 int VBUTW= 90;
 int VBUTH= 30;
 int COEWiconlistTITLE_top= 0;
 int COEWiconlistTITLE_width= WIDTH;
 int COEWiconlistTITLE_height= 50;
 int COWewICONLISTlab0_left= VPAD;
 int COWewICONLISTlab0_width= 165;
 int COWewICONLISTlab0_height= VBUTH;
 int COWewICONLISTlab1_left= COWewICONLISTlab0_left;
 int COWewICONLISTlab1_width= COWewICONLISTlab0_width;
 int COWewICONLISTlab1_height= COWewICONLISTlab0_height;
 int COWewICONLISTlab2_left= COWewICONLISTlab0_left;
 int COWewICONLISTlab2_width= COWewICONLISTlab0_width;
 int COWewICONLISTlab2_height= COWewICONLISTlab0_height;
 int COWewICONLISTlab3_left= COWewICONLISTlab0_left;
 int COWewICONLISTlab3_width= COWewICONLISTlab0_width;
 int COWewICONLISTlab3_height= COWewICONLISTlab0_height;
 int COWewICONLISTlab4_left= COWewICONLISTlab0_left;
 int COWewICONLISTlab4_width= COWewICONLISTlab0_width;
 int COWewICONLISTlab4_height= COWewICONLISTlab0_height;
 int COWewICONLISTok_height= VBUTH;
 int COWewICONLISTok_width= VBUTW;
 int COWewICONLISTok_bottom= HEIGHT-VPAD;
 int COWewICONLISTok_top= COWewICONLISTok_bottom-COWewICONLISTok_height;
 int COWewICONLISTfg_width= 120;
 int COWewICONLISTok_left= (WIDTH-VPAD-2*VBUTW)/2;
 int COWewICONLISTfg_height= VBUTH;
 int COWewICONLISTmaxtextw_width= COWewICONLISTfg_width;
 int COWewICONLISTbg_width= COWewICONLISTfg_width;
 int COWewICONLISTbg_height= COWewICONLISTfg_height;
 int COWewICONLISThpad_width= COWewICONLISTfg_width;
 int COWewICONLISThpad_height= COWewICONLISTfg_height;
 int COWewICONLISTvpad_height= COWewICONLISTfg_height;
 int COWewICONLISTvpad_width= COWewICONLISTfg_width;
 int COEWiconlistTITLE_right= COEWiconlistTITLE_left+COEWiconlistTITLE_width;
 int COWewICONLISTmulti_width= COWewICONLISTmaxtextw_width;
 int COEWiconlistTITLE_bottom= COEWiconlistTITLE_top+COEWiconlistTITLE_height;
 int COWewICONLISTlab0_right= COWewICONLISTlab0_left+COWewICONLISTlab0_width;
 int COWewICONLISTlab0_top= COEWiconlistTITLE_bottom+VPAD;
 int COWewICONLISTlab0_bottom= COWewICONLISTlab0_top+COWewICONLISTlab0_height;
 int COWewICONLISTlab5_height= COWewICONLISTlab4_height;
 int COWewICONLISTlab5_width= COWewICONLISTlab4_width;
 int COWewICONLISTlab1_right= COWewICONLISTlab1_left+COWewICONLISTlab1_width;
 int COWewICONLISTlab1_top= COWewICONLISTlab0_bottom+VPAD;
 int COWewICONLISTlab1_bottom= COWewICONLISTlab1_top+COWewICONLISTlab1_height;
 int COWewICONLISTlab2_right= COWewICONLISTlab2_left+COWewICONLISTlab2_width;
 int COWewICONLISTlab2_top= COWewICONLISTlab1_bottom+VPAD;
 int COWewICONLISTlab2_bottom= COWewICONLISTlab2_top+COWewICONLISTlab2_height;
 int COWewICONLISTlab5_left= COWewICONLISTlab4_left;
 int COWewICONLISTcancel_height= COWewICONLISTok_height;
 int COWewICONLISTcancel_width= COWewICONLISTok_width;
 int COWewICONLISTmaxtextw_height= COWewICONLISTfg_height;
 int COWewICONLISTlab3_right= COWewICONLISTlab3_left+COWewICONLISTlab3_width;
 int COWewICONLISTfg_top= COWewICONLISTlab0_top;
 int COWewICONLISTlab3_top= COWewICONLISTlab2_bottom+VPAD;
 int COWewICONLISTfg_left= COWewICONLISTlab0_right+VPAD;
 int COWewICONLISTok_right= COWewICONLISTok_left+COWewICONLISTok_width;
 int COWewICONLISTcancel_left= COWewICONLISTok_right+VPAD;
 int COWewICONLISTlab3_bottom= COWewICONLISTlab3_top+COWewICONLISTlab3_height;
 int COWewICONLISTlab4_top= COWewICONLISTlab3_bottom+VPAD;
 int COWewICONLISTlab4_right= COWewICONLISTlab4_left+COWewICONLISTlab4_width;
 int COWewICONLISTcancel_right= COWewICONLISTcancel_left+COWewICONLISTcancel_width;
 int COWewICONLISTcancel_top= COWewICONLISTok_top;
 int COWewICONLISTcancel_bottom= COWewICONLISTcancel_top+COWewICONLISTcancel_height;
 int COWewICONLISTmulti_height= COWewICONLISTmaxtextw_height;
 int COWewICONLISTlab4_bottom= COWewICONLISTlab4_top+COWewICONLISTlab4_height;
 int COWewICONLISTfg_right= COWewICONLISTfg_left+COWewICONLISTfg_width;
 int COWewICONLISTfg_bottom= COWewICONLISTfg_top+COWewICONLISTfg_height;
 int COWewICONLISTvpad_left= COWewICONLISTfg_left;
 int COWewICONLISTbg_left= COWewICONLISTfg_left;
 int COWewICONLISTbg_right= COWewICONLISTbg_left+COWewICONLISTbg_width;
 int COWewICONLISTbg_top= COWewICONLISTfg_bottom+VPAD;
 int COWewICONLISTbg_bottom= COWewICONLISTbg_top+COWewICONLISTbg_height;
 int COWewICONLISTlab5_right= COWewICONLISTlab5_left+COWewICONLISTlab5_width;
 int COWewICONLISTlab5_top= COWewICONLISTlab4_bottom+VPAD;
 int COWewICONLISTlab5_bottom= COWewICONLISTlab5_top+COWewICONLISTlab5_height;
 int COWewICONLISTmulti_top= COWewICONLISTlab5_top;
 int COWewICONLISTmaxtextw_left= COWewICONLISTfg_left;
 int COWewICONLISThpad_left= COWewICONLISTfg_left;
 int COWewICONLISThpad_right= COWewICONLISThpad_left+COWewICONLISThpad_width;
 int COWewICONLISThpad_top= COWewICONLISTbg_bottom+VPAD;
 int COWewICONLISTmulti_left= COWewICONLISTmaxtextw_left;
 int COWewICONLISThpad_bottom= COWewICONLISThpad_top+COWewICONLISThpad_height;
 int COWewICONLISTvpad_top= COWewICONLISThpad_bottom+VPAD;
 int COWewICONLISTvpad_bottom= COWewICONLISTvpad_top+COWewICONLISTvpad_height;
 int COWewICONLISTmulti_right= COWewICONLISTmulti_left+COWewICONLISTmulti_width;
 int COWewICONLISTmaxtextw_right= COWewICONLISTmaxtextw_left+COWewICONLISTmaxtextw_width;
 int COWewICONLISTmulti_bottom= COWewICONLISTmulti_top+COWewICONLISTmulti_height;
 int COWewICONLISTmaxtextw_top= COWewICONLISTvpad_bottom+VPAD;
 int COWewICONLISTvpad_right= COWewICONLISTvpad_left+COWewICONLISTvpad_width;
 int COWewICONLISTmaxtextw_bottom= COWewICONLISTmaxtextw_top+COWewICONLISTmaxtextw_height;
  L[0]= COEWiconlistTITLE_left; L[1]= COEWiconlistTITLE_top;
  L[2]= COEWiconlistTITLE_width; L[3]= COEWiconlistTITLE_height;
  L[4]= COWewICONLISTlab0_left; L[5]= COWewICONLISTlab0_top;
  L[6]= COWewICONLISTlab0_width; L[7]= COWewICONLISTlab0_height;
  L[8]= COWewICONLISTlab1_left; L[9]= COWewICONLISTlab1_top;
  L[10]= COWewICONLISTlab1_width; L[11]= COWewICONLISTlab1_height;
  L[12]= COWewICONLISTlab2_left; L[13]= COWewICONLISTlab2_top;
  L[14]= COWewICONLISTlab2_width; L[15]= COWewICONLISTlab2_height;
  L[16]= COWewICONLISTlab3_left; L[17]= COWewICONLISTlab3_top;
  L[18]= COWewICONLISTlab3_width; L[19]= COWewICONLISTlab3_height;
  L[20]= COWewICONLISTlab4_left; L[21]= COWewICONLISTlab4_top;
  L[22]= COWewICONLISTlab4_width; L[23]= COWewICONLISTlab4_height;
  L[24]= COWewICONLISTfg_left; L[25]= COWewICONLISTfg_top;
  L[26]= COWewICONLISTfg_width; L[27]= COWewICONLISTfg_height;
  L[28]= COWewICONLISTbg_left; L[29]= COWewICONLISTbg_top;
  L[30]= COWewICONLISTbg_width; L[31]= COWewICONLISTbg_height;
  L[32]= COWewICONLISThpad_left; L[33]= COWewICONLISThpad_top;
  L[34]= COWewICONLISThpad_width; L[35]= COWewICONLISThpad_height;
  L[36]= COWewICONLISTvpad_left; L[37]= COWewICONLISTvpad_top;
  L[38]= COWewICONLISTvpad_width; L[39]= COWewICONLISTvpad_height;
  L[40]= COWewICONLISTmaxtextw_left; L[41]= COWewICONLISTmaxtextw_top;
  L[42]= COWewICONLISTmaxtextw_width; L[43]= COWewICONLISTmaxtextw_height;
  L[44]= COWewICONLISTok_left; L[45]= COWewICONLISTok_top;
  L[46]= COWewICONLISTok_width; L[47]= COWewICONLISTok_height;
  L[48]= COWewICONLISTcancel_left; L[49]= COWewICONLISTcancel_top;
  L[50]= COWewICONLISTcancel_width; L[51]= COWewICONLISTcancel_height;
  L[52]= COWewICONLISTlab5_left; L[53]= COWewICONLISTlab5_top;
  L[54]= COWewICONLISTlab5_width; L[55]= COWewICONLISTlab5_height;
  L[56]= COWewICONLISTmulti_left; L[57]= COWewICONLISTmulti_top;
  L[58]= COWewICONLISTmulti_width; L[59]= COWewICONLISTmulti_height;
}
static void LAYOSCR_SCRewICONLIST(int *L,int WIDTH,int HEIGHT) {
 int COleft= 50;
 int COheight= 400;
 int COwidth= 400;
 int COright= COleft+COwidth;
 int COtop= 50;
 int CObottom= COtop+COheight;
  L[0]= COleft;
  L[1]= COtop;
  L[2]= COwidth;
  L[3]= COheight;
}
void gfx_SCRewICONLIST(){
 static int SWID[]= {     EWiconlistTITLE,
    WewICONLISTlab0,
    WewICONLISTlab1,
    WewICONLISTlab2,
    WewICONLISTlab3,
    WewICONLISTlab4,
    WewICONLISTfg,
    WewICONLISTbg,
    WewICONLISThpad,
    WewICONLISTvpad,
    WewICONLISTmaxtextw,
    WewICONLISTok,
    WewICONLISTcancel,
    WewICONLISTlab5,
    WewICONLISTmulti,
};
  int i;
  int LC[60]; /*widget coords */
  int LL[4]; /* screen coords */
  LAYOSCR_SCRewICONLIST(LL,x_window_width,x_window_height);
  enter_screen(15, SWID,LL);
  widgets[EWiconlistTITLE]= gfx_label(3,0x000000,0xcccccc,'C',"Icon List Properties");
  widgets[EWiconlistTITLE]->number= EWiconlistTITLE;
  widgets[WewICONLISTlab0]= gfx_label(1,0x000000,0xededed,'L',"Foreground");
  widgets[WewICONLISTlab0]->number= WewICONLISTlab0;
  widgets[WewICONLISTlab1]= gfx_label(1,0x000000,0xededed,'L',"Background");
  widgets[WewICONLISTlab1]->number= WewICONLISTlab1;
  widgets[WewICONLISTlab2]= gfx_label(1,0x000000,0xededed,'L',"Horizontal Padding");
  widgets[WewICONLISTlab2]->number= WewICONLISTlab2;
  widgets[WewICONLISTlab3]= gfx_label(1,0x000000,0xededed,'L',"Vertical Padding");
  widgets[WewICONLISTlab3]->number= WewICONLISTlab3;
  widgets[WewICONLISTlab4]= gfx_label(1,0x000000,0xededed,'L',"Max. Text Width");
  widgets[WewICONLISTlab4]->number= WewICONLISTlab4;
  widgets[WewICONLISTfg]= text_entry_new("");
  widgets[WewICONLISTfg]->number= WewICONLISTfg;
  widgets[WewICONLISTbg]= text_entry_new("");
  widgets[WewICONLISTbg]->number= WewICONLISTbg;
  widgets[WewICONLISThpad]= text_entry_new("");
  widgets[WewICONLISThpad]->number= WewICONLISThpad;
  widgets[WewICONLISTvpad]= text_entry_new("");
  widgets[WewICONLISTvpad]->number= WewICONLISTvpad;
  widgets[WewICONLISTmaxtextw]= text_entry_new("");
  widgets[WewICONLISTmaxtextw]->number= WewICONLISTmaxtextw;
  widgets[WewICONLISTok]= gfx_button("OK", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WewICONLISTok]->number= WewICONLISTok;
  widgets[WewICONLISTcancel]= gfx_button("Cancel", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WewICONLISTcancel]->number= WewICONLISTcancel;
  widgets[WewICONLISTlab5]= gfx_label(1,0x000000,0xededed,'L',"Multi Select");
  widgets[WewICONLISTlab5]->number= WewICONLISTlab5;
  widgets[WewICONLISTmulti]= text_entry_new("");
  widgets[WewICONLISTmulti]->number= WewICONLISTmulti;
  LAYOWID_SCRewICONLIST(LL[2],LL[3],LC);
  for(i=0;i<15;i++) { LC[4*i]+= LL[0]; LC[4*i+1]+= LL[1]; }
  widget_move(widgets[EWiconlistTITLE], LC[0], LC[1],LC[2],LC[3]);
  widget_move(widgets[WewICONLISTlab0], LC[4], LC[5],LC[6],LC[7]);
  widget_move(widgets[WewICONLISTlab1], LC[8], LC[9],LC[10],LC[11]);
  widget_move(widgets[WewICONLISTlab2], LC[12], LC[13],LC[14],LC[15]);
  widget_move(widgets[WewICONLISTlab3], LC[16], LC[17],LC[18],LC[19]);
  widget_move(widgets[WewICONLISTlab4], LC[20], LC[21],LC[22],LC[23]);
  widget_move(widgets[WewICONLISTfg], LC[24], LC[25],LC[26],LC[27]);
  widget_move(widgets[WewICONLISTbg], LC[28], LC[29],LC[30],LC[31]);
  widget_move(widgets[WewICONLISThpad], LC[32], LC[33],LC[34],LC[35]);
  widget_move(widgets[WewICONLISTvpad], LC[36], LC[37],LC[38],LC[39]);
  widget_move(widgets[WewICONLISTmaxtextw], LC[40], LC[41],LC[42],LC[43]);
  widget_move(widgets[WewICONLISTok], LC[44], LC[45],LC[46],LC[47]);
  widget_move(widgets[WewICONLISTcancel], LC[48], LC[49],LC[50],LC[51]);
  widget_move(widgets[WewICONLISTlab5], LC[52], LC[53],LC[54],LC[55]);
  widget_move(widgets[WewICONLISTmulti], LC[56], LC[57],LC[58],LC[59]);
  widget_show(widgets[EWiconlistTITLE], 1);
  widget_show(widgets[WewICONLISTlab0], 1);
  widget_show(widgets[WewICONLISTlab1], 1);
  widget_show(widgets[WewICONLISTlab2], 1);
  widget_show(widgets[WewICONLISTlab3], 1);
  widget_show(widgets[WewICONLISTlab4], 1);
  widget_show(widgets[WewICONLISTfg], 1);
  widget_show(widgets[WewICONLISTbg], 1);
  widget_show(widgets[WewICONLISThpad], 1);
  widget_show(widgets[WewICONLISTvpad], 1);
  widget_show(widgets[WewICONLISTmaxtextw], 1);
  widget_show(widgets[WewICONLISTok], 1);
  widget_show(widgets[WewICONLISTcancel], 1);
  widget_show(widgets[WewICONLISTlab5], 1);
  widget_show(widgets[WewICONLISTmulti], 1);
  gfx_update_all();
}
static void LAYOWID_SCRfonts(int WIDTH,int HEIGHT,int *L) {
 int COWfntLAB0_left= 0;
 int VPAD= 8;
 int COWfntLAB0_top= 0;
 int COWfntLAB0_width= WIDTH;
 int COWfntLAB0_height= font3height*1.2;
 int COWfntDEFFONT_left= VPAD;
 int COWfntDEFFONT_right= WIDTH-VPAD;
 int COWfntDEFFONT_width= COWfntDEFFONT_right-COWfntDEFFONT_left;
 int COWfntDEFFONT_height= font1height*1.2;
 int COWfntCUSTOMFONT_left= COWfntDEFFONT_left;
 int COWfntSAVE_bottom= HEIGHT-VPAD;
 int COWfntCUSTOMFONT_width= COWfntDEFFONT_width;
 int COWfntCUSTOMFONT_height= COWfntDEFFONT_height;
 int COWfntLAB1_left= COWfntLAB0_left;
 int COWfntLAB1_width= COWfntLAB0_width;
 int COWfntLAB1_height= font1height*1.5;
 int COWfntFILES_left= VPAD;
 int COWfntFILES_height= font1height*6;
 int COWfntFILEadd_right= WIDTH-VPAD;
 int COWfntFILEadd_width= font1height*4;
 int COWfntFILEadd_height= COWfntLAB1_height;
 int COWfntFONTmodify_width= COWfntFILEadd_width;
 int COWfntFILEremove_width= COWfntFILEadd_width;
 int COWfntFILEremove_height= COWfntFILEadd_height;
 int COWfntLAB5_left= COWfntLAB1_left;
 int COWfntLAB5_width= COWfntLAB1_width;
 int COWfntFONTADD_height= COWfntFILEadd_height;
 int COWfntFONTADD_width= COWfntFILEadd_width;
 int COWfntLAB5_height= COWfntLAB1_height;
 int COWfntFONTS_left= VPAD;
 int COWfntFONTS_width= font1height*12;
 int COWfntFONTS_height= font1height*6;
 int COWfntLAB6_width= font1height*8;
 int COWfntLAB6_height= font1height*1.3;
 int COWfntSIZE_width= font1height*3;
 int COWfntSIZE_height= COWfntLAB6_height;
 int COWfntLAB7_width= COWfntLAB6_width;
 int COWfntLAB7_height= COWfntLAB6_height;
 int COWfntLAB8_height= COWfntLAB6_height;
 int COWfntLAB8_width= COWfntLAB6_width;
 int COWfntFILEID_width= COWfntSIZE_width;
 int COWfntFILEID_height= COWfntSIZE_height;
 int COWfntCANCEL_height= COWfntFONTADD_height;
 int COWfntLAB0_right= COWfntLAB0_left+COWfntLAB0_width;
 int COWfntCANCEL_width= COWfntFONTADD_width;
 int COWfntLAB0_bottom= COWfntLAB0_top+COWfntLAB0_height;
 int COWfntDEFFONT_top= COWfntLAB0_bottom+0;
 int COWfntDEFFONT_bottom= COWfntDEFFONT_top+COWfntDEFFONT_height;
 int COWfntSAVE_height= COWfntFONTADD_height;
 int COWfntSAVE_width= COWfntFONTADD_width;
 int COWfntSAVE_top= COWfntSAVE_bottom-COWfntSAVE_height;
 int COWfntCUSTOMFONT_right= COWfntCUSTOMFONT_left+COWfntCUSTOMFONT_width;
 int COWfntCUSTOMFONT_top= COWfntDEFFONT_bottom+VPAD;
 int COWfntCUSTOMFONT_bottom= COWfntCUSTOMFONT_top+COWfntCUSTOMFONT_height;
 int COWfntSAVE_left= WIDTH/2-VPAD/2-COWfntSAVE_width;
 int COWfntLAB1_right= COWfntLAB1_left+COWfntLAB1_width;
 int COWfntLAB1_top= COWfntCUSTOMFONT_bottom;
 int COWfntLAB1_bottom= COWfntLAB1_top+COWfntLAB1_height;
 int COWfntFONTremove_width= COWfntFONTmodify_width;
 int COWfntFILES_right= WIDTH-COWfntFILEadd_width-2*VPAD;
 int COWfntFILES_top= COWfntLAB1_bottom;
 int COWfntFILES_bottom= COWfntFILES_top+COWfntFILES_height;
 int COWfntFILES_width= COWfntFILES_right-COWfntFILES_left;
 int COWfntFONTNUM_width= COWfntSIZE_width;
 int COWfntFILEadd_left= COWfntFILEadd_right-COWfntFILEadd_width;
 int COWfntFILEadd_top= COWfntFILES_top;
 int COWfntFILEadd_bottom= COWfntFILEadd_top+COWfntFILEadd_height;
 int COWfntFONTmodify_height= COWfntFILEadd_height;
 int COWfntFONTNUM_height= COWfntSIZE_height;
 int COWfntFILEremove_left= COWfntFILEadd_left;
 int COWfntFILEremove_right= COWfntFILEremove_left+COWfntFILEremove_width;
 int COWfntFILEremove_top= COWfntFILEadd_bottom+VPAD;
 int COWfntFONTS_right= COWfntFONTS_left+COWfntFONTS_width;
 int COWfntFILEremove_bottom= COWfntFILEremove_top+COWfntFILEremove_height;
 int COWfntLAB5_right= COWfntLAB5_left+COWfntLAB5_width;
 int COWfntLAB5_top= COWfntFILES_bottom+0;
 int COWfntLAB5_bottom= COWfntLAB5_top+COWfntLAB5_height;
 int COWfntCANCEL_top= COWfntSAVE_top;
 int COWfntSAVE_right= COWfntSAVE_left+COWfntSAVE_width;
 int COWfntFONTremove_height= COWfntFONTmodify_height;
 int COWfntLAB6_left= COWfntFONTS_right+VPAD;
 int COWfntFONTADD_left= COWfntFONTS_right+VPAD;
 int COWfntFONTS_top= COWfntLAB5_bottom;
 int COWfntFONTADD_right= COWfntFONTADD_left+COWfntFONTADD_width;
 int COWfntLAB8_left= COWfntLAB6_left;
 int COWfntFONTS_bottom= COWfntFONTS_top+COWfntFONTS_height;
 int COWfntLAB8_right= COWfntLAB8_left+COWfntLAB8_width;
 int COWfntCANCEL_bottom= COWfntCANCEL_top+COWfntCANCEL_height;
 int COWfntCANCEL_left= COWfntSAVE_right+VPAD;
 int COWfntLAB6_right= COWfntLAB6_left+COWfntLAB6_width;
 int COWfntFONTmodify_left= COWfntFONTADD_right+VPAD;
 int COWfntLAB6_top= COWfntFONTS_top;
 int COWfntLAB7_left= COWfntLAB6_left;
 int COWfntLAB6_bottom= COWfntLAB6_top+COWfntLAB6_height;
 int COWfntFONTmodify_right= COWfntFONTmodify_left+COWfntFONTmodify_width;
 int COWfntSIZE_left= COWfntLAB6_right+VPAD;
 int COWfntSIZE_right= COWfntSIZE_left+COWfntSIZE_width;
 int COWfntSIZE_top= COWfntLAB6_top;
 int COWfntCANCEL_right= COWfntCANCEL_left+COWfntCANCEL_width;
 int COWfntFONTremove_left= COWfntFONTmodify_right+VPAD;
 int COWfntSIZE_bottom= COWfntSIZE_top+COWfntSIZE_height;
 int COWfntFILEID_top= COWfntSIZE_bottom+VPAD;
 int COWfntFILEID_left= COWfntSIZE_left;
 int COWfntFONTNUM_left= COWfntSIZE_left;
 int COWfntLAB7_top= COWfntLAB6_bottom+VPAD;
 int COWfntFONTremove_right= COWfntFONTremove_left+COWfntFONTremove_width;
 int COWfntLAB7_right= COWfntLAB7_left+COWfntLAB7_width;
 int COWfntFILEID_bottom= COWfntFILEID_top+COWfntFILEID_height;
 int COWfntLAB7_bottom= COWfntLAB7_top+COWfntLAB7_height;
 int COWfntFONTNUM_top= COWfntFILEID_bottom+VPAD;
 int COWfntFONTNUM_right= COWfntFONTNUM_left+COWfntFONTNUM_width;
 int COWfntFILEID_right= COWfntFILEID_left+COWfntFILEID_width;
 int COWfntLAB8_top= COWfntLAB7_bottom+VPAD;
 int COWfntFONTNUM_bottom= COWfntFONTNUM_top+COWfntFONTNUM_height;
 int COWfntLAB8_bottom= COWfntLAB8_top+COWfntLAB8_height;
 int COWfntFONTADD_top= COWfntLAB8_bottom+2*VPAD;
 int COWfntFONTADD_bottom= COWfntFONTADD_top+COWfntFONTADD_height;
 int COWfntFONTmodify_top= COWfntFONTADD_top;
 int COWfntFONTremove_top= COWfntFONTmodify_top;
 int COWfntFONTmodify_bottom= COWfntFONTmodify_top+COWfntFONTmodify_height;
 int COWfntFONTremove_bottom= COWfntFONTremove_top+COWfntFONTremove_height;
  L[0]= COWfntLAB0_left; L[1]= COWfntLAB0_top;
  L[2]= COWfntLAB0_width; L[3]= COWfntLAB0_height;
  L[4]= COWfntDEFFONT_left; L[5]= COWfntDEFFONT_top;
  L[6]= COWfntDEFFONT_width; L[7]= COWfntDEFFONT_height;
  L[8]= COWfntCUSTOMFONT_left; L[9]= COWfntCUSTOMFONT_top;
  L[10]= COWfntCUSTOMFONT_width; L[11]= COWfntCUSTOMFONT_height;
  L[12]= COWfntLAB1_left; L[13]= COWfntLAB1_top;
  L[14]= COWfntLAB1_width; L[15]= COWfntLAB1_height;
  L[16]= COWfntFILES_left; L[17]= COWfntFILES_top;
  L[18]= COWfntFILES_width; L[19]= COWfntFILES_height;
  L[20]= COWfntFILEadd_left; L[21]= COWfntFILEadd_top;
  L[22]= COWfntFILEadd_width; L[23]= COWfntFILEadd_height;
  L[24]= COWfntFILEremove_left; L[25]= COWfntFILEremove_top;
  L[26]= COWfntFILEremove_width; L[27]= COWfntFILEremove_height;
  L[28]= COWfntLAB5_left; L[29]= COWfntLAB5_top;
  L[30]= COWfntLAB5_width; L[31]= COWfntLAB5_height;
  L[32]= COWfntFONTS_left; L[33]= COWfntFONTS_top;
  L[34]= COWfntFONTS_width; L[35]= COWfntFONTS_height;
  L[36]= COWfntLAB6_left; L[37]= COWfntLAB6_top;
  L[38]= COWfntLAB6_width; L[39]= COWfntLAB6_height;
  L[40]= COWfntSIZE_left; L[41]= COWfntSIZE_top;
  L[42]= COWfntSIZE_width; L[43]= COWfntSIZE_height;
  L[44]= COWfntLAB7_left; L[45]= COWfntLAB7_top;
  L[46]= COWfntLAB7_width; L[47]= COWfntLAB7_height;
  L[48]= COWfntFILEID_left; L[49]= COWfntFILEID_top;
  L[50]= COWfntFILEID_width; L[51]= COWfntFILEID_height;
  L[52]= COWfntLAB8_left; L[53]= COWfntLAB8_top;
  L[54]= COWfntLAB8_width; L[55]= COWfntLAB8_height;
  L[56]= COWfntFONTNUM_left; L[57]= COWfntFONTNUM_top;
  L[58]= COWfntFONTNUM_width; L[59]= COWfntFONTNUM_height;
  L[60]= COWfntFONTADD_left; L[61]= COWfntFONTADD_top;
  L[62]= COWfntFONTADD_width; L[63]= COWfntFONTADD_height;
  L[64]= COWfntFONTmodify_left; L[65]= COWfntFONTmodify_top;
  L[66]= COWfntFONTmodify_width; L[67]= COWfntFONTmodify_height;
  L[68]= COWfntFONTremove_left; L[69]= COWfntFONTremove_top;
  L[70]= COWfntFONTremove_width; L[71]= COWfntFONTremove_height;
  L[72]= COWfntSAVE_left; L[73]= COWfntSAVE_top;
  L[74]= COWfntSAVE_width; L[75]= COWfntSAVE_height;
  L[76]= COWfntCANCEL_left; L[77]= COWfntCANCEL_top;
  L[78]= COWfntCANCEL_width; L[79]= COWfntCANCEL_height;
}
static void LAYOSCR_SCRfonts(int *L,int WIDTH,int HEIGHT) {
 int COleft= 50;
 int COheight= 600;
 int COwidth= 600;
 int COright= COleft+COwidth;
 int COtop= 50;
 int CObottom= COtop+COheight;
  L[0]= COleft;
  L[1]= COtop;
  L[2]= COwidth;
  L[3]= COheight;
}
void gfx_SCRfonts(){
 static int SWID[]= {     WfntLAB0,
    WfntDEFFONT,
    WfntCUSTOMFONT,
    WfntLAB1,
    WfntFILES,
    WfntFILEadd,
    WfntFILEremove,
    WfntLAB5,
    WfntFONTS,
    WfntLAB6,
    WfntSIZE,
    WfntLAB7,
    WfntFILEID,
    WfntLAB8,
    WfntFONTNUM,
    WfntFONTADD,
    WfntFONTmodify,
    WfntFONTremove,
    WfntSAVE,
    WfntCANCEL,
};
  int i;
  int LC[80]; /*widget coords */
  int LL[4]; /* screen coords */
  LAYOSCR_SCRfonts(LL,x_window_width,x_window_height);
  enter_screen(20, SWID,LL);
  widgets[WfntLAB0]= gfx_label(3,0x00,0xcccccc,'C',"Font Settings");
  widgets[WfntLAB0]->number= WfntLAB0;
  widgets[WfntDEFFONT]= radio_new("Default fonts",WfntDEFFONT);
  widgets[WfntDEFFONT]->number= WfntDEFFONT;
  widgets[WfntCUSTOMFONT]= radio_new("Custom Fonts",WfntDEFFONT);
  widgets[WfntCUSTOMFONT]->number= WfntCUSTOMFONT;
  widgets[WfntLAB1]= gfx_label(2,0x000000,0xededed,'C',"Font Files");
  widgets[WfntLAB1]->number= WfntLAB1;
  widgets[WfntFILES]= gui_list_new(0,0,NULL,NULL,NULL);
  widgets[WfntFILES]->number= WfntFILES;
  widgets[WfntFILEadd]= gfx_button("Add", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WfntFILEadd]->number= WfntFILEadd;
  widgets[WfntFILEremove]= gfx_button("Remove", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WfntFILEremove]->number= WfntFILEremove;
  widgets[WfntLAB5]= gfx_label(2,0x000000,0xededed,'C',"Fonts");
  widgets[WfntLAB5]->number= WfntLAB5;
  widgets[WfntFONTS]= gui_list_new(0,0,NULL,NULL,NULL);
  widgets[WfntFONTS]->number= WfntFONTS;
  widgets[WfntLAB6]= gfx_label(1,0x000000,0xededed,'R',"Size");
  widgets[WfntLAB6]->number= WfntLAB6;
  widgets[WfntSIZE]= text_entry_new("");
  widgets[WfntSIZE]->number= WfntSIZE;
  widgets[WfntLAB7]= gfx_label(1,0x000000,0xededed,'R',"File Id");
  widgets[WfntLAB7]->number= WfntLAB7;
  widgets[WfntFILEID]= text_entry_new("");
  widgets[WfntFILEID]->number= WfntFILEID;
  widgets[WfntLAB8]= gfx_label(1,0x000000,0xededed,'R',"Font Number");
  widgets[WfntLAB8]->number= WfntLAB8;
  widgets[WfntFONTNUM]= text_entry_new("");
  widgets[WfntFONTNUM]->number= WfntFONTNUM;
  widgets[WfntFONTADD]= gfx_button("Add", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WfntFONTADD]->number= WfntFONTADD;
  widgets[WfntFONTmodify]= gfx_button("Modify", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WfntFONTmodify]->number= WfntFONTmodify;
  widgets[WfntFONTremove]= gfx_button("Remove", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WfntFONTremove]->number= WfntFONTremove;
  widgets[WfntSAVE]= gfx_button("Save", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WfntSAVE]->number= WfntSAVE;
  widgets[WfntCANCEL]= gfx_button("Cancel", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WfntCANCEL]->number= WfntCANCEL;
  LAYOWID_SCRfonts(LL[2],LL[3],LC);
  for(i=0;i<20;i++) { LC[4*i]+= LL[0]; LC[4*i+1]+= LL[1]; }
  widget_move(widgets[WfntLAB0], LC[0], LC[1],LC[2],LC[3]);
  widget_move(widgets[WfntDEFFONT], LC[4], LC[5],LC[6],LC[7]);
  widget_move(widgets[WfntCUSTOMFONT], LC[8], LC[9],LC[10],LC[11]);
  widget_move(widgets[WfntLAB1], LC[12], LC[13],LC[14],LC[15]);
  widget_move(widgets[WfntFILES], LC[16], LC[17],LC[18],LC[19]);
  widget_move(widgets[WfntFILEadd], LC[20], LC[21],LC[22],LC[23]);
  widget_move(widgets[WfntFILEremove], LC[24], LC[25],LC[26],LC[27]);
  widget_move(widgets[WfntLAB5], LC[28], LC[29],LC[30],LC[31]);
  widget_move(widgets[WfntFONTS], LC[32], LC[33],LC[34],LC[35]);
  widget_move(widgets[WfntLAB6], LC[36], LC[37],LC[38],LC[39]);
  widget_move(widgets[WfntSIZE], LC[40], LC[41],LC[42],LC[43]);
  widget_move(widgets[WfntLAB7], LC[44], LC[45],LC[46],LC[47]);
  widget_move(widgets[WfntFILEID], LC[48], LC[49],LC[50],LC[51]);
  widget_move(widgets[WfntLAB8], LC[52], LC[53],LC[54],LC[55]);
  widget_move(widgets[WfntFONTNUM], LC[56], LC[57],LC[58],LC[59]);
  widget_move(widgets[WfntFONTADD], LC[60], LC[61],LC[62],LC[63]);
  widget_move(widgets[WfntFONTmodify], LC[64], LC[65],LC[66],LC[67]);
  widget_move(widgets[WfntFONTremove], LC[68], LC[69],LC[70],LC[71]);
  widget_move(widgets[WfntSAVE], LC[72], LC[73],LC[74],LC[75]);
  widget_move(widgets[WfntCANCEL], LC[76], LC[77],LC[78],LC[79]);
  widget_show(widgets[WfntLAB0], 1);
  widget_show(widgets[WfntDEFFONT], 1);
  widget_show(widgets[WfntCUSTOMFONT], 1);
  widget_show(widgets[WfntLAB1], 1);
  widget_show(widgets[WfntFILES], 1);
  widget_show(widgets[WfntFILEadd], 1);
  widget_show(widgets[WfntFILEremove], 1);
  widget_show(widgets[WfntLAB5], 1);
  widget_show(widgets[WfntFONTS], 1);
  widget_show(widgets[WfntLAB6], 1);
  widget_show(widgets[WfntSIZE], 1);
  widget_show(widgets[WfntLAB7], 1);
  widget_show(widgets[WfntFILEID], 1);
  widget_show(widgets[WfntLAB8], 1);
  widget_show(widgets[WfntFONTNUM], 1);
  widget_show(widgets[WfntFONTADD], 1);
  widget_show(widgets[WfntFONTmodify], 1);
  widget_show(widgets[WfntFONTremove], 1);
  widget_show(widgets[WfntSAVE], 1);
  widget_show(widgets[WfntCANCEL], 1);
  gfx_update_all();
}
